# This file was auto-generated by Fern from our API Definition.

import typing

LiveSharingLinksCreateLiveSharingLinkRequestBodyType = typing.Union[
    typing.Literal["assetsLocation", "assetsNearLocation", "assetsOnRoute"], typing.Any
]
