# This file was auto-generated by Fern from our API Definition.

import typing

GetDriversVehicleAssignmentsRequestDriverActivationStatus = typing.Union[
    typing.Literal["active", "deactivated"], typing.Any
]
