# This file was auto-generated by Fern from our API Definition.

import typing

HosViolationTriggerDetailsObjectRequestBodyViolation = typing.Union[
    typing.Literal[
        "CaliforniaMealbreakMissed",
        "CycleHoursOn",
        "DailyDrivingHours",
        "DailyOnDutyHours",
        "Invalid",
        "RestbreakMissed",
        "ShiftDrivingHours",
        "ShiftHours",
        "ShiftOnDutyHours",
        "UnsubmittedLogs",
    ],
    typing.Any,
]
