# This file was auto-generated by Fern from our API Definition.

import typing

VoiceCoachingSettingsObjectResponseBodyLanguage = typing.Union[
    typing.Literal["english", "spanish", "dutch", "englishUk", "italian", "french", "german"], typing.Any
]
