# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .ridership_passenger_identifier_object_response_body_status import (
    RidershipPassengerIdentifierObjectResponseBodyStatus,
)
from .ridership_passenger_identifier_object_response_body_type import RidershipPassengerIdentifierObjectResponseBodyType


class RidershipPassengerIdentifierObjectResponseBody(UniversalBaseModel):
    """
    An identifier associated with a passenger.
    """

    id: str = pydantic.Field()
    """
    The unique Samsara ID of the identifier.
    """

    status: RidershipPassengerIdentifierObjectResponseBodyStatus = pydantic.Field()
    """
    The status of the identifier.  Valid values: `active`, `inactive`, `unknown`
    """

    type: RidershipPassengerIdentifierObjectResponseBodyType = pydantic.Field()
    """
    The type of identifier.  Valid values: `rfid`, `unknown`
    """

    value: str = pydantic.Field()
    """
    The identifier value.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
