# This file was auto-generated by Fern from our API Definition.

import typing

SpeedingIntervalResponseBodySeverityLevel = typing.Union[
    typing.Literal["light", "moderate", "heavy", "severe"], typing.Any
]
