# This file was auto-generated by Fern from our API Definition.

import typing

UsDriverRulesetOverrideCycle = typing.Union[
    typing.Literal[
        "USA Property (8/70)",
        "USA Property (7/60)",
        "USA Passenger (8/70)",
        "USA Passenger (7/60)",
        "Alaska Property (8/80)",
        "Alaska Property (7/70)",
        "Alaska Passenger (8/80)",
        "Alaska Passenger (7/70)",
        "California School/FLV (8/80)",
        "California Farm (8/112)",
        "California Property (8/80)",
        "California Flammable Liquid (8/80)",
        "California Passenger (8/80)",
        "California Motion Picture (8/80)",
        "Florida (8/80)",
        "Florida (7/70)",
        "Nebraska (8/80)",
        "Nebraska (7/70)",
        "North Carolina (8/80)",
        "North Carolina (7/70)",
        "Oklahoma (8/70)",
        "Oklahoma (7/60)",
        "Oregon (8/80)",
        "Oregon (7/70)",
        "South Carolina (8/80)",
        "South Carolina (7/70)",
        "Texas (7/70)",
        "Wisconsin (8/80)",
        "Wisconsin (7/70)",
    ],
    typing.Any,
]
