# This file was auto-generated by Fern from our API Definition.

import typing

BehaviorCountDetailsResponseBodyComparison = typing.Union[
    typing.Literal["EQUAL_TO", "GREATER_THAN", "GREATER_THAN_OR_EQUAL_TO", "LESS_THAN", "LESS_THAN_OR_EQUAL_TO"],
    typing.Any,
]
