# This file was auto-generated by Fern from our API Definition.

import typing

TireFaultCodeDetailsObjectRequestBodyManufacturer = typing.Union[
    typing.Literal[
        "MANUFACTURER_BENDIX",
        "MANUFACTURER_CONTINENTAL",
        "MANUFACTURER_DORAN",
        "MANUFACTURER_HENDRICKSON",
        "MANUFACTURER_INVALID",
        "MANUFACTURER_PRESSURE_PRO",
        "MANUFACTURER_UNIVERSAL_J1939",
        "MANUFACTURER_UNIVERSAL_R141",
    ],
    typing.Any,
]
