# This file was auto-generated by Fern from our API Definition.

import typing

FormSubmissionsPatchFormSubmissionRequestBodyStatus = typing.Union[
    typing.Literal["notStarted", "archived", "inProgress", "changesRequested", "approved"], typing.Any
]
