# This file was auto-generated by Fern from our API Definition.

import typing

RouteSettingsRequestBodySequencingMethod = typing.Union[
    typing.Literal["unknown", "scheduledArrivalTime", "manual"], typing.Any
]
