# This file was auto-generated by Fern from our API Definition.

import typing

DriverRulesetObjectResponseBodyRestart = typing.Union[
    typing.Literal["34-hour Restart", "24-hour Restart", "36-hour Restart", "72-hour Restart"], typing.Any
]
