# This file was auto-generated by Fern from our API Definition.

import typing

VehicleStatsEngineImmobilizerWithDecorationState = typing.Union[
    typing.Literal["ignition_disabled", "ignition_enabled"], typing.Any
]
