# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .trailer_stat_reefer_door_state_zone_3_type_response_body_value import (
    TrailerStatReeferDoorStateZone3TypeResponseBodyValue,
)


class TrailerStatReeferDoorStateZone3TypeResponseBody(UniversalBaseModel):
    """
    The door state of the reefer.
    """

    time: str = pydantic.Field()
    """
    UTC timestamp in RFC 3339 format.
    """

    value: TrailerStatReeferDoorStateZone3TypeResponseBodyValue = pydantic.Field()
    """
    The door state of zone 2 of the reefer.  Valid values: `open`, `closed`
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
