# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .user_auth_type import UserAuthType
from .user_email import UserEmail
from .user_id import UserId
from .user_name import UserName
from .user_roles import UserRoles


class User(UniversalBaseModel):
    """
    A user object.
    """

    auth_type: typing_extensions.Annotated[
        UserAuthType, FieldMetadata(alias="authType"), pydantic.Field(alias="authType")
    ]
    email: UserEmail
    id: UserId
    name: UserName
    roles: UserRoles

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
