# This file was auto-generated by Fern from our API Definition.

import typing

SafetyEventBehaviorLabelsResponseBodyType = typing.Union[
    typing.Literal[
        "Acceleration",
        "Braking",
        "Crash",
        "DefensiveDriving",
        "DidNotYield",
        "Drinking",
        "Drowsy",
        "Eating",
        "EatingDrinking",
        "EdgeDistractedDriving",
        "EdgeRailroadCrossingViolation",
        "FollowingDistance",
        "FollowingDistanceModerate",
        "FollowingDistanceSevere",
        "ForwardCollisionWarning",
        "GenericDistraction",
        "GenericTailgating",
        "HarshTurn",
        "HighSpeedSuddenDisconnect",
        "Invalid",
        "LaneDeparture",
        "LateResponse",
        "MobileUsage",
        "NearCollison",
        "NoSeatbelt",
        "ObstructedCamera",
        "OperationalEvent",
        "Passenger",
        "PolicyViolationMask",
        "ProtectiveEquipment",
        "RanRedLight",
        "RearCollisionWarning",
        "RollingStop",
        "RolloverProtection",
        "Smoking",
        "Speeding",
        "VehicleInBlindSpotWarning",
        "VulnerableRoadUserCollisionWarning",
        "YawControl",
    ],
    typing.Any,
]
