# This file was auto-generated by Fern from our API Definition.

import typing

WorkOrderItemObjectResponseBodyType = typing.Union[
    typing.Literal[
        "DVIR",
        "FAULT",
        "FORM",
        "ISSUE",
        "ITEM_TYPE_UNSPECIFIED",
        "MAINTENANCE_PREDICTION_EVENT",
        "SCHEDULED_MAINTENANCE",
    ],
    typing.Any,
]
