# This file was auto-generated by Fern from our API Definition.

import enum


class SamsaraEnvironment(enum.Enum):
    PRODUCTION_API = "https://api.samsara.com"
    PRODUCTION_API_EU = "https://api.eu.samsara.com"
