# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class OrganizationInfoCarrierSettings(UniversalBaseModel):
    """
    Carrier for a given organization.
    """

    carrier_name: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="carrierName"),
        pydantic.Field(alias="carrierName", description="Carrier for a given organization."),
    ] = None
    dot_number: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="dotNumber"),
        pydantic.Field(alias="dotNumber", description="Carrier US DOT Number for the organization."),
    ] = None
    main_office_address: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="mainOfficeAddress"),
        pydantic.Field(alias="mainOfficeAddress", description="Main office address for a given organization."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
