# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class QualificationTypeReferenceObjectResponseBody(UniversalBaseModel):
    """
    Qualification type (form template) reference.
    """

    id: str = pydantic.Field()
    """
    ID of the qualification type (template UUID)
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Name of the qualification type
    """

    revision_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="revisionId"),
        pydantic.Field(
            alias="revisionId", description="ID of the qualification type revision (template revision UUID)"
        ),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
