# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .equipment_time import EquipmentTime


class EquipmentEngineTotalIdleTimeMinutes(UniversalBaseModel):
    """
    A time-series of engine total idle time minutes. (Beta)
    """

    time: EquipmentTime
    value: int = pydantic.Field()
    """
    Total time in minutes that the engine has been idling since the device was installed. This value is calculated based on the time the engine has been running while the vehicle is not in motion.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
