# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class EngineStatusResponseBody(UniversalBaseModel):
    """
    Equipment engine status.
    """

    running: typing_extensions.Annotated[
        typing.Optional[bool],
        FieldMetadata(alias="Running"),
        pydantic.Field(alias="Running", description="Boolean value for whether engine is running or not."),
    ] = None
    datetime: typing.Optional[str] = pydantic.Field(default=None)
    """
    Date time in RFC 3339 format. Millisecond precision and timezones are supported. (Examples: 2019-06-13T19:08:25Z, 2019-06-13T19:08:25.455Z, OR 2015-09-15T14:00:12-04:00).
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
