# This file was auto-generated by Fern from our API Definition.

import typing

HealthReasonResponseResponseBodyHealthReasonCode = typing.Union[
    typing.Literal[
        "assetUnplugged",
        "cameraMisaligned",
        "dataPending",
        "healthy",
        "inwardCameraObstruction",
        "irregularRecording",
        "lowDeviceBattery",
        "missingEldDiagnostics",
        "missingVin",
        "needsReplacement",
        "newlyInstalledDevice",
        "noGpsSignal",
        "notDetected",
        "outwardCameraObstruction",
        "recordingTimeRequired",
        "unknown",
        "vgUnplugged",
    ],
    typing.Any,
]
