# This file was auto-generated by Fern from our API Definition.

import typing

from .tachograph_activity_list_wrapper import TachographActivityListWrapper

DriverTachographActivityData = typing.List[TachographActivityListWrapper]
