# This file was auto-generated by Fern from our API Definition.

import typing

DeviceResponseResponseBodyModel = typing.Union[
    typing.Literal[
        "AG24",
        "AG24EU",
        "AG26",
        "AG26EU",
        "AG45",
        "AG45EU",
        "AG46",
        "AG46EU",
        "AG46P",
        "AG46PEU",
        "AG51",
        "AG51EU",
        "AG52",
        "AG52EU",
        "AG53",
        "AG53EU",
        "AT11",
        "AT11X",
        "CM31",
        "CM32",
        "CM33",
        "CM34",
        "OEM",
        "OEMP",
        "OEMR",
        "OEMV",
        "VG34",
        "VG34EU",
        "VG34FN",
        "VG34M",
        "VG54EU",
        "VG54NA",
        "VG55EU",
        "VG55NA",
    ],
    typing.Any,
]
