# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .speed_trigger_details_object_response_body_operation import SpeedTriggerDetailsObjectResponseBodyOperation


class SpeedTriggerDetailsObjectResponseBody(UniversalBaseModel):
    """
    Details specific to Speed
    """

    min_duration_milliseconds: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="minDurationMilliseconds"),
        pydantic.Field(
            alias="minDurationMilliseconds",
            description="The number of milliseconds the trigger needs to stay active before alerting.",
        ),
    ]
    operation: SpeedTriggerDetailsObjectResponseBodyOperation = pydantic.Field()
    """
    How to evaluate the threshold.  Valid values: `GREATER`, `LESS`
    """

    speed_kilometers_per_hour: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="speedKilometersPerHour"),
        pydantic.Field(alias="speedKilometersPerHour", description="The speed threshold value."),
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
