# This file was auto-generated by Fern from our API Definition.

import typing

DriverVehicleAssignmentV2ObjectResponseBodyAssignmentType = typing.Union[
    typing.Literal[
        "invalid",
        "unknown",
        "HOS",
        "idCard",
        "static",
        "faceId",
        "tachograph",
        "safetyManual",
        "RFID",
        "trailer",
        "external",
        "qrCode",
        "driverApp",
    ],
    typing.Any,
]
