# This file was auto-generated by Fern from our API Definition.

import typing

FuelPurchasePostFuelPurchaseRequestBodyFuelGrade = typing.Union[
    typing.Literal["Unknown", "Regular", "Premium"], typing.Any
]
