# This file was auto-generated by Fern from our API Definition.

import typing

from .vehicle_stats_fault_codes_j_1939_trouble_code import VehicleStatsFaultCodesJ1939TroubleCode

VehicleStatsFaultCodesJ1939TroubleCodes = typing.List[VehicleStatsFaultCodesJ1939TroubleCode]
