# This file was auto-generated by Fern from our API Definition.

import typing

VehicleResponseResponseBodyAssetType = typing.Union[
    typing.Literal["uncategorized", "trailer", "equipment", "unpowered", "vehicle"], typing.Any
]
