# This file was auto-generated by Fern from our API Definition.

import typing

SafetySettingsObjectResponseBodyDefaultVehicleType = typing.Union[
    typing.Literal["off", "automatic", "passengerCar", "lightTruck", "heavyDuty"], typing.Any
]
