# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .equipment_locations_response_data import EquipmentLocationsResponseData
from .pagination_response import PaginationResponse


class EquipmentLocationsResponse(UniversalBaseModel):
    """
    The most recent equipment locations and pagination information
    """

    data: typing.List[EquipmentLocationsResponseData] = pydantic.Field()
    """
    List of the most recent locations for the specified units of equipment.
    """

    pagination: PaginationResponse

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
