# This file was auto-generated by Fern from our API Definition.

import typing

VehicleStatsFaultCodesValueObdiiDiagnosticTroubleCodesIgnitionType = typing.Union[
    typing.Literal["spark", "compression"], typing.Any
]
