# This file was auto-generated by Fern from our API Definition.

import typing

SafetyScoreSpeedingObjectResponseBodySpeedingType = typing.Union[
    typing.Literal["light", "moderate", "heavy", "severe", "maxSpeed", "unknown"], typing.Any
]
