# This file was auto-generated by Fern from our API Definition.

import typing

from .tachograph_driver_file_list_wrapper import TachographDriverFileListWrapper

TachographDriverFileData = typing.List[TachographDriverFileListWrapper]
