# This file was auto-generated by Fern from our API Definition.

import typing

ConnectionStatusResponseObjectResponseBodyHealthStatus = typing.Union[
    typing.Literal[
        "Status Not Set",
        "Connected",
        "Not Installed",
        "Power Source Off - Active Vehicle",
        "Power Source Off - Inactive Vehicle",
        "Weak Cellular Signal",
        "Requires Investigation",
        "Requires Charge",
        "Unsupported Product",
        "Low Battery. Replace Device.",
        "Low Vehicle Battery",
        "Unplugged",
        "Low Charging State",
        "Vehicle Off",
        "Weak GPS Signal",
        "Low Gateway Battery",
        "Low Gateway Battery (AG24)",
        "Low Gateway Battery (AG45)",
        "Low Gateway Battery (AG26)",
        "Low Gateway Battery (AG46)",
        "Low Gateway Battery (AG46-P)",
        "Temporarily Offline",
        "Prolonged Offline",
        "Recently Offline",
        "Replacement Required",
        "Status Unknown",
    ],
    typing.Any,
]
