# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .v_1_machine_history_response_vibrations import V1MachineHistoryResponseVibrations


class V1MachineHistoryResponseMachines(UniversalBaseModel):
    id: typing.Optional[int] = pydantic.Field(default=None)
    """
    Machine ID
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Machine name
    """

    vibrations: typing.Optional[typing.List[V1MachineHistoryResponseVibrations]] = pydantic.Field(default=None)
    """
    List of vibration datapoints, with timestamp and vibration measurement for x/y/z axis in mm/s
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
