# This file was auto-generated by Fern from our API Definition.

import typing

FieldTypesObjectResponseBodyFieldType = typing.Union[
    typing.Literal[
        "photo", "string", "number", "multipleChoice", "signature", "dateTime", "scannedDocument", "barcode"
    ],
    typing.Any,
]
