# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class VehicleStatsFaultCodesValueObdiiConfirmedDtcs(UniversalBaseModel):
    """
    Passenger vehicle DTC information
    """

    dtc_description: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="dtcDescription"),
        pydantic.Field(alias="dtcDescription", description="The DTC description, if available."),
    ] = None
    dtc_id: typing_extensions.Annotated[
        int, FieldMetadata(alias="dtcId"), pydantic.Field(alias="dtcId", description="The DTC identifier.")
    ]
    dtc_short_code: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="dtcShortCode"),
        pydantic.Field(alias="dtcShortCode", description="The DTC short code, if available."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
