# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .goa_pagination_response_response_body import GoaPaginationResponseResponseBody
from .idling_report_event_response_body import IdlingReportEventResponseBody


class IdlingReportsGetVehicleIdlingReportsResponseBody(UniversalBaseModel):
    data: typing.List[IdlingReportEventResponseBody] = pydantic.Field()
    """
    Multiple idling events.
    """

    pagination: GoaPaginationResponseResponseBody
    request_end_time: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="requestEndTime"),
        pydantic.Field(alias="requestEndTime", description="The requested end time in RFC 3339 format."),
    ]
    request_start_time: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="requestStartTime"),
        pydantic.Field(alias="requestStartTime", description="The requested start time in RFC 3339 format."),
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
