# This file was auto-generated by Fern from our API Definition.

import typing

FuelPurchasePostFuelPurchaseRequestBodyIftaFuelType = typing.Union[
    typing.Literal[
        "Unspecified",
        "A55",
        "Biodiesel",
        "CompressedNaturalGas",
        "Diesel",
        "E85",
        "Electricity",
        "Ethanol",
        "Gasohol",
        "Gasoline",
        "Hydrogen",
        "LiquifiedNaturalGas",
        "M85",
        "Methanol",
        "Propane",
        "Other",
    ],
    typing.Any,
]
