# This file was auto-generated by Fern from our API Definition.

import typing

UploadedMediaObjectResponseBodyMediaType = typing.Union[
    typing.Literal["image", "videoHighRes", "videoLowRes", "hyperlapse"], typing.Any
]
