# This file was auto-generated by Fern from our API Definition.

import typing

IftaDetailJobResponseBodyJobStatus = typing.Union[
    typing.Literal["Requested", "Processing", "Completed", "Failed"], typing.Any
]
