# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class Dvir2AssignedToPolymorphicUserObjectResponseBody(UniversalBaseModel):
    """
    The user or driver assigned to complete the DVIR.
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the user or driver assigned to the DVIR.
    """

    polymorphic_user_id: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="polymorphicUserId"),
        pydantic.Field(
            alias="polymorphicUserId", description="The polymorphic user ID that identifies the user or driver."
        ),
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
