# This file was auto-generated by Fern from our API Definition.

import typing

SafetyEventV2MediaResponseBodyCameraRole = typing.Union[
    typing.Literal[
        "leftMirrorMount",
        "leftSide",
        "rightMirrorMount",
        "rightSide",
        "rearHigh",
        "rearBumper",
        "inCab",
        "front",
        "hopper",
        "other1",
        "other2",
        "other3",
        "other4",
        "leftBev",
        "rightBev",
        "rearBev",
        "frontBev",
        "otherBev",
        "bevNotUsed",
    ],
    typing.Any,
]
