# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .column_response_body import ColumnResponseBody
from .filters_response_body import FiltersResponseBody


class ReportConfigObjectResponseBody(UniversalBaseModel):
    columns: typing.List[ColumnResponseBody] = pydantic.Field()
    """
    Columns included in the report configuration.
    """

    dataset_id: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="datasetId"),
        pydantic.Field(alias="datasetId", description="ID of dataset for report configuration."),
    ]
    filters: typing.Optional[FiltersResponseBody] = None
    id: str = pydantic.Field()
    """
    ID of report configuration.
    """

    name: str = pydantic.Field()
    """
    Name of report configuration.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
