# This file was auto-generated by Fern from our API Definition.

import typing

SafetyBehaviorTriggerDetailsObjectRequestBodyBehaviorsItem = typing.Union[
    typing.Literal[
        "Acceleration",
        "AggressiveDriving",
        "BluetoothHeadset",
        "Braking",
        "ContextConstructionOrWorkZone",
        "ContextSnowyOrIcy",
        "ContextVulnerableRoadUser",
        "ContextWet",
        "Crash",
        "CustomerCustomEvent1",
        "CustomerCustomEvent10",
        "CustomerCustomEvent2",
        "CustomerCustomEvent3",
        "CustomerCustomEvent4",
        "CustomerCustomEvent5",
        "CustomerCustomEvent6",
        "CustomerCustomEvent7",
        "CustomerCustomEvent8",
        "CustomerCustomEvent9",
        "DefensiveDriving",
        "DidNotYield",
        "Drinking",
        "Drowsy",
        "Eating",
        "EatingDrinking",
        "EdgeDistractedDriving",
        "EdgeRailroadCrossingViolation",
        "FollowingDistance",
        "FollowingDistanceModerate",
        "FollowingDistanceSevere",
        "ForwardCollisionWarning",
        "GenericDistraction",
        "GenericTailgating",
        "HarshTurn",
        "HeavySpeeding",
        "HighSpeedSuddenDisconnect",
        "HosViolation",
        "Idling",
        "Invalid",
        "LaneDeparture",
        "LateResponse",
        "LeftTurn",
        "LightSpeeding",
        "MaxSpeed",
        "MobileUsage",
        "ModerateSpeeding",
        "NearCollison",
        "NearPedestrianCollision",
        "NoSeatbelt",
        "ObstructedCamera",
        "OtherViolation",
        "Passenger",
        "PolicyViolationMask",
        "ProtectiveEquipment",
        "RanRedLight",
        "Reversing",
        "RollingStop",
        "RolloverProtection",
        "SamsaraCustomEvent1",
        "SamsaraCustomEvent10",
        "SamsaraCustomEvent2",
        "SamsaraCustomEvent3",
        "SamsaraCustomEvent4",
        "SamsaraCustomEvent5",
        "SamsaraCustomEvent6",
        "SamsaraCustomEvent7",
        "SamsaraCustomEvent8",
        "SamsaraCustomEvent9",
        "SevereSpeeding",
        "Smoking",
        "Speeding",
        "UTurn",
        "UnsafeManeuver",
        "UnsafeParking",
        "VehicleInBlindSpotWarning",
        "VulnerableRoadUserCollisionWarning",
        "YawControl",
    ],
    typing.Any,
]
