# This file was auto-generated by Fern from our API Definition.

import typing

HosViolationObjectResponseBodyType = typing.Union[
    typing.Literal[
        "NONE",
        "californiaMealbreakMissed",
        "cycleHoursOn",
        "cycleOffHoursAfterOnDutyHours",
        "dailyDrivingHours",
        "dailyOffDutyDeferralAddToDay2Consecutive",
        "dailyOffDutyDeferralNotPartMandatory",
        "dailyOffDutyDeferralTwoDayDrivingLimit",
        "dailyOffDutyDeferralTwoDayOffDuty",
        "dailyOffDutyNonResetHours",
        "dailyOffDutyTotalHours",
        "dailyOnDutyHours",
        "mandatory24HoursOffDuty",
        "restbreakMissed",
        "shiftDrivingHours",
        "shiftHours",
        "shiftOnDutyHours",
        "unsubmittedLogs",
    ],
    typing.Any,
]
