# This file was auto-generated by Fern from our API Definition.

import typing

FormSubmissionRequestFieldInputObjectRequestBodyType = typing.Union[
    typing.Literal[
        "number", "text", "multiple_choice", "check_boxes", "datetime", "asset", "person", "table", "geofence"
    ],
    typing.Any,
]
