# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class RidershipRouteSetupPassengerObjectResponseBody(UniversalBaseModel):
    """
    A passenger assignment within a route setup.
    """

    drop_off_stop_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="dropOffStopId"),
        pydantic.Field(alias="dropOffStopId", description="The stop ID for the passenger's drop-off."),
    ] = None
    passenger_id: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="passengerId"),
        pydantic.Field(alias="passengerId", description="The Samsara UUID of the passenger."),
    ]
    pick_up_stop_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="pickUpStopId"),
        pydantic.Field(alias="pickUpStopId", description="The stop ID for the passenger's pick-up."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
