# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .v_1_vision_step_results_item_fixture_coordinates import V1VisionStepResultsItemFixtureCoordinates


class V1VisionStepResultsItemFixture(UniversalBaseModel):
    coordinates: typing.Optional[V1VisionStepResultsItemFixtureCoordinates] = None
    found: typing.Optional[bool] = None
    rotation_degrees: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="rotationDegrees"), pydantic.Field(alias="rotationDegrees")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
