# This file was auto-generated by Fern from our API Definition.

import typing

SpeedingSettingsObjectResponseBodyUnit = typing.Union[
    typing.Literal["milesPerHour", "kilometersPerHour", "percentage"], typing.Any
]
