# This file was auto-generated by Fern from our API Definition.

import typing

from .v_1_asset_location_response_item import V1AssetLocationResponseItem

V1AssetLocationResponse = typing.List[V1AssetLocationResponseItem]
