# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .time import Time
from .vehicle_stats_decorations import VehicleStatsDecorations


class VehicleStatsFuelConsumedMillilitersWithDecoration(UniversalBaseModel):
    """
    Vehicle cumulative fuel consumption reading in milliliters.
    """

    decorations: typing.Optional[VehicleStatsDecorations] = None
    time: Time
    value: int = pydantic.Field()
    """
    The cumulative fuel consumption in milliliters for vehicles. Cumulative values always increase. This includes all fuel consumption reported by vehicles without filtering of invalid data points. For filtered fuel consumption that matches the Fuel & Energy Report, please use <a href="https://developers.samsara.com/reference/getfuelenergyvehiclereports" target="_blank">the Fuel and Energy API</a>.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
