# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class UrlInfoObjectResponseBody(UniversalBaseModel):
    """
    URL info for this piece of media. This field is only populated when the 'status' response field is 'available'
    """

    url: str = pydantic.Field()
    """
    Signed URL for this piece of media. The URL expires in 8 hours (after which you must make another GET request). Examples: https://sample.s3.url.com/image.jpeg
    """

    url_expiry_time: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="urlExpiryTime"),
        pydantic.Field(
            alias="urlExpiryTime",
            description="Timestamp, in RFC 3339 format, at which the URL expires. Examples: 2019-06-13T19:08:25Z, 2019-06-13T19:08:25.455Z, OR 2015-09-15T14:00:12-04:00",
        ),
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
