# This file was auto-generated by Fern from our API Definition.

import typing

RouteFeedObjectResponseBodyOperation = typing.Union[
    typing.Literal[
        "stop scheduled",
        "stop en route",
        "stop skipped",
        "stop arrived",
        "stop departed",
        "stop ETA updated",
        "stop arrival time updated",
        "stop completion time updated",
        "stop order changed",
        "stop arrival prevented",
    ],
    typing.Any,
]
