# This file was auto-generated by Fern from our API Definition.

import typing

CreateDriverRequestLocale = typing.Union[
    typing.Literal["us", "at", "be", "ca", "gb", "fr", "de", "ie", "it", "lu", "mx", "nl", "es", "ch", "pr"], typing.Any
]
