# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .cell_connectivity_response_response_body_signal_bar import CellConnectivityResponseResponseBodySignalBar


class CellConnectivityResponseResponseBody(UniversalBaseModel):
    """
    Gateway cellular connectivity information.
    """

    operator: typing.Optional[str] = pydantic.Field(default=None)
    """
    The cellular network provider name.
    """

    signal_bar: typing_extensions.Annotated[
        typing.Optional[CellConnectivityResponseResponseBodySignalBar],
        FieldMetadata(alias="signalBar"),
        pydantic.Field(
            alias="signalBar",
            description="The cellular signal strength indicator.  Valid values: `1/4`, `2/4`, `3/4`, `4/4`, `unknown`",
        ),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
