# This file was auto-generated by Fern from our API Definition.

import typing

DriverRulesetObjectResponseBodyBreak = typing.Union[
    typing.Literal["Property (off-duty/sleeper)", "Explosives/HazMat (on-duty)"], typing.Any
]
