# This file was auto-generated by Fern from our API Definition.

import typing

CurrentDutyStatusHosStatusType = typing.Union[
    typing.Literal["offDuty", "sleeperBed", "driving", "onDuty", "yardMove", "personalConveyance"], typing.Any
]
