# This file was auto-generated by Fern from our API Definition.

import typing

from .tachograph_vehicle_file_list_wrapper import TachographVehicleFileListWrapper

TachographVehicleFileData = typing.List[TachographVehicleFileListWrapper]
