# This file was auto-generated by Fern from our API Definition.

import typing

GetAssetsInputsRequestType = typing.Union[
    typing.Literal[
        "auxInput1",
        "auxInput2",
        "auxInput3",
        "auxInput4",
        "auxInput5",
        "auxInput6",
        "auxInput7",
        "auxInput8",
        "auxInput9",
        "auxInput10",
        "auxInput11",
        "auxInput12",
        "auxInput13",
        "analogInput1Voltage",
        "analogInput2Voltage",
        "analogInput1Current",
        "analogInput2Current",
        "batteryVoltage",
    ],
    typing.Any,
]
