# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class GoaPaginationResponseResponseBody(UniversalBaseModel):
    """
    Pagination parameters.
    """

    end_cursor: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="endCursor"),
        pydantic.Field(
            alias="endCursor",
            description="Cursor identifier representing the last element in the response. This value should be used in conjunction with a subsequent request's 'after' query parameter. This may be an empty string if there are no more pages left to view.",
        ),
    ]
    has_next_page: typing_extensions.Annotated[
        bool,
        FieldMetadata(alias="hasNextPage"),
        pydantic.Field(
            alias="hasNextPage",
            description="True if there are more pages of results immediately available after this endCursor.",
        ),
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
