# This file was auto-generated by Fern from our API Definition.

import typing

FormSubmissionPdfExportResponseObjectResponseBodyJobStatus = typing.Union[
    typing.Literal["unknown", "pending", "done", "failed"], typing.Any
]
