# This file was auto-generated by Fern from our API Definition.

import typing

from .dvir_trailer_defects_items import DvirTrailerDefectsItems

DvirVehicleDefects = typing.List[DvirTrailerDefectsItems]
