# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .form_submission_request_check_boxes_value_object_request_body import (
    FormSubmissionRequestCheckBoxesValueObjectRequestBody,
)
from .form_submission_request_date_time_value_object_request_body import (
    FormSubmissionRequestDateTimeValueObjectRequestBody,
)
from .form_submission_request_multiple_choice_value_object_request_body import (
    FormSubmissionRequestMultipleChoiceValueObjectRequestBody,
)
from .form_submission_request_number_value_object_request_body import FormSubmissionRequestNumberValueObjectRequestBody
from .form_submission_request_person_value_object_request_body import FormSubmissionRequestPersonValueObjectRequestBody
from .form_submission_request_table_cell_object_request_body_type import (
    FormSubmissionRequestTableCellObjectRequestBodyType,
)
from .form_submission_request_text_value_object_request_body import FormSubmissionRequestTextValueObjectRequestBody


class FormSubmissionRequestTableCellObjectRequestBody(UniversalBaseModel):
    """
    The value of a cell in a table row.
    """

    check_boxes_value: typing_extensions.Annotated[
        typing.Optional[FormSubmissionRequestCheckBoxesValueObjectRequestBody],
        FieldMetadata(alias="checkBoxesValue"),
        pydantic.Field(alias="checkBoxesValue"),
    ] = None
    date_time_value: typing_extensions.Annotated[
        typing.Optional[FormSubmissionRequestDateTimeValueObjectRequestBody],
        FieldMetadata(alias="dateTimeValue"),
        pydantic.Field(alias="dateTimeValue"),
    ] = None
    id: str = pydantic.Field()
    """
    Unique identifier for the cell.
    """

    multiple_choice_value: typing_extensions.Annotated[
        typing.Optional[FormSubmissionRequestMultipleChoiceValueObjectRequestBody],
        FieldMetadata(alias="multipleChoiceValue"),
        pydantic.Field(alias="multipleChoiceValue"),
    ] = None
    number_value: typing_extensions.Annotated[
        typing.Optional[FormSubmissionRequestNumberValueObjectRequestBody],
        FieldMetadata(alias="numberValue"),
        pydantic.Field(alias="numberValue"),
    ] = None
    person_value: typing_extensions.Annotated[
        typing.Optional[FormSubmissionRequestPersonValueObjectRequestBody],
        FieldMetadata(alias="personValue"),
        pydantic.Field(alias="personValue"),
    ] = None
    text_value: typing_extensions.Annotated[
        typing.Optional[FormSubmissionRequestTextValueObjectRequestBody],
        FieldMetadata(alias="textValue"),
        pydantic.Field(alias="textValue"),
    ] = None
    type: FormSubmissionRequestTableCellObjectRequestBodyType = pydantic.Field()
    """
    Type of the cell field.  Valid values: `number`, `text`, `multiple_choice`, `check_boxes`, `datetime`, `person`
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
