# This file was auto-generated by Fern from our API Definition.

import typing

from .v_1_vision_step_results_item import V1VisionStepResultsItem

V1VisionStepResults = typing.List[V1VisionStepResultsItem]
