# This file was auto-generated by Fern from our API Definition.

import typing

SafetyEventV2ObjectResponseBodyEventState = typing.Union[
    typing.Literal[
        "unknown", "needsReview", "reviewed", "needsCoaching", "coached", "dismissed", "needsRecognition", "recognized"
    ],
    typing.Any,
]
