# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class DriverOrTagIdsDetailsResponseBody(UniversalBaseModel):
    """
    Trigger when driver or tag IDs meet the specified condition.
    """

    driver_ids: typing_extensions.Annotated[
        typing.Optional[typing.List[str]],
        FieldMetadata(alias="driverIds"),
        pydantic.Field(alias="driverIds", description="On which driver IDs to trigger on."),
    ] = None
    tag_ids: typing_extensions.Annotated[
        typing.Optional[typing.List[str]],
        FieldMetadata(alias="tagIds"),
        pydantic.Field(alias="tagIds", description="On which tag IDs to trigger on."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
