# This file was auto-generated by Fern from our API Definition.

import typing

AttributeUnit = typing.Union[
    typing.Literal[
        "NO_UNIT",
        "METER",
        "POUND",
        "TON",
        "KILOGRAM",
        "INCH",
        "FOOT",
        "GALLON",
        "LITER",
        "BARREL",
        "POUND_PER_SQUARE_INCH",
        "BAR",
        "KILOPASCAL",
        "FAHRENHEIT",
        "CELSIUS",
        "USD",
        "CAD",
        "EUR",
        "GBP",
        "MXN",
        "HOUR",
        "MINUTE",
        "DAY",
        "MILE_PER_HOUR",
        "KILOMETER_PER_HOUR",
        "HORSEPOWER",
        "KILOWATT",
        "BTU_PER_HOUR",
        "KILOWATT_HOUR",
        "BTU",
        "HERTZ",
        "REVOLUTION_PER_MINUTE",
        "DECIBEL",
    ],
    typing.Any,
]
