# This file was auto-generated by Fern from our API Definition.

import typing

DvirSubmittedDeviceTriggerDetailsObjectResponseBodyDvirSubmissionTypesItem = typing.Union[
    typing.Literal["SAFE_NO_DEFECTS", "SAFE_WITH_DEFECTS", "UNSAFE"], typing.Any
]
