# This file was auto-generated by Fern from our API Definition.

import typing

from .tachograph_vehicle_file import TachographVehicleFile

TachographVehicleFileList = typing.List[TachographVehicleFile]
