# This file was auto-generated by Fern from our API Definition.

import typing

AttributeAttributeType = typing.Union[
    typing.Literal["single-select", "multi-select", "text", "freeform-multi-select", "number", "date"], typing.Any
]
