# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .work_order_item_object_request_body_type import WorkOrderItemObjectRequestBodyType


class WorkOrderItemObjectRequestBody(UniversalBaseModel):
    """
    Work Order Related Item object.
    """

    id: str = pydantic.Field()
    """
    ID of the item.
    """

    type: WorkOrderItemObjectRequestBodyType = pydantic.Field()
    """
    The type of item.  Valid values: `DVIR`, `FAULT`, `FORM`, `ISSUE`, `ITEM_TYPE_UNSPECIFIED`, `MAINTENANCE_PREDICTION_EVENT`, `SCHEDULED_MAINTENANCE`
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
