# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .v_1_vehicle_maintenance_j_1939 import V1VehicleMaintenanceJ1939
from .v_1_vehicle_maintenance_passenger import V1VehicleMaintenancePassenger


class V1VehicleMaintenance(UniversalBaseModel):
    """
    Contains any J1939/Passenger engine light warnings and engine faults.
    """

    id: int = pydantic.Field()
    """
    ID of the vehicle.
    """

    j_1939: typing_extensions.Annotated[
        typing.Optional[V1VehicleMaintenanceJ1939], FieldMetadata(alias="j1939"), pydantic.Field(alias="j1939")
    ] = None
    passenger: typing.Optional[V1VehicleMaintenancePassenger] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
