# This file was auto-generated by Fern from our API Definition.

import typing

ForwardCollisionDetectionAlertSettingsObjectResponseBodySensitivity = typing.Union[
    typing.Literal["near", "medium", "far"], typing.Any
]
