# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class HosDrive(UniversalBaseModel):
    """
    Remaining durations for the HOS driving shift limits.
    """

    drive_remaining_duration_ms: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="driveRemainingDurationMs"),
        pydantic.Field(
            alias="driveRemainingDurationMs",
            description="Remaining driving time the driver has in the current shift in milliseconds. For property-carrying drivers, this is the amount of time the driver can drive before hitting the 11-hour limit.",
        ),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
