# This file was auto-generated by Fern from our API Definition.

import typing

DetectionLogSafetyEventObjectResponseBodyInboxFilterReason = typing.Union[
    typing.Literal[
        "overDailyLimit",
        "overHourlyLimit",
        "overTripLimit",
        "belowConfidenceThreshold",
        "belowSeverityThreshold",
        "overEventRateLimit",
        "geofenceFilter",
        "belowNudgeThreshold",
        "belowSpeedThreshold",
        "nighttimeFilter",
        "speedingFilter",
        "inCabAlertOnly",
        "unknown",
    ],
    typing.Any,
]
