# This file was auto-generated by Fern from our API Definition.

import typing

DefectTypesResponseDataResponseBodySectionType = typing.Union[
    typing.Literal[
        "exteriorFront",
        "exteriorRear",
        "exteriorSideUnderneath",
        "interiorDriverCab",
        "interiorPassengerArea",
        "other",
        "unknown",
    ],
    typing.Any,
]
