# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        UpdateVehicleRequestAuxInputType1,
        UpdateVehicleRequestAuxInputType10,
        UpdateVehicleRequestAuxInputType11,
        UpdateVehicleRequestAuxInputType12,
        UpdateVehicleRequestAuxInputType13,
        UpdateVehicleRequestAuxInputType2,
        UpdateVehicleRequestAuxInputType3,
        UpdateVehicleRequestAuxInputType4,
        UpdateVehicleRequestAuxInputType5,
        UpdateVehicleRequestAuxInputType6,
        UpdateVehicleRequestAuxInputType7,
        UpdateVehicleRequestAuxInputType8,
        UpdateVehicleRequestAuxInputType9,
        UpdateVehicleRequestHarshAccelerationSettingType,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "UpdateVehicleRequestAuxInputType1": ".types",
    "UpdateVehicleRequestAuxInputType10": ".types",
    "UpdateVehicleRequestAuxInputType11": ".types",
    "UpdateVehicleRequestAuxInputType12": ".types",
    "UpdateVehicleRequestAuxInputType13": ".types",
    "UpdateVehicleRequestAuxInputType2": ".types",
    "UpdateVehicleRequestAuxInputType3": ".types",
    "UpdateVehicleRequestAuxInputType4": ".types",
    "UpdateVehicleRequestAuxInputType5": ".types",
    "UpdateVehicleRequestAuxInputType6": ".types",
    "UpdateVehicleRequestAuxInputType7": ".types",
    "UpdateVehicleRequestAuxInputType8": ".types",
    "UpdateVehicleRequestAuxInputType9": ".types",
    "UpdateVehicleRequestHarshAccelerationSettingType": ".types",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "UpdateVehicleRequestAuxInputType1",
    "UpdateVehicleRequestAuxInputType10",
    "UpdateVehicleRequestAuxInputType11",
    "UpdateVehicleRequestAuxInputType12",
    "UpdateVehicleRequestAuxInputType13",
    "UpdateVehicleRequestAuxInputType2",
    "UpdateVehicleRequestAuxInputType3",
    "UpdateVehicleRequestAuxInputType4",
    "UpdateVehicleRequestAuxInputType5",
    "UpdateVehicleRequestAuxInputType6",
    "UpdateVehicleRequestAuxInputType7",
    "UpdateVehicleRequestAuxInputType8",
    "UpdateVehicleRequestAuxInputType9",
    "UpdateVehicleRequestHarshAccelerationSettingType",
]
