# This file was auto-generated by Fern from our API Definition.

import typing

TrailerStatReeferDoorStateZone1WithDecorationsTypeResponseBodyValue = typing.Union[
    typing.Literal["open", "closed"], typing.Any
]
