# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class SafetyEventV2ContextLabelsResponseBody(UniversalBaseModel):
    """
    The most up-to-date context labels associated with the safety event. AI generated labels can be updated by Safety Admins.
    """

    author_id: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="authorId"),
        pydantic.Field(
            alias="authorId",
            description="The user ID associated with the user who created the context label. A value of 0 indicates the label is auto-generated.",
        ),
    ]
    created_at_time: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="createdAtTime"),
        pydantic.Field(alias="createdAtTime", description="Time the context label was created."),
    ]
    name: str = pydantic.Field()
    """
    Name of the context label
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
