# This file was auto-generated by Fern from our API Definition.

import typing

PostFuelPurchaseRequestBodyPriceRequestBodyCurrency = typing.Union[
    typing.Literal["usd", "gbp", "cad", "eur", "chf", "mxn"], typing.Any
]
