# This file was auto-generated by Fern from our API Definition.

import typing

SpecificVehicleFaultCodeObjectRequestBodyType = typing.Union[
    typing.Literal["INVALID_FAULT_CODE_TYPE", "J1939_DTC", "J1939_SPN", "PASSENGER_DTC"], typing.Any
]
