# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .forms_polymorphic_user_object_response_body_type import FormsPolymorphicUserObjectResponseBodyType


class FormsPolymorphicUserObjectResponseBody(UniversalBaseModel):
    """
    User or driver object.
    """

    id: str = pydantic.Field()
    """
    ID of the polymorphic user.
    """

    type: FormsPolymorphicUserObjectResponseBodyType = pydantic.Field()
    """
    The type of the polymorphic user.  Valid values: `driver`, `user`
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
