# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .harsh_event_trigger_details_object_request_body_types_item import (
    HarshEventTriggerDetailsObjectRequestBodyTypesItem,
)


class HarshEventTriggerDetailsObjectRequestBody(UniversalBaseModel):
    """
    Details specific to Harsh Events
    """

    types: typing.List[HarshEventTriggerDetailsObjectRequestBodyTypesItem] = pydantic.Field()
    """
    On which harsh events to trigger on.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
