# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class Dvir2DeviceObjectResponseBody(UniversalBaseModel):
    """
    Device details associated with the DVIR.
    """

    external_ids: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, str]],
        FieldMetadata(alias="externalIds"),
        pydantic.Field(alias="externalIds", description="A map of external ids"),
    ] = None
    license_plate: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="licensePlate"),
        pydantic.Field(alias="licensePlate", description="The license plate of the vehicle."),
    ] = None
    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the device.
    """

    vehicle_vin: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="vehicleVin"),
        pydantic.Field(alias="vehicleVin", description="The VIN of the vehicle."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
