# This file was auto-generated by Fern from our API Definition.

import typing

GetIftaVehicleReportsRequestMonth = typing.Union[
    typing.Literal[
        "January",
        "February",
        "March",
        "April",
        "May",
        "June",
        "July",
        "August",
        "September",
        "October",
        "November",
        "December",
    ],
    typing.Any,
]
