# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .time import Time


class EquipmentLocation(UniversalBaseModel):
    """
    Location reading.
    """

    heading: typing.Optional[float] = pydantic.Field(default=None)
    """
    Heading of the unit of equipment in degrees.
    """

    latitude: float = pydantic.Field()
    """
    GPS latitude represented in degrees
    """

    longitude: float = pydantic.Field()
    """
    GPS longitude represented in degrees
    """

    speed: typing.Optional[float] = pydantic.Field(default=None)
    """
    GPS speed of the unit of equipment in miles per hour.
    """

    time: Time

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
