# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .sensor_response_body import SensorResponseBody
from .vehicle_sensor_configuration_door_response_body_position import VehicleSensorConfigurationDoorResponseBodyPosition


class VehicleSensorConfigurationDoorResponseBody(UniversalBaseModel):
    """
    A door monitor configuration on a vehicle
    """

    position: VehicleSensorConfigurationDoorResponseBodyPosition = pydantic.Field()
    """
    Position of the door monitor on the vehicle  Valid values: `back`, `left`, `right`
    """

    sensor: SensorResponseBody

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
