# This file was auto-generated by Fern from our API Definition.

import typing

FormsConditionObjectResponseBodyType = typing.Union[
    typing.Literal["multipleChoiceValueCondition", "checkBoxesValueCondition"], typing.Any
]
