# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class V1VisionStepResultsItemExpirationDate(UniversalBaseModel):
    date_offset: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="dateOffset"), pydantic.Field(alias="dateOffset")
    ] = None
    found_date: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="foundDate"), pydantic.Field(alias="foundDate")
    ] = None
    match_date: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="matchDate"), pydantic.Field(alias="matchDate")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
