# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .in_app_notification_options_object_response_body import InAppNotificationOptionsObjectResponseBody
from .push_notification_options_object_response_body import PushNotificationOptionsObjectResponseBody


class DriverAppNotificationObjectResponseBody(UniversalBaseModel):
    """
    Driver app notification settings
    """

    in_app_notification_options: typing_extensions.Annotated[
        typing.Optional[InAppNotificationOptionsObjectResponseBody],
        FieldMetadata(alias="inAppNotificationOptions"),
        pydantic.Field(alias="inAppNotificationOptions"),
    ] = None
    push_notification_options: typing_extensions.Annotated[
        typing.Optional[PushNotificationOptionsObjectResponseBody],
        FieldMetadata(alias="pushNotificationOptions"),
        pydantic.Field(alias="pushNotificationOptions"),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
