# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .form_submission_request_table_row_object_request_body import FormSubmissionRequestTableRowObjectRequestBody


class FormSubmissionRequestTableValueObjectRequestBody(UniversalBaseModel):
    """
    The value of a table form input field. Only valid for table form input fields.
    """

    rows: typing.List[FormSubmissionRequestTableRowObjectRequestBody] = pydantic.Field()
    """
    List of rows in the table.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
