# This file was auto-generated by Fern from our API Definition.

import typing

DvirGetDvirResponseBodySafetyStatus = typing.Union[typing.Literal["unknown", "safe", "unsafe", "resolved"], typing.Any]
