# This file was auto-generated by Fern from our API Definition.

import typing

V1AssetsReeferReeferStatsPowerStatusStatus = typing.Union[
    typing.Literal["Off", "Active", "Active (Start/Stop)", "Active (Continuous)"], typing.Any
]
