# This file was auto-generated by Fern from our API Definition.

import typing

FormsFieldDefinitionObjectResponseBodyAllowedDateTimeValueType = typing.Union[
    typing.Literal["datetime", "date", "time"], typing.Any
]
