# This file was auto-generated by Fern from our API Definition.

import typing

FormSubmissionResponseObjectResponseBodyStatus = typing.Union[
    typing.Literal["notStarted", "completed", "archived", "inProgress", "needsReview", "changesRequested", "approved"],
    typing.Any,
]
