# This file was auto-generated by Fern from our API Definition.

import typing

DetectionLogDetectionObjectResponseBodyTriggerDetectionLabel = typing.Union[
    typing.Literal[
        "acceleration",
        "braking",
        "crash",
        "drowsy",
        "eatingDrinking",
        "edgeRailroadCrossingViolation",
        "followingDistance",
        "forwardCollisionWarning",
        "genericDistraction",
        "harshTurn",
        "heavySpeeding",
        "laneDeparture",
        "lightSpeeding",
        "maxSpeed",
        "mobileUsage",
        "moderateSpeeding",
        "noSeatbelt",
        "obstructedCamera",
        "passenger",
        "policyViolationMask",
        "ranRedLight",
        "rearCollisionWarning",
        "rollingStop",
        "rolloverProtection",
        "severeSpeeding",
        "smoking",
        "speeding",
        "unsafeParking",
        "vehicleInBlindSpotWarning",
        "vulnerableRoadUserCollisionWarning",
        "yawControl",
    ],
    typing.Any,
]
