# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class TrailerStatReeferSupplyAirTemperatureMilliCZone2TypeResponseBody(UniversalBaseModel):
    """
    Supply or discharge air temperature of zone 2 of the reefer. This is the temperature of the air as it leaves the cooling unit.
    """

    time: str = pydantic.Field()
    """
    UTC timestamp in RFC 3339 format.
    """

    value: int = pydantic.Field()
    """
    The supply or discharge air temperature reading in millidegree Celsius.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
