# This file was auto-generated by Fern from our API Definition.

import typing

SafetyEventActivityFeedItemResponseBodyType = typing.Union[
    typing.Literal["BehaviorLabelActivityType", "CoachingStateActivityType", "CreateSafetyEventActivityType"],
    typing.Any,
]
