# This file was auto-generated by Fern from our API Definition.

import typing

UpdateVehicleRequestAuxInputType12 = typing.Union[
    typing.Literal[
        "none",
        "emergencyLights",
        "emergencyAlarm",
        "stopPaddle",
        "powerTakeOff",
        "plow",
        "sweeper",
        "salter",
        "reefer",
        "door",
        "boom",
        "auxiliaryEngine",
        "generator",
        "eightWayLights",
        "panicButton",
        "privacyButton",
        "frontAxleDrive",
        "weightSensor",
        "other",
        "secondaryFuelSource",
        "ecuPowerTakeOff",
    ],
    typing.Any,
]
