# This file was auto-generated by Fern from our API Definition.

import typing

VoiceCoachingSettingsObjectResponseBodyEventsToCoachItem = typing.Union[
    typing.Literal["crash", "inCabSpeeding", "maximumSpeed", "seatbeltUnbuckled", "harshDriving"], typing.Any
]
