# This file was auto-generated by Fern from our API Definition.

import typing

MinimalRouteStopAuditLogsResponseBodyState = typing.Union[
    typing.Literal["unassigned", "scheduled", "en route", "skipped", "arrived", "departed"], typing.Any
]
