# This file was auto-generated by Fern from our API Definition.

import typing

TrainingAssignmentNearDueDateTriggerAssignmentGroupObjectRequestBodyAssignmentGroupType = typing.Union[
    typing.Literal["CATEGORY", "COURSE"], typing.Any
]
