# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .goa_vehicle_tiny_response_response_body import GoaVehicleTinyResponseResponseBody
from .ifta_jurisdiction_summary_object_response_body import IftaJurisdictionSummaryObjectResponseBody


class IftaVehicleReportObjectResponseBody(UniversalBaseModel):
    """
    A summary of this vehicle's IFTA data.
    """

    jurisdictions: typing.List[IftaJurisdictionSummaryObjectResponseBody] = pydantic.Field()
    """
    List of jurisdiction summaries.
    """

    vehicle: GoaVehicleTinyResponseResponseBody

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
