# This file was auto-generated by Fern from our API Definition.

import typing

DriverRulesetObjectResponseBodyCycle = typing.Union[
    typing.Literal[
        "USA 60 hour / 7 day",
        "USA 70 hour / 8 day",
        "AK 80 hour / 8 day",
        "AK 70 hour / 7 day",
        "CA 80 hour / 8 day",
        "CA 112 hour / 8 day",
        "FL 80 hour / 8 day",
        "FL 70 hour / 7 day",
        "NE 80 hour / 8 day",
        "NE 70 hour / 7 day",
        "NC 80 hour / 8 day",
        "NC 70 hour / 7 day",
        "OK 70 hour / 8 day",
        "OK 60 hour / 7 day",
        "OR 80 hour / 8 day",
        "OR 70 hour / 7 day",
        "SC 80 hour / 8 day",
        "SC 70 hour / 7 day",
        "TX 70 hour / 7 day",
        "WI 80 hour / 8 day",
        "WI 70 hour / 7 day",
        "Canada South Cycle 1 (70 hour / 7 day)",
        "Canada South Cycle 2 (120 hour / 14 day)",
        "Canada North Cycle 1 (80 hour / 7 day)",
        "Canada North Cycle 2 (120 hour / 14 day)",
    ],
    typing.Any,
]
