# This file was auto-generated by Fern from our API Definition.

import typing

TrainingCourseResponseObjectResponseBodyStatus = typing.Union[
    typing.Literal["published", "deleted", "archived", "unknown"], typing.Any
]
