# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .hub_custom_property_object_response_body import HubCustomPropertyObjectResponseBody
from .list_hub_custom_properties_response_pagination_response_body import (
    ListHubCustomPropertiesResponsePaginationResponseBody,
)


class HubCustomPropertiesListHubCustomPropertiesResponseBody(UniversalBaseModel):
    data: typing.List[HubCustomPropertyObjectResponseBody] = pydantic.Field()
    """
    Hub custom properties data
    """

    pagination: ListHubCustomPropertiesResponsePaginationResponseBody

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
