# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .parent_tag_id import ParentTagId
from .tag_id import TagId
from .tag_name import TagName


class TinyTag(UniversalBaseModel):
    id: typing.Optional[TagId] = None
    name: typing.Optional[TagName] = None
    parent_tag_id: typing_extensions.Annotated[
        typing.Optional[ParentTagId], FieldMetadata(alias="parentTagId"), pydantic.Field(alias="parentTagId")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
