# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .ridership_route_setup_passenger_object_response_body import RidershipRouteSetupPassengerObjectResponseBody


class RidershipRouteSetupObjectResponseBody(UniversalBaseModel):
    """
    A ridership route setup representing planned passenger assignments.
    """

    account_id: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="accountId"),
        pydantic.Field(alias="accountId", description="The Samsara UUID of the ridership account."),
    ]
    passengers: typing.List[RidershipRouteSetupPassengerObjectResponseBody] = pydantic.Field()
    """
    List of passenger assignments.
    """

    route_id: typing_extensions.Annotated[
        str, FieldMetadata(alias="routeId"), pydantic.Field(alias="routeId", description="The route ID.")
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
