# This file was auto-generated by Fern from our API Definition.

import typing

GetVehicleStatsHistoryRequestDecorationsItem = typing.Union[
    typing.Literal[
        "ambientAirTemperatureMilliC",
        "auxInput1",
        "auxInput2",
        "auxInput3",
        "auxInput4",
        "auxInput5",
        "auxInput6",
        "auxInput7",
        "auxInput8",
        "auxInput9",
        "auxInput10",
        "auxInput11",
        "auxInput12",
        "auxInput13",
        "batteryMilliVolts",
        "barometricPressurePa",
        "defLevelMilliPercent",
        "ecuSpeedMph",
        "engineCoolantTemperatureMilliC",
        "engineImmobilizer",
        "engineLoadPercent",
        "engineOilPressureKPa",
        "engineRpm",
        "engineStates",
        "faultCodes",
        "fuelPercents",
        "fuelConsumedMilliliters",
        "gps",
        "gpsDistanceMeters",
        "idlingDurationMilliseconds",
        "intakeManifoldTemperatureMilliC",
        "nfcCardScans",
        "obdEngineSeconds",
        "obdOdometerMeters",
        "spreaderLiquidRate",
        "spreaderGranularRate",
        "spreaderPrewetRate",
        "spreaderAirTemp",
        "spreaderRoadTemp",
        "spreaderOnState",
        "spreaderActive",
        "spreaderBlastState",
        "spreaderGranularName",
        "spreaderPrewetName",
        "spreaderLiquidName",
        "spreaderPlowStatus",
        "seatbeltDriver",
        "tellTales",
        "ecuDoorStatus",
    ],
    typing.Any,
]
