# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .ridership_passenger_identifier_input_request_body_status import RidershipPassengerIdentifierInputRequestBodyStatus
from .ridership_passenger_identifier_input_request_body_type import RidershipPassengerIdentifierInputRequestBodyType


class RidershipPassengerIdentifierInputRequestBody(UniversalBaseModel):
    """
    An identifier (e.g., RFID tag) associated with the passenger.
    """

    status: RidershipPassengerIdentifierInputRequestBodyStatus = pydantic.Field()
    """
    The status of the identifier.  Valid values: `active`, `inactive`, `unknown`
    """

    type: RidershipPassengerIdentifierInputRequestBodyType = pydantic.Field()
    """
    The type of identifier.  Valid values: `rfid`, `unknown`
    """

    value: str = pydantic.Field()
    """
    The identifier value.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
