# This file was auto-generated by Fern from our API Definition.

import typing

SafetyBehaviorTriggerDetailsObjectResponseBodyStatusesItem = typing.Union[
    typing.Literal["NEEDS_COACHING", "NEEDS_RECOGNITION", "NEEDS_REVIEW", "RECOGNIZED", "REVIEWED"], typing.Any
]
