# This file was auto-generated by Fern from our API Definition.

import typing

TrainingAssignmentResponseObjectResponseBodyStatus = typing.Union[
    typing.Literal["notStarted", "inProgress", "completed"], typing.Any
]
