# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class GoaAttributeTinyRequestBody(UniversalBaseModel):
    """
    Attribute properties.
    """

    date_values: typing_extensions.Annotated[
        typing.Optional[typing.List[str]],
        FieldMetadata(alias="dateValues"),
        pydantic.Field(
            alias="dateValues",
            description="List of date values associated with the attribute (RFC 3339 full-date format: YYYY-MM-DD).",
        ),
    ] = None
    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Id of the attribute
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Name of the attribute
    """

    number_values: typing_extensions.Annotated[
        typing.Optional[typing.List[float]],
        FieldMetadata(alias="numberValues"),
        pydantic.Field(alias="numberValues", description="List of number values associated with the attribute"),
    ] = None
    string_values: typing_extensions.Annotated[
        typing.Optional[typing.List[str]],
        FieldMetadata(alias="stringValues"),
        pydantic.Field(alias="stringValues", description="List of string values associated with the attribute."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
