# This file was auto-generated by Fern from our API Definition.

import typing

HarshTurnSensitivityV2SettingsObjectResponseBodyLightDuty = typing.Union[
    typing.Literal["unknown", "invalid", "off", "veryLow", "low", "normal", "high"], typing.Any
]
