# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .current_duty_status import CurrentDutyStatus
from .driver_tiny_response import DriverTinyResponse
from .hos_clocks import HosClocks
from .hos_violations import HosViolations
from .vehicle_tiny_response import VehicleTinyResponse


class HosClocksForDriver(UniversalBaseModel):
    """
    HOS clock values for a specific driver, including remaining times and violations.
    """

    clocks: typing.Optional[HosClocks] = None
    current_duty_status: typing_extensions.Annotated[
        typing.Optional[CurrentDutyStatus],
        FieldMetadata(alias="currentDutyStatus"),
        pydantic.Field(alias="currentDutyStatus"),
    ] = None
    current_vehicle: typing_extensions.Annotated[
        typing.Optional[VehicleTinyResponse],
        FieldMetadata(alias="currentVehicle"),
        pydantic.Field(alias="currentVehicle"),
    ] = None
    driver: typing.Optional[DriverTinyResponse] = None
    violations: typing.Optional[HosViolations] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
