# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .hos_violation_trigger_details_object_response_body_violation import (
    HosViolationTriggerDetailsObjectResponseBodyViolation,
)


class HosViolationTriggerDetailsObjectResponseBody(UniversalBaseModel):
    """
    Details specific to HOS Violation
    """

    max_until_violation_milliseconds: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="maxUntilViolationMilliseconds"),
        pydantic.Field(
            alias="maxUntilViolationMilliseconds",
            description="Alert if driver has this specified time until driving causes an HOS violation.",
        ),
    ]
    violation: HosViolationTriggerDetailsObjectResponseBodyViolation = pydantic.Field()
    """
    The type of HOS violation.  Valid values: `CaliforniaMealbreakMissed`, `CycleHoursOn`, `DailyDrivingHours`, `DailyOnDutyHours`, `Invalid`, `RestbreakMissed`, `ShiftDrivingHours`, `ShiftHours`, `ShiftOnDutyHours`, `UnsubmittedLogs`
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
