# This file was auto-generated by Fern from our API Definition.

import typing

UploadedMediaObjectResponseBodyInput = typing.Union[
    typing.Literal["dashcamForwardFacing", "dashcamInwardFacing", "analog1", "analog2", "analog3", "analog4"],
    typing.Any,
]
