# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .accessory_response_object_response_body import AccessoryResponseObjectResponseBody
    from .action_object_request_body import ActionObjectRequestBody
    from .action_object_response_body import ActionObjectResponseBody
    from .action_params_object_request_body import ActionParamsObjectRequestBody
    from .action_params_object_response_body import ActionParamsObjectResponseBody
    from .address import Address
    from .address_address_types_item import AddressAddressTypesItem
    from .address_external_ids import AddressExternalIds
    from .address_geofence import AddressGeofence
    from .address_geofence_circle import AddressGeofenceCircle
    from .address_geofence_polygon import AddressGeofencePolygon
    from .address_geofence_polygon_vertices import AddressGeofencePolygonVertices
    from .address_geofence_settings import AddressGeofenceSettings
    from .address_response import AddressResponse
    from .address_response_response_body import AddressResponseResponseBody
    from .address_tiny_response import AddressTinyResponse
    from .advanced_idling_get_idling_events_bad_gateway_error_response_body import (
        AdvancedIdlingGetIdlingEventsBadGatewayErrorResponseBody,
    )
    from .advanced_idling_get_idling_events_gateway_timeout_error_response_body import (
        AdvancedIdlingGetIdlingEventsGatewayTimeoutErrorResponseBody,
    )
    from .advanced_idling_get_idling_events_internal_server_error_response_body import (
        AdvancedIdlingGetIdlingEventsInternalServerErrorResponseBody,
    )
    from .advanced_idling_get_idling_events_method_not_allowed_error_response_body import (
        AdvancedIdlingGetIdlingEventsMethodNotAllowedErrorResponseBody,
    )
    from .advanced_idling_get_idling_events_not_found_error_response_body import (
        AdvancedIdlingGetIdlingEventsNotFoundErrorResponseBody,
    )
    from .advanced_idling_get_idling_events_not_implemented_error_response_body import (
        AdvancedIdlingGetIdlingEventsNotImplementedErrorResponseBody,
    )
    from .advanced_idling_get_idling_events_response_body import AdvancedIdlingGetIdlingEventsResponseBody
    from .advanced_idling_get_idling_events_service_unavailable_error_response_body import (
        AdvancedIdlingGetIdlingEventsServiceUnavailableErrorResponseBody,
    )
    from .advanced_idling_get_idling_events_too_many_requests_error_response_body import (
        AdvancedIdlingGetIdlingEventsTooManyRequestsErrorResponseBody,
    )
    from .advanced_idling_get_idling_events_unauthorized_error_response_body import (
        AdvancedIdlingGetIdlingEventsUnauthorizedErrorResponseBody,
    )
    from .aemp_equipment_get_aemp_equipment_list_bad_gateway_error_response_body import (
        AempEquipmentGetAempEquipmentListBadGatewayErrorResponseBody,
    )
    from .aemp_equipment_get_aemp_equipment_list_gateway_timeout_error_response_body import (
        AempEquipmentGetAempEquipmentListGatewayTimeoutErrorResponseBody,
    )
    from .aemp_equipment_get_aemp_equipment_list_internal_server_error_response_body import (
        AempEquipmentGetAempEquipmentListInternalServerErrorResponseBody,
    )
    from .aemp_equipment_get_aemp_equipment_list_method_not_allowed_error_response_body import (
        AempEquipmentGetAempEquipmentListMethodNotAllowedErrorResponseBody,
    )
    from .aemp_equipment_get_aemp_equipment_list_not_found_error_response_body import (
        AempEquipmentGetAempEquipmentListNotFoundErrorResponseBody,
    )
    from .aemp_equipment_get_aemp_equipment_list_not_implemented_error_response_body import (
        AempEquipmentGetAempEquipmentListNotImplementedErrorResponseBody,
    )
    from .aemp_equipment_get_aemp_equipment_list_response_body import AempEquipmentGetAempEquipmentListResponseBody
    from .aemp_equipment_get_aemp_equipment_list_service_unavailable_error_response_body import (
        AempEquipmentGetAempEquipmentListServiceUnavailableErrorResponseBody,
    )
    from .aemp_equipment_get_aemp_equipment_list_too_many_requests_error_response_body import (
        AempEquipmentGetAempEquipmentListTooManyRequestsErrorResponseBody,
    )
    from .aemp_equipment_get_aemp_equipment_list_unauthorized_error_response_body import (
        AempEquipmentGetAempEquipmentListUnauthorizedErrorResponseBody,
    )
    from .aemp_equipment_with_additional_fields_response_body import AempEquipmentWithAdditionalFieldsResponseBody
    from .aemp_fleet_list_response_body import AempFleetListResponseBody
    from .aemp_link_response_body import AempLinkResponseBody
    from .alert_object_asset_response_body import AlertObjectAssetResponseBody
    from .alert_object_asset_response_body_type import AlertObjectAssetResponseBodyType
    from .alert_object_driver_response_body import AlertObjectDriverResponseBody
    from .alert_object_machine_input_response_body import AlertObjectMachineInputResponseBody
    from .alert_object_onvif_camera_stream_response_body import AlertObjectOnvifCameraStreamResponseBody
    from .alert_object_product_response_body import AlertObjectProductResponseBody
    from .alert_object_sensor_response_body import AlertObjectSensorResponseBody
    from .alert_object_sites_response_body import AlertObjectSitesResponseBody
    from .alert_object_trailer_response_body import AlertObjectTrailerResponseBody
    from .alert_object_vehicle_response_body import AlertObjectVehicleResponseBody
    from .alert_object_workforce_camera_device_response_body import AlertObjectWorkforceCameraDeviceResponseBody
    from .alerts_delete_configurations_bad_gateway_error_response_body import (
        AlertsDeleteConfigurationsBadGatewayErrorResponseBody,
    )
    from .alerts_delete_configurations_gateway_timeout_error_response_body import (
        AlertsDeleteConfigurationsGatewayTimeoutErrorResponseBody,
    )
    from .alerts_delete_configurations_internal_server_error_response_body import (
        AlertsDeleteConfigurationsInternalServerErrorResponseBody,
    )
    from .alerts_delete_configurations_method_not_allowed_error_response_body import (
        AlertsDeleteConfigurationsMethodNotAllowedErrorResponseBody,
    )
    from .alerts_delete_configurations_not_found_error_response_body import (
        AlertsDeleteConfigurationsNotFoundErrorResponseBody,
    )
    from .alerts_delete_configurations_not_implemented_error_response_body import (
        AlertsDeleteConfigurationsNotImplementedErrorResponseBody,
    )
    from .alerts_delete_configurations_service_unavailable_error_response_body import (
        AlertsDeleteConfigurationsServiceUnavailableErrorResponseBody,
    )
    from .alerts_delete_configurations_too_many_requests_error_response_body import (
        AlertsDeleteConfigurationsTooManyRequestsErrorResponseBody,
    )
    from .alerts_delete_configurations_unauthorized_error_response_body import (
        AlertsDeleteConfigurationsUnauthorizedErrorResponseBody,
    )
    from .alerts_get_configurations_bad_gateway_error_response_body import (
        AlertsGetConfigurationsBadGatewayErrorResponseBody,
    )
    from .alerts_get_configurations_gateway_timeout_error_response_body import (
        AlertsGetConfigurationsGatewayTimeoutErrorResponseBody,
    )
    from .alerts_get_configurations_internal_server_error_response_body import (
        AlertsGetConfigurationsInternalServerErrorResponseBody,
    )
    from .alerts_get_configurations_method_not_allowed_error_response_body import (
        AlertsGetConfigurationsMethodNotAllowedErrorResponseBody,
    )
    from .alerts_get_configurations_not_found_error_response_body import (
        AlertsGetConfigurationsNotFoundErrorResponseBody,
    )
    from .alerts_get_configurations_not_implemented_error_response_body import (
        AlertsGetConfigurationsNotImplementedErrorResponseBody,
    )
    from .alerts_get_configurations_response_body import AlertsGetConfigurationsResponseBody
    from .alerts_get_configurations_service_unavailable_error_response_body import (
        AlertsGetConfigurationsServiceUnavailableErrorResponseBody,
    )
    from .alerts_get_configurations_too_many_requests_error_response_body import (
        AlertsGetConfigurationsTooManyRequestsErrorResponseBody,
    )
    from .alerts_get_configurations_unauthorized_error_response_body import (
        AlertsGetConfigurationsUnauthorizedErrorResponseBody,
    )
    from .alerts_get_incidents_bad_gateway_error_response_body import AlertsGetIncidentsBadGatewayErrorResponseBody
    from .alerts_get_incidents_gateway_timeout_error_response_body import (
        AlertsGetIncidentsGatewayTimeoutErrorResponseBody,
    )
    from .alerts_get_incidents_internal_server_error_response_body import (
        AlertsGetIncidentsInternalServerErrorResponseBody,
    )
    from .alerts_get_incidents_method_not_allowed_error_response_body import (
        AlertsGetIncidentsMethodNotAllowedErrorResponseBody,
    )
    from .alerts_get_incidents_not_found_error_response_body import AlertsGetIncidentsNotFoundErrorResponseBody
    from .alerts_get_incidents_not_implemented_error_response_body import (
        AlertsGetIncidentsNotImplementedErrorResponseBody,
    )
    from .alerts_get_incidents_response_body import AlertsGetIncidentsResponseBody
    from .alerts_get_incidents_service_unavailable_error_response_body import (
        AlertsGetIncidentsServiceUnavailableErrorResponseBody,
    )
    from .alerts_get_incidents_too_many_requests_error_response_body import (
        AlertsGetIncidentsTooManyRequestsErrorResponseBody,
    )
    from .alerts_get_incidents_unauthorized_error_response_body import AlertsGetIncidentsUnauthorizedErrorResponseBody
    from .alerts_patch_configurations_bad_gateway_error_response_body import (
        AlertsPatchConfigurationsBadGatewayErrorResponseBody,
    )
    from .alerts_patch_configurations_gateway_timeout_error_response_body import (
        AlertsPatchConfigurationsGatewayTimeoutErrorResponseBody,
    )
    from .alerts_patch_configurations_internal_server_error_response_body import (
        AlertsPatchConfigurationsInternalServerErrorResponseBody,
    )
    from .alerts_patch_configurations_method_not_allowed_error_response_body import (
        AlertsPatchConfigurationsMethodNotAllowedErrorResponseBody,
    )
    from .alerts_patch_configurations_not_found_error_response_body import (
        AlertsPatchConfigurationsNotFoundErrorResponseBody,
    )
    from .alerts_patch_configurations_not_implemented_error_response_body import (
        AlertsPatchConfigurationsNotImplementedErrorResponseBody,
    )
    from .alerts_patch_configurations_response_body import AlertsPatchConfigurationsResponseBody
    from .alerts_patch_configurations_service_unavailable_error_response_body import (
        AlertsPatchConfigurationsServiceUnavailableErrorResponseBody,
    )
    from .alerts_patch_configurations_too_many_requests_error_response_body import (
        AlertsPatchConfigurationsTooManyRequestsErrorResponseBody,
    )
    from .alerts_patch_configurations_unauthorized_error_response_body import (
        AlertsPatchConfigurationsUnauthorizedErrorResponseBody,
    )
    from .alerts_post_configurations_bad_gateway_error_response_body import (
        AlertsPostConfigurationsBadGatewayErrorResponseBody,
    )
    from .alerts_post_configurations_gateway_timeout_error_response_body import (
        AlertsPostConfigurationsGatewayTimeoutErrorResponseBody,
    )
    from .alerts_post_configurations_internal_server_error_response_body import (
        AlertsPostConfigurationsInternalServerErrorResponseBody,
    )
    from .alerts_post_configurations_method_not_allowed_error_response_body import (
        AlertsPostConfigurationsMethodNotAllowedErrorResponseBody,
    )
    from .alerts_post_configurations_not_found_error_response_body import (
        AlertsPostConfigurationsNotFoundErrorResponseBody,
    )
    from .alerts_post_configurations_not_implemented_error_response_body import (
        AlertsPostConfigurationsNotImplementedErrorResponseBody,
    )
    from .alerts_post_configurations_response_body import AlertsPostConfigurationsResponseBody
    from .alerts_post_configurations_service_unavailable_error_response_body import (
        AlertsPostConfigurationsServiceUnavailableErrorResponseBody,
    )
    from .alerts_post_configurations_too_many_requests_error_response_body import (
        AlertsPostConfigurationsTooManyRequestsErrorResponseBody,
    )
    from .alerts_post_configurations_unauthorized_error_response_body import (
        AlertsPostConfigurationsUnauthorizedErrorResponseBody,
    )
    from .ambient_temperature_details_object_request_body import AmbientTemperatureDetailsObjectRequestBody
    from .ambient_temperature_details_object_request_body_operation import (
        AmbientTemperatureDetailsObjectRequestBodyOperation,
    )
    from .ambient_temperature_details_object_response_body import AmbientTemperatureDetailsObjectResponseBody
    from .ambient_temperature_details_object_response_body_operation import (
        AmbientTemperatureDetailsObjectResponseBodyOperation,
    )
    from .ambient_temperature_response_body import AmbientTemperatureResponseBody
    from .anticipation_brake_event_count import AnticipationBrakeEventCount
    from .appointment_window_request_body import AppointmentWindowRequestBody
    from .appointment_window_response_body import AppointmentWindowResponseBody
    from .asset_data_input import AssetDataInput
    from .asset_data_input_last_point import AssetDataInputLastPoint
    from .asset_data_output import AssetDataOutput
    from .asset_data_outputs_patch_asset_data_outputs_bad_gateway_error_response_body import (
        AssetDataOutputsPatchAssetDataOutputsBadGatewayErrorResponseBody,
    )
    from .asset_data_outputs_patch_asset_data_outputs_gateway_timeout_error_response_body import (
        AssetDataOutputsPatchAssetDataOutputsGatewayTimeoutErrorResponseBody,
    )
    from .asset_data_outputs_patch_asset_data_outputs_internal_server_error_response_body import (
        AssetDataOutputsPatchAssetDataOutputsInternalServerErrorResponseBody,
    )
    from .asset_data_outputs_patch_asset_data_outputs_method_not_allowed_error_response_body import (
        AssetDataOutputsPatchAssetDataOutputsMethodNotAllowedErrorResponseBody,
    )
    from .asset_data_outputs_patch_asset_data_outputs_not_found_error_response_body import (
        AssetDataOutputsPatchAssetDataOutputsNotFoundErrorResponseBody,
    )
    from .asset_data_outputs_patch_asset_data_outputs_not_implemented_error_response_body import (
        AssetDataOutputsPatchAssetDataOutputsNotImplementedErrorResponseBody,
    )
    from .asset_data_outputs_patch_asset_data_outputs_response_body import (
        AssetDataOutputsPatchAssetDataOutputsResponseBody,
    )
    from .asset_data_outputs_patch_asset_data_outputs_service_unavailable_error_response_body import (
        AssetDataOutputsPatchAssetDataOutputsServiceUnavailableErrorResponseBody,
    )
    from .asset_data_outputs_patch_asset_data_outputs_too_many_requests_error_response_body import (
        AssetDataOutputsPatchAssetDataOutputsTooManyRequestsErrorResponseBody,
    )
    from .asset_data_outputs_patch_asset_data_outputs_unauthorized_error_response_body import (
        AssetDataOutputsPatchAssetDataOutputsUnauthorizedErrorResponseBody,
    )
    from .asset_location import AssetLocation
    from .asset_location_heading import AssetLocationHeading
    from .asset_location_speed import AssetLocationSpeed
    from .asset_name import AssetName
    from .asset_response import AssetResponse
    from .asset_response_body import AssetResponseBody
    from .asset_response_body_regulation_mode import AssetResponseBodyRegulationMode
    from .asset_response_body_type import AssetResponseBodyType
    from .asset_response_location_data_input import AssetResponseLocationDataInput
    from .asset_response_parent_asset import AssetResponseParentAsset
    from .asset_response_response_body import AssetResponseResponseBody
    from .asset_response_running_status_data_input import AssetResponseRunningStatusDataInput
    from .assets_create_asset_bad_gateway_error_response_body import AssetsCreateAssetBadGatewayErrorResponseBody
    from .assets_create_asset_gateway_timeout_error_response_body import (
        AssetsCreateAssetGatewayTimeoutErrorResponseBody,
    )
    from .assets_create_asset_internal_server_error_response_body import (
        AssetsCreateAssetInternalServerErrorResponseBody,
    )
    from .assets_create_asset_method_not_allowed_error_response_body import (
        AssetsCreateAssetMethodNotAllowedErrorResponseBody,
    )
    from .assets_create_asset_not_found_error_response_body import AssetsCreateAssetNotFoundErrorResponseBody
    from .assets_create_asset_not_implemented_error_response_body import (
        AssetsCreateAssetNotImplementedErrorResponseBody,
    )
    from .assets_create_asset_response_body import AssetsCreateAssetResponseBody
    from .assets_create_asset_service_unavailable_error_response_body import (
        AssetsCreateAssetServiceUnavailableErrorResponseBody,
    )
    from .assets_create_asset_too_many_requests_error_response_body import (
        AssetsCreateAssetTooManyRequestsErrorResponseBody,
    )
    from .assets_create_asset_unauthorized_error_response_body import AssetsCreateAssetUnauthorizedErrorResponseBody
    from .assets_delete_asset_bad_gateway_error_response_body import AssetsDeleteAssetBadGatewayErrorResponseBody
    from .assets_delete_asset_gateway_timeout_error_response_body import (
        AssetsDeleteAssetGatewayTimeoutErrorResponseBody,
    )
    from .assets_delete_asset_internal_server_error_response_body import (
        AssetsDeleteAssetInternalServerErrorResponseBody,
    )
    from .assets_delete_asset_method_not_allowed_error_response_body import (
        AssetsDeleteAssetMethodNotAllowedErrorResponseBody,
    )
    from .assets_delete_asset_not_found_error_response_body import AssetsDeleteAssetNotFoundErrorResponseBody
    from .assets_delete_asset_not_implemented_error_response_body import (
        AssetsDeleteAssetNotImplementedErrorResponseBody,
    )
    from .assets_delete_asset_service_unavailable_error_response_body import (
        AssetsDeleteAssetServiceUnavailableErrorResponseBody,
    )
    from .assets_delete_asset_too_many_requests_error_response_body import (
        AssetsDeleteAssetTooManyRequestsErrorResponseBody,
    )
    from .assets_delete_asset_unauthorized_error_response_body import AssetsDeleteAssetUnauthorizedErrorResponseBody
    from .assets_inputs_asset_response_response_body import AssetsInputsAssetResponseResponseBody
    from .assets_inputs_aux_input_response_body import AssetsInputsAuxInputResponseBody
    from .assets_inputs_get_assets_inputs_bad_gateway_error_response_body import (
        AssetsInputsGetAssetsInputsBadGatewayErrorResponseBody,
    )
    from .assets_inputs_get_assets_inputs_gateway_timeout_error_response_body import (
        AssetsInputsGetAssetsInputsGatewayTimeoutErrorResponseBody,
    )
    from .assets_inputs_get_assets_inputs_internal_server_error_response_body import (
        AssetsInputsGetAssetsInputsInternalServerErrorResponseBody,
    )
    from .assets_inputs_get_assets_inputs_method_not_allowed_error_response_body import (
        AssetsInputsGetAssetsInputsMethodNotAllowedErrorResponseBody,
    )
    from .assets_inputs_get_assets_inputs_not_found_error_response_body import (
        AssetsInputsGetAssetsInputsNotFoundErrorResponseBody,
    )
    from .assets_inputs_get_assets_inputs_not_implemented_error_response_body import (
        AssetsInputsGetAssetsInputsNotImplementedErrorResponseBody,
    )
    from .assets_inputs_get_assets_inputs_response_body import AssetsInputsGetAssetsInputsResponseBody
    from .assets_inputs_get_assets_inputs_service_unavailable_error_response_body import (
        AssetsInputsGetAssetsInputsServiceUnavailableErrorResponseBody,
    )
    from .assets_inputs_get_assets_inputs_too_many_requests_error_response_body import (
        AssetsInputsGetAssetsInputsTooManyRequestsErrorResponseBody,
    )
    from .assets_inputs_get_assets_inputs_unauthorized_error_response_body import (
        AssetsInputsGetAssetsInputsUnauthorizedErrorResponseBody,
    )
    from .assets_inputs_response_response_body import AssetsInputsResponseResponseBody
    from .assets_inputs_response_response_body_units import AssetsInputsResponseResponseBodyUnits
    from .assets_list_assets_bad_gateway_error_response_body import AssetsListAssetsBadGatewayErrorResponseBody
    from .assets_list_assets_gateway_timeout_error_response_body import AssetsListAssetsGatewayTimeoutErrorResponseBody
    from .assets_list_assets_internal_server_error_response_body import AssetsListAssetsInternalServerErrorResponseBody
    from .assets_list_assets_method_not_allowed_error_response_body import (
        AssetsListAssetsMethodNotAllowedErrorResponseBody,
    )
    from .assets_list_assets_not_found_error_response_body import AssetsListAssetsNotFoundErrorResponseBody
    from .assets_list_assets_not_implemented_error_response_body import AssetsListAssetsNotImplementedErrorResponseBody
    from .assets_list_assets_response_body import AssetsListAssetsResponseBody
    from .assets_list_assets_service_unavailable_error_response_body import (
        AssetsListAssetsServiceUnavailableErrorResponseBody,
    )
    from .assets_list_assets_too_many_requests_error_response_body import (
        AssetsListAssetsTooManyRequestsErrorResponseBody,
    )
    from .assets_list_assets_unauthorized_error_response_body import AssetsListAssetsUnauthorizedErrorResponseBody
    from .assets_location_link_config_address_details_object import AssetsLocationLinkConfigAddressDetailsObject
    from .assets_location_link_config_address_details_object_response_body import (
        AssetsLocationLinkConfigAddressDetailsObjectResponseBody,
    )
    from .assets_location_link_request_config_object import AssetsLocationLinkRequestConfigObject
    from .assets_location_link_response_config_object_response_body import (
        AssetsLocationLinkResponseConfigObjectResponseBody,
    )
    from .assets_near_location_link_config_object import AssetsNearLocationLinkConfigObject
    from .assets_near_location_link_config_object_response_body import AssetsNearLocationLinkConfigObjectResponseBody
    from .assets_on_route_link_config_object import AssetsOnRouteLinkConfigObject
    from .assets_on_route_link_config_object_response_body import AssetsOnRouteLinkConfigObjectResponseBody
    from .assets_update_asset_bad_gateway_error_response_body import AssetsUpdateAssetBadGatewayErrorResponseBody
    from .assets_update_asset_gateway_timeout_error_response_body import (
        AssetsUpdateAssetGatewayTimeoutErrorResponseBody,
    )
    from .assets_update_asset_internal_server_error_response_body import (
        AssetsUpdateAssetInternalServerErrorResponseBody,
    )
    from .assets_update_asset_method_not_allowed_error_response_body import (
        AssetsUpdateAssetMethodNotAllowedErrorResponseBody,
    )
    from .assets_update_asset_not_found_error_response_body import AssetsUpdateAssetNotFoundErrorResponseBody
    from .assets_update_asset_not_implemented_error_response_body import (
        AssetsUpdateAssetNotImplementedErrorResponseBody,
    )
    from .assets_update_asset_response_body import AssetsUpdateAssetResponseBody
    from .assets_update_asset_service_unavailable_error_response_body import (
        AssetsUpdateAssetServiceUnavailableErrorResponseBody,
    )
    from .assets_update_asset_too_many_requests_error_response_body import (
        AssetsUpdateAssetTooManyRequestsErrorResponseBody,
    )
    from .assets_update_asset_unauthorized_error_response_body import AssetsUpdateAssetUnauthorizedErrorResponseBody
    from .attribute import Attribute
    from .attribute_attribute_type import AttributeAttributeType
    from .attribute_entity import AttributeEntity
    from .attribute_entity_external_ids import AttributeEntityExternalIds
    from .attribute_entity_type import AttributeEntityType
    from .attribute_expanded import AttributeExpanded
    from .attribute_expanded_all_of import AttributeExpandedAllOf
    from .attribute_expanded_response import AttributeExpandedResponse
    from .attribute_tiny import AttributeTiny
    from .attribute_unit import AttributeUnit
    from .attribute_value_tiny import AttributeValueTiny
    from .auth_token_auth_token_bad_gateway_error_response_body import AuthTokenAuthTokenBadGatewayErrorResponseBody
    from .auth_token_auth_token_gateway_timeout_error_response_body import (
        AuthTokenAuthTokenGatewayTimeoutErrorResponseBody,
    )
    from .auth_token_auth_token_internal_server_error_response_body import (
        AuthTokenAuthTokenInternalServerErrorResponseBody,
    )
    from .auth_token_auth_token_method_not_allowed_error_response_body import (
        AuthTokenAuthTokenMethodNotAllowedErrorResponseBody,
    )
    from .auth_token_auth_token_not_found_error_response_body import AuthTokenAuthTokenNotFoundErrorResponseBody
    from .auth_token_auth_token_not_implemented_error_response_body import (
        AuthTokenAuthTokenNotImplementedErrorResponseBody,
    )
    from .auth_token_auth_token_response_body import AuthTokenAuthTokenResponseBody
    from .auth_token_auth_token_service_unavailable_error_response_body import (
        AuthTokenAuthTokenServiceUnavailableErrorResponseBody,
    )
    from .auth_token_auth_token_too_many_requests_error_response_body import (
        AuthTokenAuthTokenTooManyRequestsErrorResponseBody,
    )
    from .auth_token_auth_token_unauthorized_error_response_body import AuthTokenAuthTokenUnauthorizedErrorResponseBody
    from .auth_token_for_driver_response_response_body import AuthTokenForDriverResponseResponseBody
    from .author_signature_object_response_body import AuthorSignatureObjectResponseBody
    from .author_signature_object_response_body_type import AuthorSignatureObjectResponseBodyType
    from .barcode_value_object_request_body import BarcodeValueObjectRequestBody
    from .barcode_value_object_response_body import BarcodeValueObjectResponseBody
    from .base_route_response_object_response_body import BaseRouteResponseObjectResponseBody
    from .behavior_count_details_request_body import BehaviorCountDetailsRequestBody
    from .behavior_count_details_request_body_comparison import BehaviorCountDetailsRequestBodyComparison
    from .behavior_count_details_response_body import BehaviorCountDetailsResponseBody
    from .behavior_count_details_response_body_comparison import BehaviorCountDetailsResponseBodyComparison
    from .behavior_response_body import BehaviorResponseBody
    from .behavior_response_body_coachable_behavior_type import BehaviorResponseBodyCoachableBehaviorType
    from .camera_connector_disconected_response_body import CameraConnectorDisconectedResponseBody
    from .camera_details_response_response_body import CameraDetailsResponseResponseBody
    from .camera_serial import CameraSerial
    from .camera_stream_issue_response_body import CameraStreamIssueResponseBody
    from .carrier_proposed_assignment import CarrierProposedAssignment
    from .carrier_proposed_assignment_accepted_time import CarrierProposedAssignmentAcceptedTime
    from .carrier_proposed_assignment_active_time import CarrierProposedAssignmentActiveTime
    from .carrier_proposed_assignment_driver import CarrierProposedAssignmentDriver
    from .carrier_proposed_assignment_driver_all_of import CarrierProposedAssignmentDriverAllOf
    from .carrier_proposed_assignment_driver_all_of_2_external_ids import (
        CarrierProposedAssignmentDriverAllOf2ExternalIds,
    )
    from .carrier_proposed_assignment_first_seen_time import CarrierProposedAssignmentFirstSeenTime
    from .carrier_proposed_assignment_id import CarrierProposedAssignmentId
    from .carrier_proposed_assignment_rejected_time import CarrierProposedAssignmentRejectedTime
    from .carrier_proposed_assignment_response import CarrierProposedAssignmentResponse
    from .carrier_proposed_assignment_shipping_docs import CarrierProposedAssignmentShippingDocs
    from .carrier_proposed_assignment_trailer import CarrierProposedAssignmentTrailer
    from .carrier_proposed_assignment_trailers import CarrierProposedAssignmentTrailers
    from .carrier_proposed_assignment_vehicle import CarrierProposedAssignmentVehicle
    from .cell_connectivity_response_response_body import CellConnectivityResponseResponseBody
    from .cell_connectivity_response_response_body_signal_bar import CellConnectivityResponseResponseBodySignalBar
    from .cell_signal_loss_details_object_request_body import CellSignalLossDetailsObjectRequestBody
    from .cell_signal_loss_details_object_response_body import CellSignalLossDetailsObjectResponseBody
    from .cell_signal_loss_response_body import CellSignalLossResponseBody
    from .circle_request_body import CircleRequestBody
    from .circle_response_body import CircleResponseBody
    from .cloud_backup_upload_issue_response_body import CloudBackupUploadIssueResponseBody
    from .coach_assignment_with_driver_external_ids_response_response_body import (
        CoachAssignmentWithDriverExternalIdsResponseResponseBody,
    )
    from .coach_assignment_without_driver_external_ids_response_response_body import (
        CoachAssignmentWithoutDriverExternalIdsResponseResponseBody,
    )
    from .coachable_event_response_body import CoachableEventResponseBody
    from .coaching_sessions_get_coaching_sessions_bad_gateway_error_response_body import (
        CoachingSessionsGetCoachingSessionsBadGatewayErrorResponseBody,
    )
    from .coaching_sessions_get_coaching_sessions_gateway_timeout_error_response_body import (
        CoachingSessionsGetCoachingSessionsGatewayTimeoutErrorResponseBody,
    )
    from .coaching_sessions_get_coaching_sessions_internal_server_error_response_body import (
        CoachingSessionsGetCoachingSessionsInternalServerErrorResponseBody,
    )
    from .coaching_sessions_get_coaching_sessions_method_not_allowed_error_response_body import (
        CoachingSessionsGetCoachingSessionsMethodNotAllowedErrorResponseBody,
    )
    from .coaching_sessions_get_coaching_sessions_not_found_error_response_body import (
        CoachingSessionsGetCoachingSessionsNotFoundErrorResponseBody,
    )
    from .coaching_sessions_get_coaching_sessions_not_implemented_error_response_body import (
        CoachingSessionsGetCoachingSessionsNotImplementedErrorResponseBody,
    )
    from .coaching_sessions_get_coaching_sessions_response_body import CoachingSessionsGetCoachingSessionsResponseBody
    from .coaching_sessions_get_coaching_sessions_service_unavailable_error_response_body import (
        CoachingSessionsGetCoachingSessionsServiceUnavailableErrorResponseBody,
    )
    from .coaching_sessions_get_coaching_sessions_too_many_requests_error_response_body import (
        CoachingSessionsGetCoachingSessionsTooManyRequestsErrorResponseBody,
    )
    from .coaching_sessions_get_coaching_sessions_unauthorized_error_response_body import (
        CoachingSessionsGetCoachingSessionsUnauthorizedErrorResponseBody,
    )
    from .coaching_sessions_response_response_body import CoachingSessionsResponseResponseBody
    from .coaching_sessions_response_response_body_coaching_type import CoachingSessionsResponseResponseBodyCoachingType
    from .coaching_sessions_response_response_body_session_status import (
        CoachingSessionsResponseResponseBodySessionStatus,
    )
    from .coasting_duration_ms import CoastingDurationMs
    from .column_response_body import ColumnResponseBody
    from .column_response_body_data_type import ColumnResponseBodyDataType
    from .column_response_body_unit import ColumnResponseBodyUnit
    from .conditional_field_section_object_response_body import ConditionalFieldSectionObjectResponseBody
    from .connection_status_response_object_response_body import ConnectionStatusResponseObjectResponseBody
    from .connection_status_response_object_response_body_health_status import (
        ConnectionStatusResponseObjectResponseBodyHealthStatus,
    )
    from .contact import Contact
    from .contact_email import ContactEmail
    from .contact_first_name import ContactFirstName
    from .contact_id import ContactId
    from .contact_last_name import ContactLastName
    from .contact_phone import ContactPhone
    from .contact_response import ContactResponse
    from .contact_tiny_response import ContactTinyResponse
    from .continuous_reading_alert_threshold_response_body import ContinuousReadingAlertThresholdResponseBody
    from .continuous_reading_alert_threshold_response_body_operation import (
        ContinuousReadingAlertThresholdResponseBodyOperation,
    )
    from .continuous_reading_alert_threshold_response_body_unit import ContinuousReadingAlertThresholdResponseBodyUnit
    from .create_address_request_geofence import CreateAddressRequestGeofence
    from .create_address_request_geofence_settings import CreateAddressRequestGeofenceSettings
    from .create_attribute_request_entities import CreateAttributeRequestEntities
    from .create_driver_auth_token_response_response_body import CreateDriverAuthTokenResponseResponseBody
    from .create_driver_request_attributes import CreateDriverRequestAttributes
    from .create_report_config_column_request_body import CreateReportConfigColumnRequestBody
    from .create_report_config_object_request_body import CreateReportConfigObjectRequestBody
    from .create_routes_stop_request_object_request_body import CreateRoutesStopRequestObjectRequestBody
    from .create_user_request_roles import CreateUserRequestRoles
    from .cruise_control_duration_ms import CruiseControlDurationMs
    from .cumulative_operating_hours_response_body import CumulativeOperatingHoursResponseBody
    from .current_duty_status import CurrentDutyStatus
    from .current_duty_status_hos_status_type import CurrentDutyStatusHosStatusType
    from .custom_headers_object_request_body import CustomHeadersObjectRequestBody
    from .custom_headers_object_response_body import CustomHeadersObjectResponseBody
    from .custom_metadata import CustomMetadata
    from .dashcam_disconnected_response_body import DashcamDisconnectedResponseBody
    from .data_input_list_response import DataInputListResponse
    from .data_input_response import DataInputResponse
    from .data_input_response_all_of import DataInputResponseAllOf
    from .data_input_snapshot import DataInputSnapshot
    from .data_input_snapshot_all_of import DataInputSnapshotAllOf
    from .data_input_snapshot_response import DataInputSnapshotResponse
    from .data_input_tiny_response import DataInputTinyResponse
    from .data_input_value_response_body import DataInputValueResponseBody
    from .data_inputs_tiny_response import DataInputsTinyResponse
    from .data_usage_response_object_response_body import DataUsageResponseObjectResponseBody
    from .date_time_value_object_request_body import DateTimeValueObjectRequestBody
    from .date_time_value_object_response_body import DateTimeValueObjectResponseBody
    from .def_level_trigger_details_object_request_body import DefLevelTriggerDetailsObjectRequestBody
    from .def_level_trigger_details_object_request_body_operation import (
        DefLevelTriggerDetailsObjectRequestBodyOperation,
    )
    from .def_level_trigger_details_object_response_body import DefLevelTriggerDetailsObjectResponseBody
    from .def_level_trigger_details_object_response_body_operation import (
        DefLevelTriggerDetailsObjectResponseBodyOperation,
    )
    from .def_remaining_response_body import DefRemainingResponseBody
    from .defect import Defect
    from .defect_photo_response_response_body import DefectPhotoResponseResponseBody
    from .defect_resolved_by import DefectResolvedBy
    from .defect_resolved_by_type import DefectResolvedByType
    from .defect_response import DefectResponse
    from .defect_trailer import DefectTrailer
    from .defect_trailer_response_response_body import DefectTrailerResponseResponseBody
    from .defect_types_response_data_response_body import DefectTypesResponseDataResponseBody
    from .defect_types_response_data_response_body_section_type import DefectTypesResponseDataResponseBodySectionType
    from .defect_vehicle import DefectVehicle
    from .defect_vehicle_response_response_body import DefectVehicleResponseResponseBody
    from .defects_response import DefectsResponse
    from .defects_response_data_response_body import DefectsResponseDataResponseBody
    from .depreciation_get_depreciation_transactions_bad_gateway_error_response_body import (
        DepreciationGetDepreciationTransactionsBadGatewayErrorResponseBody,
    )
    from .depreciation_get_depreciation_transactions_gateway_timeout_error_response_body import (
        DepreciationGetDepreciationTransactionsGatewayTimeoutErrorResponseBody,
    )
    from .depreciation_get_depreciation_transactions_internal_server_error_response_body import (
        DepreciationGetDepreciationTransactionsInternalServerErrorResponseBody,
    )
    from .depreciation_get_depreciation_transactions_method_not_allowed_error_response_body import (
        DepreciationGetDepreciationTransactionsMethodNotAllowedErrorResponseBody,
    )
    from .depreciation_get_depreciation_transactions_not_found_error_response_body import (
        DepreciationGetDepreciationTransactionsNotFoundErrorResponseBody,
    )
    from .depreciation_get_depreciation_transactions_not_implemented_error_response_body import (
        DepreciationGetDepreciationTransactionsNotImplementedErrorResponseBody,
    )
    from .depreciation_get_depreciation_transactions_response_body import (
        DepreciationGetDepreciationTransactionsResponseBody,
    )
    from .depreciation_get_depreciation_transactions_service_unavailable_error_response_body import (
        DepreciationGetDepreciationTransactionsServiceUnavailableErrorResponseBody,
    )
    from .depreciation_get_depreciation_transactions_too_many_requests_error_response_body import (
        DepreciationGetDepreciationTransactionsTooManyRequestsErrorResponseBody,
    )
    from .depreciation_get_depreciation_transactions_unauthorized_error_response_body import (
        DepreciationGetDepreciationTransactionsUnauthorizedErrorResponseBody,
    )
    from .depreciation_transaction_money_object_response_body import DepreciationTransactionMoneyObjectResponseBody
    from .depreciation_transaction_money_object_response_body_currency import (
        DepreciationTransactionMoneyObjectResponseBodyCurrency,
    )
    from .depreciation_transaction_object_response_body import DepreciationTransactionObjectResponseBody
    from .depreciation_transaction_object_response_body_transaction_type import (
        DepreciationTransactionObjectResponseBodyTransactionType,
    )
    from .detection_log_asset_object_response_body import DetectionLogAssetObjectResponseBody
    from .detection_log_detection_object_response_body import DetectionLogDetectionObjectResponseBody
    from .detection_log_detection_object_response_body_trigger_detection_label import (
        DetectionLogDetectionObjectResponseBodyTriggerDetectionLabel,
    )
    from .detection_log_driver_object_response_body import DetectionLogDriverObjectResponseBody
    from .detection_log_get_detections_bad_gateway_error_response_body import (
        DetectionLogGetDetectionsBadGatewayErrorResponseBody,
    )
    from .detection_log_get_detections_gateway_timeout_error_response_body import (
        DetectionLogGetDetectionsGatewayTimeoutErrorResponseBody,
    )
    from .detection_log_get_detections_internal_server_error_response_body import (
        DetectionLogGetDetectionsInternalServerErrorResponseBody,
    )
    from .detection_log_get_detections_method_not_allowed_error_response_body import (
        DetectionLogGetDetectionsMethodNotAllowedErrorResponseBody,
    )
    from .detection_log_get_detections_not_found_error_response_body import (
        DetectionLogGetDetectionsNotFoundErrorResponseBody,
    )
    from .detection_log_get_detections_not_implemented_error_response_body import (
        DetectionLogGetDetectionsNotImplementedErrorResponseBody,
    )
    from .detection_log_get_detections_response_body import DetectionLogGetDetectionsResponseBody
    from .detection_log_get_detections_service_unavailable_error_response_body import (
        DetectionLogGetDetectionsServiceUnavailableErrorResponseBody,
    )
    from .detection_log_get_detections_too_many_requests_error_response_body import (
        DetectionLogGetDetectionsTooManyRequestsErrorResponseBody,
    )
    from .detection_log_get_detections_unauthorized_error_response_body import (
        DetectionLogGetDetectionsUnauthorizedErrorResponseBody,
    )
    from .detection_log_safety_event_object_response_body import DetectionLogSafetyEventObjectResponseBody
    from .detection_log_safety_event_object_response_body_inbox_filter_reason import (
        DetectionLogSafetyEventObjectResponseBodyInboxFilterReason,
    )
    from .device_asset_response_response_body import DeviceAssetResponseResponseBody
    from .device_movement_data_response_body import DeviceMovementDataResponseBody
    from .device_movement_stopped_data_response_body import DeviceMovementStoppedDataResponseBody
    from .device_movement_trigger_details_object_request_body import DeviceMovementTriggerDetailsObjectRequestBody
    from .device_movement_trigger_details_object_response_body import DeviceMovementTriggerDetailsObjectResponseBody
    from .device_response_response_body import DeviceResponseResponseBody
    from .device_response_response_body_model import DeviceResponseResponseBodyModel
    from .devices_get_devices_bad_gateway_error_response_body import DevicesGetDevicesBadGatewayErrorResponseBody
    from .devices_get_devices_gateway_timeout_error_response_body import (
        DevicesGetDevicesGatewayTimeoutErrorResponseBody,
    )
    from .devices_get_devices_internal_server_error_response_body import (
        DevicesGetDevicesInternalServerErrorResponseBody,
    )
    from .devices_get_devices_method_not_allowed_error_response_body import (
        DevicesGetDevicesMethodNotAllowedErrorResponseBody,
    )
    from .devices_get_devices_not_found_error_response_body import DevicesGetDevicesNotFoundErrorResponseBody
    from .devices_get_devices_not_implemented_error_response_body import (
        DevicesGetDevicesNotImplementedErrorResponseBody,
    )
    from .devices_get_devices_response_body import DevicesGetDevicesResponseBody
    from .devices_get_devices_service_unavailable_error_response_body import (
        DevicesGetDevicesServiceUnavailableErrorResponseBody,
    )
    from .devices_get_devices_too_many_requests_error_response_body import (
        DevicesGetDevicesTooManyRequestsErrorResponseBody,
    )
    from .devices_get_devices_unauthorized_error_response_body import DevicesGetDevicesUnauthorizedErrorResponseBody
    from .distance_driven_meters import DistanceDrivenMeters
    from .distance_response_body import DistanceResponseBody
    from .distance_traveled_object_response_body import DistanceTraveledObjectResponseBody
    from .distracted_driving_detection_alert_settings_object_response_body import (
        DistractedDrivingDetectionAlertSettingsObjectResponseBody,
    )
    from .document_pdf_generation_response import DocumentPdfGenerationResponse
    from .document_pdf_generation_response_data import DocumentPdfGenerationResponseData
    from .document_pdf_query_response import DocumentPdfQueryResponse
    from .document_pdf_query_response_data import DocumentPdfQueryResponseData
    from .document_pdf_query_response_data_job_status import DocumentPdfQueryResponseDataJobStatus
    from .document_response_object_response_body import DocumentResponseObjectResponseBody
    from .document_response_object_response_body_state import DocumentResponseObjectResponseBodyState
    from .document_types_get_document_types_bad_gateway_error_response_body import (
        DocumentTypesGetDocumentTypesBadGatewayErrorResponseBody,
    )
    from .document_types_get_document_types_gateway_timeout_error_response_body import (
        DocumentTypesGetDocumentTypesGatewayTimeoutErrorResponseBody,
    )
    from .document_types_get_document_types_internal_server_error_response_body import (
        DocumentTypesGetDocumentTypesInternalServerErrorResponseBody,
    )
    from .document_types_get_document_types_method_not_allowed_error_response_body import (
        DocumentTypesGetDocumentTypesMethodNotAllowedErrorResponseBody,
    )
    from .document_types_get_document_types_not_found_error_response_body import (
        DocumentTypesGetDocumentTypesNotFoundErrorResponseBody,
    )
    from .document_types_get_document_types_not_implemented_error_response_body import (
        DocumentTypesGetDocumentTypesNotImplementedErrorResponseBody,
    )
    from .document_types_get_document_types_response_body import DocumentTypesGetDocumentTypesResponseBody
    from .document_types_get_document_types_service_unavailable_error_response_body import (
        DocumentTypesGetDocumentTypesServiceUnavailableErrorResponseBody,
    )
    from .document_types_get_document_types_too_many_requests_error_response_body import (
        DocumentTypesGetDocumentTypesTooManyRequestsErrorResponseBody,
    )
    from .document_types_get_document_types_unauthorized_error_response_body import (
        DocumentTypesGetDocumentTypesUnauthorizedErrorResponseBody,
    )
    from .documents_delete_document_bad_gateway_error_response_body import (
        DocumentsDeleteDocumentBadGatewayErrorResponseBody,
    )
    from .documents_delete_document_gateway_timeout_error_response_body import (
        DocumentsDeleteDocumentGatewayTimeoutErrorResponseBody,
    )
    from .documents_delete_document_internal_server_error_response_body import (
        DocumentsDeleteDocumentInternalServerErrorResponseBody,
    )
    from .documents_delete_document_method_not_allowed_error_response_body import (
        DocumentsDeleteDocumentMethodNotAllowedErrorResponseBody,
    )
    from .documents_delete_document_not_found_error_response_body import (
        DocumentsDeleteDocumentNotFoundErrorResponseBody,
    )
    from .documents_delete_document_not_implemented_error_response_body import (
        DocumentsDeleteDocumentNotImplementedErrorResponseBody,
    )
    from .documents_delete_document_service_unavailable_error_response_body import (
        DocumentsDeleteDocumentServiceUnavailableErrorResponseBody,
    )
    from .documents_delete_document_too_many_requests_error_response_body import (
        DocumentsDeleteDocumentTooManyRequestsErrorResponseBody,
    )
    from .documents_delete_document_unauthorized_error_response_body import (
        DocumentsDeleteDocumentUnauthorizedErrorResponseBody,
    )
    from .documents_get_document_bad_gateway_error_response_body import DocumentsGetDocumentBadGatewayErrorResponseBody
    from .documents_get_document_gateway_timeout_error_response_body import (
        DocumentsGetDocumentGatewayTimeoutErrorResponseBody,
    )
    from .documents_get_document_internal_server_error_response_body import (
        DocumentsGetDocumentInternalServerErrorResponseBody,
    )
    from .documents_get_document_method_not_allowed_error_response_body import (
        DocumentsGetDocumentMethodNotAllowedErrorResponseBody,
    )
    from .documents_get_document_not_found_error_response_body import DocumentsGetDocumentNotFoundErrorResponseBody
    from .documents_get_document_not_implemented_error_response_body import (
        DocumentsGetDocumentNotImplementedErrorResponseBody,
    )
    from .documents_get_document_response_body import DocumentsGetDocumentResponseBody
    from .documents_get_document_service_unavailable_error_response_body import (
        DocumentsGetDocumentServiceUnavailableErrorResponseBody,
    )
    from .documents_get_document_too_many_requests_error_response_body import (
        DocumentsGetDocumentTooManyRequestsErrorResponseBody,
    )
    from .documents_get_document_unauthorized_error_response_body import (
        DocumentsGetDocumentUnauthorizedErrorResponseBody,
    )
    from .documents_get_documents_bad_gateway_error_response_body import (
        DocumentsGetDocumentsBadGatewayErrorResponseBody,
    )
    from .documents_get_documents_gateway_timeout_error_response_body import (
        DocumentsGetDocumentsGatewayTimeoutErrorResponseBody,
    )
    from .documents_get_documents_internal_server_error_response_body import (
        DocumentsGetDocumentsInternalServerErrorResponseBody,
    )
    from .documents_get_documents_method_not_allowed_error_response_body import (
        DocumentsGetDocumentsMethodNotAllowedErrorResponseBody,
    )
    from .documents_get_documents_not_found_error_response_body import DocumentsGetDocumentsNotFoundErrorResponseBody
    from .documents_get_documents_not_implemented_error_response_body import (
        DocumentsGetDocumentsNotImplementedErrorResponseBody,
    )
    from .documents_get_documents_response_body import DocumentsGetDocumentsResponseBody
    from .documents_get_documents_service_unavailable_error_response_body import (
        DocumentsGetDocumentsServiceUnavailableErrorResponseBody,
    )
    from .documents_get_documents_too_many_requests_error_response_body import (
        DocumentsGetDocumentsTooManyRequestsErrorResponseBody,
    )
    from .documents_get_documents_unauthorized_error_response_body import (
        DocumentsGetDocumentsUnauthorizedErrorResponseBody,
    )
    from .documents_post_document_bad_gateway_error_response_body import (
        DocumentsPostDocumentBadGatewayErrorResponseBody,
    )
    from .documents_post_document_gateway_timeout_error_response_body import (
        DocumentsPostDocumentGatewayTimeoutErrorResponseBody,
    )
    from .documents_post_document_internal_server_error_response_body import (
        DocumentsPostDocumentInternalServerErrorResponseBody,
    )
    from .documents_post_document_method_not_allowed_error_response_body import (
        DocumentsPostDocumentMethodNotAllowedErrorResponseBody,
    )
    from .documents_post_document_not_found_error_response_body import DocumentsPostDocumentNotFoundErrorResponseBody
    from .documents_post_document_not_implemented_error_response_body import (
        DocumentsPostDocumentNotImplementedErrorResponseBody,
    )
    from .documents_post_document_response_body import DocumentsPostDocumentResponseBody
    from .documents_post_document_service_unavailable_error_response_body import (
        DocumentsPostDocumentServiceUnavailableErrorResponseBody,
    )
    from .documents_post_document_too_many_requests_error_response_body import (
        DocumentsPostDocumentTooManyRequestsErrorResponseBody,
    )
    from .documents_post_document_unauthorized_error_response_body import (
        DocumentsPostDocumentUnauthorizedErrorResponseBody,
    )
    from .door_open_response_body import DoorOpenResponseBody
    from .drive_time_duration_ms import DriveTimeDurationMs
    from .driver import Driver
    from .driver_activation_status import DriverActivationStatus
    from .driver_app_notification_object_request_body import DriverAppNotificationObjectRequestBody
    from .driver_app_notification_object_response_body import DriverAppNotificationObjectResponseBody
    from .driver_app_settings_gamification_config_tiny_object_request_body import (
        DriverAppSettingsGamificationConfigTinyObjectRequestBody,
    )
    from .driver_app_settings_gamification_config_tiny_object_response_body import (
        DriverAppSettingsGamificationConfigTinyObjectResponseBody,
    )
    from .driver_app_settings_response_object_response_body import DriverAppSettingsResponseObjectResponseBody
    from .driver_app_settings_trailer_selection_config_tiny_object_request_body import (
        DriverAppSettingsTrailerSelectionConfigTinyObjectRequestBody,
    )
    from .driver_app_settings_trailer_selection_config_tiny_object_response_body import (
        DriverAppSettingsTrailerSelectionConfigTinyObjectResponseBody,
    )
    from .driver_app_sign_in_response_body import DriverAppSignInResponseBody
    from .driver_app_sign_out_response_body import DriverAppSignOutResponseBody
    from .driver_assignment_metadata_tiny_object_response_body import DriverAssignmentMetadataTinyObjectResponseBody
    from .driver_assignment_object_response_body import DriverAssignmentObjectResponseBody
    from .driver_assignment_object_response_body_assignment_type import DriverAssignmentObjectResponseBodyAssignmentType
    from .driver_carrier_settings import DriverCarrierSettings
    from .driver_coach_assignments_get_driver_coach_assignment_bad_gateway_error_response_body import (
        DriverCoachAssignmentsGetDriverCoachAssignmentBadGatewayErrorResponseBody,
    )
    from .driver_coach_assignments_get_driver_coach_assignment_gateway_timeout_error_response_body import (
        DriverCoachAssignmentsGetDriverCoachAssignmentGatewayTimeoutErrorResponseBody,
    )
    from .driver_coach_assignments_get_driver_coach_assignment_internal_server_error_response_body import (
        DriverCoachAssignmentsGetDriverCoachAssignmentInternalServerErrorResponseBody,
    )
    from .driver_coach_assignments_get_driver_coach_assignment_method_not_allowed_error_response_body import (
        DriverCoachAssignmentsGetDriverCoachAssignmentMethodNotAllowedErrorResponseBody,
    )
    from .driver_coach_assignments_get_driver_coach_assignment_not_found_error_response_body import (
        DriverCoachAssignmentsGetDriverCoachAssignmentNotFoundErrorResponseBody,
    )
    from .driver_coach_assignments_get_driver_coach_assignment_not_implemented_error_response_body import (
        DriverCoachAssignmentsGetDriverCoachAssignmentNotImplementedErrorResponseBody,
    )
    from .driver_coach_assignments_get_driver_coach_assignment_response_body import (
        DriverCoachAssignmentsGetDriverCoachAssignmentResponseBody,
    )
    from .driver_coach_assignments_get_driver_coach_assignment_service_unavailable_error_response_body import (
        DriverCoachAssignmentsGetDriverCoachAssignmentServiceUnavailableErrorResponseBody,
    )
    from .driver_coach_assignments_get_driver_coach_assignment_too_many_requests_error_response_body import (
        DriverCoachAssignmentsGetDriverCoachAssignmentTooManyRequestsErrorResponseBody,
    )
    from .driver_coach_assignments_get_driver_coach_assignment_unauthorized_error_response_body import (
        DriverCoachAssignmentsGetDriverCoachAssignmentUnauthorizedErrorResponseBody,
    )
    from .driver_coach_assignments_put_driver_coach_assignment_bad_gateway_error_response_body import (
        DriverCoachAssignmentsPutDriverCoachAssignmentBadGatewayErrorResponseBody,
    )
    from .driver_coach_assignments_put_driver_coach_assignment_gateway_timeout_error_response_body import (
        DriverCoachAssignmentsPutDriverCoachAssignmentGatewayTimeoutErrorResponseBody,
    )
    from .driver_coach_assignments_put_driver_coach_assignment_internal_server_error_response_body import (
        DriverCoachAssignmentsPutDriverCoachAssignmentInternalServerErrorResponseBody,
    )
    from .driver_coach_assignments_put_driver_coach_assignment_method_not_allowed_error_response_body import (
        DriverCoachAssignmentsPutDriverCoachAssignmentMethodNotAllowedErrorResponseBody,
    )
    from .driver_coach_assignments_put_driver_coach_assignment_not_found_error_response_body import (
        DriverCoachAssignmentsPutDriverCoachAssignmentNotFoundErrorResponseBody,
    )
    from .driver_coach_assignments_put_driver_coach_assignment_not_implemented_error_response_body import (
        DriverCoachAssignmentsPutDriverCoachAssignmentNotImplementedErrorResponseBody,
    )
    from .driver_coach_assignments_put_driver_coach_assignment_response_body import (
        DriverCoachAssignmentsPutDriverCoachAssignmentResponseBody,
    )
    from .driver_coach_assignments_put_driver_coach_assignment_service_unavailable_error_response_body import (
        DriverCoachAssignmentsPutDriverCoachAssignmentServiceUnavailableErrorResponseBody,
    )
    from .driver_coach_assignments_put_driver_coach_assignment_too_many_requests_error_response_body import (
        DriverCoachAssignmentsPutDriverCoachAssignmentTooManyRequestsErrorResponseBody,
    )
    from .driver_coach_assignments_put_driver_coach_assignment_unauthorized_error_response_body import (
        DriverCoachAssignmentsPutDriverCoachAssignmentUnauthorizedErrorResponseBody,
    )
    from .driver_created_at_time import DriverCreatedAtTime
    from .driver_document_submitted_details_object_request_body import DriverDocumentSubmittedDetailsObjectRequestBody
    from .driver_document_submitted_details_object_response_body import DriverDocumentSubmittedDetailsObjectResponseBody
    from .driver_document_submitted_response_body import DriverDocumentSubmittedResponseBody
    from .driver_efficiencies_response import DriverEfficienciesResponse
    from .driver_efficiencies_response_data import DriverEfficienciesResponseData
    from .driver_efficiency import DriverEfficiency
    from .driver_efficiency_data_object_response_body import DriverEfficiencyDataObjectResponseBody
    from .driver_efficiency_difficulty_score_data_object_response_body import (
        DriverEfficiencyDifficultyScoreDataObjectResponseBody,
    )
    from .driver_efficiency_get_driver_efficiency_by_drivers_bad_gateway_error_response_body import (
        DriverEfficiencyGetDriverEfficiencyByDriversBadGatewayErrorResponseBody,
    )
    from .driver_efficiency_get_driver_efficiency_by_drivers_gateway_timeout_error_response_body import (
        DriverEfficiencyGetDriverEfficiencyByDriversGatewayTimeoutErrorResponseBody,
    )
    from .driver_efficiency_get_driver_efficiency_by_drivers_internal_server_error_response_body import (
        DriverEfficiencyGetDriverEfficiencyByDriversInternalServerErrorResponseBody,
    )
    from .driver_efficiency_get_driver_efficiency_by_drivers_method_not_allowed_error_response_body import (
        DriverEfficiencyGetDriverEfficiencyByDriversMethodNotAllowedErrorResponseBody,
    )
    from .driver_efficiency_get_driver_efficiency_by_drivers_not_found_error_response_body import (
        DriverEfficiencyGetDriverEfficiencyByDriversNotFoundErrorResponseBody,
    )
    from .driver_efficiency_get_driver_efficiency_by_drivers_not_implemented_error_response_body import (
        DriverEfficiencyGetDriverEfficiencyByDriversNotImplementedErrorResponseBody,
    )
    from .driver_efficiency_get_driver_efficiency_by_drivers_response_body import (
        DriverEfficiencyGetDriverEfficiencyByDriversResponseBody,
    )
    from .driver_efficiency_get_driver_efficiency_by_drivers_service_unavailable_error_response_body import (
        DriverEfficiencyGetDriverEfficiencyByDriversServiceUnavailableErrorResponseBody,
    )
    from .driver_efficiency_get_driver_efficiency_by_drivers_too_many_requests_error_response_body import (
        DriverEfficiencyGetDriverEfficiencyByDriversTooManyRequestsErrorResponseBody,
    )
    from .driver_efficiency_get_driver_efficiency_by_drivers_unauthorized_error_response_body import (
        DriverEfficiencyGetDriverEfficiencyByDriversUnauthorizedErrorResponseBody,
    )
    from .driver_efficiency_get_driver_efficiency_by_vehicles_bad_gateway_error_response_body import (
        DriverEfficiencyGetDriverEfficiencyByVehiclesBadGatewayErrorResponseBody,
    )
    from .driver_efficiency_get_driver_efficiency_by_vehicles_gateway_timeout_error_response_body import (
        DriverEfficiencyGetDriverEfficiencyByVehiclesGatewayTimeoutErrorResponseBody,
    )
    from .driver_efficiency_get_driver_efficiency_by_vehicles_internal_server_error_response_body import (
        DriverEfficiencyGetDriverEfficiencyByVehiclesInternalServerErrorResponseBody,
    )
    from .driver_efficiency_get_driver_efficiency_by_vehicles_method_not_allowed_error_response_body import (
        DriverEfficiencyGetDriverEfficiencyByVehiclesMethodNotAllowedErrorResponseBody,
    )
    from .driver_efficiency_get_driver_efficiency_by_vehicles_not_found_error_response_body import (
        DriverEfficiencyGetDriverEfficiencyByVehiclesNotFoundErrorResponseBody,
    )
    from .driver_efficiency_get_driver_efficiency_by_vehicles_not_implemented_error_response_body import (
        DriverEfficiencyGetDriverEfficiencyByVehiclesNotImplementedErrorResponseBody,
    )
    from .driver_efficiency_get_driver_efficiency_by_vehicles_response_body import (
        DriverEfficiencyGetDriverEfficiencyByVehiclesResponseBody,
    )
    from .driver_efficiency_get_driver_efficiency_by_vehicles_service_unavailable_error_response_body import (
        DriverEfficiencyGetDriverEfficiencyByVehiclesServiceUnavailableErrorResponseBody,
    )
    from .driver_efficiency_get_driver_efficiency_by_vehicles_too_many_requests_error_response_body import (
        DriverEfficiencyGetDriverEfficiencyByVehiclesTooManyRequestsErrorResponseBody,
    )
    from .driver_efficiency_get_driver_efficiency_by_vehicles_unauthorized_error_response_body import (
        DriverEfficiencyGetDriverEfficiencyByVehiclesUnauthorizedErrorResponseBody,
    )
    from .driver_efficiency_percentage_data_object_response_body import DriverEfficiencyPercentageDataObjectResponseBody
    from .driver_efficiency_raw_data_object_response_body import DriverEfficiencyRawDataObjectResponseBody
    from .driver_eld_adverse_weather_exemption_enabled import DriverEldAdverseWeatherExemptionEnabled
    from .driver_eld_big_day_exemption_enabled import DriverEldBigDayExemptionEnabled
    from .driver_eld_day_start_hour import DriverEldDayStartHour
    from .driver_eld_exempt import DriverEldExempt
    from .driver_eld_exempt_reason import DriverEldExemptReason
    from .driver_eld_pc_enabled import DriverEldPcEnabled
    from .driver_eld_ruleset import DriverEldRuleset
    from .driver_eld_ruleset_cycle import DriverEldRulesetCycle
    from .driver_eld_ruleset_jurisdiction import DriverEldRulesetJurisdiction
    from .driver_eld_ruleset_rest_break import DriverEldRulesetRestBreak
    from .driver_eld_ruleset_restart import DriverEldRulesetRestart
    from .driver_eld_ruleset_shift import DriverEldRulesetShift
    from .driver_eld_rulesets import DriverEldRulesets
    from .driver_eld_settings import DriverEldSettings
    from .driver_eld_ym_enabled import DriverEldYmEnabled
    from .driver_external_ids import DriverExternalIds
    from .driver_has_driving_features_hidden import DriverHasDrivingFeaturesHidden
    from .driver_has_vehicle_unpinning_enabled import DriverHasVehicleUnpinningEnabled
    from .driver_heavy_haul_exemption_toggle_enabled import DriverHeavyHaulExemptionToggleEnabled
    from .driver_home_terminal_address import DriverHomeTerminalAddress
    from .driver_home_terminal_name import DriverHomeTerminalName
    from .driver_hos_setting import DriverHosSetting
    from .driver_id import DriverId
    from .driver_id_card_code import DriverIdCardCode
    from .driver_is_deactivated import DriverIsDeactivated
    from .driver_license_number import DriverLicenseNumber
    from .driver_license_state import DriverLicenseState
    from .driver_locale import DriverLocale
    from .driver_message_received_response_body import DriverMessageReceivedResponseBody
    from .driver_message_sent_response_body import DriverMessageSentResponseBody
    from .driver_name import DriverName
    from .driver_notes import DriverNotes
    from .driver_object_response_body import DriverObjectResponseBody
    from .driver_or_tag_ids_details_request_body import DriverOrTagIdsDetailsRequestBody
    from .driver_or_tag_ids_details_response_body import DriverOrTagIdsDetailsResponseBody
    from .driver_phone import DriverPhone
    from .driver_profile_image_base_64 import DriverProfileImageBase64
    from .driver_profile_image_url import DriverProfileImageUrl
    from .driver_qr_codes_create_driver_qr_code_bad_gateway_error_response_body import (
        DriverQrCodesCreateDriverQrCodeBadGatewayErrorResponseBody,
    )
    from .driver_qr_codes_create_driver_qr_code_gateway_timeout_error_response_body import (
        DriverQrCodesCreateDriverQrCodeGatewayTimeoutErrorResponseBody,
    )
    from .driver_qr_codes_create_driver_qr_code_internal_server_error_response_body import (
        DriverQrCodesCreateDriverQrCodeInternalServerErrorResponseBody,
    )
    from .driver_qr_codes_create_driver_qr_code_method_not_allowed_error_response_body import (
        DriverQrCodesCreateDriverQrCodeMethodNotAllowedErrorResponseBody,
    )
    from .driver_qr_codes_create_driver_qr_code_not_found_error_response_body import (
        DriverQrCodesCreateDriverQrCodeNotFoundErrorResponseBody,
    )
    from .driver_qr_codes_create_driver_qr_code_not_implemented_error_response_body import (
        DriverQrCodesCreateDriverQrCodeNotImplementedErrorResponseBody,
    )
    from .driver_qr_codes_create_driver_qr_code_response_body import DriverQrCodesCreateDriverQrCodeResponseBody
    from .driver_qr_codes_create_driver_qr_code_service_unavailable_error_response_body import (
        DriverQrCodesCreateDriverQrCodeServiceUnavailableErrorResponseBody,
    )
    from .driver_qr_codes_create_driver_qr_code_too_many_requests_error_response_body import (
        DriverQrCodesCreateDriverQrCodeTooManyRequestsErrorResponseBody,
    )
    from .driver_qr_codes_create_driver_qr_code_unauthorized_error_response_body import (
        DriverQrCodesCreateDriverQrCodeUnauthorizedErrorResponseBody,
    )
    from .driver_qr_codes_delete_driver_qr_code_bad_gateway_error_response_body import (
        DriverQrCodesDeleteDriverQrCodeBadGatewayErrorResponseBody,
    )
    from .driver_qr_codes_delete_driver_qr_code_gateway_timeout_error_response_body import (
        DriverQrCodesDeleteDriverQrCodeGatewayTimeoutErrorResponseBody,
    )
    from .driver_qr_codes_delete_driver_qr_code_internal_server_error_response_body import (
        DriverQrCodesDeleteDriverQrCodeInternalServerErrorResponseBody,
    )
    from .driver_qr_codes_delete_driver_qr_code_method_not_allowed_error_response_body import (
        DriverQrCodesDeleteDriverQrCodeMethodNotAllowedErrorResponseBody,
    )
    from .driver_qr_codes_delete_driver_qr_code_not_found_error_response_body import (
        DriverQrCodesDeleteDriverQrCodeNotFoundErrorResponseBody,
    )
    from .driver_qr_codes_delete_driver_qr_code_not_implemented_error_response_body import (
        DriverQrCodesDeleteDriverQrCodeNotImplementedErrorResponseBody,
    )
    from .driver_qr_codes_delete_driver_qr_code_service_unavailable_error_response_body import (
        DriverQrCodesDeleteDriverQrCodeServiceUnavailableErrorResponseBody,
    )
    from .driver_qr_codes_delete_driver_qr_code_too_many_requests_error_response_body import (
        DriverQrCodesDeleteDriverQrCodeTooManyRequestsErrorResponseBody,
    )
    from .driver_qr_codes_delete_driver_qr_code_unauthorized_error_response_body import (
        DriverQrCodesDeleteDriverQrCodeUnauthorizedErrorResponseBody,
    )
    from .driver_qr_codes_get_drivers_qr_codes_bad_gateway_error_response_body import (
        DriverQrCodesGetDriversQrCodesBadGatewayErrorResponseBody,
    )
    from .driver_qr_codes_get_drivers_qr_codes_gateway_timeout_error_response_body import (
        DriverQrCodesGetDriversQrCodesGatewayTimeoutErrorResponseBody,
    )
    from .driver_qr_codes_get_drivers_qr_codes_internal_server_error_response_body import (
        DriverQrCodesGetDriversQrCodesInternalServerErrorResponseBody,
    )
    from .driver_qr_codes_get_drivers_qr_codes_method_not_allowed_error_response_body import (
        DriverQrCodesGetDriversQrCodesMethodNotAllowedErrorResponseBody,
    )
    from .driver_qr_codes_get_drivers_qr_codes_not_found_error_response_body import (
        DriverQrCodesGetDriversQrCodesNotFoundErrorResponseBody,
    )
    from .driver_qr_codes_get_drivers_qr_codes_not_implemented_error_response_body import (
        DriverQrCodesGetDriversQrCodesNotImplementedErrorResponseBody,
    )
    from .driver_qr_codes_get_drivers_qr_codes_response_body import DriverQrCodesGetDriversQrCodesResponseBody
    from .driver_qr_codes_get_drivers_qr_codes_service_unavailable_error_response_body import (
        DriverQrCodesGetDriversQrCodesServiceUnavailableErrorResponseBody,
    )
    from .driver_qr_codes_get_drivers_qr_codes_too_many_requests_error_response_body import (
        DriverQrCodesGetDriversQrCodesTooManyRequestsErrorResponseBody,
    )
    from .driver_qr_codes_get_drivers_qr_codes_unauthorized_error_response_body import (
        DriverQrCodesGetDriversQrCodesUnauthorizedErrorResponseBody,
    )
    from .driver_recorded_response_body import DriverRecordedResponseBody
    from .driver_remote_signout_post_driver_remote_signout_bad_gateway_error_response_body import (
        DriverRemoteSignoutPostDriverRemoteSignoutBadGatewayErrorResponseBody,
    )
    from .driver_remote_signout_post_driver_remote_signout_gateway_timeout_error_response_body import (
        DriverRemoteSignoutPostDriverRemoteSignoutGatewayTimeoutErrorResponseBody,
    )
    from .driver_remote_signout_post_driver_remote_signout_internal_server_error_response_body import (
        DriverRemoteSignoutPostDriverRemoteSignoutInternalServerErrorResponseBody,
    )
    from .driver_remote_signout_post_driver_remote_signout_method_not_allowed_error_response_body import (
        DriverRemoteSignoutPostDriverRemoteSignoutMethodNotAllowedErrorResponseBody,
    )
    from .driver_remote_signout_post_driver_remote_signout_not_found_error_response_body import (
        DriverRemoteSignoutPostDriverRemoteSignoutNotFoundErrorResponseBody,
    )
    from .driver_remote_signout_post_driver_remote_signout_not_implemented_error_response_body import (
        DriverRemoteSignoutPostDriverRemoteSignoutNotImplementedErrorResponseBody,
    )
    from .driver_remote_signout_post_driver_remote_signout_response_body import (
        DriverRemoteSignoutPostDriverRemoteSignoutResponseBody,
    )
    from .driver_remote_signout_post_driver_remote_signout_service_unavailable_error_response_body import (
        DriverRemoteSignoutPostDriverRemoteSignoutServiceUnavailableErrorResponseBody,
    )
    from .driver_remote_signout_post_driver_remote_signout_too_many_requests_error_response_body import (
        DriverRemoteSignoutPostDriverRemoteSignoutTooManyRequestsErrorResponseBody,
    )
    from .driver_remote_signout_post_driver_remote_signout_unauthorized_error_response_body import (
        DriverRemoteSignoutPostDriverRemoteSignoutUnauthorizedErrorResponseBody,
    )
    from .driver_response import DriverResponse
    from .driver_ruleset_object_response_body import DriverRulesetObjectResponseBody
    from .driver_ruleset_object_response_body_break import DriverRulesetObjectResponseBodyBreak
    from .driver_ruleset_object_response_body_cycle import DriverRulesetObjectResponseBodyCycle
    from .driver_ruleset_object_response_body_restart import DriverRulesetObjectResponseBodyRestart
    from .driver_ruleset_object_response_body_shift import DriverRulesetObjectResponseBodyShift
    from .driver_safety_score_response_body import DriverSafetyScoreResponseBody
    from .driver_static_assigned_vehicle import DriverStaticAssignedVehicle
    from .driver_tachograph_activity_data import DriverTachographActivityData
    from .driver_tachograph_activity_response import DriverTachographActivityResponse
    from .driver_tachograph_card_number import DriverTachographCardNumber
    from .driver_tags import DriverTags
    from .driver_timezone import DriverTimezone
    from .driver_tiny_response import DriverTinyResponse
    from .driver_updated_at_time import DriverUpdatedAtTime
    from .driver_username import DriverUsername
    from .driver_vehicle_assignment_v_2_object_response_body import DriverVehicleAssignmentV2ObjectResponseBody
    from .driver_vehicle_assignment_v_2_object_response_body_assignment_type import (
        DriverVehicleAssignmentV2ObjectResponseBodyAssignmentType,
    )
    from .driver_vehicle_assignments_v_2_create_driver_vehicle_assignment_bad_gateway_error_response_body import (
        DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentBadGatewayErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_create_driver_vehicle_assignment_gateway_timeout_error_response_body import (
        DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentGatewayTimeoutErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_create_driver_vehicle_assignment_internal_server_error_response_body import (
        DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentInternalServerErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_create_driver_vehicle_assignment_method_not_allowed_error_response_body import (
        DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentMethodNotAllowedErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_create_driver_vehicle_assignment_not_found_error_response_body import (
        DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentNotFoundErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_create_driver_vehicle_assignment_not_implemented_error_response_body import (
        DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentNotImplementedErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_create_driver_vehicle_assignment_response_body import (
        DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentResponseBody,
    )
    from .driver_vehicle_assignments_v_2_create_driver_vehicle_assignment_service_unavailable_error_response_body import (
        DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentServiceUnavailableErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_create_driver_vehicle_assignment_too_many_requests_error_response_body import (
        DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentTooManyRequestsErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_create_driver_vehicle_assignment_unauthorized_error_response_body import (
        DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentUnauthorizedErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_delete_driver_vehicle_assignments_bad_gateway_error_response_body import (
        DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsBadGatewayErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_delete_driver_vehicle_assignments_gateway_timeout_error_response_body import (
        DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsGatewayTimeoutErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_delete_driver_vehicle_assignments_internal_server_error_response_body import (
        DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsInternalServerErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_delete_driver_vehicle_assignments_method_not_allowed_error_response_body import (
        DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsMethodNotAllowedErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_delete_driver_vehicle_assignments_not_found_error_response_body import (
        DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsNotFoundErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_delete_driver_vehicle_assignments_not_implemented_error_response_body import (
        DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsNotImplementedErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_delete_driver_vehicle_assignments_service_unavailable_error_response_body import (
        DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsServiceUnavailableErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_delete_driver_vehicle_assignments_too_many_requests_error_response_body import (
        DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsTooManyRequestsErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_delete_driver_vehicle_assignments_unauthorized_error_response_body import (
        DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsUnauthorizedErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_get_driver_vehicle_assignments_bad_gateway_error_response_body import (
        DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsBadGatewayErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_get_driver_vehicle_assignments_gateway_timeout_error_response_body import (
        DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsGatewayTimeoutErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_get_driver_vehicle_assignments_internal_server_error_response_body import (
        DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsInternalServerErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_get_driver_vehicle_assignments_method_not_allowed_error_response_body import (
        DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsMethodNotAllowedErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_get_driver_vehicle_assignments_not_found_error_response_body import (
        DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsNotFoundErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_get_driver_vehicle_assignments_not_implemented_error_response_body import (
        DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsNotImplementedErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_get_driver_vehicle_assignments_response_body import (
        DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsResponseBody,
    )
    from .driver_vehicle_assignments_v_2_get_driver_vehicle_assignments_service_unavailable_error_response_body import (
        DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsServiceUnavailableErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_get_driver_vehicle_assignments_too_many_requests_error_response_body import (
        DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsTooManyRequestsErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_get_driver_vehicle_assignments_unauthorized_error_response_body import (
        DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsUnauthorizedErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_update_driver_vehicle_assignment_bad_gateway_error_response_body import (
        DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentBadGatewayErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_update_driver_vehicle_assignment_gateway_timeout_error_response_body import (
        DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentGatewayTimeoutErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_update_driver_vehicle_assignment_internal_server_error_response_body import (
        DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentInternalServerErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_update_driver_vehicle_assignment_method_not_allowed_error_response_body import (
        DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentMethodNotAllowedErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_update_driver_vehicle_assignment_not_found_error_response_body import (
        DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentNotFoundErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_update_driver_vehicle_assignment_not_implemented_error_response_body import (
        DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentNotImplementedErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_update_driver_vehicle_assignment_response_body import (
        DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentResponseBody,
    )
    from .driver_vehicle_assignments_v_2_update_driver_vehicle_assignment_service_unavailable_error_response_body import (
        DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentServiceUnavailableErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_update_driver_vehicle_assignment_too_many_requests_error_response_body import (
        DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentTooManyRequestsErrorResponseBody,
    )
    from .driver_vehicle_assignments_v_2_update_driver_vehicle_assignment_unauthorized_error_response_body import (
        DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentUnauthorizedErrorResponseBody,
    )
    from .driver_vehicle_group_tag import DriverVehicleGroupTag
    from .driver_waiting_time_duty_status_enabled import DriverWaitingTimeDutyStatusEnabled
    from .driver_with_external_id_object_response_body import DriverWithExternalIdObjectResponseBody
    from .driver_with_timezone_eld_settings_object_response_body import DriverWithTimezoneEldSettingsObjectResponseBody
    from .drivers_auth_token_create_driver_auth_token_bad_gateway_error_response_body import (
        DriversAuthTokenCreateDriverAuthTokenBadGatewayErrorResponseBody,
    )
    from .drivers_auth_token_create_driver_auth_token_gateway_timeout_error_response_body import (
        DriversAuthTokenCreateDriverAuthTokenGatewayTimeoutErrorResponseBody,
    )
    from .drivers_auth_token_create_driver_auth_token_internal_server_error_response_body import (
        DriversAuthTokenCreateDriverAuthTokenInternalServerErrorResponseBody,
    )
    from .drivers_auth_token_create_driver_auth_token_method_not_allowed_error_response_body import (
        DriversAuthTokenCreateDriverAuthTokenMethodNotAllowedErrorResponseBody,
    )
    from .drivers_auth_token_create_driver_auth_token_not_found_error_response_body import (
        DriversAuthTokenCreateDriverAuthTokenNotFoundErrorResponseBody,
    )
    from .drivers_auth_token_create_driver_auth_token_not_implemented_error_response_body import (
        DriversAuthTokenCreateDriverAuthTokenNotImplementedErrorResponseBody,
    )
    from .drivers_auth_token_create_driver_auth_token_response_body import (
        DriversAuthTokenCreateDriverAuthTokenResponseBody,
    )
    from .drivers_auth_token_create_driver_auth_token_service_unavailable_error_response_body import (
        DriversAuthTokenCreateDriverAuthTokenServiceUnavailableErrorResponseBody,
    )
    from .drivers_auth_token_create_driver_auth_token_too_many_requests_error_response_body import (
        DriversAuthTokenCreateDriverAuthTokenTooManyRequestsErrorResponseBody,
    )
    from .drivers_auth_token_create_driver_auth_token_unauthorized_error_response_body import (
        DriversAuthTokenCreateDriverAuthTokenUnauthorizedErrorResponseBody,
    )
    from .drivers_vehicle_assignments_get_drivers_vehicle_assignments_bad_gateway_error_response_body import (
        DriversVehicleAssignmentsGetDriversVehicleAssignmentsBadGatewayErrorResponseBody,
    )
    from .drivers_vehicle_assignments_get_drivers_vehicle_assignments_gateway_timeout_error_response_body import (
        DriversVehicleAssignmentsGetDriversVehicleAssignmentsGatewayTimeoutErrorResponseBody,
    )
    from .drivers_vehicle_assignments_get_drivers_vehicle_assignments_internal_server_error_response_body import (
        DriversVehicleAssignmentsGetDriversVehicleAssignmentsInternalServerErrorResponseBody,
    )
    from .drivers_vehicle_assignments_get_drivers_vehicle_assignments_method_not_allowed_error_response_body import (
        DriversVehicleAssignmentsGetDriversVehicleAssignmentsMethodNotAllowedErrorResponseBody,
    )
    from .drivers_vehicle_assignments_get_drivers_vehicle_assignments_not_found_error_response_body import (
        DriversVehicleAssignmentsGetDriversVehicleAssignmentsNotFoundErrorResponseBody,
    )
    from .drivers_vehicle_assignments_get_drivers_vehicle_assignments_not_implemented_error_response_body import (
        DriversVehicleAssignmentsGetDriversVehicleAssignmentsNotImplementedErrorResponseBody,
    )
    from .drivers_vehicle_assignments_get_drivers_vehicle_assignments_response_body import (
        DriversVehicleAssignmentsGetDriversVehicleAssignmentsResponseBody,
    )
    from .drivers_vehicle_assignments_get_drivers_vehicle_assignments_service_unavailable_error_response_body import (
        DriversVehicleAssignmentsGetDriversVehicleAssignmentsServiceUnavailableErrorResponseBody,
    )
    from .drivers_vehicle_assignments_get_drivers_vehicle_assignments_too_many_requests_error_response_body import (
        DriversVehicleAssignmentsGetDriversVehicleAssignmentsTooManyRequestsErrorResponseBody,
    )
    from .drivers_vehicle_assignments_get_drivers_vehicle_assignments_unauthorized_error_response_body import (
        DriversVehicleAssignmentsGetDriversVehicleAssignmentsUnauthorizedErrorResponseBody,
    )
    from .drivers_vehicle_assignments_object_response_body import DriversVehicleAssignmentsObjectResponseBody
    from .drivers_vehicle_assignments_object_response_body_driver_activation_status import (
        DriversVehicleAssignmentsObjectResponseBodyDriverActivationStatus,
    )
    from .duty_status_duration_object_response_body import DutyStatusDurationObjectResponseBody
    from .dvir import Dvir
    from .dvir_2_assigned_to_polymorphic_user_object_response_body import (
        Dvir2AssignedToPolymorphicUserObjectResponseBody,
    )
    from .dvir_2_device_object_response_body import Dvir2DeviceObjectResponseBody
    from .dvir_2_form_submission_object_response_body import Dvir2FormSubmissionObjectResponseBody
    from .dvir_2_related_device_object_response_body import Dvir2RelatedDeviceObjectResponseBody
    from .dvir_2_related_device_object_response_body_asset_type import Dvir2RelatedDeviceObjectResponseBodyAssetType
    from .dvir_2_submission_response_object_response_body import Dvir2SubmissionResponseObjectResponseBody
    from .dvir_2_submission_response_object_response_body_inspection_type import (
        Dvir2SubmissionResponseObjectResponseBodyInspectionType,
    )
    from .dvir_author_signature import DvirAuthorSignature
    from .dvir_defect_get_defect_bad_gateway_error_response_body import DvirDefectGetDefectBadGatewayErrorResponseBody
    from .dvir_defect_get_defect_gateway_timeout_error_response_body import (
        DvirDefectGetDefectGatewayTimeoutErrorResponseBody,
    )
    from .dvir_defect_get_defect_internal_server_error_response_body import (
        DvirDefectGetDefectInternalServerErrorResponseBody,
    )
    from .dvir_defect_get_defect_method_not_allowed_error_response_body import (
        DvirDefectGetDefectMethodNotAllowedErrorResponseBody,
    )
    from .dvir_defect_get_defect_not_found_error_response_body import DvirDefectGetDefectNotFoundErrorResponseBody
    from .dvir_defect_get_defect_not_implemented_error_response_body import (
        DvirDefectGetDefectNotImplementedErrorResponseBody,
    )
    from .dvir_defect_get_defect_response_body import DvirDefectGetDefectResponseBody
    from .dvir_defect_get_defect_service_unavailable_error_response_body import (
        DvirDefectGetDefectServiceUnavailableErrorResponseBody,
    )
    from .dvir_defect_get_defect_too_many_requests_error_response_body import (
        DvirDefectGetDefectTooManyRequestsErrorResponseBody,
    )
    from .dvir_defect_get_defect_unauthorized_error_response_body import (
        DvirDefectGetDefectUnauthorizedErrorResponseBody,
    )
    from .dvir_defect_stream_defects_bad_gateway_error_response_body import (
        DvirDefectStreamDefectsBadGatewayErrorResponseBody,
    )
    from .dvir_defect_stream_defects_gateway_timeout_error_response_body import (
        DvirDefectStreamDefectsGatewayTimeoutErrorResponseBody,
    )
    from .dvir_defect_stream_defects_internal_server_error_response_body import (
        DvirDefectStreamDefectsInternalServerErrorResponseBody,
    )
    from .dvir_defect_stream_defects_method_not_allowed_error_response_body import (
        DvirDefectStreamDefectsMethodNotAllowedErrorResponseBody,
    )
    from .dvir_defect_stream_defects_not_found_error_response_body import (
        DvirDefectStreamDefectsNotFoundErrorResponseBody,
    )
    from .dvir_defect_stream_defects_not_implemented_error_response_body import (
        DvirDefectStreamDefectsNotImplementedErrorResponseBody,
    )
    from .dvir_defect_stream_defects_response_body import DvirDefectStreamDefectsResponseBody
    from .dvir_defect_stream_defects_service_unavailable_error_response_body import (
        DvirDefectStreamDefectsServiceUnavailableErrorResponseBody,
    )
    from .dvir_defect_stream_defects_too_many_requests_error_response_body import (
        DvirDefectStreamDefectsTooManyRequestsErrorResponseBody,
    )
    from .dvir_defect_stream_defects_unauthorized_error_response_body import (
        DvirDefectStreamDefectsUnauthorizedErrorResponseBody,
    )
    from .dvir_defect_type_get_defect_types_bad_gateway_error_response_body import (
        DvirDefectTypeGetDefectTypesBadGatewayErrorResponseBody,
    )
    from .dvir_defect_type_get_defect_types_gateway_timeout_error_response_body import (
        DvirDefectTypeGetDefectTypesGatewayTimeoutErrorResponseBody,
    )
    from .dvir_defect_type_get_defect_types_internal_server_error_response_body import (
        DvirDefectTypeGetDefectTypesInternalServerErrorResponseBody,
    )
    from .dvir_defect_type_get_defect_types_method_not_allowed_error_response_body import (
        DvirDefectTypeGetDefectTypesMethodNotAllowedErrorResponseBody,
    )
    from .dvir_defect_type_get_defect_types_not_found_error_response_body import (
        DvirDefectTypeGetDefectTypesNotFoundErrorResponseBody,
    )
    from .dvir_defect_type_get_defect_types_not_implemented_error_response_body import (
        DvirDefectTypeGetDefectTypesNotImplementedErrorResponseBody,
    )
    from .dvir_defect_type_get_defect_types_response_body import DvirDefectTypeGetDefectTypesResponseBody
    from .dvir_defect_type_get_defect_types_service_unavailable_error_response_body import (
        DvirDefectTypeGetDefectTypesServiceUnavailableErrorResponseBody,
    )
    from .dvir_defect_type_get_defect_types_too_many_requests_error_response_body import (
        DvirDefectTypeGetDefectTypesTooManyRequestsErrorResponseBody,
    )
    from .dvir_defect_type_get_defect_types_unauthorized_error_response_body import (
        DvirDefectTypeGetDefectTypesUnauthorizedErrorResponseBody,
    )
    from .dvir_defects_object_v_20220913_response_body import DvirDefectsObjectV20220913ResponseBody
    from .dvir_get_dvir_bad_gateway_error_response_body import DvirGetDvirBadGatewayErrorResponseBody
    from .dvir_get_dvir_gateway_timeout_error_response_body import DvirGetDvirGatewayTimeoutErrorResponseBody
    from .dvir_get_dvir_internal_server_error_response_body import DvirGetDvirInternalServerErrorResponseBody
    from .dvir_get_dvir_method_not_allowed_error_response_body import DvirGetDvirMethodNotAllowedErrorResponseBody
    from .dvir_get_dvir_not_found_error_response_body import DvirGetDvirNotFoundErrorResponseBody
    from .dvir_get_dvir_not_implemented_error_response_body import DvirGetDvirNotImplementedErrorResponseBody
    from .dvir_get_dvir_response_body import DvirGetDvirResponseBody
    from .dvir_get_dvir_response_body_safety_status import DvirGetDvirResponseBodySafetyStatus
    from .dvir_get_dvir_response_body_type import DvirGetDvirResponseBodyType
    from .dvir_get_dvir_service_unavailable_error_response_body import DvirGetDvirServiceUnavailableErrorResponseBody
    from .dvir_get_dvir_too_many_requests_error_response_body import DvirGetDvirTooManyRequestsErrorResponseBody
    from .dvir_get_dvir_unauthorized_error_response_body import DvirGetDvirUnauthorizedErrorResponseBody
    from .dvir_get_dvirs_bad_gateway_error_response_body import DvirGetDvirsBadGatewayErrorResponseBody
    from .dvir_get_dvirs_gateway_timeout_error_response_body import DvirGetDvirsGatewayTimeoutErrorResponseBody
    from .dvir_get_dvirs_internal_server_error_response_body import DvirGetDvirsInternalServerErrorResponseBody
    from .dvir_get_dvirs_method_not_allowed_error_response_body import DvirGetDvirsMethodNotAllowedErrorResponseBody
    from .dvir_get_dvirs_not_found_error_response_body import DvirGetDvirsNotFoundErrorResponseBody
    from .dvir_get_dvirs_not_implemented_error_response_body import DvirGetDvirsNotImplementedErrorResponseBody
    from .dvir_get_dvirs_response_body import DvirGetDvirsResponseBody
    from .dvir_get_dvirs_service_unavailable_error_response_body import DvirGetDvirsServiceUnavailableErrorResponseBody
    from .dvir_get_dvirs_too_many_requests_error_response_body import DvirGetDvirsTooManyRequestsErrorResponseBody
    from .dvir_get_dvirs_unauthorized_error_response_body import DvirGetDvirsUnauthorizedErrorResponseBody
    from .dvir_license_plate import DvirLicensePlate
    from .dvir_location import DvirLocation
    from .dvir_mechanic_notes import DvirMechanicNotes
    from .dvir_odometer_meters import DvirOdometerMeters
    from .dvir_resolved_by_object_response_body import DvirResolvedByObjectResponseBody
    from .dvir_resolved_by_object_response_body_type import DvirResolvedByObjectResponseBodyType
    from .dvir_response import DvirResponse
    from .dvir_safety_status import DvirSafetyStatus
    from .dvir_second_signature import DvirSecondSignature
    from .dvir_signature import DvirSignature
    from .dvir_signature_signatory_user import DvirSignatureSignatoryUser
    from .dvir_signature_type import DvirSignatureType
    from .dvir_stream_response_data_response_body import DvirStreamResponseDataResponseBody
    from .dvir_stream_response_data_response_body_safety_status import DvirStreamResponseDataResponseBodySafetyStatus
    from .dvir_stream_response_data_response_body_type import DvirStreamResponseDataResponseBodyType
    from .dvir_submitted_device_trigger_details_object_request_body import (
        DvirSubmittedDeviceTriggerDetailsObjectRequestBody,
    )
    from .dvir_submitted_device_trigger_details_object_request_body_dvir_submission_types_item import (
        DvirSubmittedDeviceTriggerDetailsObjectRequestBodyDvirSubmissionTypesItem,
    )
    from .dvir_submitted_device_trigger_details_object_response_body import (
        DvirSubmittedDeviceTriggerDetailsObjectResponseBody,
    )
    from .dvir_submitted_device_trigger_details_object_response_body_dvir_submission_types_item import (
        DvirSubmittedDeviceTriggerDetailsObjectResponseBodyDvirSubmissionTypesItem,
    )
    from .dvir_third_signature import DvirThirdSignature
    from .dvir_trailer import DvirTrailer
    from .dvir_trailer_defects import DvirTrailerDefects
    from .dvir_trailer_defects_items import DvirTrailerDefectsItems
    from .dvir_trailer_defects_items_trailer import DvirTrailerDefectsItemsTrailer
    from .dvir_trailer_defects_items_vehicle import DvirTrailerDefectsItemsVehicle
    from .dvir_type import DvirType
    from .dvir_vehicle import DvirVehicle
    from .dvir_vehicle_defects import DvirVehicleDefects
    from .dvirs_list_response import DvirsListResponse
    from .eld_settings_object_response_body import EldSettingsObjectResponseBody
    from .engine_idle_data_response_body import EngineIdleDataResponseBody
    from .engine_idle_trigger_details_object_request_body import EngineIdleTriggerDetailsObjectRequestBody
    from .engine_idle_trigger_details_object_response_body import EngineIdleTriggerDetailsObjectResponseBody
    from .engine_immobilizer_get_engine_immobilizer_states_bad_gateway_error_response_body import (
        EngineImmobilizerGetEngineImmobilizerStatesBadGatewayErrorResponseBody,
    )
    from .engine_immobilizer_get_engine_immobilizer_states_gateway_timeout_error_response_body import (
        EngineImmobilizerGetEngineImmobilizerStatesGatewayTimeoutErrorResponseBody,
    )
    from .engine_immobilizer_get_engine_immobilizer_states_internal_server_error_response_body import (
        EngineImmobilizerGetEngineImmobilizerStatesInternalServerErrorResponseBody,
    )
    from .engine_immobilizer_get_engine_immobilizer_states_method_not_allowed_error_response_body import (
        EngineImmobilizerGetEngineImmobilizerStatesMethodNotAllowedErrorResponseBody,
    )
    from .engine_immobilizer_get_engine_immobilizer_states_not_found_error_response_body import (
        EngineImmobilizerGetEngineImmobilizerStatesNotFoundErrorResponseBody,
    )
    from .engine_immobilizer_get_engine_immobilizer_states_not_implemented_error_response_body import (
        EngineImmobilizerGetEngineImmobilizerStatesNotImplementedErrorResponseBody,
    )
    from .engine_immobilizer_get_engine_immobilizer_states_response_body import (
        EngineImmobilizerGetEngineImmobilizerStatesResponseBody,
    )
    from .engine_immobilizer_get_engine_immobilizer_states_service_unavailable_error_response_body import (
        EngineImmobilizerGetEngineImmobilizerStatesServiceUnavailableErrorResponseBody,
    )
    from .engine_immobilizer_get_engine_immobilizer_states_too_many_requests_error_response_body import (
        EngineImmobilizerGetEngineImmobilizerStatesTooManyRequestsErrorResponseBody,
    )
    from .engine_immobilizer_get_engine_immobilizer_states_unauthorized_error_response_body import (
        EngineImmobilizerGetEngineImmobilizerStatesUnauthorizedErrorResponseBody,
    )
    from .engine_immobilizer_relay_state_response_body import EngineImmobilizerRelayStateResponseBody
    from .engine_immobilizer_relay_state_response_body_id import EngineImmobilizerRelayStateResponseBodyId
    from .engine_immobilizer_state_response_body import EngineImmobilizerStateResponseBody
    from .engine_immobilizer_update_engine_immobilizer_state_bad_gateway_error_response_body import (
        EngineImmobilizerUpdateEngineImmobilizerStateBadGatewayErrorResponseBody,
    )
    from .engine_immobilizer_update_engine_immobilizer_state_gateway_timeout_error_response_body import (
        EngineImmobilizerUpdateEngineImmobilizerStateGatewayTimeoutErrorResponseBody,
    )
    from .engine_immobilizer_update_engine_immobilizer_state_internal_server_error_response_body import (
        EngineImmobilizerUpdateEngineImmobilizerStateInternalServerErrorResponseBody,
    )
    from .engine_immobilizer_update_engine_immobilizer_state_method_not_allowed_error_response_body import (
        EngineImmobilizerUpdateEngineImmobilizerStateMethodNotAllowedErrorResponseBody,
    )
    from .engine_immobilizer_update_engine_immobilizer_state_not_found_error_response_body import (
        EngineImmobilizerUpdateEngineImmobilizerStateNotFoundErrorResponseBody,
    )
    from .engine_immobilizer_update_engine_immobilizer_state_not_implemented_error_response_body import (
        EngineImmobilizerUpdateEngineImmobilizerStateNotImplementedErrorResponseBody,
    )
    from .engine_immobilizer_update_engine_immobilizer_state_service_unavailable_error_response_body import (
        EngineImmobilizerUpdateEngineImmobilizerStateServiceUnavailableErrorResponseBody,
    )
    from .engine_immobilizer_update_engine_immobilizer_state_too_many_requests_error_response_body import (
        EngineImmobilizerUpdateEngineImmobilizerStateTooManyRequestsErrorResponseBody,
    )
    from .engine_immobilizer_update_engine_immobilizer_state_unauthorized_error_response_body import (
        EngineImmobilizerUpdateEngineImmobilizerStateUnauthorizedErrorResponseBody,
    )
    from .engine_off_details_object_request_body import EngineOffDetailsObjectRequestBody
    from .engine_off_details_object_response_body import EngineOffDetailsObjectResponseBody
    from .engine_off_response_body import EngineOffResponseBody
    from .engine_on_details_object_request_body import EngineOnDetailsObjectRequestBody
    from .engine_on_details_object_response_body import EngineOnDetailsObjectResponseBody
    from .engine_on_response_body import EngineOnResponseBody
    from .engine_status_response_body import EngineStatusResponseBody
    from .enum_reading_alert_threshold_response_body import EnumReadingAlertThresholdResponseBody
    from .enum_value_response_body import EnumValueResponseBody
    from .equipment_engine_rpm import EquipmentEngineRpm
    from .equipment_engine_seconds import EquipmentEngineSeconds
    from .equipment_engine_state import EquipmentEngineState
    from .equipment_engine_state_value import EquipmentEngineStateValue
    from .equipment_engine_total_idle_time_minutes import EquipmentEngineTotalIdleTimeMinutes
    from .equipment_fuel_percent import EquipmentFuelPercent
    from .equipment_gateway_engine_seconds import EquipmentGatewayEngineSeconds
    from .equipment_gateway_engine_state import EquipmentGatewayEngineState
    from .equipment_gateway_engine_state_value import EquipmentGatewayEngineStateValue
    from .equipment_gateway_j_1939_engine_seconds import EquipmentGatewayJ1939EngineSeconds
    from .equipment_gps_odometer_meters import EquipmentGpsOdometerMeters
    from .equipment_header_with_additional_fields_response_body import EquipmentHeaderWithAdditionalFieldsResponseBody
    from .equipment_id import EquipmentId
    from .equipment_installed_gateway import EquipmentInstalledGateway
    from .equipment_list_response import EquipmentListResponse
    from .equipment_location import EquipmentLocation
    from .equipment_locations_list_response import EquipmentLocationsListResponse
    from .equipment_locations_list_response_data import EquipmentLocationsListResponseData
    from .equipment_locations_response import EquipmentLocationsResponse
    from .equipment_locations_response_data import EquipmentLocationsResponseData
    from .equipment_name import EquipmentName
    from .equipment_obd_engine_seconds import EquipmentObdEngineSeconds
    from .equipment_obd_engine_state import EquipmentObdEngineState
    from .equipment_obd_engine_state_value import EquipmentObdEngineStateValue
    from .equipment_object import EquipmentObject
    from .equipment_patch_equipment_bad_gateway_error_response_body import (
        EquipmentPatchEquipmentBadGatewayErrorResponseBody,
    )
    from .equipment_patch_equipment_gateway_timeout_error_response_body import (
        EquipmentPatchEquipmentGatewayTimeoutErrorResponseBody,
    )
    from .equipment_patch_equipment_internal_server_error_response_body import (
        EquipmentPatchEquipmentInternalServerErrorResponseBody,
    )
    from .equipment_patch_equipment_method_not_allowed_error_response_body import (
        EquipmentPatchEquipmentMethodNotAllowedErrorResponseBody,
    )
    from .equipment_patch_equipment_not_found_error_response_body import (
        EquipmentPatchEquipmentNotFoundErrorResponseBody,
    )
    from .equipment_patch_equipment_not_implemented_error_response_body import (
        EquipmentPatchEquipmentNotImplementedErrorResponseBody,
    )
    from .equipment_patch_equipment_response_body import EquipmentPatchEquipmentResponseBody
    from .equipment_patch_equipment_service_unavailable_error_response_body import (
        EquipmentPatchEquipmentServiceUnavailableErrorResponseBody,
    )
    from .equipment_patch_equipment_too_many_requests_error_response_body import (
        EquipmentPatchEquipmentTooManyRequestsErrorResponseBody,
    )
    from .equipment_patch_equipment_unauthorized_error_response_body import (
        EquipmentPatchEquipmentUnauthorizedErrorResponseBody,
    )
    from .equipment_response import EquipmentResponse
    from .equipment_stats_gps import EquipmentStatsGps
    from .equipment_stats_list_response import EquipmentStatsListResponse
    from .equipment_stats_list_response_data import EquipmentStatsListResponseData
    from .equipment_stats_response import EquipmentStatsResponse
    from .equipment_stats_response_data import EquipmentStatsResponseData
    from .equipment_time import EquipmentTime
    from .equipment_with_attributes_response_object_response_body import (
        EquipmentWithAttributesResponseObjectResponseBody,
    )
    from .event_location_response_body import EventLocationResponseBody
    from .extended_driver_tiny_response import ExtendedDriverTinyResponse
    from .extended_driver_tiny_response_external_ids import ExtendedDriverTinyResponseExternalIds
    from .fft_spectra_data_point import FftSpectraDataPoint
    from .fft_spectra_data_point_fft_spectra import FftSpectraDataPointFftSpectra
    from .field_object_post_request_body import FieldObjectPostRequestBody
    from .field_object_post_request_body_type import FieldObjectPostRequestBodyType
    from .field_object_response_body import FieldObjectResponseBody
    from .field_object_response_body_type import FieldObjectResponseBodyType
    from .field_object_value_request_body import FieldObjectValueRequestBody
    from .field_object_value_response_body import FieldObjectValueResponseBody
    from .field_types_object_response_body import FieldTypesObjectResponseBody
    from .field_types_object_response_body_field_type import FieldTypesObjectResponseBodyFieldType
    from .filters_request_body import FiltersRequestBody
    from .filters_response_body import FiltersResponseBody
    from .fleet_device_object_response_body import FleetDeviceObjectResponseBody
    from .following_distance_detection_alert_settings_object_response_body import (
        FollowingDistanceDetectionAlertSettingsObjectResponseBody,
    )
    from .form_submission_pdf_export_response_object_response_body import (
        FormSubmissionPdfExportResponseObjectResponseBody,
    )
    from .form_submission_pdf_export_response_object_response_body_job_status import (
        FormSubmissionPdfExportResponseObjectResponseBodyJobStatus,
    )
    from .form_submission_request_approval_details_request_body import FormSubmissionRequestApprovalDetailsRequestBody
    from .form_submission_request_asset_object_request_body import FormSubmissionRequestAssetObjectRequestBody
    from .form_submission_request_asset_value_object_request_body import (
        FormSubmissionRequestAssetValueObjectRequestBody,
    )
    from .form_submission_request_assigned_to_request_body import FormSubmissionRequestAssignedToRequestBody
    from .form_submission_request_assigned_to_request_body_type import FormSubmissionRequestAssignedToRequestBodyType
    from .form_submission_request_check_boxes_value_object_request_body import (
        FormSubmissionRequestCheckBoxesValueObjectRequestBody,
    )
    from .form_submission_request_date_time_value_object_request_body import (
        FormSubmissionRequestDateTimeValueObjectRequestBody,
    )
    from .form_submission_request_field_input_object_request_body import (
        FormSubmissionRequestFieldInputObjectRequestBody,
    )
    from .form_submission_request_field_input_object_request_body_type import (
        FormSubmissionRequestFieldInputObjectRequestBodyType,
    )
    from .form_submission_request_geofence_object_request_body import FormSubmissionRequestGeofenceObjectRequestBody
    from .form_submission_request_geofence_value_object_request_body import (
        FormSubmissionRequestGeofenceValueObjectRequestBody,
    )
    from .form_submission_request_media_item_object_request_body import FormSubmissionRequestMediaItemObjectRequestBody
    from .form_submission_request_media_value_object_request_body import (
        FormSubmissionRequestMediaValueObjectRequestBody,
    )
    from .form_submission_request_multiple_choice_value_object_request_body import (
        FormSubmissionRequestMultipleChoiceValueObjectRequestBody,
    )
    from .form_submission_request_number_value_object_request_body import (
        FormSubmissionRequestNumberValueObjectRequestBody,
    )
    from .form_submission_request_person_object_request_body import FormSubmissionRequestPersonObjectRequestBody
    from .form_submission_request_person_value_object_request_body import (
        FormSubmissionRequestPersonValueObjectRequestBody,
    )
    from .form_submission_request_signature_value_object_request_body import (
        FormSubmissionRequestSignatureValueObjectRequestBody,
    )
    from .form_submission_request_table_cell_object_request_body import FormSubmissionRequestTableCellObjectRequestBody
    from .form_submission_request_table_cell_object_request_body_type import (
        FormSubmissionRequestTableCellObjectRequestBodyType,
    )
    from .form_submission_request_table_row_object_request_body import FormSubmissionRequestTableRowObjectRequestBody
    from .form_submission_request_table_value_object_request_body import (
        FormSubmissionRequestTableValueObjectRequestBody,
    )
    from .form_submission_request_text_value_object_request_body import FormSubmissionRequestTextValueObjectRequestBody
    from .form_submission_response_object_response_body import FormSubmissionResponseObjectResponseBody
    from .form_submission_response_object_response_body_status import FormSubmissionResponseObjectResponseBodyStatus
    from .form_submissions_get_form_submissions_bad_gateway_error_response_body import (
        FormSubmissionsGetFormSubmissionsBadGatewayErrorResponseBody,
    )
    from .form_submissions_get_form_submissions_gateway_timeout_error_response_body import (
        FormSubmissionsGetFormSubmissionsGatewayTimeoutErrorResponseBody,
    )
    from .form_submissions_get_form_submissions_internal_server_error_response_body import (
        FormSubmissionsGetFormSubmissionsInternalServerErrorResponseBody,
    )
    from .form_submissions_get_form_submissions_method_not_allowed_error_response_body import (
        FormSubmissionsGetFormSubmissionsMethodNotAllowedErrorResponseBody,
    )
    from .form_submissions_get_form_submissions_not_found_error_response_body import (
        FormSubmissionsGetFormSubmissionsNotFoundErrorResponseBody,
    )
    from .form_submissions_get_form_submissions_not_implemented_error_response_body import (
        FormSubmissionsGetFormSubmissionsNotImplementedErrorResponseBody,
    )
    from .form_submissions_get_form_submissions_pdf_exports_bad_gateway_error_response_body import (
        FormSubmissionsGetFormSubmissionsPdfExportsBadGatewayErrorResponseBody,
    )
    from .form_submissions_get_form_submissions_pdf_exports_gateway_timeout_error_response_body import (
        FormSubmissionsGetFormSubmissionsPdfExportsGatewayTimeoutErrorResponseBody,
    )
    from .form_submissions_get_form_submissions_pdf_exports_internal_server_error_response_body import (
        FormSubmissionsGetFormSubmissionsPdfExportsInternalServerErrorResponseBody,
    )
    from .form_submissions_get_form_submissions_pdf_exports_method_not_allowed_error_response_body import (
        FormSubmissionsGetFormSubmissionsPdfExportsMethodNotAllowedErrorResponseBody,
    )
    from .form_submissions_get_form_submissions_pdf_exports_not_found_error_response_body import (
        FormSubmissionsGetFormSubmissionsPdfExportsNotFoundErrorResponseBody,
    )
    from .form_submissions_get_form_submissions_pdf_exports_not_implemented_error_response_body import (
        FormSubmissionsGetFormSubmissionsPdfExportsNotImplementedErrorResponseBody,
    )
    from .form_submissions_get_form_submissions_pdf_exports_response_body import (
        FormSubmissionsGetFormSubmissionsPdfExportsResponseBody,
    )
    from .form_submissions_get_form_submissions_pdf_exports_service_unavailable_error_response_body import (
        FormSubmissionsGetFormSubmissionsPdfExportsServiceUnavailableErrorResponseBody,
    )
    from .form_submissions_get_form_submissions_pdf_exports_too_many_requests_error_response_body import (
        FormSubmissionsGetFormSubmissionsPdfExportsTooManyRequestsErrorResponseBody,
    )
    from .form_submissions_get_form_submissions_pdf_exports_unauthorized_error_response_body import (
        FormSubmissionsGetFormSubmissionsPdfExportsUnauthorizedErrorResponseBody,
    )
    from .form_submissions_get_form_submissions_response_body import FormSubmissionsGetFormSubmissionsResponseBody
    from .form_submissions_get_form_submissions_service_unavailable_error_response_body import (
        FormSubmissionsGetFormSubmissionsServiceUnavailableErrorResponseBody,
    )
    from .form_submissions_get_form_submissions_stream_bad_gateway_error_response_body import (
        FormSubmissionsGetFormSubmissionsStreamBadGatewayErrorResponseBody,
    )
    from .form_submissions_get_form_submissions_stream_gateway_timeout_error_response_body import (
        FormSubmissionsGetFormSubmissionsStreamGatewayTimeoutErrorResponseBody,
    )
    from .form_submissions_get_form_submissions_stream_internal_server_error_response_body import (
        FormSubmissionsGetFormSubmissionsStreamInternalServerErrorResponseBody,
    )
    from .form_submissions_get_form_submissions_stream_method_not_allowed_error_response_body import (
        FormSubmissionsGetFormSubmissionsStreamMethodNotAllowedErrorResponseBody,
    )
    from .form_submissions_get_form_submissions_stream_not_found_error_response_body import (
        FormSubmissionsGetFormSubmissionsStreamNotFoundErrorResponseBody,
    )
    from .form_submissions_get_form_submissions_stream_not_implemented_error_response_body import (
        FormSubmissionsGetFormSubmissionsStreamNotImplementedErrorResponseBody,
    )
    from .form_submissions_get_form_submissions_stream_response_body import (
        FormSubmissionsGetFormSubmissionsStreamResponseBody,
    )
    from .form_submissions_get_form_submissions_stream_service_unavailable_error_response_body import (
        FormSubmissionsGetFormSubmissionsStreamServiceUnavailableErrorResponseBody,
    )
    from .form_submissions_get_form_submissions_stream_too_many_requests_error_response_body import (
        FormSubmissionsGetFormSubmissionsStreamTooManyRequestsErrorResponseBody,
    )
    from .form_submissions_get_form_submissions_stream_unauthorized_error_response_body import (
        FormSubmissionsGetFormSubmissionsStreamUnauthorizedErrorResponseBody,
    )
    from .form_submissions_get_form_submissions_too_many_requests_error_response_body import (
        FormSubmissionsGetFormSubmissionsTooManyRequestsErrorResponseBody,
    )
    from .form_submissions_get_form_submissions_unauthorized_error_response_body import (
        FormSubmissionsGetFormSubmissionsUnauthorizedErrorResponseBody,
    )
    from .form_submissions_patch_form_submission_bad_gateway_error_response_body import (
        FormSubmissionsPatchFormSubmissionBadGatewayErrorResponseBody,
    )
    from .form_submissions_patch_form_submission_gateway_timeout_error_response_body import (
        FormSubmissionsPatchFormSubmissionGatewayTimeoutErrorResponseBody,
    )
    from .form_submissions_patch_form_submission_internal_server_error_response_body import (
        FormSubmissionsPatchFormSubmissionInternalServerErrorResponseBody,
    )
    from .form_submissions_patch_form_submission_method_not_allowed_error_response_body import (
        FormSubmissionsPatchFormSubmissionMethodNotAllowedErrorResponseBody,
    )
    from .form_submissions_patch_form_submission_not_found_error_response_body import (
        FormSubmissionsPatchFormSubmissionNotFoundErrorResponseBody,
    )
    from .form_submissions_patch_form_submission_not_implemented_error_response_body import (
        FormSubmissionsPatchFormSubmissionNotImplementedErrorResponseBody,
    )
    from .form_submissions_patch_form_submission_response_body import FormSubmissionsPatchFormSubmissionResponseBody
    from .form_submissions_patch_form_submission_service_unavailable_error_response_body import (
        FormSubmissionsPatchFormSubmissionServiceUnavailableErrorResponseBody,
    )
    from .form_submissions_patch_form_submission_too_many_requests_error_response_body import (
        FormSubmissionsPatchFormSubmissionTooManyRequestsErrorResponseBody,
    )
    from .form_submissions_patch_form_submission_unauthorized_error_response_body import (
        FormSubmissionsPatchFormSubmissionUnauthorizedErrorResponseBody,
    )
    from .form_submissions_post_form_submission_bad_gateway_error_response_body import (
        FormSubmissionsPostFormSubmissionBadGatewayErrorResponseBody,
    )
    from .form_submissions_post_form_submission_gateway_timeout_error_response_body import (
        FormSubmissionsPostFormSubmissionGatewayTimeoutErrorResponseBody,
    )
    from .form_submissions_post_form_submission_internal_server_error_response_body import (
        FormSubmissionsPostFormSubmissionInternalServerErrorResponseBody,
    )
    from .form_submissions_post_form_submission_method_not_allowed_error_response_body import (
        FormSubmissionsPostFormSubmissionMethodNotAllowedErrorResponseBody,
    )
    from .form_submissions_post_form_submission_not_found_error_response_body import (
        FormSubmissionsPostFormSubmissionNotFoundErrorResponseBody,
    )
    from .form_submissions_post_form_submission_not_implemented_error_response_body import (
        FormSubmissionsPostFormSubmissionNotImplementedErrorResponseBody,
    )
    from .form_submissions_post_form_submission_response_body import FormSubmissionsPostFormSubmissionResponseBody
    from .form_submissions_post_form_submission_service_unavailable_error_response_body import (
        FormSubmissionsPostFormSubmissionServiceUnavailableErrorResponseBody,
    )
    from .form_submissions_post_form_submission_too_many_requests_error_response_body import (
        FormSubmissionsPostFormSubmissionTooManyRequestsErrorResponseBody,
    )
    from .form_submissions_post_form_submission_unauthorized_error_response_body import (
        FormSubmissionsPostFormSubmissionUnauthorizedErrorResponseBody,
    )
    from .form_submissions_post_form_submissions_pdf_exports_bad_gateway_error_response_body import (
        FormSubmissionsPostFormSubmissionsPdfExportsBadGatewayErrorResponseBody,
    )
    from .form_submissions_post_form_submissions_pdf_exports_gateway_timeout_error_response_body import (
        FormSubmissionsPostFormSubmissionsPdfExportsGatewayTimeoutErrorResponseBody,
    )
    from .form_submissions_post_form_submissions_pdf_exports_internal_server_error_response_body import (
        FormSubmissionsPostFormSubmissionsPdfExportsInternalServerErrorResponseBody,
    )
    from .form_submissions_post_form_submissions_pdf_exports_method_not_allowed_error_response_body import (
        FormSubmissionsPostFormSubmissionsPdfExportsMethodNotAllowedErrorResponseBody,
    )
    from .form_submissions_post_form_submissions_pdf_exports_not_found_error_response_body import (
        FormSubmissionsPostFormSubmissionsPdfExportsNotFoundErrorResponseBody,
    )
    from .form_submissions_post_form_submissions_pdf_exports_not_implemented_error_response_body import (
        FormSubmissionsPostFormSubmissionsPdfExportsNotImplementedErrorResponseBody,
    )
    from .form_submissions_post_form_submissions_pdf_exports_response_body import (
        FormSubmissionsPostFormSubmissionsPdfExportsResponseBody,
    )
    from .form_submissions_post_form_submissions_pdf_exports_service_unavailable_error_response_body import (
        FormSubmissionsPostFormSubmissionsPdfExportsServiceUnavailableErrorResponseBody,
    )
    from .form_submissions_post_form_submissions_pdf_exports_too_many_requests_error_response_body import (
        FormSubmissionsPostFormSubmissionsPdfExportsTooManyRequestsErrorResponseBody,
    )
    from .form_submissions_post_form_submissions_pdf_exports_unauthorized_error_response_body import (
        FormSubmissionsPostFormSubmissionsPdfExportsUnauthorizedErrorResponseBody,
    )
    from .form_submitted_response_body import FormSubmittedResponseBody
    from .form_template_reference_object_response_body import FormTemplateReferenceObjectResponseBody
    from .form_template_request_object_request_body import FormTemplateRequestObjectRequestBody
    from .form_template_response_object_response_body import FormTemplateResponseObjectResponseBody
    from .form_template_response_object_response_body_form_category import (
        FormTemplateResponseObjectResponseBodyFormCategory,
    )
    from .form_template_section_object_response_body import FormTemplateSectionObjectResponseBody
    from .form_templates_get_form_templates_bad_gateway_error_response_body import (
        FormTemplatesGetFormTemplatesBadGatewayErrorResponseBody,
    )
    from .form_templates_get_form_templates_gateway_timeout_error_response_body import (
        FormTemplatesGetFormTemplatesGatewayTimeoutErrorResponseBody,
    )
    from .form_templates_get_form_templates_internal_server_error_response_body import (
        FormTemplatesGetFormTemplatesInternalServerErrorResponseBody,
    )
    from .form_templates_get_form_templates_method_not_allowed_error_response_body import (
        FormTemplatesGetFormTemplatesMethodNotAllowedErrorResponseBody,
    )
    from .form_templates_get_form_templates_not_found_error_response_body import (
        FormTemplatesGetFormTemplatesNotFoundErrorResponseBody,
    )
    from .form_templates_get_form_templates_not_implemented_error_response_body import (
        FormTemplatesGetFormTemplatesNotImplementedErrorResponseBody,
    )
    from .form_templates_get_form_templates_response_body import FormTemplatesGetFormTemplatesResponseBody
    from .form_templates_get_form_templates_service_unavailable_error_response_body import (
        FormTemplatesGetFormTemplatesServiceUnavailableErrorResponseBody,
    )
    from .form_templates_get_form_templates_too_many_requests_error_response_body import (
        FormTemplatesGetFormTemplatesTooManyRequestsErrorResponseBody,
    )
    from .form_templates_get_form_templates_unauthorized_error_response_body import (
        FormTemplatesGetFormTemplatesUnauthorizedErrorResponseBody,
    )
    from .form_updated_response_body import FormUpdatedResponseBody
    from .forms_action_object_response_body import FormsActionObjectResponseBody
    from .forms_action_object_response_body_type import FormsActionObjectResponseBodyType
    from .forms_approval_config_object_response_body import FormsApprovalConfigObjectResponseBody
    from .forms_approval_config_object_response_body_type import FormsApprovalConfigObjectResponseBodyType
    from .forms_asset_object_response_body import FormsAssetObjectResponseBody
    from .forms_asset_object_response_body_entry_type import FormsAssetObjectResponseBodyEntryType
    from .forms_asset_value_object_response_body import FormsAssetValueObjectResponseBody
    from .forms_check_boxes_value_object_response_body import FormsCheckBoxesValueObjectResponseBody
    from .forms_condition_object_response_body import FormsConditionObjectResponseBody
    from .forms_condition_object_response_body_type import FormsConditionObjectResponseBodyType
    from .forms_conditional_action_object_response_body import FormsConditionalActionObjectResponseBody
    from .forms_date_time_value_object_response_body import FormsDateTimeValueObjectResponseBody
    from .forms_date_time_value_object_response_body_type import FormsDateTimeValueObjectResponseBodyType
    from .forms_field_definition_object_response_body import FormsFieldDefinitionObjectResponseBody
    from .forms_field_definition_object_response_body_allowed_asset_types_item import (
        FormsFieldDefinitionObjectResponseBodyAllowedAssetTypesItem,
    )
    from .forms_field_definition_object_response_body_allowed_date_time_value_type import (
        FormsFieldDefinitionObjectResponseBodyAllowedDateTimeValueType,
    )
    from .forms_field_definition_object_response_body_type import FormsFieldDefinitionObjectResponseBodyType
    from .forms_field_input_object_response_body import FormsFieldInputObjectResponseBody
    from .forms_field_input_object_response_body_type import FormsFieldInputObjectResponseBodyType
    from .forms_geofence_object_response_body import FormsGeofenceObjectResponseBody
    from .forms_geofence_object_response_body_entry_type import FormsGeofenceObjectResponseBodyEntryType
    from .forms_geofence_value_object_response_body import FormsGeofenceValueObjectResponseBody
    from .forms_issue_created_by_field_object_response_body import FormsIssueCreatedByFieldObjectResponseBody
    from .forms_location_object_response_body import FormsLocationObjectResponseBody
    from .forms_media_record_object_response_body import FormsMediaRecordObjectResponseBody
    from .forms_media_record_object_response_body_processing_status import (
        FormsMediaRecordObjectResponseBodyProcessingStatus,
    )
    from .forms_media_value_object_response_body import FormsMediaValueObjectResponseBody
    from .forms_multiple_choice_value_object_response_body import FormsMultipleChoiceValueObjectResponseBody
    from .forms_number_value_object_response_body import FormsNumberValueObjectResponseBody
    from .forms_person_object_response_body import FormsPersonObjectResponseBody
    from .forms_person_object_response_body_entry_type import FormsPersonObjectResponseBodyEntryType
    from .forms_person_value_object_response_body import FormsPersonValueObjectResponseBody
    from .forms_polymorphic_user_object_response_body import FormsPolymorphicUserObjectResponseBody
    from .forms_polymorphic_user_object_response_body_type import FormsPolymorphicUserObjectResponseBodyType
    from .forms_product_submission_approval_details_object_response_body import (
        FormsProductSubmissionApprovalDetailsObjectResponseBody,
    )
    from .forms_score_object_response_body import FormsScoreObjectResponseBody
    from .forms_select_option_object_response_body import FormsSelectOptionObjectResponseBody
    from .forms_signature_value_object_response_body import FormsSignatureValueObjectResponseBody
    from .forms_single_approval_config_object_response_body import FormsSingleApprovalConfigObjectResponseBody
    from .forms_table_cell_object_response_body import FormsTableCellObjectResponseBody
    from .forms_table_cell_object_response_body_type import FormsTableCellObjectResponseBodyType
    from .forms_table_column_object_response_body import FormsTableColumnObjectResponseBody
    from .forms_table_column_object_response_body_type import FormsTableColumnObjectResponseBodyType
    from .forms_table_field_definition_object_response_body import FormsTableFieldDefinitionObjectResponseBody
    from .forms_table_field_definition_object_response_body_allowed_date_time_value_type import (
        FormsTableFieldDefinitionObjectResponseBodyAllowedDateTimeValueType,
    )
    from .forms_table_field_definition_object_response_body_type import FormsTableFieldDefinitionObjectResponseBodyType
    from .forms_table_row_object_response_body import FormsTableRowObjectResponseBody
    from .forms_table_value_object_response_body import FormsTableValueObjectResponseBody
    from .forms_text_value_object_response_body import FormsTextValueObjectResponseBody
    from .forward_collision_detection_alert_settings_object_response_body import (
        ForwardCollisionDetectionAlertSettingsObjectResponseBody,
    )
    from .forward_collision_detection_alert_settings_object_response_body_sensitivity import (
        ForwardCollisionDetectionAlertSettingsObjectResponseBodySensitivity,
    )
    from .fuel_consumed_ml import FuelConsumedMl
    from .fuel_cost_object_response_body import FuelCostObjectResponseBody
    from .fuel_cost_object_response_body_currency import FuelCostObjectResponseBodyCurrency
    from .fuel_energy_cost_response_response_body import FuelEnergyCostResponseResponseBody
    from .fuel_energy_driver_report_data_object_response_body import FuelEnergyDriverReportDataObjectResponseBody
    from .fuel_energy_driver_report_object_response_body import FuelEnergyDriverReportObjectResponseBody
    from .fuel_energy_get_fuel_energy_driver_reports_bad_gateway_error_response_body import (
        FuelEnergyGetFuelEnergyDriverReportsBadGatewayErrorResponseBody,
    )
    from .fuel_energy_get_fuel_energy_driver_reports_gateway_timeout_error_response_body import (
        FuelEnergyGetFuelEnergyDriverReportsGatewayTimeoutErrorResponseBody,
    )
    from .fuel_energy_get_fuel_energy_driver_reports_internal_server_error_response_body import (
        FuelEnergyGetFuelEnergyDriverReportsInternalServerErrorResponseBody,
    )
    from .fuel_energy_get_fuel_energy_driver_reports_method_not_allowed_error_response_body import (
        FuelEnergyGetFuelEnergyDriverReportsMethodNotAllowedErrorResponseBody,
    )
    from .fuel_energy_get_fuel_energy_driver_reports_not_found_error_response_body import (
        FuelEnergyGetFuelEnergyDriverReportsNotFoundErrorResponseBody,
    )
    from .fuel_energy_get_fuel_energy_driver_reports_not_implemented_error_response_body import (
        FuelEnergyGetFuelEnergyDriverReportsNotImplementedErrorResponseBody,
    )
    from .fuel_energy_get_fuel_energy_driver_reports_response_body import (
        FuelEnergyGetFuelEnergyDriverReportsResponseBody,
    )
    from .fuel_energy_get_fuel_energy_driver_reports_service_unavailable_error_response_body import (
        FuelEnergyGetFuelEnergyDriverReportsServiceUnavailableErrorResponseBody,
    )
    from .fuel_energy_get_fuel_energy_driver_reports_too_many_requests_error_response_body import (
        FuelEnergyGetFuelEnergyDriverReportsTooManyRequestsErrorResponseBody,
    )
    from .fuel_energy_get_fuel_energy_driver_reports_unauthorized_error_response_body import (
        FuelEnergyGetFuelEnergyDriverReportsUnauthorizedErrorResponseBody,
    )
    from .fuel_energy_get_fuel_energy_vehicle_reports_bad_gateway_error_response_body import (
        FuelEnergyGetFuelEnergyVehicleReportsBadGatewayErrorResponseBody,
    )
    from .fuel_energy_get_fuel_energy_vehicle_reports_gateway_timeout_error_response_body import (
        FuelEnergyGetFuelEnergyVehicleReportsGatewayTimeoutErrorResponseBody,
    )
    from .fuel_energy_get_fuel_energy_vehicle_reports_internal_server_error_response_body import (
        FuelEnergyGetFuelEnergyVehicleReportsInternalServerErrorResponseBody,
    )
    from .fuel_energy_get_fuel_energy_vehicle_reports_method_not_allowed_error_response_body import (
        FuelEnergyGetFuelEnergyVehicleReportsMethodNotAllowedErrorResponseBody,
    )
    from .fuel_energy_get_fuel_energy_vehicle_reports_not_found_error_response_body import (
        FuelEnergyGetFuelEnergyVehicleReportsNotFoundErrorResponseBody,
    )
    from .fuel_energy_get_fuel_energy_vehicle_reports_not_implemented_error_response_body import (
        FuelEnergyGetFuelEnergyVehicleReportsNotImplementedErrorResponseBody,
    )
    from .fuel_energy_get_fuel_energy_vehicle_reports_response_body import (
        FuelEnergyGetFuelEnergyVehicleReportsResponseBody,
    )
    from .fuel_energy_get_fuel_energy_vehicle_reports_service_unavailable_error_response_body import (
        FuelEnergyGetFuelEnergyVehicleReportsServiceUnavailableErrorResponseBody,
    )
    from .fuel_energy_get_fuel_energy_vehicle_reports_too_many_requests_error_response_body import (
        FuelEnergyGetFuelEnergyVehicleReportsTooManyRequestsErrorResponseBody,
    )
    from .fuel_energy_get_fuel_energy_vehicle_reports_unauthorized_error_response_body import (
        FuelEnergyGetFuelEnergyVehicleReportsUnauthorizedErrorResponseBody,
    )
    from .fuel_energy_vehicle_object_response_body import FuelEnergyVehicleObjectResponseBody
    from .fuel_energy_vehicle_object_response_body_energy_type import FuelEnergyVehicleObjectResponseBodyEnergyType
    from .fuel_energy_vehicle_report_data_object_response_body import FuelEnergyVehicleReportDataObjectResponseBody
    from .fuel_energy_vehicle_report_object_response_body import FuelEnergyVehicleReportObjectResponseBody
    from .fuel_level_percentage_response_body import FuelLevelPercentageResponseBody
    from .fuel_level_trigger_details_object_request_body import FuelLevelTriggerDetailsObjectRequestBody
    from .fuel_level_trigger_details_object_request_body_operation import (
        FuelLevelTriggerDetailsObjectRequestBodyOperation,
    )
    from .fuel_level_trigger_details_object_response_body import FuelLevelTriggerDetailsObjectResponseBody
    from .fuel_level_trigger_details_object_response_body_operation import (
        FuelLevelTriggerDetailsObjectResponseBodyOperation,
    )
    from .fuel_purchase_post_fuel_purchase_bad_gateway_error_response_body import (
        FuelPurchasePostFuelPurchaseBadGatewayErrorResponseBody,
    )
    from .fuel_purchase_post_fuel_purchase_gateway_timeout_error_response_body import (
        FuelPurchasePostFuelPurchaseGatewayTimeoutErrorResponseBody,
    )
    from .fuel_purchase_post_fuel_purchase_internal_server_error_response_body import (
        FuelPurchasePostFuelPurchaseInternalServerErrorResponseBody,
    )
    from .fuel_purchase_post_fuel_purchase_method_not_allowed_error_response_body import (
        FuelPurchasePostFuelPurchaseMethodNotAllowedErrorResponseBody,
    )
    from .fuel_purchase_post_fuel_purchase_not_found_error_response_body import (
        FuelPurchasePostFuelPurchaseNotFoundErrorResponseBody,
    )
    from .fuel_purchase_post_fuel_purchase_not_implemented_error_response_body import (
        FuelPurchasePostFuelPurchaseNotImplementedErrorResponseBody,
    )
    from .fuel_purchase_post_fuel_purchase_response_body import FuelPurchasePostFuelPurchaseResponseBody
    from .fuel_purchase_post_fuel_purchase_service_unavailable_error_response_body import (
        FuelPurchasePostFuelPurchaseServiceUnavailableErrorResponseBody,
    )
    from .fuel_purchase_post_fuel_purchase_too_many_requests_error_response_body import (
        FuelPurchasePostFuelPurchaseTooManyRequestsErrorResponseBody,
    )
    from .fuel_purchase_post_fuel_purchase_unauthorized_error_response_body import (
        FuelPurchasePostFuelPurchaseUnauthorizedErrorResponseBody,
    )
    from .fuel_remaining_response_body import FuelRemainingResponseBody
    from .fuel_volume_response_body import FuelVolumeResponseBody
    from .fuel_volume_response_body_unit import FuelVolumeResponseBodyUnit
    from .functions_start_function_run_bad_gateway_error_response_body import (
        FunctionsStartFunctionRunBadGatewayErrorResponseBody,
    )
    from .functions_start_function_run_gateway_timeout_error_response_body import (
        FunctionsStartFunctionRunGatewayTimeoutErrorResponseBody,
    )
    from .functions_start_function_run_internal_server_error_response_body import (
        FunctionsStartFunctionRunInternalServerErrorResponseBody,
    )
    from .functions_start_function_run_method_not_allowed_error_response_body import (
        FunctionsStartFunctionRunMethodNotAllowedErrorResponseBody,
    )
    from .functions_start_function_run_not_found_error_response_body import (
        FunctionsStartFunctionRunNotFoundErrorResponseBody,
    )
    from .functions_start_function_run_not_implemented_error_response_body import (
        FunctionsStartFunctionRunNotImplementedErrorResponseBody,
    )
    from .functions_start_function_run_response_body import FunctionsStartFunctionRunResponseBody
    from .functions_start_function_run_service_unavailable_error_response_body import (
        FunctionsStartFunctionRunServiceUnavailableErrorResponseBody,
    )
    from .functions_start_function_run_too_many_requests_error_response_body import (
        FunctionsStartFunctionRunTooManyRequestsErrorResponseBody,
    )
    from .functions_start_function_run_unauthorized_error_response_body import (
        FunctionsStartFunctionRunUnauthorizedErrorResponseBody,
    )
    from .gaseous_fuel_cost_object_response_body import GaseousFuelCostObjectResponseBody
    from .gaseous_fuel_cost_object_response_body_currency import GaseousFuelCostObjectResponseBodyCurrency
    from .gateway_asset_response_object_response_body import GatewayAssetResponseObjectResponseBody
    from .gateway_details_response_response_body import GatewayDetailsResponseResponseBody
    from .gateway_details_response_response_body_gateway_battery_state import (
        GatewayDetailsResponseResponseBodyGatewayBatteryState,
    )
    from .gateway_disconnected_details_object_request_body import GatewayDisconnectedDetailsObjectRequestBody
    from .gateway_disconnected_details_object_response_body import GatewayDisconnectedDetailsObjectResponseBody
    from .gateway_disconnected_response_body import GatewayDisconnectedResponseBody
    from .gateway_response_object_response_body import GatewayResponseObjectResponseBody
    from .gateway_response_object_response_body_model import GatewayResponseObjectResponseBodyModel
    from .gateway_tiny import GatewayTiny
    from .gateway_unplugged_trigger_details_object_request_body import GatewayUnpluggedTriggerDetailsObjectRequestBody
    from .gateway_unplugged_trigger_details_object_response_body import GatewayUnpluggedTriggerDetailsObjectResponseBody
    from .gateway_with_vehicle_tiny_response_response_body import GatewayWithVehicleTinyResponseResponseBody
    from .gateway_with_vehicle_tiny_response_response_body_model import GatewayWithVehicleTinyResponseResponseBodyModel
    from .gateways_delete_gateway_bad_gateway_error_response_body import (
        GatewaysDeleteGatewayBadGatewayErrorResponseBody,
    )
    from .gateways_delete_gateway_gateway_timeout_error_response_body import (
        GatewaysDeleteGatewayGatewayTimeoutErrorResponseBody,
    )
    from .gateways_delete_gateway_internal_server_error_response_body import (
        GatewaysDeleteGatewayInternalServerErrorResponseBody,
    )
    from .gateways_delete_gateway_method_not_allowed_error_response_body import (
        GatewaysDeleteGatewayMethodNotAllowedErrorResponseBody,
    )
    from .gateways_delete_gateway_not_found_error_response_body import GatewaysDeleteGatewayNotFoundErrorResponseBody
    from .gateways_delete_gateway_not_implemented_error_response_body import (
        GatewaysDeleteGatewayNotImplementedErrorResponseBody,
    )
    from .gateways_delete_gateway_service_unavailable_error_response_body import (
        GatewaysDeleteGatewayServiceUnavailableErrorResponseBody,
    )
    from .gateways_delete_gateway_too_many_requests_error_response_body import (
        GatewaysDeleteGatewayTooManyRequestsErrorResponseBody,
    )
    from .gateways_delete_gateway_unauthorized_error_response_body import (
        GatewaysDeleteGatewayUnauthorizedErrorResponseBody,
    )
    from .gateways_get_gateways_bad_gateway_error_response_body import GatewaysGetGatewaysBadGatewayErrorResponseBody
    from .gateways_get_gateways_gateway_timeout_error_response_body import (
        GatewaysGetGatewaysGatewayTimeoutErrorResponseBody,
    )
    from .gateways_get_gateways_internal_server_error_response_body import (
        GatewaysGetGatewaysInternalServerErrorResponseBody,
    )
    from .gateways_get_gateways_method_not_allowed_error_response_body import (
        GatewaysGetGatewaysMethodNotAllowedErrorResponseBody,
    )
    from .gateways_get_gateways_not_found_error_response_body import GatewaysGetGatewaysNotFoundErrorResponseBody
    from .gateways_get_gateways_not_implemented_error_response_body import (
        GatewaysGetGatewaysNotImplementedErrorResponseBody,
    )
    from .gateways_get_gateways_response_body import GatewaysGetGatewaysResponseBody
    from .gateways_get_gateways_service_unavailable_error_response_body import (
        GatewaysGetGatewaysServiceUnavailableErrorResponseBody,
    )
    from .gateways_get_gateways_too_many_requests_error_response_body import (
        GatewaysGetGatewaysTooManyRequestsErrorResponseBody,
    )
    from .gateways_get_gateways_unauthorized_error_response_body import GatewaysGetGatewaysUnauthorizedErrorResponseBody
    from .gateways_post_gateway_bad_gateway_error_response_body import GatewaysPostGatewayBadGatewayErrorResponseBody
    from .gateways_post_gateway_gateway_timeout_error_response_body import (
        GatewaysPostGatewayGatewayTimeoutErrorResponseBody,
    )
    from .gateways_post_gateway_internal_server_error_response_body import (
        GatewaysPostGatewayInternalServerErrorResponseBody,
    )
    from .gateways_post_gateway_method_not_allowed_error_response_body import (
        GatewaysPostGatewayMethodNotAllowedErrorResponseBody,
    )
    from .gateways_post_gateway_not_found_error_response_body import GatewaysPostGatewayNotFoundErrorResponseBody
    from .gateways_post_gateway_not_implemented_error_response_body import (
        GatewaysPostGatewayNotImplementedErrorResponseBody,
    )
    from .gateways_post_gateway_response_body import GatewaysPostGatewayResponseBody
    from .gateways_post_gateway_service_unavailable_error_response_body import (
        GatewaysPostGatewayServiceUnavailableErrorResponseBody,
    )
    from .gateways_post_gateway_too_many_requests_error_response_body import (
        GatewaysPostGatewayTooManyRequestsErrorResponseBody,
    )
    from .gateways_post_gateway_unauthorized_error_response_body import GatewaysPostGatewayUnauthorizedErrorResponseBody
    from .geofence_entry_trigger_details_object_request_body import GeofenceEntryTriggerDetailsObjectRequestBody
    from .geofence_entry_trigger_details_object_response_body import GeofenceEntryTriggerDetailsObjectResponseBody
    from .geofence_exit_trigger_details_object_request_body import GeofenceExitTriggerDetailsObjectRequestBody
    from .geofence_exit_trigger_details_object_response_body import GeofenceExitTriggerDetailsObjectResponseBody
    from .geofence_response_response_body import GeofenceResponseResponseBody
    from .get_attributes_by_entity_type_response import GetAttributesByEntityTypeResponse
    from .get_document_type_response_object_response_body import GetDocumentTypeResponseObjectResponseBody
    from .get_driver_trailer_assignments_response_body_response_body import (
        GetDriverTrailerAssignmentsResponseBodyResponseBody,
    )
    from .get_media_retrieval_object_response_body import GetMediaRetrievalObjectResponseBody
    from .get_report_runs_data_object_response_body import GetReportRunsDataObjectResponseBody
    from .get_report_runs_data_object_response_body_status import GetReportRunsDataObjectResponseBodyStatus
    from .get_response_workflow_configuration_object_response_body import (
        GetResponseWorkflowConfigurationObjectResponseBody,
    )
    from .get_workflow_incident_response_object_response_body import GetWorkflowIncidentResponseObjectResponseBody
    from .goa_address_tiny_response_response_body import GoaAddressTinyResponseResponseBody
    from .goa_attribute_tiny import GoaAttributeTiny
    from .goa_attribute_tiny_request_body import GoaAttributeTinyRequestBody
    from .goa_attribute_tiny_response_body import GoaAttributeTinyResponseBody
    from .goa_document_tiny_response_response_body import GoaDocumentTinyResponseResponseBody
    from .goa_document_type_tiny_response_response_body import GoaDocumentTypeTinyResponseResponseBody
    from .goa_driver_tiny_response_response_body import GoaDriverTinyResponseResponseBody
    from .goa_form_tiny_response_response_body import GoaFormTinyResponseResponseBody
    from .goa_gateway_tiny_response_response_body import GoaGatewayTinyResponseResponseBody
    from .goa_gateway_tiny_response_response_body_model import GoaGatewayTinyResponseResponseBodyModel
    from .goa_issue_tiny_response_response_body import GoaIssueTinyResponseResponseBody
    from .goa_pagination_response_response_body import GoaPaginationResponseResponseBody
    from .goa_pagination_with_tokens_response_response_body import GoaPaginationWithTokensResponseResponseBody
    from .goa_route_stop_tiny_response_response_body import GoaRouteStopTinyResponseResponseBody
    from .goa_route_tiny_response_response_body import GoaRouteTinyResponseResponseBody
    from .goa_tag_tiny_response_request_body import GoaTagTinyResponseRequestBody
    from .goa_tag_tiny_response_response_body import GoaTagTinyResponseResponseBody
    from .goa_trailer_tiny_response_response_body import GoaTrailerTinyResponseResponseBody
    from .goa_vehicle_tiny_response_response_body import GoaVehicleTinyResponseResponseBody
    from .gps_signal_loss_details_object_request_body import GpsSignalLossDetailsObjectRequestBody
    from .gps_signal_loss_details_object_response_body import GpsSignalLossDetailsObjectResponseBody
    from .gps_signal_loss_response_body import GpsSignalLossResponseBody
    from .green_band_driving_duration_ms import GreenBandDrivingDurationMs
    from .gross_vehicle_weight import GrossVehicleWeight
    from .gross_vehicle_weight_unit import GrossVehicleWeightUnit
    from .harsh_accel_sensitivity_g_force_settings_object_response_body import (
        HarshAccelSensitivityGForceSettingsObjectResponseBody,
    )
    from .harsh_accel_sensitivity_v_2_settings_object_response_body import (
        HarshAccelSensitivityV2SettingsObjectResponseBody,
    )
    from .harsh_accel_sensitivity_v_2_settings_object_response_body_heavy_duty import (
        HarshAccelSensitivityV2SettingsObjectResponseBodyHeavyDuty,
    )
    from .harsh_accel_sensitivity_v_2_settings_object_response_body_light_duty import (
        HarshAccelSensitivityV2SettingsObjectResponseBodyLightDuty,
    )
    from .harsh_accel_sensitivity_v_2_settings_object_response_body_passenger import (
        HarshAccelSensitivityV2SettingsObjectResponseBodyPassenger,
    )
    from .harsh_brake_sensitivity_g_force_settings_object_response_body import (
        HarshBrakeSensitivityGForceSettingsObjectResponseBody,
    )
    from .harsh_brake_sensitivity_v_2_settings_object_response_body import (
        HarshBrakeSensitivityV2SettingsObjectResponseBody,
    )
    from .harsh_brake_sensitivity_v_2_settings_object_response_body_heavy_duty import (
        HarshBrakeSensitivityV2SettingsObjectResponseBodyHeavyDuty,
    )
    from .harsh_brake_sensitivity_v_2_settings_object_response_body_light_duty import (
        HarshBrakeSensitivityV2SettingsObjectResponseBodyLightDuty,
    )
    from .harsh_brake_sensitivity_v_2_settings_object_response_body_passenger import (
        HarshBrakeSensitivityV2SettingsObjectResponseBodyPassenger,
    )
    from .harsh_event_data_response_body import HarshEventDataResponseBody
    from .harsh_event_sensitivity_settings_object_response_body import HarshEventSensitivitySettingsObjectResponseBody
    from .harsh_event_sensitivity_v_2_settings_object_response_body import (
        HarshEventSensitivityV2SettingsObjectResponseBody,
    )
    from .harsh_event_trigger_details_object_request_body import HarshEventTriggerDetailsObjectRequestBody
    from .harsh_event_trigger_details_object_request_body_types_item import (
        HarshEventTriggerDetailsObjectRequestBodyTypesItem,
    )
    from .harsh_event_trigger_details_object_response_body import HarshEventTriggerDetailsObjectResponseBody
    from .harsh_event_trigger_details_object_response_body_types_item import (
        HarshEventTriggerDetailsObjectResponseBodyTypesItem,
    )
    from .harsh_turn_sensitivity_g_force_settings_object_response_body import (
        HarshTurnSensitivityGForceSettingsObjectResponseBody,
    )
    from .harsh_turn_sensitivity_v_2_settings_object_response_body import (
        HarshTurnSensitivityV2SettingsObjectResponseBody,
    )
    from .harsh_turn_sensitivity_v_2_settings_object_response_body_heavy_duty import (
        HarshTurnSensitivityV2SettingsObjectResponseBodyHeavyDuty,
    )
    from .harsh_turn_sensitivity_v_2_settings_object_response_body_light_duty import (
        HarshTurnSensitivityV2SettingsObjectResponseBodyLightDuty,
    )
    from .harsh_turn_sensitivity_v_2_settings_object_response_body_passenger import (
        HarshTurnSensitivityV2SettingsObjectResponseBodyPassenger,
    )
    from .health_details_response_response_body import HealthDetailsResponseResponseBody
    from .health_reason_response_response_body import HealthReasonResponseResponseBody
    from .health_reason_response_response_body_health_reason_code import (
        HealthReasonResponseResponseBodyHealthReasonCode,
    )
    from .health_response_response_body import HealthResponseResponseBody
    from .health_response_response_body_health_status import HealthResponseResponseBodyHealthStatus
    from .health_response_response_body_primary_health_reason import HealthResponseResponseBodyPrimaryHealthReason
    from .health_response_response_body_recommended_action import HealthResponseResponseBodyRecommendedAction
    from .high_torque_ms import HighTorqueMs
    from .hos_break import HosBreak
    from .hos_clocks import HosClocks
    from .hos_clocks_for_driver import HosClocksForDriver
    from .hos_clocks_for_drivers import HosClocksForDrivers
    from .hos_clocks_response import HosClocksResponse
    from .hos_cycle import HosCycle
    from .hos_daily_logs_get_hos_daily_logs_bad_gateway_error_response_body import (
        HosDailyLogsGetHosDailyLogsBadGatewayErrorResponseBody,
    )
    from .hos_daily_logs_get_hos_daily_logs_gateway_timeout_error_response_body import (
        HosDailyLogsGetHosDailyLogsGatewayTimeoutErrorResponseBody,
    )
    from .hos_daily_logs_get_hos_daily_logs_internal_server_error_response_body import (
        HosDailyLogsGetHosDailyLogsInternalServerErrorResponseBody,
    )
    from .hos_daily_logs_get_hos_daily_logs_method_not_allowed_error_response_body import (
        HosDailyLogsGetHosDailyLogsMethodNotAllowedErrorResponseBody,
    )
    from .hos_daily_logs_get_hos_daily_logs_not_found_error_response_body import (
        HosDailyLogsGetHosDailyLogsNotFoundErrorResponseBody,
    )
    from .hos_daily_logs_get_hos_daily_logs_not_implemented_error_response_body import (
        HosDailyLogsGetHosDailyLogsNotImplementedErrorResponseBody,
    )
    from .hos_daily_logs_get_hos_daily_logs_response_body import HosDailyLogsGetHosDailyLogsResponseBody
    from .hos_daily_logs_get_hos_daily_logs_service_unavailable_error_response_body import (
        HosDailyLogsGetHosDailyLogsServiceUnavailableErrorResponseBody,
    )
    from .hos_daily_logs_get_hos_daily_logs_too_many_requests_error_response_body import (
        HosDailyLogsGetHosDailyLogsTooManyRequestsErrorResponseBody,
    )
    from .hos_daily_logs_get_hos_daily_logs_unauthorized_error_response_body import (
        HosDailyLogsGetHosDailyLogsUnauthorizedErrorResponseBody,
    )
    from .hos_daily_logs_object_response_body import HosDailyLogsObjectResponseBody
    from .hos_daily_logs_update_shipping_docs_bad_gateway_error_response_body import (
        HosDailyLogsUpdateShippingDocsBadGatewayErrorResponseBody,
    )
    from .hos_daily_logs_update_shipping_docs_gateway_timeout_error_response_body import (
        HosDailyLogsUpdateShippingDocsGatewayTimeoutErrorResponseBody,
    )
    from .hos_daily_logs_update_shipping_docs_internal_server_error_response_body import (
        HosDailyLogsUpdateShippingDocsInternalServerErrorResponseBody,
    )
    from .hos_daily_logs_update_shipping_docs_method_not_allowed_error_response_body import (
        HosDailyLogsUpdateShippingDocsMethodNotAllowedErrorResponseBody,
    )
    from .hos_daily_logs_update_shipping_docs_not_found_error_response_body import (
        HosDailyLogsUpdateShippingDocsNotFoundErrorResponseBody,
    )
    from .hos_daily_logs_update_shipping_docs_not_implemented_error_response_body import (
        HosDailyLogsUpdateShippingDocsNotImplementedErrorResponseBody,
    )
    from .hos_daily_logs_update_shipping_docs_response_body import HosDailyLogsUpdateShippingDocsResponseBody
    from .hos_daily_logs_update_shipping_docs_service_unavailable_error_response_body import (
        HosDailyLogsUpdateShippingDocsServiceUnavailableErrorResponseBody,
    )
    from .hos_daily_logs_update_shipping_docs_too_many_requests_error_response_body import (
        HosDailyLogsUpdateShippingDocsTooManyRequestsErrorResponseBody,
    )
    from .hos_daily_logs_update_shipping_docs_unauthorized_error_response_body import (
        HosDailyLogsUpdateShippingDocsUnauthorizedErrorResponseBody,
    )
    from .hos_drive import HosDrive
    from .hos_drivers_eld_event_object_response_body import HosDriversEldEventObjectResponseBody
    from .hos_drivers_eld_event_object_response_body_driver_activation_status import (
        HosDriversEldEventObjectResponseBodyDriverActivationStatus,
    )
    from .hos_eld_event_location_object_response_body import HosEldEventLocationObjectResponseBody
    from .hos_eld_event_object_response_body import HosEldEventObjectResponseBody
    from .hos_eld_event_object_response_body_malfunction_diagnostic_code import (
        HosEldEventObjectResponseBodyMalfunctionDiagnosticCode,
    )
    from .hos_eld_event_remark_object_response_body import HosEldEventRemarkObjectResponseBody
    from .hos_eld_events_get_hos_eld_events_bad_gateway_error_response_body import (
        HosEldEventsGetHosEldEventsBadGatewayErrorResponseBody,
    )
    from .hos_eld_events_get_hos_eld_events_gateway_timeout_error_response_body import (
        HosEldEventsGetHosEldEventsGatewayTimeoutErrorResponseBody,
    )
    from .hos_eld_events_get_hos_eld_events_internal_server_error_response_body import (
        HosEldEventsGetHosEldEventsInternalServerErrorResponseBody,
    )
    from .hos_eld_events_get_hos_eld_events_method_not_allowed_error_response_body import (
        HosEldEventsGetHosEldEventsMethodNotAllowedErrorResponseBody,
    )
    from .hos_eld_events_get_hos_eld_events_not_found_error_response_body import (
        HosEldEventsGetHosEldEventsNotFoundErrorResponseBody,
    )
    from .hos_eld_events_get_hos_eld_events_not_implemented_error_response_body import (
        HosEldEventsGetHosEldEventsNotImplementedErrorResponseBody,
    )
    from .hos_eld_events_get_hos_eld_events_response_body import HosEldEventsGetHosEldEventsResponseBody
    from .hos_eld_events_get_hos_eld_events_service_unavailable_error_response_body import (
        HosEldEventsGetHosEldEventsServiceUnavailableErrorResponseBody,
    )
    from .hos_eld_events_get_hos_eld_events_too_many_requests_error_response_body import (
        HosEldEventsGetHosEldEventsTooManyRequestsErrorResponseBody,
    )
    from .hos_eld_events_get_hos_eld_events_unauthorized_error_response_body import (
        HosEldEventsGetHosEldEventsUnauthorizedErrorResponseBody,
    )
    from .hos_log_entry import HosLogEntry
    from .hos_log_entry_hos_status_type import HosLogEntryHosStatusType
    from .hos_log_location import HosLogLocation
    from .hos_logs_for_driver import HosLogsForDriver
    from .hos_logs_for_drivers import HosLogsForDrivers
    from .hos_logs_list import HosLogsList
    from .hos_logs_response import HosLogsResponse
    from .hos_shift import HosShift
    from .hos_violation_data_response_body import HosViolationDataResponseBody
    from .hos_violation_day_object_response_body import HosViolationDayObjectResponseBody
    from .hos_violation_object_response_body import HosViolationObjectResponseBody
    from .hos_violation_object_response_body_type import HosViolationObjectResponseBodyType
    from .hos_violation_trigger_details_object_request_body import HosViolationTriggerDetailsObjectRequestBody
    from .hos_violation_trigger_details_object_request_body_violation import (
        HosViolationTriggerDetailsObjectRequestBodyViolation,
    )
    from .hos_violation_trigger_details_object_response_body import HosViolationTriggerDetailsObjectResponseBody
    from .hos_violation_trigger_details_object_response_body_violation import (
        HosViolationTriggerDetailsObjectResponseBodyViolation,
    )
    from .hos_violations import HosViolations
    from .hos_violations_get_hos_violations_bad_gateway_error_response_body import (
        HosViolationsGetHosViolationsBadGatewayErrorResponseBody,
    )
    from .hos_violations_get_hos_violations_gateway_timeout_error_response_body import (
        HosViolationsGetHosViolationsGatewayTimeoutErrorResponseBody,
    )
    from .hos_violations_get_hos_violations_internal_server_error_response_body import (
        HosViolationsGetHosViolationsInternalServerErrorResponseBody,
    )
    from .hos_violations_get_hos_violations_method_not_allowed_error_response_body import (
        HosViolationsGetHosViolationsMethodNotAllowedErrorResponseBody,
    )
    from .hos_violations_get_hos_violations_not_found_error_response_body import (
        HosViolationsGetHosViolationsNotFoundErrorResponseBody,
    )
    from .hos_violations_get_hos_violations_not_implemented_error_response_body import (
        HosViolationsGetHosViolationsNotImplementedErrorResponseBody,
    )
    from .hos_violations_get_hos_violations_response_body import HosViolationsGetHosViolationsResponseBody
    from .hos_violations_get_hos_violations_service_unavailable_error_response_body import (
        HosViolationsGetHosViolationsServiceUnavailableErrorResponseBody,
    )
    from .hos_violations_get_hos_violations_too_many_requests_error_response_body import (
        HosViolationsGetHosViolationsTooManyRequestsErrorResponseBody,
    )
    from .hos_violations_get_hos_violations_unauthorized_error_response_body import (
        HosViolationsGetHosViolationsUnauthorizedErrorResponseBody,
    )
    from .hos_violations_object_response_body import HosViolationsObjectResponseBody
    from .hub_capacities_list_hub_capacities_bad_gateway_error_response_body import (
        HubCapacitiesListHubCapacitiesBadGatewayErrorResponseBody,
    )
    from .hub_capacities_list_hub_capacities_gateway_timeout_error_response_body import (
        HubCapacitiesListHubCapacitiesGatewayTimeoutErrorResponseBody,
    )
    from .hub_capacities_list_hub_capacities_internal_server_error_response_body import (
        HubCapacitiesListHubCapacitiesInternalServerErrorResponseBody,
    )
    from .hub_capacities_list_hub_capacities_method_not_allowed_error_response_body import (
        HubCapacitiesListHubCapacitiesMethodNotAllowedErrorResponseBody,
    )
    from .hub_capacities_list_hub_capacities_not_found_error_response_body import (
        HubCapacitiesListHubCapacitiesNotFoundErrorResponseBody,
    )
    from .hub_capacities_list_hub_capacities_not_implemented_error_response_body import (
        HubCapacitiesListHubCapacitiesNotImplementedErrorResponseBody,
    )
    from .hub_capacities_list_hub_capacities_response_body import HubCapacitiesListHubCapacitiesResponseBody
    from .hub_capacities_list_hub_capacities_service_unavailable_error_response_body import (
        HubCapacitiesListHubCapacitiesServiceUnavailableErrorResponseBody,
    )
    from .hub_capacities_list_hub_capacities_too_many_requests_error_response_body import (
        HubCapacitiesListHubCapacitiesTooManyRequestsErrorResponseBody,
    )
    from .hub_capacities_list_hub_capacities_unauthorized_error_response_body import (
        HubCapacitiesListHubCapacitiesUnauthorizedErrorResponseBody,
    )
    from .hub_capacity_object_response_body import HubCapacityObjectResponseBody
    from .hub_custom_properties_list_hub_custom_properties_bad_gateway_error_response_body import (
        HubCustomPropertiesListHubCustomPropertiesBadGatewayErrorResponseBody,
    )
    from .hub_custom_properties_list_hub_custom_properties_gateway_timeout_error_response_body import (
        HubCustomPropertiesListHubCustomPropertiesGatewayTimeoutErrorResponseBody,
    )
    from .hub_custom_properties_list_hub_custom_properties_internal_server_error_response_body import (
        HubCustomPropertiesListHubCustomPropertiesInternalServerErrorResponseBody,
    )
    from .hub_custom_properties_list_hub_custom_properties_method_not_allowed_error_response_body import (
        HubCustomPropertiesListHubCustomPropertiesMethodNotAllowedErrorResponseBody,
    )
    from .hub_custom_properties_list_hub_custom_properties_not_found_error_response_body import (
        HubCustomPropertiesListHubCustomPropertiesNotFoundErrorResponseBody,
    )
    from .hub_custom_properties_list_hub_custom_properties_not_implemented_error_response_body import (
        HubCustomPropertiesListHubCustomPropertiesNotImplementedErrorResponseBody,
    )
    from .hub_custom_properties_list_hub_custom_properties_response_body import (
        HubCustomPropertiesListHubCustomPropertiesResponseBody,
    )
    from .hub_custom_properties_list_hub_custom_properties_service_unavailable_error_response_body import (
        HubCustomPropertiesListHubCustomPropertiesServiceUnavailableErrorResponseBody,
    )
    from .hub_custom_properties_list_hub_custom_properties_too_many_requests_error_response_body import (
        HubCustomPropertiesListHubCustomPropertiesTooManyRequestsErrorResponseBody,
    )
    from .hub_custom_properties_list_hub_custom_properties_unauthorized_error_response_body import (
        HubCustomPropertiesListHubCustomPropertiesUnauthorizedErrorResponseBody,
    )
    from .hub_custom_property_object_response_body import HubCustomPropertyObjectResponseBody
    from .hub_location_created_object_response_body import HubLocationCreatedObjectResponseBody
    from .hub_location_input_object_request_body import HubLocationInputObjectRequestBody
    from .hub_location_object_response_body import HubLocationObjectResponseBody
    from .hub_location_service_window_input_request_body import HubLocationServiceWindowInputRequestBody
    from .hub_location_updated_object_response_body import HubLocationUpdatedObjectResponseBody
    from .hub_locations_create_hub_locations_bad_gateway_error_response_body import (
        HubLocationsCreateHubLocationsBadGatewayErrorResponseBody,
    )
    from .hub_locations_create_hub_locations_gateway_timeout_error_response_body import (
        HubLocationsCreateHubLocationsGatewayTimeoutErrorResponseBody,
    )
    from .hub_locations_create_hub_locations_internal_server_error_response_body import (
        HubLocationsCreateHubLocationsInternalServerErrorResponseBody,
    )
    from .hub_locations_create_hub_locations_method_not_allowed_error_response_body import (
        HubLocationsCreateHubLocationsMethodNotAllowedErrorResponseBody,
    )
    from .hub_locations_create_hub_locations_not_found_error_response_body import (
        HubLocationsCreateHubLocationsNotFoundErrorResponseBody,
    )
    from .hub_locations_create_hub_locations_not_implemented_error_response_body import (
        HubLocationsCreateHubLocationsNotImplementedErrorResponseBody,
    )
    from .hub_locations_create_hub_locations_response_body import HubLocationsCreateHubLocationsResponseBody
    from .hub_locations_create_hub_locations_service_unavailable_error_response_body import (
        HubLocationsCreateHubLocationsServiceUnavailableErrorResponseBody,
    )
    from .hub_locations_create_hub_locations_too_many_requests_error_response_body import (
        HubLocationsCreateHubLocationsTooManyRequestsErrorResponseBody,
    )
    from .hub_locations_create_hub_locations_unauthorized_error_response_body import (
        HubLocationsCreateHubLocationsUnauthorizedErrorResponseBody,
    )
    from .hub_locations_list_hub_locations_bad_gateway_error_response_body import (
        HubLocationsListHubLocationsBadGatewayErrorResponseBody,
    )
    from .hub_locations_list_hub_locations_gateway_timeout_error_response_body import (
        HubLocationsListHubLocationsGatewayTimeoutErrorResponseBody,
    )
    from .hub_locations_list_hub_locations_internal_server_error_response_body import (
        HubLocationsListHubLocationsInternalServerErrorResponseBody,
    )
    from .hub_locations_list_hub_locations_method_not_allowed_error_response_body import (
        HubLocationsListHubLocationsMethodNotAllowedErrorResponseBody,
    )
    from .hub_locations_list_hub_locations_not_found_error_response_body import (
        HubLocationsListHubLocationsNotFoundErrorResponseBody,
    )
    from .hub_locations_list_hub_locations_not_implemented_error_response_body import (
        HubLocationsListHubLocationsNotImplementedErrorResponseBody,
    )
    from .hub_locations_list_hub_locations_response_body import HubLocationsListHubLocationsResponseBody
    from .hub_locations_list_hub_locations_service_unavailable_error_response_body import (
        HubLocationsListHubLocationsServiceUnavailableErrorResponseBody,
    )
    from .hub_locations_list_hub_locations_too_many_requests_error_response_body import (
        HubLocationsListHubLocationsTooManyRequestsErrorResponseBody,
    )
    from .hub_locations_list_hub_locations_unauthorized_error_response_body import (
        HubLocationsListHubLocationsUnauthorizedErrorResponseBody,
    )
    from .hub_locations_update_hub_location_bad_gateway_error_response_body import (
        HubLocationsUpdateHubLocationBadGatewayErrorResponseBody,
    )
    from .hub_locations_update_hub_location_gateway_timeout_error_response_body import (
        HubLocationsUpdateHubLocationGatewayTimeoutErrorResponseBody,
    )
    from .hub_locations_update_hub_location_internal_server_error_response_body import (
        HubLocationsUpdateHubLocationInternalServerErrorResponseBody,
    )
    from .hub_locations_update_hub_location_method_not_allowed_error_response_body import (
        HubLocationsUpdateHubLocationMethodNotAllowedErrorResponseBody,
    )
    from .hub_locations_update_hub_location_not_found_error_response_body import (
        HubLocationsUpdateHubLocationNotFoundErrorResponseBody,
    )
    from .hub_locations_update_hub_location_not_implemented_error_response_body import (
        HubLocationsUpdateHubLocationNotImplementedErrorResponseBody,
    )
    from .hub_locations_update_hub_location_response_body import HubLocationsUpdateHubLocationResponseBody
    from .hub_locations_update_hub_location_service_unavailable_error_response_body import (
        HubLocationsUpdateHubLocationServiceUnavailableErrorResponseBody,
    )
    from .hub_locations_update_hub_location_too_many_requests_error_response_body import (
        HubLocationsUpdateHubLocationTooManyRequestsErrorResponseBody,
    )
    from .hub_locations_update_hub_location_unauthorized_error_response_body import (
        HubLocationsUpdateHubLocationUnauthorizedErrorResponseBody,
    )
    from .hub_object_response_body import HubObjectResponseBody
    from .hub_plan_routes_list_hub_plan_routes_bad_gateway_error_response_body import (
        HubPlanRoutesListHubPlanRoutesBadGatewayErrorResponseBody,
    )
    from .hub_plan_routes_list_hub_plan_routes_gateway_timeout_error_response_body import (
        HubPlanRoutesListHubPlanRoutesGatewayTimeoutErrorResponseBody,
    )
    from .hub_plan_routes_list_hub_plan_routes_internal_server_error_response_body import (
        HubPlanRoutesListHubPlanRoutesInternalServerErrorResponseBody,
    )
    from .hub_plan_routes_list_hub_plan_routes_method_not_allowed_error_response_body import (
        HubPlanRoutesListHubPlanRoutesMethodNotAllowedErrorResponseBody,
    )
    from .hub_plan_routes_list_hub_plan_routes_not_found_error_response_body import (
        HubPlanRoutesListHubPlanRoutesNotFoundErrorResponseBody,
    )
    from .hub_plan_routes_list_hub_plan_routes_not_implemented_error_response_body import (
        HubPlanRoutesListHubPlanRoutesNotImplementedErrorResponseBody,
    )
    from .hub_plan_routes_list_hub_plan_routes_response_body import HubPlanRoutesListHubPlanRoutesResponseBody
    from .hub_plan_routes_list_hub_plan_routes_service_unavailable_error_response_body import (
        HubPlanRoutesListHubPlanRoutesServiceUnavailableErrorResponseBody,
    )
    from .hub_plan_routes_list_hub_plan_routes_too_many_requests_error_response_body import (
        HubPlanRoutesListHubPlanRoutesTooManyRequestsErrorResponseBody,
    )
    from .hub_plan_routes_list_hub_plan_routes_unauthorized_error_response_body import (
        HubPlanRoutesListHubPlanRoutesUnauthorizedErrorResponseBody,
    )
    from .hub_plans_create_hub_plan_bad_gateway_error_response_body import (
        HubPlansCreateHubPlanBadGatewayErrorResponseBody,
    )
    from .hub_plans_create_hub_plan_gateway_timeout_error_response_body import (
        HubPlansCreateHubPlanGatewayTimeoutErrorResponseBody,
    )
    from .hub_plans_create_hub_plan_internal_server_error_response_body import (
        HubPlansCreateHubPlanInternalServerErrorResponseBody,
    )
    from .hub_plans_create_hub_plan_method_not_allowed_error_response_body import (
        HubPlansCreateHubPlanMethodNotAllowedErrorResponseBody,
    )
    from .hub_plans_create_hub_plan_not_found_error_response_body import HubPlansCreateHubPlanNotFoundErrorResponseBody
    from .hub_plans_create_hub_plan_not_implemented_error_response_body import (
        HubPlansCreateHubPlanNotImplementedErrorResponseBody,
    )
    from .hub_plans_create_hub_plan_response_body import HubPlansCreateHubPlanResponseBody
    from .hub_plans_create_hub_plan_service_unavailable_error_response_body import (
        HubPlansCreateHubPlanServiceUnavailableErrorResponseBody,
    )
    from .hub_plans_create_hub_plan_too_many_requests_error_response_body import (
        HubPlansCreateHubPlanTooManyRequestsErrorResponseBody,
    )
    from .hub_plans_create_hub_plan_unauthorized_error_response_body import (
        HubPlansCreateHubPlanUnauthorizedErrorResponseBody,
    )
    from .hub_plans_list_hub_plans_bad_gateway_error_response_body import (
        HubPlansListHubPlansBadGatewayErrorResponseBody,
    )
    from .hub_plans_list_hub_plans_gateway_timeout_error_response_body import (
        HubPlansListHubPlansGatewayTimeoutErrorResponseBody,
    )
    from .hub_plans_list_hub_plans_internal_server_error_response_body import (
        HubPlansListHubPlansInternalServerErrorResponseBody,
    )
    from .hub_plans_list_hub_plans_method_not_allowed_error_response_body import (
        HubPlansListHubPlansMethodNotAllowedErrorResponseBody,
    )
    from .hub_plans_list_hub_plans_not_found_error_response_body import HubPlansListHubPlansNotFoundErrorResponseBody
    from .hub_plans_list_hub_plans_not_implemented_error_response_body import (
        HubPlansListHubPlansNotImplementedErrorResponseBody,
    )
    from .hub_plans_list_hub_plans_response_body import HubPlansListHubPlansResponseBody
    from .hub_plans_list_hub_plans_service_unavailable_error_response_body import (
        HubPlansListHubPlansServiceUnavailableErrorResponseBody,
    )
    from .hub_plans_list_hub_plans_too_many_requests_error_response_body import (
        HubPlansListHubPlansTooManyRequestsErrorResponseBody,
    )
    from .hub_plans_list_hub_plans_unauthorized_error_response_body import (
        HubPlansListHubPlansUnauthorizedErrorResponseBody,
    )
    from .hub_skill_object_response_body import HubSkillObjectResponseBody
    from .hub_skills_list_hub_skills_bad_gateway_error_response_body import (
        HubSkillsListHubSkillsBadGatewayErrorResponseBody,
    )
    from .hub_skills_list_hub_skills_gateway_timeout_error_response_body import (
        HubSkillsListHubSkillsGatewayTimeoutErrorResponseBody,
    )
    from .hub_skills_list_hub_skills_internal_server_error_response_body import (
        HubSkillsListHubSkillsInternalServerErrorResponseBody,
    )
    from .hub_skills_list_hub_skills_method_not_allowed_error_response_body import (
        HubSkillsListHubSkillsMethodNotAllowedErrorResponseBody,
    )
    from .hub_skills_list_hub_skills_not_found_error_response_body import (
        HubSkillsListHubSkillsNotFoundErrorResponseBody,
    )
    from .hub_skills_list_hub_skills_not_implemented_error_response_body import (
        HubSkillsListHubSkillsNotImplementedErrorResponseBody,
    )
    from .hub_skills_list_hub_skills_response_body import HubSkillsListHubSkillsResponseBody
    from .hub_skills_list_hub_skills_service_unavailable_error_response_body import (
        HubSkillsListHubSkillsServiceUnavailableErrorResponseBody,
    )
    from .hub_skills_list_hub_skills_too_many_requests_error_response_body import (
        HubSkillsListHubSkillsTooManyRequestsErrorResponseBody,
    )
    from .hub_skills_list_hub_skills_unauthorized_error_response_body import (
        HubSkillsListHubSkillsUnauthorizedErrorResponseBody,
    )
    from .hubs_list_hubs_bad_gateway_error_response_body import HubsListHubsBadGatewayErrorResponseBody
    from .hubs_list_hubs_gateway_timeout_error_response_body import HubsListHubsGatewayTimeoutErrorResponseBody
    from .hubs_list_hubs_internal_server_error_response_body import HubsListHubsInternalServerErrorResponseBody
    from .hubs_list_hubs_method_not_allowed_error_response_body import HubsListHubsMethodNotAllowedErrorResponseBody
    from .hubs_list_hubs_not_found_error_response_body import HubsListHubsNotFoundErrorResponseBody
    from .hubs_list_hubs_not_implemented_error_response_body import HubsListHubsNotImplementedErrorResponseBody
    from .hubs_list_hubs_response_body import HubsListHubsResponseBody
    from .hubs_list_hubs_service_unavailable_error_response_body import HubsListHubsServiceUnavailableErrorResponseBody
    from .hubs_list_hubs_too_many_requests_error_response_body import HubsListHubsTooManyRequestsErrorResponseBody
    from .hubs_list_hubs_unauthorized_error_response_body import HubsListHubsUnauthorizedErrorResponseBody
    from .idle_time_duration_ms import IdleTimeDurationMs
    from .idling_event_address_object_response_body import IdlingEventAddressObjectResponseBody
    from .idling_event_address_object_response_body_address_types_item import (
        IdlingEventAddressObjectResponseBodyAddressTypesItem,
    )
    from .idling_event_asset_object_response_body import IdlingEventAssetObjectResponseBody
    from .idling_event_object_v_20251023_response_body import IdlingEventObjectV20251023ResponseBody
    from .idling_event_object_v_20251023_response_body_pto_state import IdlingEventObjectV20251023ResponseBodyPtoState
    from .idling_event_operator_object_response_body import IdlingEventOperatorObjectResponseBody
    from .idling_report_event_address_response_body import IdlingReportEventAddressResponseBody
    from .idling_report_event_response_body import IdlingReportEventResponseBody
    from .idling_reports_get_vehicle_idling_reports_bad_gateway_error_response_body import (
        IdlingReportsGetVehicleIdlingReportsBadGatewayErrorResponseBody,
    )
    from .idling_reports_get_vehicle_idling_reports_gateway_timeout_error_response_body import (
        IdlingReportsGetVehicleIdlingReportsGatewayTimeoutErrorResponseBody,
    )
    from .idling_reports_get_vehicle_idling_reports_internal_server_error_response_body import (
        IdlingReportsGetVehicleIdlingReportsInternalServerErrorResponseBody,
    )
    from .idling_reports_get_vehicle_idling_reports_method_not_allowed_error_response_body import (
        IdlingReportsGetVehicleIdlingReportsMethodNotAllowedErrorResponseBody,
    )
    from .idling_reports_get_vehicle_idling_reports_not_found_error_response_body import (
        IdlingReportsGetVehicleIdlingReportsNotFoundErrorResponseBody,
    )
    from .idling_reports_get_vehicle_idling_reports_not_implemented_error_response_body import (
        IdlingReportsGetVehicleIdlingReportsNotImplementedErrorResponseBody,
    )
    from .idling_reports_get_vehicle_idling_reports_response_body import (
        IdlingReportsGetVehicleIdlingReportsResponseBody,
    )
    from .idling_reports_get_vehicle_idling_reports_service_unavailable_error_response_body import (
        IdlingReportsGetVehicleIdlingReportsServiceUnavailableErrorResponseBody,
    )
    from .idling_reports_get_vehicle_idling_reports_too_many_requests_error_response_body import (
        IdlingReportsGetVehicleIdlingReportsTooManyRequestsErrorResponseBody,
    )
    from .idling_reports_get_vehicle_idling_reports_unauthorized_error_response_body import (
        IdlingReportsGetVehicleIdlingReportsUnauthorizedErrorResponseBody,
    )
    from .ifta_create_ifta_detail_job_bad_gateway_error_response_body import (
        IftaCreateIftaDetailJobBadGatewayErrorResponseBody,
    )
    from .ifta_create_ifta_detail_job_gateway_timeout_error_response_body import (
        IftaCreateIftaDetailJobGatewayTimeoutErrorResponseBody,
    )
    from .ifta_create_ifta_detail_job_internal_server_error_response_body import (
        IftaCreateIftaDetailJobInternalServerErrorResponseBody,
    )
    from .ifta_create_ifta_detail_job_method_not_allowed_error_response_body import (
        IftaCreateIftaDetailJobMethodNotAllowedErrorResponseBody,
    )
    from .ifta_create_ifta_detail_job_not_found_error_response_body import (
        IftaCreateIftaDetailJobNotFoundErrorResponseBody,
    )
    from .ifta_create_ifta_detail_job_not_implemented_error_response_body import (
        IftaCreateIftaDetailJobNotImplementedErrorResponseBody,
    )
    from .ifta_create_ifta_detail_job_response_body import IftaCreateIftaDetailJobResponseBody
    from .ifta_create_ifta_detail_job_service_unavailable_error_response_body import (
        IftaCreateIftaDetailJobServiceUnavailableErrorResponseBody,
    )
    from .ifta_create_ifta_detail_job_too_many_requests_error_response_body import (
        IftaCreateIftaDetailJobTooManyRequestsErrorResponseBody,
    )
    from .ifta_create_ifta_detail_job_unauthorized_error_response_body import (
        IftaCreateIftaDetailJobUnauthorizedErrorResponseBody,
    )
    from .ifta_detail_job_args_response_body import IftaDetailJobArgsResponseBody
    from .ifta_detail_job_output_response_body import IftaDetailJobOutputResponseBody
    from .ifta_detail_job_response_body import IftaDetailJobResponseBody
    from .ifta_detail_job_response_body_job_status import IftaDetailJobResponseBodyJobStatus
    from .ifta_get_ifta_detail_job_bad_gateway_error_response_body import (
        IftaGetIftaDetailJobBadGatewayErrorResponseBody,
    )
    from .ifta_get_ifta_detail_job_gateway_timeout_error_response_body import (
        IftaGetIftaDetailJobGatewayTimeoutErrorResponseBody,
    )
    from .ifta_get_ifta_detail_job_internal_server_error_response_body import (
        IftaGetIftaDetailJobInternalServerErrorResponseBody,
    )
    from .ifta_get_ifta_detail_job_method_not_allowed_error_response_body import (
        IftaGetIftaDetailJobMethodNotAllowedErrorResponseBody,
    )
    from .ifta_get_ifta_detail_job_not_found_error_response_body import IftaGetIftaDetailJobNotFoundErrorResponseBody
    from .ifta_get_ifta_detail_job_not_implemented_error_response_body import (
        IftaGetIftaDetailJobNotImplementedErrorResponseBody,
    )
    from .ifta_get_ifta_detail_job_response_body import IftaGetIftaDetailJobResponseBody
    from .ifta_get_ifta_detail_job_service_unavailable_error_response_body import (
        IftaGetIftaDetailJobServiceUnavailableErrorResponseBody,
    )
    from .ifta_get_ifta_detail_job_too_many_requests_error_response_body import (
        IftaGetIftaDetailJobTooManyRequestsErrorResponseBody,
    )
    from .ifta_get_ifta_detail_job_unauthorized_error_response_body import (
        IftaGetIftaDetailJobUnauthorizedErrorResponseBody,
    )
    from .ifta_get_ifta_jurisdiction_reports_bad_gateway_error_response_body import (
        IftaGetIftaJurisdictionReportsBadGatewayErrorResponseBody,
    )
    from .ifta_get_ifta_jurisdiction_reports_gateway_timeout_error_response_body import (
        IftaGetIftaJurisdictionReportsGatewayTimeoutErrorResponseBody,
    )
    from .ifta_get_ifta_jurisdiction_reports_internal_server_error_response_body import (
        IftaGetIftaJurisdictionReportsInternalServerErrorResponseBody,
    )
    from .ifta_get_ifta_jurisdiction_reports_method_not_allowed_error_response_body import (
        IftaGetIftaJurisdictionReportsMethodNotAllowedErrorResponseBody,
    )
    from .ifta_get_ifta_jurisdiction_reports_not_found_error_response_body import (
        IftaGetIftaJurisdictionReportsNotFoundErrorResponseBody,
    )
    from .ifta_get_ifta_jurisdiction_reports_not_implemented_error_response_body import (
        IftaGetIftaJurisdictionReportsNotImplementedErrorResponseBody,
    )
    from .ifta_get_ifta_jurisdiction_reports_response_body import IftaGetIftaJurisdictionReportsResponseBody
    from .ifta_get_ifta_jurisdiction_reports_service_unavailable_error_response_body import (
        IftaGetIftaJurisdictionReportsServiceUnavailableErrorResponseBody,
    )
    from .ifta_get_ifta_jurisdiction_reports_too_many_requests_error_response_body import (
        IftaGetIftaJurisdictionReportsTooManyRequestsErrorResponseBody,
    )
    from .ifta_get_ifta_jurisdiction_reports_unauthorized_error_response_body import (
        IftaGetIftaJurisdictionReportsUnauthorizedErrorResponseBody,
    )
    from .ifta_get_ifta_vehicle_reports_bad_gateway_error_response_body import (
        IftaGetIftaVehicleReportsBadGatewayErrorResponseBody,
    )
    from .ifta_get_ifta_vehicle_reports_gateway_timeout_error_response_body import (
        IftaGetIftaVehicleReportsGatewayTimeoutErrorResponseBody,
    )
    from .ifta_get_ifta_vehicle_reports_internal_server_error_response_body import (
        IftaGetIftaVehicleReportsInternalServerErrorResponseBody,
    )
    from .ifta_get_ifta_vehicle_reports_method_not_allowed_error_response_body import (
        IftaGetIftaVehicleReportsMethodNotAllowedErrorResponseBody,
    )
    from .ifta_get_ifta_vehicle_reports_not_found_error_response_body import (
        IftaGetIftaVehicleReportsNotFoundErrorResponseBody,
    )
    from .ifta_get_ifta_vehicle_reports_not_implemented_error_response_body import (
        IftaGetIftaVehicleReportsNotImplementedErrorResponseBody,
    )
    from .ifta_get_ifta_vehicle_reports_response_body import IftaGetIftaVehicleReportsResponseBody
    from .ifta_get_ifta_vehicle_reports_service_unavailable_error_response_body import (
        IftaGetIftaVehicleReportsServiceUnavailableErrorResponseBody,
    )
    from .ifta_get_ifta_vehicle_reports_too_many_requests_error_response_body import (
        IftaGetIftaVehicleReportsTooManyRequestsErrorResponseBody,
    )
    from .ifta_get_ifta_vehicle_reports_unauthorized_error_response_body import (
        IftaGetIftaVehicleReportsUnauthorizedErrorResponseBody,
    )
    from .ifta_jurisdiction_report_data_object_response_body import IftaJurisdictionReportDataObjectResponseBody
    from .ifta_jurisdiction_summary_object_response_body import IftaJurisdictionSummaryObjectResponseBody
    from .ifta_report_troubleshooting_object_response_body import IftaReportTroubleshootingObjectResponseBody
    from .ifta_vehicle_report_data_object_response_body import IftaVehicleReportDataObjectResponseBody
    from .ifta_vehicle_report_object_response_body import IftaVehicleReportObjectResponseBody
    from .in_app_notification_options_object_request_body import InAppNotificationOptionsObjectRequestBody
    from .in_app_notification_options_object_response_body import InAppNotificationOptionsObjectResponseBody
    from .inactivity_response_body import InactivityResponseBody
    from .inattentive_driving_detection_alert_settings_object_response_body import (
        InattentiveDrivingDetectionAlertSettingsObjectResponseBody,
    )
    from .inattentive_driving_detection_alert_settings_object_response_body_severity import (
        InattentiveDrivingDetectionAlertSettingsObjectResponseBodySeverity,
    )
    from .industrial_asset_object_response_body import IndustrialAssetObjectResponseBody
    from .inline_response_200 import InlineResponse200
    from .inline_response_2001 import InlineResponse2001
    from .inline_response_2002 import InlineResponse2002
    from .inline_response_2003 import InlineResponse2003
    from .inline_response_2004 import InlineResponse2004
    from .inline_response_2005 import InlineResponse2005
    from .inline_response_2006 import InlineResponse2006
    from .inline_response_2007 import InlineResponse2007
    from .inline_response_2008 import InlineResponse2008
    from .inline_response_2009 import InlineResponse2009
    from .inside_geofence_data_response_body import InsideGeofenceDataResponseBody
    from .inside_geofence_trigger_details_object_request_body import InsideGeofenceTriggerDetailsObjectRequestBody
    from .inside_geofence_trigger_details_object_response_body import InsideGeofenceTriggerDetailsObjectResponseBody
    from .invoice_scan_file_request_body import InvoiceScanFileRequestBody
    from .issue_created_response_body import IssueCreatedResponseBody
    from .issue_response_object_response_body import IssueResponseObjectResponseBody
    from .issue_response_object_response_body_priority import IssueResponseObjectResponseBodyPriority
    from .issue_response_object_response_body_status import IssueResponseObjectResponseBodyStatus
    from .issue_source_object_response_body import IssueSourceObjectResponseBody
    from .issue_source_object_response_body_type import IssueSourceObjectResponseBodyType
    from .issues_get_issues_bad_gateway_error_response_body import IssuesGetIssuesBadGatewayErrorResponseBody
    from .issues_get_issues_gateway_timeout_error_response_body import IssuesGetIssuesGatewayTimeoutErrorResponseBody
    from .issues_get_issues_internal_server_error_response_body import IssuesGetIssuesInternalServerErrorResponseBody
    from .issues_get_issues_method_not_allowed_error_response_body import (
        IssuesGetIssuesMethodNotAllowedErrorResponseBody,
    )
    from .issues_get_issues_not_found_error_response_body import IssuesGetIssuesNotFoundErrorResponseBody
    from .issues_get_issues_not_implemented_error_response_body import IssuesGetIssuesNotImplementedErrorResponseBody
    from .issues_get_issues_response_body import IssuesGetIssuesResponseBody
    from .issues_get_issues_service_unavailable_error_response_body import (
        IssuesGetIssuesServiceUnavailableErrorResponseBody,
    )
    from .issues_get_issues_stream_bad_gateway_error_response_body import (
        IssuesGetIssuesStreamBadGatewayErrorResponseBody,
    )
    from .issues_get_issues_stream_gateway_timeout_error_response_body import (
        IssuesGetIssuesStreamGatewayTimeoutErrorResponseBody,
    )
    from .issues_get_issues_stream_internal_server_error_response_body import (
        IssuesGetIssuesStreamInternalServerErrorResponseBody,
    )
    from .issues_get_issues_stream_method_not_allowed_error_response_body import (
        IssuesGetIssuesStreamMethodNotAllowedErrorResponseBody,
    )
    from .issues_get_issues_stream_not_found_error_response_body import IssuesGetIssuesStreamNotFoundErrorResponseBody
    from .issues_get_issues_stream_not_implemented_error_response_body import (
        IssuesGetIssuesStreamNotImplementedErrorResponseBody,
    )
    from .issues_get_issues_stream_response_body import IssuesGetIssuesStreamResponseBody
    from .issues_get_issues_stream_service_unavailable_error_response_body import (
        IssuesGetIssuesStreamServiceUnavailableErrorResponseBody,
    )
    from .issues_get_issues_stream_too_many_requests_error_response_body import (
        IssuesGetIssuesStreamTooManyRequestsErrorResponseBody,
    )
    from .issues_get_issues_stream_unauthorized_error_response_body import (
        IssuesGetIssuesStreamUnauthorizedErrorResponseBody,
    )
    from .issues_get_issues_too_many_requests_error_response_body import IssuesGetIssuesTooManyRequestsErrorResponseBody
    from .issues_get_issues_unauthorized_error_response_body import IssuesGetIssuesUnauthorizedErrorResponseBody
    from .issues_patch_issue_bad_gateway_error_response_body import IssuesPatchIssueBadGatewayErrorResponseBody
    from .issues_patch_issue_gateway_timeout_error_response_body import IssuesPatchIssueGatewayTimeoutErrorResponseBody
    from .issues_patch_issue_internal_server_error_response_body import IssuesPatchIssueInternalServerErrorResponseBody
    from .issues_patch_issue_method_not_allowed_error_response_body import (
        IssuesPatchIssueMethodNotAllowedErrorResponseBody,
    )
    from .issues_patch_issue_not_found_error_response_body import IssuesPatchIssueNotFoundErrorResponseBody
    from .issues_patch_issue_not_implemented_error_response_body import IssuesPatchIssueNotImplementedErrorResponseBody
    from .issues_patch_issue_response_body import IssuesPatchIssueResponseBody
    from .issues_patch_issue_service_unavailable_error_response_body import (
        IssuesPatchIssueServiceUnavailableErrorResponseBody,
    )
    from .issues_patch_issue_too_many_requests_error_response_body import (
        IssuesPatchIssueTooManyRequestsErrorResponseBody,
    )
    from .issues_patch_issue_unauthorized_error_response_body import IssuesPatchIssueUnauthorizedErrorResponseBody
    from .j_1939_d_1_status_data_point import J1939D1StatusDataPoint
    from .j_1939_d_1_status_data_point_value import J1939D1StatusDataPointValue
    from .jamming_detected_response_body import JammingDetectedResponseBody
    from .job_location_response_object_response_body import JobLocationResponseObjectResponseBody
    from .job_response_object_response_body import JobResponseObjectResponseBody
    from .job_response_object_response_body_status import JobResponseObjectResponseBodyStatus
    from .jobs_create_job_bad_gateway_error_response_body import JobsCreateJobBadGatewayErrorResponseBody
    from .jobs_create_job_gateway_timeout_error_response_body import JobsCreateJobGatewayTimeoutErrorResponseBody
    from .jobs_create_job_internal_server_error_response_body import JobsCreateJobInternalServerErrorResponseBody
    from .jobs_create_job_method_not_allowed_error_response_body import JobsCreateJobMethodNotAllowedErrorResponseBody
    from .jobs_create_job_not_found_error_response_body import JobsCreateJobNotFoundErrorResponseBody
    from .jobs_create_job_not_implemented_error_response_body import JobsCreateJobNotImplementedErrorResponseBody
    from .jobs_create_job_response_body import JobsCreateJobResponseBody
    from .jobs_create_job_service_unavailable_error_response_body import (
        JobsCreateJobServiceUnavailableErrorResponseBody,
    )
    from .jobs_create_job_too_many_requests_error_response_body import JobsCreateJobTooManyRequestsErrorResponseBody
    from .jobs_create_job_unauthorized_error_response_body import JobsCreateJobUnauthorizedErrorResponseBody
    from .jobs_delete_job_bad_gateway_error_response_body import JobsDeleteJobBadGatewayErrorResponseBody
    from .jobs_delete_job_gateway_timeout_error_response_body import JobsDeleteJobGatewayTimeoutErrorResponseBody
    from .jobs_delete_job_internal_server_error_response_body import JobsDeleteJobInternalServerErrorResponseBody
    from .jobs_delete_job_method_not_allowed_error_response_body import JobsDeleteJobMethodNotAllowedErrorResponseBody
    from .jobs_delete_job_not_found_error_response_body import JobsDeleteJobNotFoundErrorResponseBody
    from .jobs_delete_job_not_implemented_error_response_body import JobsDeleteJobNotImplementedErrorResponseBody
    from .jobs_delete_job_response_body import JobsDeleteJobResponseBody
    from .jobs_delete_job_service_unavailable_error_response_body import (
        JobsDeleteJobServiceUnavailableErrorResponseBody,
    )
    from .jobs_delete_job_too_many_requests_error_response_body import JobsDeleteJobTooManyRequestsErrorResponseBody
    from .jobs_delete_job_unauthorized_error_response_body import JobsDeleteJobUnauthorizedErrorResponseBody
    from .jobs_get_jobs_bad_gateway_error_response_body import JobsGetJobsBadGatewayErrorResponseBody
    from .jobs_get_jobs_gateway_timeout_error_response_body import JobsGetJobsGatewayTimeoutErrorResponseBody
    from .jobs_get_jobs_internal_server_error_response_body import JobsGetJobsInternalServerErrorResponseBody
    from .jobs_get_jobs_method_not_allowed_error_response_body import JobsGetJobsMethodNotAllowedErrorResponseBody
    from .jobs_get_jobs_not_found_error_response_body import JobsGetJobsNotFoundErrorResponseBody
    from .jobs_get_jobs_not_implemented_error_response_body import JobsGetJobsNotImplementedErrorResponseBody
    from .jobs_get_jobs_response_body import JobsGetJobsResponseBody
    from .jobs_get_jobs_service_unavailable_error_response_body import JobsGetJobsServiceUnavailableErrorResponseBody
    from .jobs_get_jobs_too_many_requests_error_response_body import JobsGetJobsTooManyRequestsErrorResponseBody
    from .jobs_get_jobs_unauthorized_error_response_body import JobsGetJobsUnauthorizedErrorResponseBody
    from .jobs_patch_job_bad_gateway_error_response_body import JobsPatchJobBadGatewayErrorResponseBody
    from .jobs_patch_job_gateway_timeout_error_response_body import JobsPatchJobGatewayTimeoutErrorResponseBody
    from .jobs_patch_job_internal_server_error_response_body import JobsPatchJobInternalServerErrorResponseBody
    from .jobs_patch_job_method_not_allowed_error_response_body import JobsPatchJobMethodNotAllowedErrorResponseBody
    from .jobs_patch_job_not_found_error_response_body import JobsPatchJobNotFoundErrorResponseBody
    from .jobs_patch_job_not_implemented_error_response_body import JobsPatchJobNotImplementedErrorResponseBody
    from .jobs_patch_job_response_body import JobsPatchJobResponseBody
    from .jobs_patch_job_service_unavailable_error_response_body import JobsPatchJobServiceUnavailableErrorResponseBody
    from .jobs_patch_job_too_many_requests_error_response_body import JobsPatchJobTooManyRequestsErrorResponseBody
    from .jobs_patch_job_unauthorized_error_response_body import JobsPatchJobUnauthorizedErrorResponseBody
    from .last_known_location_response_response_body import LastKnownLocationResponseResponseBody
    from .latitude import Latitude
    from .list_addresses_response import ListAddressesResponse
    from .list_carrier_proposed_assignment_response import ListCarrierProposedAssignmentResponse
    from .list_contacts_response import ListContactsResponse
    from .list_drivers_response import ListDriversResponse
    from .list_hub_capacities_response_pagination_response_body import ListHubCapacitiesResponsePaginationResponseBody
    from .list_hub_custom_properties_response_pagination_response_body import (
        ListHubCustomPropertiesResponsePaginationResponseBody,
    )
    from .list_hub_locations_response_pagination_response_body import ListHubLocationsResponsePaginationResponseBody
    from .list_hub_plan_routes_response_pagination_response_body import ListHubPlanRoutesResponsePaginationResponseBody
    from .list_hub_plans_response_pagination_response_body import ListHubPlansResponsePaginationResponseBody
    from .list_hub_skills_response_pagination_response_body import ListHubSkillsResponsePaginationResponseBody
    from .list_hubs_response_pagination_response_body import ListHubsResponsePaginationResponseBody
    from .list_industrial_assets_response import ListIndustrialAssetsResponse
    from .list_tags_response import ListTagsResponse
    from .list_uploaded_media_object_response_body import ListUploadedMediaObjectResponseBody
    from .list_user_roles_response import ListUserRolesResponse
    from .list_users_response import ListUsersResponse
    from .live_sharing_link_full_response_object_response_body import LiveSharingLinkFullResponseObjectResponseBody
    from .live_sharing_link_full_response_object_response_body_type import (
        LiveSharingLinkFullResponseObjectResponseBodyType,
    )
    from .live_sharing_link_response_object_response_body import LiveSharingLinkResponseObjectResponseBody
    from .live_sharing_links_create_live_sharing_link_bad_gateway_error_response_body import (
        LiveSharingLinksCreateLiveSharingLinkBadGatewayErrorResponseBody,
    )
    from .live_sharing_links_create_live_sharing_link_gateway_timeout_error_response_body import (
        LiveSharingLinksCreateLiveSharingLinkGatewayTimeoutErrorResponseBody,
    )
    from .live_sharing_links_create_live_sharing_link_internal_server_error_response_body import (
        LiveSharingLinksCreateLiveSharingLinkInternalServerErrorResponseBody,
    )
    from .live_sharing_links_create_live_sharing_link_method_not_allowed_error_response_body import (
        LiveSharingLinksCreateLiveSharingLinkMethodNotAllowedErrorResponseBody,
    )
    from .live_sharing_links_create_live_sharing_link_not_found_error_response_body import (
        LiveSharingLinksCreateLiveSharingLinkNotFoundErrorResponseBody,
    )
    from .live_sharing_links_create_live_sharing_link_not_implemented_error_response_body import (
        LiveSharingLinksCreateLiveSharingLinkNotImplementedErrorResponseBody,
    )
    from .live_sharing_links_create_live_sharing_link_response_body import (
        LiveSharingLinksCreateLiveSharingLinkResponseBody,
    )
    from .live_sharing_links_create_live_sharing_link_service_unavailable_error_response_body import (
        LiveSharingLinksCreateLiveSharingLinkServiceUnavailableErrorResponseBody,
    )
    from .live_sharing_links_create_live_sharing_link_too_many_requests_error_response_body import (
        LiveSharingLinksCreateLiveSharingLinkTooManyRequestsErrorResponseBody,
    )
    from .live_sharing_links_create_live_sharing_link_unauthorized_error_response_body import (
        LiveSharingLinksCreateLiveSharingLinkUnauthorizedErrorResponseBody,
    )
    from .live_sharing_links_delete_live_sharing_link_bad_gateway_error_response_body import (
        LiveSharingLinksDeleteLiveSharingLinkBadGatewayErrorResponseBody,
    )
    from .live_sharing_links_delete_live_sharing_link_gateway_timeout_error_response_body import (
        LiveSharingLinksDeleteLiveSharingLinkGatewayTimeoutErrorResponseBody,
    )
    from .live_sharing_links_delete_live_sharing_link_internal_server_error_response_body import (
        LiveSharingLinksDeleteLiveSharingLinkInternalServerErrorResponseBody,
    )
    from .live_sharing_links_delete_live_sharing_link_method_not_allowed_error_response_body import (
        LiveSharingLinksDeleteLiveSharingLinkMethodNotAllowedErrorResponseBody,
    )
    from .live_sharing_links_delete_live_sharing_link_not_found_error_response_body import (
        LiveSharingLinksDeleteLiveSharingLinkNotFoundErrorResponseBody,
    )
    from .live_sharing_links_delete_live_sharing_link_not_implemented_error_response_body import (
        LiveSharingLinksDeleteLiveSharingLinkNotImplementedErrorResponseBody,
    )
    from .live_sharing_links_delete_live_sharing_link_service_unavailable_error_response_body import (
        LiveSharingLinksDeleteLiveSharingLinkServiceUnavailableErrorResponseBody,
    )
    from .live_sharing_links_delete_live_sharing_link_too_many_requests_error_response_body import (
        LiveSharingLinksDeleteLiveSharingLinkTooManyRequestsErrorResponseBody,
    )
    from .live_sharing_links_delete_live_sharing_link_unauthorized_error_response_body import (
        LiveSharingLinksDeleteLiveSharingLinkUnauthorizedErrorResponseBody,
    )
    from .live_sharing_links_get_live_sharing_links_bad_gateway_error_response_body import (
        LiveSharingLinksGetLiveSharingLinksBadGatewayErrorResponseBody,
    )
    from .live_sharing_links_get_live_sharing_links_gateway_timeout_error_response_body import (
        LiveSharingLinksGetLiveSharingLinksGatewayTimeoutErrorResponseBody,
    )
    from .live_sharing_links_get_live_sharing_links_internal_server_error_response_body import (
        LiveSharingLinksGetLiveSharingLinksInternalServerErrorResponseBody,
    )
    from .live_sharing_links_get_live_sharing_links_method_not_allowed_error_response_body import (
        LiveSharingLinksGetLiveSharingLinksMethodNotAllowedErrorResponseBody,
    )
    from .live_sharing_links_get_live_sharing_links_not_found_error_response_body import (
        LiveSharingLinksGetLiveSharingLinksNotFoundErrorResponseBody,
    )
    from .live_sharing_links_get_live_sharing_links_not_implemented_error_response_body import (
        LiveSharingLinksGetLiveSharingLinksNotImplementedErrorResponseBody,
    )
    from .live_sharing_links_get_live_sharing_links_response_body import LiveSharingLinksGetLiveSharingLinksResponseBody
    from .live_sharing_links_get_live_sharing_links_service_unavailable_error_response_body import (
        LiveSharingLinksGetLiveSharingLinksServiceUnavailableErrorResponseBody,
    )
    from .live_sharing_links_get_live_sharing_links_too_many_requests_error_response_body import (
        LiveSharingLinksGetLiveSharingLinksTooManyRequestsErrorResponseBody,
    )
    from .live_sharing_links_get_live_sharing_links_unauthorized_error_response_body import (
        LiveSharingLinksGetLiveSharingLinksUnauthorizedErrorResponseBody,
    )
    from .live_sharing_links_update_live_sharing_link_bad_gateway_error_response_body import (
        LiveSharingLinksUpdateLiveSharingLinkBadGatewayErrorResponseBody,
    )
    from .live_sharing_links_update_live_sharing_link_gateway_timeout_error_response_body import (
        LiveSharingLinksUpdateLiveSharingLinkGatewayTimeoutErrorResponseBody,
    )
    from .live_sharing_links_update_live_sharing_link_internal_server_error_response_body import (
        LiveSharingLinksUpdateLiveSharingLinkInternalServerErrorResponseBody,
    )
    from .live_sharing_links_update_live_sharing_link_method_not_allowed_error_response_body import (
        LiveSharingLinksUpdateLiveSharingLinkMethodNotAllowedErrorResponseBody,
    )
    from .live_sharing_links_update_live_sharing_link_not_found_error_response_body import (
        LiveSharingLinksUpdateLiveSharingLinkNotFoundErrorResponseBody,
    )
    from .live_sharing_links_update_live_sharing_link_not_implemented_error_response_body import (
        LiveSharingLinksUpdateLiveSharingLinkNotImplementedErrorResponseBody,
    )
    from .live_sharing_links_update_live_sharing_link_response_body import (
        LiveSharingLinksUpdateLiveSharingLinkResponseBody,
    )
    from .live_sharing_links_update_live_sharing_link_service_unavailable_error_response_body import (
        LiveSharingLinksUpdateLiveSharingLinkServiceUnavailableErrorResponseBody,
    )
    from .live_sharing_links_update_live_sharing_link_too_many_requests_error_response_body import (
        LiveSharingLinksUpdateLiveSharingLinkTooManyRequestsErrorResponseBody,
    )
    from .live_sharing_links_update_live_sharing_link_unauthorized_error_response_body import (
        LiveSharingLinksUpdateLiveSharingLinkUnauthorizedErrorResponseBody,
    )
    from .location import Location
    from .location_and_speed_get_location_and_speed_bad_gateway_error_response_body import (
        LocationAndSpeedGetLocationAndSpeedBadGatewayErrorResponseBody,
    )
    from .location_and_speed_get_location_and_speed_gateway_timeout_error_response_body import (
        LocationAndSpeedGetLocationAndSpeedGatewayTimeoutErrorResponseBody,
    )
    from .location_and_speed_get_location_and_speed_internal_server_error_response_body import (
        LocationAndSpeedGetLocationAndSpeedInternalServerErrorResponseBody,
    )
    from .location_and_speed_get_location_and_speed_method_not_allowed_error_response_body import (
        LocationAndSpeedGetLocationAndSpeedMethodNotAllowedErrorResponseBody,
    )
    from .location_and_speed_get_location_and_speed_not_found_error_response_body import (
        LocationAndSpeedGetLocationAndSpeedNotFoundErrorResponseBody,
    )
    from .location_and_speed_get_location_and_speed_not_implemented_error_response_body import (
        LocationAndSpeedGetLocationAndSpeedNotImplementedErrorResponseBody,
    )
    from .location_and_speed_get_location_and_speed_response_body import LocationAndSpeedGetLocationAndSpeedResponseBody
    from .location_and_speed_get_location_and_speed_service_unavailable_error_response_body import (
        LocationAndSpeedGetLocationAndSpeedServiceUnavailableErrorResponseBody,
    )
    from .location_and_speed_get_location_and_speed_too_many_requests_error_response_body import (
        LocationAndSpeedGetLocationAndSpeedTooManyRequestsErrorResponseBody,
    )
    from .location_and_speed_get_location_and_speed_unauthorized_error_response_body import (
        LocationAndSpeedGetLocationAndSpeedUnauthorizedErrorResponseBody,
    )
    from .location_and_speed_response_response_body import LocationAndSpeedResponseResponseBody
    from .location_data_point import LocationDataPoint
    from .location_data_point_gps_location import LocationDataPointGpsLocation
    from .location_data_point_gps_location_place import LocationDataPointGpsLocationPlace
    from .location_object_request_body import LocationObjectRequestBody
    from .location_object_request_body_address_types_item import LocationObjectRequestBodyAddressTypesItem
    from .location_object_response_body import LocationObjectResponseBody
    from .location_object_response_body_address_types_item import LocationObjectResponseBodyAddressTypesItem
    from .location_response_body import LocationResponseBody
    from .location_response_response_body import LocationResponseResponseBody
    from .location_type import LocationType
    from .log_meta_data_object_response_body import LogMetaDataObjectResponseBody
    from .longitude import Longitude
    from .media_object_response_body import MediaObjectResponseBody
    from .media_object_response_body_camera_role import MediaObjectResponseBodyCameraRole
    from .media_object_response_body_input import MediaObjectResponseBodyInput
    from .media_object_response_body_media_type import MediaObjectResponseBodyMediaType
    from .media_object_response_body_status import MediaObjectResponseBodyStatus
    from .media_retrieval_get_media_retrieval_bad_gateway_error_response_body import (
        MediaRetrievalGetMediaRetrievalBadGatewayErrorResponseBody,
    )
    from .media_retrieval_get_media_retrieval_gateway_timeout_error_response_body import (
        MediaRetrievalGetMediaRetrievalGatewayTimeoutErrorResponseBody,
    )
    from .media_retrieval_get_media_retrieval_internal_server_error_response_body import (
        MediaRetrievalGetMediaRetrievalInternalServerErrorResponseBody,
    )
    from .media_retrieval_get_media_retrieval_method_not_allowed_error_response_body import (
        MediaRetrievalGetMediaRetrievalMethodNotAllowedErrorResponseBody,
    )
    from .media_retrieval_get_media_retrieval_not_found_error_response_body import (
        MediaRetrievalGetMediaRetrievalNotFoundErrorResponseBody,
    )
    from .media_retrieval_get_media_retrieval_not_implemented_error_response_body import (
        MediaRetrievalGetMediaRetrievalNotImplementedErrorResponseBody,
    )
    from .media_retrieval_get_media_retrieval_response_body import MediaRetrievalGetMediaRetrievalResponseBody
    from .media_retrieval_get_media_retrieval_service_unavailable_error_response_body import (
        MediaRetrievalGetMediaRetrievalServiceUnavailableErrorResponseBody,
    )
    from .media_retrieval_get_media_retrieval_too_many_requests_error_response_body import (
        MediaRetrievalGetMediaRetrievalTooManyRequestsErrorResponseBody,
    )
    from .media_retrieval_get_media_retrieval_unauthorized_error_response_body import (
        MediaRetrievalGetMediaRetrievalUnauthorizedErrorResponseBody,
    )
    from .media_retrieval_list_uploaded_media_bad_gateway_error_response_body import (
        MediaRetrievalListUploadedMediaBadGatewayErrorResponseBody,
    )
    from .media_retrieval_list_uploaded_media_gateway_timeout_error_response_body import (
        MediaRetrievalListUploadedMediaGatewayTimeoutErrorResponseBody,
    )
    from .media_retrieval_list_uploaded_media_internal_server_error_response_body import (
        MediaRetrievalListUploadedMediaInternalServerErrorResponseBody,
    )
    from .media_retrieval_list_uploaded_media_method_not_allowed_error_response_body import (
        MediaRetrievalListUploadedMediaMethodNotAllowedErrorResponseBody,
    )
    from .media_retrieval_list_uploaded_media_not_found_error_response_body import (
        MediaRetrievalListUploadedMediaNotFoundErrorResponseBody,
    )
    from .media_retrieval_list_uploaded_media_not_implemented_error_response_body import (
        MediaRetrievalListUploadedMediaNotImplementedErrorResponseBody,
    )
    from .media_retrieval_list_uploaded_media_response_body import MediaRetrievalListUploadedMediaResponseBody
    from .media_retrieval_list_uploaded_media_service_unavailable_error_response_body import (
        MediaRetrievalListUploadedMediaServiceUnavailableErrorResponseBody,
    )
    from .media_retrieval_list_uploaded_media_too_many_requests_error_response_body import (
        MediaRetrievalListUploadedMediaTooManyRequestsErrorResponseBody,
    )
    from .media_retrieval_list_uploaded_media_unauthorized_error_response_body import (
        MediaRetrievalListUploadedMediaUnauthorizedErrorResponseBody,
    )
    from .media_retrieval_post_media_retrieval_bad_gateway_error_response_body import (
        MediaRetrievalPostMediaRetrievalBadGatewayErrorResponseBody,
    )
    from .media_retrieval_post_media_retrieval_gateway_timeout_error_response_body import (
        MediaRetrievalPostMediaRetrievalGatewayTimeoutErrorResponseBody,
    )
    from .media_retrieval_post_media_retrieval_internal_server_error_response_body import (
        MediaRetrievalPostMediaRetrievalInternalServerErrorResponseBody,
    )
    from .media_retrieval_post_media_retrieval_method_not_allowed_error_response_body import (
        MediaRetrievalPostMediaRetrievalMethodNotAllowedErrorResponseBody,
    )
    from .media_retrieval_post_media_retrieval_not_found_error_response_body import (
        MediaRetrievalPostMediaRetrievalNotFoundErrorResponseBody,
    )
    from .media_retrieval_post_media_retrieval_not_implemented_error_response_body import (
        MediaRetrievalPostMediaRetrievalNotImplementedErrorResponseBody,
    )
    from .media_retrieval_post_media_retrieval_response_body import MediaRetrievalPostMediaRetrievalResponseBody
    from .media_retrieval_post_media_retrieval_service_unavailable_error_response_body import (
        MediaRetrievalPostMediaRetrievalServiceUnavailableErrorResponseBody,
    )
    from .media_retrieval_post_media_retrieval_too_many_requests_error_response_body import (
        MediaRetrievalPostMediaRetrievalTooManyRequestsErrorResponseBody,
    )
    from .media_retrieval_post_media_retrieval_unauthorized_error_response_body import (
        MediaRetrievalPostMediaRetrievalUnauthorizedErrorResponseBody,
    )
    from .minimal_route_audit_logs_response_body import MinimalRouteAuditLogsResponseBody
    from .minimal_route_stop_audit_logs_response_body import MinimalRouteStopAuditLogsResponseBody
    from .minimal_route_stop_audit_logs_response_body_state import MinimalRouteStopAuditLogsResponseBodyState
    from .minimal_route_stop_response_body import MinimalRouteStopResponseBody
    from .minimal_route_stop_response_body_state import MinimalRouteStopResponseBodyState
    from .missing_dvir_past_due_response_body import MissingDvirPastDueResponseBody
    from .mobile_usage_detection_alert_settings_object_response_body import (
        MobileUsageDetectionAlertSettingsObjectResponseBody,
    )
    from .motion_detected_response_body import MotionDetectedResponseBody
    from .multiple_choice_field_type_meta_data_object_response_body import (
        MultipleChoiceFieldTypeMetaDataObjectResponseBody,
    )
    from .multiple_choice_value_object_request_body import MultipleChoiceValueObjectRequestBody
    from .multiple_choice_value_object_response_body import MultipleChoiceValueObjectResponseBody
    from .number_data_point import NumberDataPoint
    from .number_field_type_meta_data_object_response_body import NumberFieldTypeMetaDataObjectResponseBody
    from .operational_settings_object_request_body import OperationalSettingsObjectRequestBody
    from .operational_settings_object_request_body_time_range_type import (
        OperationalSettingsObjectRequestBodyTimeRangeType,
    )
    from .operational_settings_object_response_body import OperationalSettingsObjectResponseBody
    from .operational_settings_object_response_body_time_range_type import (
        OperationalSettingsObjectResponseBodyTimeRangeType,
    )
    from .order_custom_property_input_request_body import OrderCustomPropertyInputRequestBody
    from .order_custom_property_response_body import OrderCustomPropertyResponseBody
    from .order_input_object_request_body import OrderInputObjectRequestBody
    from .order_object_response_body import OrderObjectResponseBody
    from .order_quantity_input_request_body import OrderQuantityInputRequestBody
    from .order_quantity_response_body import OrderQuantityResponseBody
    from .order_task_custom_property_object_response_body import OrderTaskCustomPropertyObjectResponseBody
    from .order_task_object_response_body import OrderTaskObjectResponseBody
    from .order_task_request_body import OrderTaskRequestBody
    from .order_task_request_body_position import OrderTaskRequestBodyPosition
    from .order_task_response_body import OrderTaskResponseBody
    from .order_task_response_body_position import OrderTaskResponseBodyPosition
    from .order_task_skill_object_response_body import OrderTaskSkillObjectResponseBody
    from .organization_info_carrier_settings import OrganizationInfoCarrierSettings
    from .organization_info_object import OrganizationInfoObject
    from .organization_info_response import OrganizationInfoResponse
    from .out_of_route_details_object_request_body import OutOfRouteDetailsObjectRequestBody
    from .out_of_route_details_object_response_body import OutOfRouteDetailsObjectResponseBody
    from .out_of_route_response_body import OutOfRouteResponseBody
    from .outside_geofence_data_response_body import OutsideGeofenceDataResponseBody
    from .outside_geofence_trigger_details_object_request_body import OutsideGeofenceTriggerDetailsObjectRequestBody
    from .outside_geofence_trigger_details_object_response_body import OutsideGeofenceTriggerDetailsObjectResponseBody
    from .over_speed_ms import OverSpeedMs
    from .pagination_response import PaginationResponse
    from .panic_button_details_object_request_body import PanicButtonDetailsObjectRequestBody
    from .panic_button_details_object_response_body import PanicButtonDetailsObjectResponseBody
    from .panic_button_response_body import PanicButtonResponseBody
    from .parent_id import ParentId
    from .parent_tag import ParentTag
    from .parent_tag_id import ParentTagId
    from .parent_tag_name import ParentTagName
    from .part_instance_input_object_request_body import PartInstanceInputObjectRequestBody
    from .part_instance_object_response_body import PartInstanceObjectResponseBody
    from .patch_asset_data_outputs_single_response_response_body import PatchAssetDataOutputsSingleResponseResponseBody
    from .patch_driver_trailer_assignments_response_body_response_body import (
        PatchDriverTrailerAssignmentsResponseBodyResponseBody,
    )
    from .patch_driver_vehicle_assignments_v_2_request_body_metadata_request_body import (
        PatchDriverVehicleAssignmentsV2RequestBodyMetadataRequestBody,
    )
    from .patch_driver_vehicle_assignments_v_2_response_body_response_body import (
        PatchDriverVehicleAssignmentsV2ResponseBodyResponseBody,
    )
    from .patch_issue_request_body_assigned_to_request_body import PatchIssueRequestBodyAssignedToRequestBody
    from .patch_issue_request_body_assigned_to_request_body_type import PatchIssueRequestBodyAssignedToRequestBodyType
    from .patch_job_object_request_body import PatchJobObjectRequestBody
    from .patch_job_objectjob_location_request_object_request_body import (
        PatchJobObjectjobLocationRequestObjectRequestBody,
    )
    from .patch_response_workflow_configuration_object_response_body import (
        PatchResponseWorkflowConfigurationObjectResponseBody,
    )
    from .patch_shipping_docs_response_body_response_body import PatchShippingDocsResponseBodyResponseBody
    from .pending_duty_status_durations_object_response_body import PendingDutyStatusDurationsObjectResponseBody
    from .person_detected_response_body import PersonDetectedResponseBody
    from .photo_value_object_request_body import PhotoValueObjectRequestBody
    from .photo_value_object_response_body import PhotoValueObjectResponseBody
    from .plan_object_response_body import PlanObjectResponseBody
    from .plan_orders_create_plan_orders_bad_gateway_error_response_body import (
        PlanOrdersCreatePlanOrdersBadGatewayErrorResponseBody,
    )
    from .plan_orders_create_plan_orders_gateway_timeout_error_response_body import (
        PlanOrdersCreatePlanOrdersGatewayTimeoutErrorResponseBody,
    )
    from .plan_orders_create_plan_orders_internal_server_error_response_body import (
        PlanOrdersCreatePlanOrdersInternalServerErrorResponseBody,
    )
    from .plan_orders_create_plan_orders_method_not_allowed_error_response_body import (
        PlanOrdersCreatePlanOrdersMethodNotAllowedErrorResponseBody,
    )
    from .plan_orders_create_plan_orders_not_found_error_response_body import (
        PlanOrdersCreatePlanOrdersNotFoundErrorResponseBody,
    )
    from .plan_orders_create_plan_orders_not_implemented_error_response_body import (
        PlanOrdersCreatePlanOrdersNotImplementedErrorResponseBody,
    )
    from .plan_orders_create_plan_orders_response_body import PlanOrdersCreatePlanOrdersResponseBody
    from .plan_orders_create_plan_orders_service_unavailable_error_response_body import (
        PlanOrdersCreatePlanOrdersServiceUnavailableErrorResponseBody,
    )
    from .plan_orders_create_plan_orders_too_many_requests_error_response_body import (
        PlanOrdersCreatePlanOrdersTooManyRequestsErrorResponseBody,
    )
    from .plan_orders_create_plan_orders_unauthorized_error_response_body import (
        PlanOrdersCreatePlanOrdersUnauthorizedErrorResponseBody,
    )
    from .policy_violations_detection_alert_settings_object_response_body import (
        PolicyViolationsDetectionAlertSettingsObjectResponseBody,
    )
    from .policy_violations_detection_alert_settings_object_response_body_events_available_for_testing_item import (
        PolicyViolationsDetectionAlertSettingsObjectResponseBodyEventsAvailableForTestingItem,
    )
    from .policy_violations_detection_alert_settings_object_response_body_events_to_coach_item import (
        PolicyViolationsDetectionAlertSettingsObjectResponseBodyEventsToCoachItem,
    )
    from .polygon_request_body import PolygonRequestBody
    from .polygon_response_body import PolygonResponseBody
    from .post_driver_trailer_assignments_response_body_response_body import (
        PostDriverTrailerAssignmentsResponseBodyResponseBody,
    )
    from .post_driver_vehicle_assignments_v_2_request_body_metadata_request_body import (
        PostDriverVehicleAssignmentsV2RequestBodyMetadataRequestBody,
    )
    from .post_driver_vehicle_assignments_v_2_response_body_response_body import (
        PostDriverVehicleAssignmentsV2ResponseBodyResponseBody,
    )
    from .post_fuel_purchase_request_body_discount_request_body import PostFuelPurchaseRequestBodyDiscountRequestBody
    from .post_fuel_purchase_request_body_discount_request_body_currency import (
        PostFuelPurchaseRequestBodyDiscountRequestBodyCurrency,
    )
    from .post_fuel_purchase_request_body_price_request_body import PostFuelPurchaseRequestBodyPriceRequestBody
    from .post_fuel_purchase_request_body_price_request_body_currency import (
        PostFuelPurchaseRequestBodyPriceRequestBodyCurrency,
    )
    from .post_fuel_purchase_response_body_response_body import PostFuelPurchaseResponseBodyResponseBody
    from .post_invoice_scan_response_data_response_body import PostInvoiceScanResponseDataResponseBody
    from .post_job_object_request_body import PostJobObjectRequestBody
    from .post_job_objectjob_location_request_object_request_body import (
        PostJobObjectjobLocationRequestObjectRequestBody,
    )
    from .post_media_retrieval_object_response_body import PostMediaRetrievalObjectResponseBody
    from .post_response_res_workflow_configuration_object_response_body import (
        PostResponseResWorkflowConfigurationObjectResponseBody,
    )
    from .power_take_off_duration_ms import PowerTakeOffDurationMs
    from .primary_time_range_request_body import PrimaryTimeRangeRequestBody
    from .primary_time_range_response_body import PrimaryTimeRangeResponseBody
    from .push_notification_options_object_request_body import PushNotificationOptionsObjectRequestBody
    from .push_notification_options_object_response_body import PushNotificationOptionsObjectResponseBody
    from .qr_code_response_object_response_body import QrCodeResponseObjectResponseBody
    from .qualification_field_input_object_response_body import QualificationFieldInputObjectResponseBody
    from .qualification_field_input_object_response_body_type import QualificationFieldInputObjectResponseBodyType
    from .qualification_owner_object_response_body import QualificationOwnerObjectResponseBody
    from .qualification_owner_object_response_body_entity_type import QualificationOwnerObjectResponseBodyEntityType
    from .qualification_owner_request_object_request_body import QualificationOwnerRequestObjectRequestBody
    from .qualification_owner_request_object_request_body_entity_type import (
        QualificationOwnerRequestObjectRequestBodyEntityType,
    )
    from .qualification_record_request_field_input_object_request_body import (
        QualificationRecordRequestFieldInputObjectRequestBody,
    )
    from .qualification_record_request_field_input_object_request_body_type import (
        QualificationRecordRequestFieldInputObjectRequestBodyType,
    )
    from .qualification_record_response_object_response_body import QualificationRecordResponseObjectResponseBody
    from .qualification_record_response_object_response_body_record_status import (
        QualificationRecordResponseObjectResponseBodyRecordStatus,
    )
    from .qualification_type_reference_object_response_body import QualificationTypeReferenceObjectResponseBody
    from .qualification_type_request_object_request_body import QualificationTypeRequestObjectRequestBody
    from .qualification_type_response_object_response_body import QualificationTypeResponseObjectResponseBody
    from .qualification_type_response_object_response_body_entity_type import (
        QualificationTypeResponseObjectResponseBodyEntityType,
    )
    from .qualifications_archive_qualification_record_bad_gateway_error_response_body import (
        QualificationsArchiveQualificationRecordBadGatewayErrorResponseBody,
    )
    from .qualifications_archive_qualification_record_gateway_timeout_error_response_body import (
        QualificationsArchiveQualificationRecordGatewayTimeoutErrorResponseBody,
    )
    from .qualifications_archive_qualification_record_internal_server_error_response_body import (
        QualificationsArchiveQualificationRecordInternalServerErrorResponseBody,
    )
    from .qualifications_archive_qualification_record_method_not_allowed_error_response_body import (
        QualificationsArchiveQualificationRecordMethodNotAllowedErrorResponseBody,
    )
    from .qualifications_archive_qualification_record_not_found_error_response_body import (
        QualificationsArchiveQualificationRecordNotFoundErrorResponseBody,
    )
    from .qualifications_archive_qualification_record_not_implemented_error_response_body import (
        QualificationsArchiveQualificationRecordNotImplementedErrorResponseBody,
    )
    from .qualifications_archive_qualification_record_service_unavailable_error_response_body import (
        QualificationsArchiveQualificationRecordServiceUnavailableErrorResponseBody,
    )
    from .qualifications_archive_qualification_record_too_many_requests_error_response_body import (
        QualificationsArchiveQualificationRecordTooManyRequestsErrorResponseBody,
    )
    from .qualifications_archive_qualification_record_unauthorized_error_response_body import (
        QualificationsArchiveQualificationRecordUnauthorizedErrorResponseBody,
    )
    from .qualifications_delete_qualification_record_bad_gateway_error_response_body import (
        QualificationsDeleteQualificationRecordBadGatewayErrorResponseBody,
    )
    from .qualifications_delete_qualification_record_gateway_timeout_error_response_body import (
        QualificationsDeleteQualificationRecordGatewayTimeoutErrorResponseBody,
    )
    from .qualifications_delete_qualification_record_internal_server_error_response_body import (
        QualificationsDeleteQualificationRecordInternalServerErrorResponseBody,
    )
    from .qualifications_delete_qualification_record_method_not_allowed_error_response_body import (
        QualificationsDeleteQualificationRecordMethodNotAllowedErrorResponseBody,
    )
    from .qualifications_delete_qualification_record_not_found_error_response_body import (
        QualificationsDeleteQualificationRecordNotFoundErrorResponseBody,
    )
    from .qualifications_delete_qualification_record_not_implemented_error_response_body import (
        QualificationsDeleteQualificationRecordNotImplementedErrorResponseBody,
    )
    from .qualifications_delete_qualification_record_service_unavailable_error_response_body import (
        QualificationsDeleteQualificationRecordServiceUnavailableErrorResponseBody,
    )
    from .qualifications_delete_qualification_record_too_many_requests_error_response_body import (
        QualificationsDeleteQualificationRecordTooManyRequestsErrorResponseBody,
    )
    from .qualifications_delete_qualification_record_unauthorized_error_response_body import (
        QualificationsDeleteQualificationRecordUnauthorizedErrorResponseBody,
    )
    from .qualifications_get_qualification_records_bad_gateway_error_response_body import (
        QualificationsGetQualificationRecordsBadGatewayErrorResponseBody,
    )
    from .qualifications_get_qualification_records_gateway_timeout_error_response_body import (
        QualificationsGetQualificationRecordsGatewayTimeoutErrorResponseBody,
    )
    from .qualifications_get_qualification_records_internal_server_error_response_body import (
        QualificationsGetQualificationRecordsInternalServerErrorResponseBody,
    )
    from .qualifications_get_qualification_records_method_not_allowed_error_response_body import (
        QualificationsGetQualificationRecordsMethodNotAllowedErrorResponseBody,
    )
    from .qualifications_get_qualification_records_not_found_error_response_body import (
        QualificationsGetQualificationRecordsNotFoundErrorResponseBody,
    )
    from .qualifications_get_qualification_records_not_implemented_error_response_body import (
        QualificationsGetQualificationRecordsNotImplementedErrorResponseBody,
    )
    from .qualifications_get_qualification_records_response_body import (
        QualificationsGetQualificationRecordsResponseBody,
    )
    from .qualifications_get_qualification_records_service_unavailable_error_response_body import (
        QualificationsGetQualificationRecordsServiceUnavailableErrorResponseBody,
    )
    from .qualifications_get_qualification_records_stream_bad_gateway_error_response_body import (
        QualificationsGetQualificationRecordsStreamBadGatewayErrorResponseBody,
    )
    from .qualifications_get_qualification_records_stream_gateway_timeout_error_response_body import (
        QualificationsGetQualificationRecordsStreamGatewayTimeoutErrorResponseBody,
    )
    from .qualifications_get_qualification_records_stream_internal_server_error_response_body import (
        QualificationsGetQualificationRecordsStreamInternalServerErrorResponseBody,
    )
    from .qualifications_get_qualification_records_stream_method_not_allowed_error_response_body import (
        QualificationsGetQualificationRecordsStreamMethodNotAllowedErrorResponseBody,
    )
    from .qualifications_get_qualification_records_stream_not_found_error_response_body import (
        QualificationsGetQualificationRecordsStreamNotFoundErrorResponseBody,
    )
    from .qualifications_get_qualification_records_stream_not_implemented_error_response_body import (
        QualificationsGetQualificationRecordsStreamNotImplementedErrorResponseBody,
    )
    from .qualifications_get_qualification_records_stream_response_body import (
        QualificationsGetQualificationRecordsStreamResponseBody,
    )
    from .qualifications_get_qualification_records_stream_service_unavailable_error_response_body import (
        QualificationsGetQualificationRecordsStreamServiceUnavailableErrorResponseBody,
    )
    from .qualifications_get_qualification_records_stream_too_many_requests_error_response_body import (
        QualificationsGetQualificationRecordsStreamTooManyRequestsErrorResponseBody,
    )
    from .qualifications_get_qualification_records_stream_unauthorized_error_response_body import (
        QualificationsGetQualificationRecordsStreamUnauthorizedErrorResponseBody,
    )
    from .qualifications_get_qualification_records_too_many_requests_error_response_body import (
        QualificationsGetQualificationRecordsTooManyRequestsErrorResponseBody,
    )
    from .qualifications_get_qualification_records_unauthorized_error_response_body import (
        QualificationsGetQualificationRecordsUnauthorizedErrorResponseBody,
    )
    from .qualifications_get_qualification_types_bad_gateway_error_response_body import (
        QualificationsGetQualificationTypesBadGatewayErrorResponseBody,
    )
    from .qualifications_get_qualification_types_gateway_timeout_error_response_body import (
        QualificationsGetQualificationTypesGatewayTimeoutErrorResponseBody,
    )
    from .qualifications_get_qualification_types_internal_server_error_response_body import (
        QualificationsGetQualificationTypesInternalServerErrorResponseBody,
    )
    from .qualifications_get_qualification_types_method_not_allowed_error_response_body import (
        QualificationsGetQualificationTypesMethodNotAllowedErrorResponseBody,
    )
    from .qualifications_get_qualification_types_not_found_error_response_body import (
        QualificationsGetQualificationTypesNotFoundErrorResponseBody,
    )
    from .qualifications_get_qualification_types_not_implemented_error_response_body import (
        QualificationsGetQualificationTypesNotImplementedErrorResponseBody,
    )
    from .qualifications_get_qualification_types_response_body import QualificationsGetQualificationTypesResponseBody
    from .qualifications_get_qualification_types_service_unavailable_error_response_body import (
        QualificationsGetQualificationTypesServiceUnavailableErrorResponseBody,
    )
    from .qualifications_get_qualification_types_too_many_requests_error_response_body import (
        QualificationsGetQualificationTypesTooManyRequestsErrorResponseBody,
    )
    from .qualifications_get_qualification_types_unauthorized_error_response_body import (
        QualificationsGetQualificationTypesUnauthorizedErrorResponseBody,
    )
    from .qualifications_patch_qualification_record_bad_gateway_error_response_body import (
        QualificationsPatchQualificationRecordBadGatewayErrorResponseBody,
    )
    from .qualifications_patch_qualification_record_gateway_timeout_error_response_body import (
        QualificationsPatchQualificationRecordGatewayTimeoutErrorResponseBody,
    )
    from .qualifications_patch_qualification_record_internal_server_error_response_body import (
        QualificationsPatchQualificationRecordInternalServerErrorResponseBody,
    )
    from .qualifications_patch_qualification_record_method_not_allowed_error_response_body import (
        QualificationsPatchQualificationRecordMethodNotAllowedErrorResponseBody,
    )
    from .qualifications_patch_qualification_record_not_found_error_response_body import (
        QualificationsPatchQualificationRecordNotFoundErrorResponseBody,
    )
    from .qualifications_patch_qualification_record_not_implemented_error_response_body import (
        QualificationsPatchQualificationRecordNotImplementedErrorResponseBody,
    )
    from .qualifications_patch_qualification_record_response_body import (
        QualificationsPatchQualificationRecordResponseBody,
    )
    from .qualifications_patch_qualification_record_service_unavailable_error_response_body import (
        QualificationsPatchQualificationRecordServiceUnavailableErrorResponseBody,
    )
    from .qualifications_patch_qualification_record_too_many_requests_error_response_body import (
        QualificationsPatchQualificationRecordTooManyRequestsErrorResponseBody,
    )
    from .qualifications_patch_qualification_record_unauthorized_error_response_body import (
        QualificationsPatchQualificationRecordUnauthorizedErrorResponseBody,
    )
    from .qualifications_post_qualification_record_bad_gateway_error_response_body import (
        QualificationsPostQualificationRecordBadGatewayErrorResponseBody,
    )
    from .qualifications_post_qualification_record_gateway_timeout_error_response_body import (
        QualificationsPostQualificationRecordGatewayTimeoutErrorResponseBody,
    )
    from .qualifications_post_qualification_record_internal_server_error_response_body import (
        QualificationsPostQualificationRecordInternalServerErrorResponseBody,
    )
    from .qualifications_post_qualification_record_method_not_allowed_error_response_body import (
        QualificationsPostQualificationRecordMethodNotAllowedErrorResponseBody,
    )
    from .qualifications_post_qualification_record_not_found_error_response_body import (
        QualificationsPostQualificationRecordNotFoundErrorResponseBody,
    )
    from .qualifications_post_qualification_record_not_implemented_error_response_body import (
        QualificationsPostQualificationRecordNotImplementedErrorResponseBody,
    )
    from .qualifications_post_qualification_record_response_body import (
        QualificationsPostQualificationRecordResponseBody,
    )
    from .qualifications_post_qualification_record_service_unavailable_error_response_body import (
        QualificationsPostQualificationRecordServiceUnavailableErrorResponseBody,
    )
    from .qualifications_post_qualification_record_too_many_requests_error_response_body import (
        QualificationsPostQualificationRecordTooManyRequestsErrorResponseBody,
    )
    from .qualifications_post_qualification_record_unauthorized_error_response_body import (
        QualificationsPostQualificationRecordUnauthorizedErrorResponseBody,
    )
    from .qualifications_unarchive_qualification_record_bad_gateway_error_response_body import (
        QualificationsUnarchiveQualificationRecordBadGatewayErrorResponseBody,
    )
    from .qualifications_unarchive_qualification_record_gateway_timeout_error_response_body import (
        QualificationsUnarchiveQualificationRecordGatewayTimeoutErrorResponseBody,
    )
    from .qualifications_unarchive_qualification_record_internal_server_error_response_body import (
        QualificationsUnarchiveQualificationRecordInternalServerErrorResponseBody,
    )
    from .qualifications_unarchive_qualification_record_method_not_allowed_error_response_body import (
        QualificationsUnarchiveQualificationRecordMethodNotAllowedErrorResponseBody,
    )
    from .qualifications_unarchive_qualification_record_not_found_error_response_body import (
        QualificationsUnarchiveQualificationRecordNotFoundErrorResponseBody,
    )
    from .qualifications_unarchive_qualification_record_not_implemented_error_response_body import (
        QualificationsUnarchiveQualificationRecordNotImplementedErrorResponseBody,
    )
    from .qualifications_unarchive_qualification_record_service_unavailable_error_response_body import (
        QualificationsUnarchiveQualificationRecordServiceUnavailableErrorResponseBody,
    )
    from .qualifications_unarchive_qualification_record_too_many_requests_error_response_body import (
        QualificationsUnarchiveQualificationRecordTooManyRequestsErrorResponseBody,
    )
    from .qualifications_unarchive_qualification_record_unauthorized_error_response_body import (
        QualificationsUnarchiveQualificationRecordUnauthorizedErrorResponseBody,
    )
    from .quantity_object_response_body import QuantityObjectResponseBody
    from .reading_datapoint_request_body import ReadingDatapointRequestBody
    from .reading_datapoint_request_body_entity_type import ReadingDatapointRequestBodyEntityType
    from .reading_definition_response_body import ReadingDefinitionResponseBody
    from .reading_history_response_body import ReadingHistoryResponseBody
    from .reading_snapshot_response_body import ReadingSnapshotResponseBody
    from .reading_trigger_continuous_value_object_request_body import ReadingTriggerContinuousValueObjectRequestBody
    from .reading_trigger_continuous_value_object_request_body_operation import (
        ReadingTriggerContinuousValueObjectRequestBodyOperation,
    )
    from .reading_trigger_continuous_value_object_request_body_unit import (
        ReadingTriggerContinuousValueObjectRequestBodyUnit,
    )
    from .reading_trigger_continuous_value_object_response_body import ReadingTriggerContinuousValueObjectResponseBody
    from .reading_trigger_continuous_value_object_response_body_operation import (
        ReadingTriggerContinuousValueObjectResponseBodyOperation,
    )
    from .reading_trigger_continuous_value_object_response_body_unit import (
        ReadingTriggerContinuousValueObjectResponseBodyUnit,
    )
    from .reading_trigger_details_object_request_body import ReadingTriggerDetailsObjectRequestBody
    from .reading_trigger_details_object_response_body import ReadingTriggerDetailsObjectResponseBody
    from .reading_trigger_details_response_body import ReadingTriggerDetailsResponseBody
    from .reading_trigger_enum_value_object_request_body import ReadingTriggerEnumValueObjectRequestBody
    from .reading_trigger_enum_value_object_response_body import ReadingTriggerEnumValueObjectResponseBody
    from .readings_get_readings_history_bad_gateway_error_response_body import (
        ReadingsGetReadingsHistoryBadGatewayErrorResponseBody,
    )
    from .readings_get_readings_history_gateway_timeout_error_response_body import (
        ReadingsGetReadingsHistoryGatewayTimeoutErrorResponseBody,
    )
    from .readings_get_readings_history_internal_server_error_response_body import (
        ReadingsGetReadingsHistoryInternalServerErrorResponseBody,
    )
    from .readings_get_readings_history_method_not_allowed_error_response_body import (
        ReadingsGetReadingsHistoryMethodNotAllowedErrorResponseBody,
    )
    from .readings_get_readings_history_not_found_error_response_body import (
        ReadingsGetReadingsHistoryNotFoundErrorResponseBody,
    )
    from .readings_get_readings_history_not_implemented_error_response_body import (
        ReadingsGetReadingsHistoryNotImplementedErrorResponseBody,
    )
    from .readings_get_readings_history_response_body import ReadingsGetReadingsHistoryResponseBody
    from .readings_get_readings_history_service_unavailable_error_response_body import (
        ReadingsGetReadingsHistoryServiceUnavailableErrorResponseBody,
    )
    from .readings_get_readings_history_too_many_requests_error_response_body import (
        ReadingsGetReadingsHistoryTooManyRequestsErrorResponseBody,
    )
    from .readings_get_readings_history_unauthorized_error_response_body import (
        ReadingsGetReadingsHistoryUnauthorizedErrorResponseBody,
    )
    from .readings_get_readings_snapshot_bad_gateway_error_response_body import (
        ReadingsGetReadingsSnapshotBadGatewayErrorResponseBody,
    )
    from .readings_get_readings_snapshot_gateway_timeout_error_response_body import (
        ReadingsGetReadingsSnapshotGatewayTimeoutErrorResponseBody,
    )
    from .readings_get_readings_snapshot_internal_server_error_response_body import (
        ReadingsGetReadingsSnapshotInternalServerErrorResponseBody,
    )
    from .readings_get_readings_snapshot_method_not_allowed_error_response_body import (
        ReadingsGetReadingsSnapshotMethodNotAllowedErrorResponseBody,
    )
    from .readings_get_readings_snapshot_not_found_error_response_body import (
        ReadingsGetReadingsSnapshotNotFoundErrorResponseBody,
    )
    from .readings_get_readings_snapshot_not_implemented_error_response_body import (
        ReadingsGetReadingsSnapshotNotImplementedErrorResponseBody,
    )
    from .readings_get_readings_snapshot_response_body import ReadingsGetReadingsSnapshotResponseBody
    from .readings_get_readings_snapshot_service_unavailable_error_response_body import (
        ReadingsGetReadingsSnapshotServiceUnavailableErrorResponseBody,
    )
    from .readings_get_readings_snapshot_too_many_requests_error_response_body import (
        ReadingsGetReadingsSnapshotTooManyRequestsErrorResponseBody,
    )
    from .readings_get_readings_snapshot_unauthorized_error_response_body import (
        ReadingsGetReadingsSnapshotUnauthorizedErrorResponseBody,
    )
    from .readings_list_readings_definitions_bad_gateway_error_response_body import (
        ReadingsListReadingsDefinitionsBadGatewayErrorResponseBody,
    )
    from .readings_list_readings_definitions_gateway_timeout_error_response_body import (
        ReadingsListReadingsDefinitionsGatewayTimeoutErrorResponseBody,
    )
    from .readings_list_readings_definitions_internal_server_error_response_body import (
        ReadingsListReadingsDefinitionsInternalServerErrorResponseBody,
    )
    from .readings_list_readings_definitions_method_not_allowed_error_response_body import (
        ReadingsListReadingsDefinitionsMethodNotAllowedErrorResponseBody,
    )
    from .readings_list_readings_definitions_not_found_error_response_body import (
        ReadingsListReadingsDefinitionsNotFoundErrorResponseBody,
    )
    from .readings_list_readings_definitions_not_implemented_error_response_body import (
        ReadingsListReadingsDefinitionsNotImplementedErrorResponseBody,
    )
    from .readings_list_readings_definitions_response_body import ReadingsListReadingsDefinitionsResponseBody
    from .readings_list_readings_definitions_service_unavailable_error_response_body import (
        ReadingsListReadingsDefinitionsServiceUnavailableErrorResponseBody,
    )
    from .readings_list_readings_definitions_too_many_requests_error_response_body import (
        ReadingsListReadingsDefinitionsTooManyRequestsErrorResponseBody,
    )
    from .readings_list_readings_definitions_unauthorized_error_response_body import (
        ReadingsListReadingsDefinitionsUnauthorizedErrorResponseBody,
    )
    from .readings_post_readings_bad_gateway_error_response_body import ReadingsPostReadingsBadGatewayErrorResponseBody
    from .readings_post_readings_gateway_timeout_error_response_body import (
        ReadingsPostReadingsGatewayTimeoutErrorResponseBody,
    )
    from .readings_post_readings_internal_server_error_response_body import (
        ReadingsPostReadingsInternalServerErrorResponseBody,
    )
    from .readings_post_readings_method_not_allowed_error_response_body import (
        ReadingsPostReadingsMethodNotAllowedErrorResponseBody,
    )
    from .readings_post_readings_not_found_error_response_body import ReadingsPostReadingsNotFoundErrorResponseBody
    from .readings_post_readings_not_implemented_error_response_body import (
        ReadingsPostReadingsNotImplementedErrorResponseBody,
    )
    from .readings_post_readings_service_unavailable_error_response_body import (
        ReadingsPostReadingsServiceUnavailableErrorResponseBody,
    )
    from .readings_post_readings_too_many_requests_error_response_body import (
        ReadingsPostReadingsTooManyRequestsErrorResponseBody,
    )
    from .readings_post_readings_unauthorized_error_response_body import (
        ReadingsPostReadingsUnauthorizedErrorResponseBody,
    )
    from .recipient_object_request_body import RecipientObjectRequestBody
    from .recipient_object_request_body_notification_types_item import RecipientObjectRequestBodyNotificationTypesItem
    from .recipient_object_request_body_type import RecipientObjectRequestBodyType
    from .recipient_object_response_body import RecipientObjectResponseBody
    from .recipient_object_response_body_notification_types_item import RecipientObjectResponseBodyNotificationTypesItem
    from .recipient_object_response_body_type import RecipientObjectResponseBodyType
    from .reefer_temperature_response_body import ReeferTemperatureResponseBody
    from .report_columns_object_response_body import ReportColumnsObjectResponseBody
    from .report_columns_object_response_body_data_type import ReportColumnsObjectResponseBodyDataType
    from .report_columns_object_response_body_unit import ReportColumnsObjectResponseBodyUnit
    from .report_config_object_response_body import ReportConfigObjectResponseBody
    from .report_run_object_response_body import ReportRunObjectResponseBody
    from .report_run_object_response_body_status import ReportRunObjectResponseBodyStatus
    from .reports_create_report_run_bad_gateway_error_response_body import (
        ReportsCreateReportRunBadGatewayErrorResponseBody,
    )
    from .reports_create_report_run_gateway_timeout_error_response_body import (
        ReportsCreateReportRunGatewayTimeoutErrorResponseBody,
    )
    from .reports_create_report_run_internal_server_error_response_body import (
        ReportsCreateReportRunInternalServerErrorResponseBody,
    )
    from .reports_create_report_run_method_not_allowed_error_response_body import (
        ReportsCreateReportRunMethodNotAllowedErrorResponseBody,
    )
    from .reports_create_report_run_not_found_error_response_body import ReportsCreateReportRunNotFoundErrorResponseBody
    from .reports_create_report_run_not_implemented_error_response_body import (
        ReportsCreateReportRunNotImplementedErrorResponseBody,
    )
    from .reports_create_report_run_response_body import ReportsCreateReportRunResponseBody
    from .reports_create_report_run_service_unavailable_error_response_body import (
        ReportsCreateReportRunServiceUnavailableErrorResponseBody,
    )
    from .reports_create_report_run_too_many_requests_error_response_body import (
        ReportsCreateReportRunTooManyRequestsErrorResponseBody,
    )
    from .reports_create_report_run_unauthorized_error_response_body import (
        ReportsCreateReportRunUnauthorizedErrorResponseBody,
    )
    from .reports_dataset_field_response_body import ReportsDatasetFieldResponseBody
    from .reports_dataset_field_response_body_data_type import ReportsDatasetFieldResponseBodyDataType
    from .reports_dataset_field_response_body_unit import ReportsDatasetFieldResponseBodyUnit
    from .reports_dataset_response_body import ReportsDatasetResponseBody
    from .reports_get_datasets_bad_gateway_error_response_body import ReportsGetDatasetsBadGatewayErrorResponseBody
    from .reports_get_datasets_gateway_timeout_error_response_body import (
        ReportsGetDatasetsGatewayTimeoutErrorResponseBody,
    )
    from .reports_get_datasets_internal_server_error_response_body import (
        ReportsGetDatasetsInternalServerErrorResponseBody,
    )
    from .reports_get_datasets_method_not_allowed_error_response_body import (
        ReportsGetDatasetsMethodNotAllowedErrorResponseBody,
    )
    from .reports_get_datasets_not_found_error_response_body import ReportsGetDatasetsNotFoundErrorResponseBody
    from .reports_get_datasets_not_implemented_error_response_body import (
        ReportsGetDatasetsNotImplementedErrorResponseBody,
    )
    from .reports_get_datasets_response_body import ReportsGetDatasetsResponseBody
    from .reports_get_datasets_service_unavailable_error_response_body import (
        ReportsGetDatasetsServiceUnavailableErrorResponseBody,
    )
    from .reports_get_datasets_too_many_requests_error_response_body import (
        ReportsGetDatasetsTooManyRequestsErrorResponseBody,
    )
    from .reports_get_datasets_unauthorized_error_response_body import ReportsGetDatasetsUnauthorizedErrorResponseBody
    from .reports_get_report_configs_bad_gateway_error_response_body import (
        ReportsGetReportConfigsBadGatewayErrorResponseBody,
    )
    from .reports_get_report_configs_gateway_timeout_error_response_body import (
        ReportsGetReportConfigsGatewayTimeoutErrorResponseBody,
    )
    from .reports_get_report_configs_internal_server_error_response_body import (
        ReportsGetReportConfigsInternalServerErrorResponseBody,
    )
    from .reports_get_report_configs_method_not_allowed_error_response_body import (
        ReportsGetReportConfigsMethodNotAllowedErrorResponseBody,
    )
    from .reports_get_report_configs_not_found_error_response_body import (
        ReportsGetReportConfigsNotFoundErrorResponseBody,
    )
    from .reports_get_report_configs_not_implemented_error_response_body import (
        ReportsGetReportConfigsNotImplementedErrorResponseBody,
    )
    from .reports_get_report_configs_response_body import ReportsGetReportConfigsResponseBody
    from .reports_get_report_configs_service_unavailable_error_response_body import (
        ReportsGetReportConfigsServiceUnavailableErrorResponseBody,
    )
    from .reports_get_report_configs_too_many_requests_error_response_body import (
        ReportsGetReportConfigsTooManyRequestsErrorResponseBody,
    )
    from .reports_get_report_configs_unauthorized_error_response_body import (
        ReportsGetReportConfigsUnauthorizedErrorResponseBody,
    )
    from .reports_get_report_run_data_bad_gateway_error_response_body import (
        ReportsGetReportRunDataBadGatewayErrorResponseBody,
    )
    from .reports_get_report_run_data_gateway_timeout_error_response_body import (
        ReportsGetReportRunDataGatewayTimeoutErrorResponseBody,
    )
    from .reports_get_report_run_data_internal_server_error_response_body import (
        ReportsGetReportRunDataInternalServerErrorResponseBody,
    )
    from .reports_get_report_run_data_method_not_allowed_error_response_body import (
        ReportsGetReportRunDataMethodNotAllowedErrorResponseBody,
    )
    from .reports_get_report_run_data_not_found_error_response_body import (
        ReportsGetReportRunDataNotFoundErrorResponseBody,
    )
    from .reports_get_report_run_data_not_implemented_error_response_body import (
        ReportsGetReportRunDataNotImplementedErrorResponseBody,
    )
    from .reports_get_report_run_data_response_body import ReportsGetReportRunDataResponseBody
    from .reports_get_report_run_data_service_unavailable_error_response_body import (
        ReportsGetReportRunDataServiceUnavailableErrorResponseBody,
    )
    from .reports_get_report_run_data_too_many_requests_error_response_body import (
        ReportsGetReportRunDataTooManyRequestsErrorResponseBody,
    )
    from .reports_get_report_run_data_unauthorized_error_response_body import (
        ReportsGetReportRunDataUnauthorizedErrorResponseBody,
    )
    from .reports_get_report_runs_bad_gateway_error_response_body import ReportsGetReportRunsBadGatewayErrorResponseBody
    from .reports_get_report_runs_gateway_timeout_error_response_body import (
        ReportsGetReportRunsGatewayTimeoutErrorResponseBody,
    )
    from .reports_get_report_runs_internal_server_error_response_body import (
        ReportsGetReportRunsInternalServerErrorResponseBody,
    )
    from .reports_get_report_runs_method_not_allowed_error_response_body import (
        ReportsGetReportRunsMethodNotAllowedErrorResponseBody,
    )
    from .reports_get_report_runs_not_found_error_response_body import ReportsGetReportRunsNotFoundErrorResponseBody
    from .reports_get_report_runs_not_implemented_error_response_body import (
        ReportsGetReportRunsNotImplementedErrorResponseBody,
    )
    from .reports_get_report_runs_response_body import ReportsGetReportRunsResponseBody
    from .reports_get_report_runs_service_unavailable_error_response_body import (
        ReportsGetReportRunsServiceUnavailableErrorResponseBody,
    )
    from .reports_get_report_runs_too_many_requests_error_response_body import (
        ReportsGetReportRunsTooManyRequestsErrorResponseBody,
    )
    from .reports_get_report_runs_unauthorized_error_response_body import (
        ReportsGetReportRunsUnauthorizedErrorResponseBody,
    )
    from .resolved_by import ResolvedBy
    from .resolved_by_type import ResolvedByType
    from .reverse_geo import ReverseGeo
    from .reverse_geo_object_response_body import ReverseGeoObjectResponseBody
    from .ridership_account_object_response_body import RidershipAccountObjectResponseBody
    from .ridership_accounts_create_ridership_account_bad_gateway_error_response_body import (
        RidershipAccountsCreateRidershipAccountBadGatewayErrorResponseBody,
    )
    from .ridership_accounts_create_ridership_account_gateway_timeout_error_response_body import (
        RidershipAccountsCreateRidershipAccountGatewayTimeoutErrorResponseBody,
    )
    from .ridership_accounts_create_ridership_account_internal_server_error_response_body import (
        RidershipAccountsCreateRidershipAccountInternalServerErrorResponseBody,
    )
    from .ridership_accounts_create_ridership_account_method_not_allowed_error_response_body import (
        RidershipAccountsCreateRidershipAccountMethodNotAllowedErrorResponseBody,
    )
    from .ridership_accounts_create_ridership_account_not_found_error_response_body import (
        RidershipAccountsCreateRidershipAccountNotFoundErrorResponseBody,
    )
    from .ridership_accounts_create_ridership_account_not_implemented_error_response_body import (
        RidershipAccountsCreateRidershipAccountNotImplementedErrorResponseBody,
    )
    from .ridership_accounts_create_ridership_account_response_body import (
        RidershipAccountsCreateRidershipAccountResponseBody,
    )
    from .ridership_accounts_create_ridership_account_service_unavailable_error_response_body import (
        RidershipAccountsCreateRidershipAccountServiceUnavailableErrorResponseBody,
    )
    from .ridership_accounts_create_ridership_account_too_many_requests_error_response_body import (
        RidershipAccountsCreateRidershipAccountTooManyRequestsErrorResponseBody,
    )
    from .ridership_accounts_create_ridership_account_unauthorized_error_response_body import (
        RidershipAccountsCreateRidershipAccountUnauthorizedErrorResponseBody,
    )
    from .ridership_accounts_delete_ridership_account_bad_gateway_error_response_body import (
        RidershipAccountsDeleteRidershipAccountBadGatewayErrorResponseBody,
    )
    from .ridership_accounts_delete_ridership_account_gateway_timeout_error_response_body import (
        RidershipAccountsDeleteRidershipAccountGatewayTimeoutErrorResponseBody,
    )
    from .ridership_accounts_delete_ridership_account_internal_server_error_response_body import (
        RidershipAccountsDeleteRidershipAccountInternalServerErrorResponseBody,
    )
    from .ridership_accounts_delete_ridership_account_method_not_allowed_error_response_body import (
        RidershipAccountsDeleteRidershipAccountMethodNotAllowedErrorResponseBody,
    )
    from .ridership_accounts_delete_ridership_account_not_found_error_response_body import (
        RidershipAccountsDeleteRidershipAccountNotFoundErrorResponseBody,
    )
    from .ridership_accounts_delete_ridership_account_not_implemented_error_response_body import (
        RidershipAccountsDeleteRidershipAccountNotImplementedErrorResponseBody,
    )
    from .ridership_accounts_delete_ridership_account_service_unavailable_error_response_body import (
        RidershipAccountsDeleteRidershipAccountServiceUnavailableErrorResponseBody,
    )
    from .ridership_accounts_delete_ridership_account_too_many_requests_error_response_body import (
        RidershipAccountsDeleteRidershipAccountTooManyRequestsErrorResponseBody,
    )
    from .ridership_accounts_delete_ridership_account_unauthorized_error_response_body import (
        RidershipAccountsDeleteRidershipAccountUnauthorizedErrorResponseBody,
    )
    from .ridership_accounts_get_ridership_account_bad_gateway_error_response_body import (
        RidershipAccountsGetRidershipAccountBadGatewayErrorResponseBody,
    )
    from .ridership_accounts_get_ridership_account_gateway_timeout_error_response_body import (
        RidershipAccountsGetRidershipAccountGatewayTimeoutErrorResponseBody,
    )
    from .ridership_accounts_get_ridership_account_internal_server_error_response_body import (
        RidershipAccountsGetRidershipAccountInternalServerErrorResponseBody,
    )
    from .ridership_accounts_get_ridership_account_method_not_allowed_error_response_body import (
        RidershipAccountsGetRidershipAccountMethodNotAllowedErrorResponseBody,
    )
    from .ridership_accounts_get_ridership_account_not_found_error_response_body import (
        RidershipAccountsGetRidershipAccountNotFoundErrorResponseBody,
    )
    from .ridership_accounts_get_ridership_account_not_implemented_error_response_body import (
        RidershipAccountsGetRidershipAccountNotImplementedErrorResponseBody,
    )
    from .ridership_accounts_get_ridership_account_response_body import RidershipAccountsGetRidershipAccountResponseBody
    from .ridership_accounts_get_ridership_account_service_unavailable_error_response_body import (
        RidershipAccountsGetRidershipAccountServiceUnavailableErrorResponseBody,
    )
    from .ridership_accounts_get_ridership_account_too_many_requests_error_response_body import (
        RidershipAccountsGetRidershipAccountTooManyRequestsErrorResponseBody,
    )
    from .ridership_accounts_get_ridership_account_unauthorized_error_response_body import (
        RidershipAccountsGetRidershipAccountUnauthorizedErrorResponseBody,
    )
    from .ridership_accounts_list_ridership_accounts_bad_gateway_error_response_body import (
        RidershipAccountsListRidershipAccountsBadGatewayErrorResponseBody,
    )
    from .ridership_accounts_list_ridership_accounts_gateway_timeout_error_response_body import (
        RidershipAccountsListRidershipAccountsGatewayTimeoutErrorResponseBody,
    )
    from .ridership_accounts_list_ridership_accounts_internal_server_error_response_body import (
        RidershipAccountsListRidershipAccountsInternalServerErrorResponseBody,
    )
    from .ridership_accounts_list_ridership_accounts_method_not_allowed_error_response_body import (
        RidershipAccountsListRidershipAccountsMethodNotAllowedErrorResponseBody,
    )
    from .ridership_accounts_list_ridership_accounts_not_found_error_response_body import (
        RidershipAccountsListRidershipAccountsNotFoundErrorResponseBody,
    )
    from .ridership_accounts_list_ridership_accounts_not_implemented_error_response_body import (
        RidershipAccountsListRidershipAccountsNotImplementedErrorResponseBody,
    )
    from .ridership_accounts_list_ridership_accounts_response_body import (
        RidershipAccountsListRidershipAccountsResponseBody,
    )
    from .ridership_accounts_list_ridership_accounts_service_unavailable_error_response_body import (
        RidershipAccountsListRidershipAccountsServiceUnavailableErrorResponseBody,
    )
    from .ridership_accounts_list_ridership_accounts_too_many_requests_error_response_body import (
        RidershipAccountsListRidershipAccountsTooManyRequestsErrorResponseBody,
    )
    from .ridership_accounts_list_ridership_accounts_unauthorized_error_response_body import (
        RidershipAccountsListRidershipAccountsUnauthorizedErrorResponseBody,
    )
    from .ridership_accounts_update_ridership_account_bad_gateway_error_response_body import (
        RidershipAccountsUpdateRidershipAccountBadGatewayErrorResponseBody,
    )
    from .ridership_accounts_update_ridership_account_gateway_timeout_error_response_body import (
        RidershipAccountsUpdateRidershipAccountGatewayTimeoutErrorResponseBody,
    )
    from .ridership_accounts_update_ridership_account_internal_server_error_response_body import (
        RidershipAccountsUpdateRidershipAccountInternalServerErrorResponseBody,
    )
    from .ridership_accounts_update_ridership_account_method_not_allowed_error_response_body import (
        RidershipAccountsUpdateRidershipAccountMethodNotAllowedErrorResponseBody,
    )
    from .ridership_accounts_update_ridership_account_not_found_error_response_body import (
        RidershipAccountsUpdateRidershipAccountNotFoundErrorResponseBody,
    )
    from .ridership_accounts_update_ridership_account_not_implemented_error_response_body import (
        RidershipAccountsUpdateRidershipAccountNotImplementedErrorResponseBody,
    )
    from .ridership_accounts_update_ridership_account_response_body import (
        RidershipAccountsUpdateRidershipAccountResponseBody,
    )
    from .ridership_accounts_update_ridership_account_service_unavailable_error_response_body import (
        RidershipAccountsUpdateRidershipAccountServiceUnavailableErrorResponseBody,
    )
    from .ridership_accounts_update_ridership_account_too_many_requests_error_response_body import (
        RidershipAccountsUpdateRidershipAccountTooManyRequestsErrorResponseBody,
    )
    from .ridership_accounts_update_ridership_account_unauthorized_error_response_body import (
        RidershipAccountsUpdateRidershipAccountUnauthorizedErrorResponseBody,
    )
    from .ridership_passenger_identifier_input_request_body import RidershipPassengerIdentifierInputRequestBody
    from .ridership_passenger_identifier_input_request_body_status import (
        RidershipPassengerIdentifierInputRequestBodyStatus,
    )
    from .ridership_passenger_identifier_input_request_body_type import RidershipPassengerIdentifierInputRequestBodyType
    from .ridership_passenger_identifier_object_response_body import RidershipPassengerIdentifierObjectResponseBody
    from .ridership_passenger_identifier_object_response_body_status import (
        RidershipPassengerIdentifierObjectResponseBodyStatus,
    )
    from .ridership_passenger_identifier_object_response_body_type import (
        RidershipPassengerIdentifierObjectResponseBodyType,
    )
    from .ridership_passenger_object_response_body import RidershipPassengerObjectResponseBody
    from .ridership_passenger_special_instructions_input_request_body import (
        RidershipPassengerSpecialInstructionsInputRequestBody,
    )
    from .ridership_passenger_special_instructions_object_response_body import (
        RidershipPassengerSpecialInstructionsObjectResponseBody,
    )
    from .ridership_passengers_create_ridership_passenger_bad_gateway_error_response_body import (
        RidershipPassengersCreateRidershipPassengerBadGatewayErrorResponseBody,
    )
    from .ridership_passengers_create_ridership_passenger_gateway_timeout_error_response_body import (
        RidershipPassengersCreateRidershipPassengerGatewayTimeoutErrorResponseBody,
    )
    from .ridership_passengers_create_ridership_passenger_internal_server_error_response_body import (
        RidershipPassengersCreateRidershipPassengerInternalServerErrorResponseBody,
    )
    from .ridership_passengers_create_ridership_passenger_method_not_allowed_error_response_body import (
        RidershipPassengersCreateRidershipPassengerMethodNotAllowedErrorResponseBody,
    )
    from .ridership_passengers_create_ridership_passenger_not_found_error_response_body import (
        RidershipPassengersCreateRidershipPassengerNotFoundErrorResponseBody,
    )
    from .ridership_passengers_create_ridership_passenger_not_implemented_error_response_body import (
        RidershipPassengersCreateRidershipPassengerNotImplementedErrorResponseBody,
    )
    from .ridership_passengers_create_ridership_passenger_response_body import (
        RidershipPassengersCreateRidershipPassengerResponseBody,
    )
    from .ridership_passengers_create_ridership_passenger_service_unavailable_error_response_body import (
        RidershipPassengersCreateRidershipPassengerServiceUnavailableErrorResponseBody,
    )
    from .ridership_passengers_create_ridership_passenger_too_many_requests_error_response_body import (
        RidershipPassengersCreateRidershipPassengerTooManyRequestsErrorResponseBody,
    )
    from .ridership_passengers_create_ridership_passenger_unauthorized_error_response_body import (
        RidershipPassengersCreateRidershipPassengerUnauthorizedErrorResponseBody,
    )
    from .ridership_passengers_delete_ridership_passenger_bad_gateway_error_response_body import (
        RidershipPassengersDeleteRidershipPassengerBadGatewayErrorResponseBody,
    )
    from .ridership_passengers_delete_ridership_passenger_gateway_timeout_error_response_body import (
        RidershipPassengersDeleteRidershipPassengerGatewayTimeoutErrorResponseBody,
    )
    from .ridership_passengers_delete_ridership_passenger_internal_server_error_response_body import (
        RidershipPassengersDeleteRidershipPassengerInternalServerErrorResponseBody,
    )
    from .ridership_passengers_delete_ridership_passenger_method_not_allowed_error_response_body import (
        RidershipPassengersDeleteRidershipPassengerMethodNotAllowedErrorResponseBody,
    )
    from .ridership_passengers_delete_ridership_passenger_not_found_error_response_body import (
        RidershipPassengersDeleteRidershipPassengerNotFoundErrorResponseBody,
    )
    from .ridership_passengers_delete_ridership_passenger_not_implemented_error_response_body import (
        RidershipPassengersDeleteRidershipPassengerNotImplementedErrorResponseBody,
    )
    from .ridership_passengers_delete_ridership_passenger_service_unavailable_error_response_body import (
        RidershipPassengersDeleteRidershipPassengerServiceUnavailableErrorResponseBody,
    )
    from .ridership_passengers_delete_ridership_passenger_too_many_requests_error_response_body import (
        RidershipPassengersDeleteRidershipPassengerTooManyRequestsErrorResponseBody,
    )
    from .ridership_passengers_delete_ridership_passenger_unauthorized_error_response_body import (
        RidershipPassengersDeleteRidershipPassengerUnauthorizedErrorResponseBody,
    )
    from .ridership_passengers_get_ridership_passenger_bad_gateway_error_response_body import (
        RidershipPassengersGetRidershipPassengerBadGatewayErrorResponseBody,
    )
    from .ridership_passengers_get_ridership_passenger_gateway_timeout_error_response_body import (
        RidershipPassengersGetRidershipPassengerGatewayTimeoutErrorResponseBody,
    )
    from .ridership_passengers_get_ridership_passenger_internal_server_error_response_body import (
        RidershipPassengersGetRidershipPassengerInternalServerErrorResponseBody,
    )
    from .ridership_passengers_get_ridership_passenger_method_not_allowed_error_response_body import (
        RidershipPassengersGetRidershipPassengerMethodNotAllowedErrorResponseBody,
    )
    from .ridership_passengers_get_ridership_passenger_not_found_error_response_body import (
        RidershipPassengersGetRidershipPassengerNotFoundErrorResponseBody,
    )
    from .ridership_passengers_get_ridership_passenger_not_implemented_error_response_body import (
        RidershipPassengersGetRidershipPassengerNotImplementedErrorResponseBody,
    )
    from .ridership_passengers_get_ridership_passenger_response_body import (
        RidershipPassengersGetRidershipPassengerResponseBody,
    )
    from .ridership_passengers_get_ridership_passenger_service_unavailable_error_response_body import (
        RidershipPassengersGetRidershipPassengerServiceUnavailableErrorResponseBody,
    )
    from .ridership_passengers_get_ridership_passenger_too_many_requests_error_response_body import (
        RidershipPassengersGetRidershipPassengerTooManyRequestsErrorResponseBody,
    )
    from .ridership_passengers_get_ridership_passenger_unauthorized_error_response_body import (
        RidershipPassengersGetRidershipPassengerUnauthorizedErrorResponseBody,
    )
    from .ridership_passengers_list_ridership_passengers_bad_gateway_error_response_body import (
        RidershipPassengersListRidershipPassengersBadGatewayErrorResponseBody,
    )
    from .ridership_passengers_list_ridership_passengers_gateway_timeout_error_response_body import (
        RidershipPassengersListRidershipPassengersGatewayTimeoutErrorResponseBody,
    )
    from .ridership_passengers_list_ridership_passengers_internal_server_error_response_body import (
        RidershipPassengersListRidershipPassengersInternalServerErrorResponseBody,
    )
    from .ridership_passengers_list_ridership_passengers_method_not_allowed_error_response_body import (
        RidershipPassengersListRidershipPassengersMethodNotAllowedErrorResponseBody,
    )
    from .ridership_passengers_list_ridership_passengers_not_found_error_response_body import (
        RidershipPassengersListRidershipPassengersNotFoundErrorResponseBody,
    )
    from .ridership_passengers_list_ridership_passengers_not_implemented_error_response_body import (
        RidershipPassengersListRidershipPassengersNotImplementedErrorResponseBody,
    )
    from .ridership_passengers_list_ridership_passengers_response_body import (
        RidershipPassengersListRidershipPassengersResponseBody,
    )
    from .ridership_passengers_list_ridership_passengers_service_unavailable_error_response_body import (
        RidershipPassengersListRidershipPassengersServiceUnavailableErrorResponseBody,
    )
    from .ridership_passengers_list_ridership_passengers_too_many_requests_error_response_body import (
        RidershipPassengersListRidershipPassengersTooManyRequestsErrorResponseBody,
    )
    from .ridership_passengers_list_ridership_passengers_unauthorized_error_response_body import (
        RidershipPassengersListRidershipPassengersUnauthorizedErrorResponseBody,
    )
    from .ridership_passengers_update_ridership_passenger_bad_gateway_error_response_body import (
        RidershipPassengersUpdateRidershipPassengerBadGatewayErrorResponseBody,
    )
    from .ridership_passengers_update_ridership_passenger_gateway_timeout_error_response_body import (
        RidershipPassengersUpdateRidershipPassengerGatewayTimeoutErrorResponseBody,
    )
    from .ridership_passengers_update_ridership_passenger_internal_server_error_response_body import (
        RidershipPassengersUpdateRidershipPassengerInternalServerErrorResponseBody,
    )
    from .ridership_passengers_update_ridership_passenger_method_not_allowed_error_response_body import (
        RidershipPassengersUpdateRidershipPassengerMethodNotAllowedErrorResponseBody,
    )
    from .ridership_passengers_update_ridership_passenger_not_found_error_response_body import (
        RidershipPassengersUpdateRidershipPassengerNotFoundErrorResponseBody,
    )
    from .ridership_passengers_update_ridership_passenger_not_implemented_error_response_body import (
        RidershipPassengersUpdateRidershipPassengerNotImplementedErrorResponseBody,
    )
    from .ridership_passengers_update_ridership_passenger_response_body import (
        RidershipPassengersUpdateRidershipPassengerResponseBody,
    )
    from .ridership_passengers_update_ridership_passenger_service_unavailable_error_response_body import (
        RidershipPassengersUpdateRidershipPassengerServiceUnavailableErrorResponseBody,
    )
    from .ridership_passengers_update_ridership_passenger_too_many_requests_error_response_body import (
        RidershipPassengersUpdateRidershipPassengerTooManyRequestsErrorResponseBody,
    )
    from .ridership_passengers_update_ridership_passenger_unauthorized_error_response_body import (
        RidershipPassengersUpdateRidershipPassengerUnauthorizedErrorResponseBody,
    )
    from .ridership_route_setup_object_response_body import RidershipRouteSetupObjectResponseBody
    from .ridership_route_setup_passenger_input_request_body import RidershipRouteSetupPassengerInputRequestBody
    from .ridership_route_setup_passenger_object_response_body import RidershipRouteSetupPassengerObjectResponseBody
    from .ridership_route_setups_create_ridership_route_setup_bad_gateway_error_response_body import (
        RidershipRouteSetupsCreateRidershipRouteSetupBadGatewayErrorResponseBody,
    )
    from .ridership_route_setups_create_ridership_route_setup_gateway_timeout_error_response_body import (
        RidershipRouteSetupsCreateRidershipRouteSetupGatewayTimeoutErrorResponseBody,
    )
    from .ridership_route_setups_create_ridership_route_setup_internal_server_error_response_body import (
        RidershipRouteSetupsCreateRidershipRouteSetupInternalServerErrorResponseBody,
    )
    from .ridership_route_setups_create_ridership_route_setup_method_not_allowed_error_response_body import (
        RidershipRouteSetupsCreateRidershipRouteSetupMethodNotAllowedErrorResponseBody,
    )
    from .ridership_route_setups_create_ridership_route_setup_not_found_error_response_body import (
        RidershipRouteSetupsCreateRidershipRouteSetupNotFoundErrorResponseBody,
    )
    from .ridership_route_setups_create_ridership_route_setup_not_implemented_error_response_body import (
        RidershipRouteSetupsCreateRidershipRouteSetupNotImplementedErrorResponseBody,
    )
    from .ridership_route_setups_create_ridership_route_setup_response_body import (
        RidershipRouteSetupsCreateRidershipRouteSetupResponseBody,
    )
    from .ridership_route_setups_create_ridership_route_setup_service_unavailable_error_response_body import (
        RidershipRouteSetupsCreateRidershipRouteSetupServiceUnavailableErrorResponseBody,
    )
    from .ridership_route_setups_create_ridership_route_setup_too_many_requests_error_response_body import (
        RidershipRouteSetupsCreateRidershipRouteSetupTooManyRequestsErrorResponseBody,
    )
    from .ridership_route_setups_create_ridership_route_setup_unauthorized_error_response_body import (
        RidershipRouteSetupsCreateRidershipRouteSetupUnauthorizedErrorResponseBody,
    )
    from .ridership_route_setups_delete_ridership_route_setup_bad_gateway_error_response_body import (
        RidershipRouteSetupsDeleteRidershipRouteSetupBadGatewayErrorResponseBody,
    )
    from .ridership_route_setups_delete_ridership_route_setup_gateway_timeout_error_response_body import (
        RidershipRouteSetupsDeleteRidershipRouteSetupGatewayTimeoutErrorResponseBody,
    )
    from .ridership_route_setups_delete_ridership_route_setup_internal_server_error_response_body import (
        RidershipRouteSetupsDeleteRidershipRouteSetupInternalServerErrorResponseBody,
    )
    from .ridership_route_setups_delete_ridership_route_setup_method_not_allowed_error_response_body import (
        RidershipRouteSetupsDeleteRidershipRouteSetupMethodNotAllowedErrorResponseBody,
    )
    from .ridership_route_setups_delete_ridership_route_setup_not_found_error_response_body import (
        RidershipRouteSetupsDeleteRidershipRouteSetupNotFoundErrorResponseBody,
    )
    from .ridership_route_setups_delete_ridership_route_setup_not_implemented_error_response_body import (
        RidershipRouteSetupsDeleteRidershipRouteSetupNotImplementedErrorResponseBody,
    )
    from .ridership_route_setups_delete_ridership_route_setup_service_unavailable_error_response_body import (
        RidershipRouteSetupsDeleteRidershipRouteSetupServiceUnavailableErrorResponseBody,
    )
    from .ridership_route_setups_delete_ridership_route_setup_too_many_requests_error_response_body import (
        RidershipRouteSetupsDeleteRidershipRouteSetupTooManyRequestsErrorResponseBody,
    )
    from .ridership_route_setups_delete_ridership_route_setup_unauthorized_error_response_body import (
        RidershipRouteSetupsDeleteRidershipRouteSetupUnauthorizedErrorResponseBody,
    )
    from .ridership_route_setups_get_ridership_route_setup_bad_gateway_error_response_body import (
        RidershipRouteSetupsGetRidershipRouteSetupBadGatewayErrorResponseBody,
    )
    from .ridership_route_setups_get_ridership_route_setup_gateway_timeout_error_response_body import (
        RidershipRouteSetupsGetRidershipRouteSetupGatewayTimeoutErrorResponseBody,
    )
    from .ridership_route_setups_get_ridership_route_setup_internal_server_error_response_body import (
        RidershipRouteSetupsGetRidershipRouteSetupInternalServerErrorResponseBody,
    )
    from .ridership_route_setups_get_ridership_route_setup_method_not_allowed_error_response_body import (
        RidershipRouteSetupsGetRidershipRouteSetupMethodNotAllowedErrorResponseBody,
    )
    from .ridership_route_setups_get_ridership_route_setup_not_found_error_response_body import (
        RidershipRouteSetupsGetRidershipRouteSetupNotFoundErrorResponseBody,
    )
    from .ridership_route_setups_get_ridership_route_setup_not_implemented_error_response_body import (
        RidershipRouteSetupsGetRidershipRouteSetupNotImplementedErrorResponseBody,
    )
    from .ridership_route_setups_get_ridership_route_setup_response_body import (
        RidershipRouteSetupsGetRidershipRouteSetupResponseBody,
    )
    from .ridership_route_setups_get_ridership_route_setup_service_unavailable_error_response_body import (
        RidershipRouteSetupsGetRidershipRouteSetupServiceUnavailableErrorResponseBody,
    )
    from .ridership_route_setups_get_ridership_route_setup_too_many_requests_error_response_body import (
        RidershipRouteSetupsGetRidershipRouteSetupTooManyRequestsErrorResponseBody,
    )
    from .ridership_route_setups_get_ridership_route_setup_unauthorized_error_response_body import (
        RidershipRouteSetupsGetRidershipRouteSetupUnauthorizedErrorResponseBody,
    )
    from .ridership_route_setups_update_ridership_route_setup_bad_gateway_error_response_body import (
        RidershipRouteSetupsUpdateRidershipRouteSetupBadGatewayErrorResponseBody,
    )
    from .ridership_route_setups_update_ridership_route_setup_gateway_timeout_error_response_body import (
        RidershipRouteSetupsUpdateRidershipRouteSetupGatewayTimeoutErrorResponseBody,
    )
    from .ridership_route_setups_update_ridership_route_setup_internal_server_error_response_body import (
        RidershipRouteSetupsUpdateRidershipRouteSetupInternalServerErrorResponseBody,
    )
    from .ridership_route_setups_update_ridership_route_setup_method_not_allowed_error_response_body import (
        RidershipRouteSetupsUpdateRidershipRouteSetupMethodNotAllowedErrorResponseBody,
    )
    from .ridership_route_setups_update_ridership_route_setup_not_found_error_response_body import (
        RidershipRouteSetupsUpdateRidershipRouteSetupNotFoundErrorResponseBody,
    )
    from .ridership_route_setups_update_ridership_route_setup_not_implemented_error_response_body import (
        RidershipRouteSetupsUpdateRidershipRouteSetupNotImplementedErrorResponseBody,
    )
    from .ridership_route_setups_update_ridership_route_setup_response_body import (
        RidershipRouteSetupsUpdateRidershipRouteSetupResponseBody,
    )
    from .ridership_route_setups_update_ridership_route_setup_service_unavailable_error_response_body import (
        RidershipRouteSetupsUpdateRidershipRouteSetupServiceUnavailableErrorResponseBody,
    )
    from .ridership_route_setups_update_ridership_route_setup_too_many_requests_error_response_body import (
        RidershipRouteSetupsUpdateRidershipRouteSetupTooManyRequestsErrorResponseBody,
    )
    from .ridership_route_setups_update_ridership_route_setup_unauthorized_error_response_body import (
        RidershipRouteSetupsUpdateRidershipRouteSetupUnauthorizedErrorResponseBody,
    )
    from .rolling_stop_detection_alert_settings_object_response_body import (
        RollingStopDetectionAlertSettingsObjectResponseBody,
    )
    from .route_changes_response_body import RouteChangesResponseBody
    from .route_event_details_response_body import RouteEventDetailsResponseBody
    from .route_event_response_response_body import RouteEventResponseResponseBody
    from .route_event_response_response_body_event_type import RouteEventResponseResponseBodyEventType
    from .route_event_route_response_response_body import RouteEventRouteResponseResponseBody
    from .route_event_stop_response_response_body import RouteEventStopResponseResponseBody
    from .route_feed_object_response_body import RouteFeedObjectResponseBody
    from .route_feed_object_response_body_operation import RouteFeedObjectResponseBodyOperation
    from .route_feed_object_response_body_source import RouteFeedObjectResponseBodySource
    from .route_feed_object_response_body_type import RouteFeedObjectResponseBodyType
    from .route_object_response_body import RouteObjectResponseBody
    from .route_settings_request_body import RouteSettingsRequestBody
    from .route_settings_request_body_route_completion_condition import RouteSettingsRequestBodyRouteCompletionCondition
    from .route_settings_request_body_route_starting_condition import RouteSettingsRequestBodyRouteStartingCondition
    from .route_settings_request_body_sequencing_method import RouteSettingsRequestBodySequencingMethod
    from .route_settings_response_body import RouteSettingsResponseBody
    from .route_settings_response_body_route_completion_condition import (
        RouteSettingsResponseBodyRouteCompletionCondition,
    )
    from .route_settings_response_body_route_starting_condition import RouteSettingsResponseBodyRouteStartingCondition
    from .route_settings_response_body_sequencing_method import RouteSettingsResponseBodySequencingMethod
    from .route_stop_details_object_response_body import RouteStopDetailsObjectResponseBody
    from .route_stop_details_object_response_body_operation import RouteStopDetailsObjectResponseBodyOperation
    from .route_stop_details_object_response_body_type import RouteStopDetailsObjectResponseBodyType
    from .route_stop_estimated_arrival_details_object_request_body import (
        RouteStopEstimatedArrivalDetailsObjectRequestBody,
    )
    from .route_stop_estimated_arrival_details_object_response_body import (
        RouteStopEstimatedArrivalDetailsObjectResponseBody,
    )
    from .route_stop_eta_response_body import RouteStopEtaResponseBody
    from .route_stop_object_response_body import RouteStopObjectResponseBody
    from .routes_create_route_bad_gateway_error_response_body import RoutesCreateRouteBadGatewayErrorResponseBody
    from .routes_create_route_gateway_timeout_error_response_body import (
        RoutesCreateRouteGatewayTimeoutErrorResponseBody,
    )
    from .routes_create_route_internal_server_error_response_body import (
        RoutesCreateRouteInternalServerErrorResponseBody,
    )
    from .routes_create_route_method_not_allowed_error_response_body import (
        RoutesCreateRouteMethodNotAllowedErrorResponseBody,
    )
    from .routes_create_route_not_found_error_response_body import RoutesCreateRouteNotFoundErrorResponseBody
    from .routes_create_route_not_implemented_error_response_body import (
        RoutesCreateRouteNotImplementedErrorResponseBody,
    )
    from .routes_create_route_response_body import RoutesCreateRouteResponseBody
    from .routes_create_route_service_unavailable_error_response_body import (
        RoutesCreateRouteServiceUnavailableErrorResponseBody,
    )
    from .routes_create_route_too_many_requests_error_response_body import (
        RoutesCreateRouteTooManyRequestsErrorResponseBody,
    )
    from .routes_create_route_unauthorized_error_response_body import RoutesCreateRouteUnauthorizedErrorResponseBody
    from .routes_delete_route_bad_gateway_error_response_body import RoutesDeleteRouteBadGatewayErrorResponseBody
    from .routes_delete_route_gateway_timeout_error_response_body import (
        RoutesDeleteRouteGatewayTimeoutErrorResponseBody,
    )
    from .routes_delete_route_internal_server_error_response_body import (
        RoutesDeleteRouteInternalServerErrorResponseBody,
    )
    from .routes_delete_route_method_not_allowed_error_response_body import (
        RoutesDeleteRouteMethodNotAllowedErrorResponseBody,
    )
    from .routes_delete_route_not_found_error_response_body import RoutesDeleteRouteNotFoundErrorResponseBody
    from .routes_delete_route_not_implemented_error_response_body import (
        RoutesDeleteRouteNotImplementedErrorResponseBody,
    )
    from .routes_delete_route_service_unavailable_error_response_body import (
        RoutesDeleteRouteServiceUnavailableErrorResponseBody,
    )
    from .routes_delete_route_too_many_requests_error_response_body import (
        RoutesDeleteRouteTooManyRequestsErrorResponseBody,
    )
    from .routes_delete_route_unauthorized_error_response_body import RoutesDeleteRouteUnauthorizedErrorResponseBody
    from .routes_fetch_route_bad_gateway_error_response_body import RoutesFetchRouteBadGatewayErrorResponseBody
    from .routes_fetch_route_gateway_timeout_error_response_body import RoutesFetchRouteGatewayTimeoutErrorResponseBody
    from .routes_fetch_route_internal_server_error_response_body import RoutesFetchRouteInternalServerErrorResponseBody
    from .routes_fetch_route_method_not_allowed_error_response_body import (
        RoutesFetchRouteMethodNotAllowedErrorResponseBody,
    )
    from .routes_fetch_route_not_found_error_response_body import RoutesFetchRouteNotFoundErrorResponseBody
    from .routes_fetch_route_not_implemented_error_response_body import RoutesFetchRouteNotImplementedErrorResponseBody
    from .routes_fetch_route_response_body import RoutesFetchRouteResponseBody
    from .routes_fetch_route_service_unavailable_error_response_body import (
        RoutesFetchRouteServiceUnavailableErrorResponseBody,
    )
    from .routes_fetch_route_too_many_requests_error_response_body import (
        RoutesFetchRouteTooManyRequestsErrorResponseBody,
    )
    from .routes_fetch_route_unauthorized_error_response_body import RoutesFetchRouteUnauthorizedErrorResponseBody
    from .routes_fetch_routes_bad_gateway_error_response_body import RoutesFetchRoutesBadGatewayErrorResponseBody
    from .routes_fetch_routes_gateway_timeout_error_response_body import (
        RoutesFetchRoutesGatewayTimeoutErrorResponseBody,
    )
    from .routes_fetch_routes_internal_server_error_response_body import (
        RoutesFetchRoutesInternalServerErrorResponseBody,
    )
    from .routes_fetch_routes_method_not_allowed_error_response_body import (
        RoutesFetchRoutesMethodNotAllowedErrorResponseBody,
    )
    from .routes_fetch_routes_not_found_error_response_body import RoutesFetchRoutesNotFoundErrorResponseBody
    from .routes_fetch_routes_not_implemented_error_response_body import (
        RoutesFetchRoutesNotImplementedErrorResponseBody,
    )
    from .routes_fetch_routes_response_body import RoutesFetchRoutesResponseBody
    from .routes_fetch_routes_service_unavailable_error_response_body import (
        RoutesFetchRoutesServiceUnavailableErrorResponseBody,
    )
    from .routes_fetch_routes_too_many_requests_error_response_body import (
        RoutesFetchRoutesTooManyRequestsErrorResponseBody,
    )
    from .routes_fetch_routes_unauthorized_error_response_body import RoutesFetchRoutesUnauthorizedErrorResponseBody
    from .routes_get_route_events_stream_bad_gateway_error_response_body import (
        RoutesGetRouteEventsStreamBadGatewayErrorResponseBody,
    )
    from .routes_get_route_events_stream_gateway_timeout_error_response_body import (
        RoutesGetRouteEventsStreamGatewayTimeoutErrorResponseBody,
    )
    from .routes_get_route_events_stream_internal_server_error_response_body import (
        RoutesGetRouteEventsStreamInternalServerErrorResponseBody,
    )
    from .routes_get_route_events_stream_method_not_allowed_error_response_body import (
        RoutesGetRouteEventsStreamMethodNotAllowedErrorResponseBody,
    )
    from .routes_get_route_events_stream_not_found_error_response_body import (
        RoutesGetRouteEventsStreamNotFoundErrorResponseBody,
    )
    from .routes_get_route_events_stream_not_implemented_error_response_body import (
        RoutesGetRouteEventsStreamNotImplementedErrorResponseBody,
    )
    from .routes_get_route_events_stream_response_body import RoutesGetRouteEventsStreamResponseBody
    from .routes_get_route_events_stream_service_unavailable_error_response_body import (
        RoutesGetRouteEventsStreamServiceUnavailableErrorResponseBody,
    )
    from .routes_get_route_events_stream_too_many_requests_error_response_body import (
        RoutesGetRouteEventsStreamTooManyRequestsErrorResponseBody,
    )
    from .routes_get_route_events_stream_unauthorized_error_response_body import (
        RoutesGetRouteEventsStreamUnauthorizedErrorResponseBody,
    )
    from .routes_get_routes_feed_bad_gateway_error_response_body import RoutesGetRoutesFeedBadGatewayErrorResponseBody
    from .routes_get_routes_feed_gateway_timeout_error_response_body import (
        RoutesGetRoutesFeedGatewayTimeoutErrorResponseBody,
    )
    from .routes_get_routes_feed_internal_server_error_response_body import (
        RoutesGetRoutesFeedInternalServerErrorResponseBody,
    )
    from .routes_get_routes_feed_method_not_allowed_error_response_body import (
        RoutesGetRoutesFeedMethodNotAllowedErrorResponseBody,
    )
    from .routes_get_routes_feed_not_found_error_response_body import RoutesGetRoutesFeedNotFoundErrorResponseBody
    from .routes_get_routes_feed_not_implemented_error_response_body import (
        RoutesGetRoutesFeedNotImplementedErrorResponseBody,
    )
    from .routes_get_routes_feed_response_body import RoutesGetRoutesFeedResponseBody
    from .routes_get_routes_feed_service_unavailable_error_response_body import (
        RoutesGetRoutesFeedServiceUnavailableErrorResponseBody,
    )
    from .routes_get_routes_feed_too_many_requests_error_response_body import (
        RoutesGetRoutesFeedTooManyRequestsErrorResponseBody,
    )
    from .routes_get_routes_feed_unauthorized_error_response_body import (
        RoutesGetRoutesFeedUnauthorizedErrorResponseBody,
    )
    from .routes_patch_route_bad_gateway_error_response_body import RoutesPatchRouteBadGatewayErrorResponseBody
    from .routes_patch_route_gateway_timeout_error_response_body import RoutesPatchRouteGatewayTimeoutErrorResponseBody
    from .routes_patch_route_internal_server_error_response_body import RoutesPatchRouteInternalServerErrorResponseBody
    from .routes_patch_route_method_not_allowed_error_response_body import (
        RoutesPatchRouteMethodNotAllowedErrorResponseBody,
    )
    from .routes_patch_route_not_found_error_response_body import RoutesPatchRouteNotFoundErrorResponseBody
    from .routes_patch_route_not_implemented_error_response_body import RoutesPatchRouteNotImplementedErrorResponseBody
    from .routes_patch_route_response_body import RoutesPatchRouteResponseBody
    from .routes_patch_route_service_unavailable_error_response_body import (
        RoutesPatchRouteServiceUnavailableErrorResponseBody,
    )
    from .routes_patch_route_too_many_requests_error_response_body import (
        RoutesPatchRouteTooManyRequestsErrorResponseBody,
    )
    from .routes_patch_route_unauthorized_error_response_body import RoutesPatchRouteUnauthorizedErrorResponseBody
    from .routes_single_use_address_object_request_body import RoutesSingleUseAddressObjectRequestBody
    from .routes_single_use_address_object_response_body import RoutesSingleUseAddressObjectResponseBody
    from .routes_stop_response_object_response_body import RoutesStopResponseObjectResponseBody
    from .routes_stop_response_object_response_body_state import RoutesStopResponseObjectResponseBodyState
    from .safety_behavior_trigger_details_object_request_body import SafetyBehaviorTriggerDetailsObjectRequestBody
    from .safety_behavior_trigger_details_object_request_body_behaviors_item import (
        SafetyBehaviorTriggerDetailsObjectRequestBodyBehaviorsItem,
    )
    from .safety_behavior_trigger_details_object_request_body_severities_item import (
        SafetyBehaviorTriggerDetailsObjectRequestBodySeveritiesItem,
    )
    from .safety_behavior_trigger_details_object_request_body_statuses_item import (
        SafetyBehaviorTriggerDetailsObjectRequestBodyStatusesItem,
    )
    from .safety_behavior_trigger_details_object_response_body import SafetyBehaviorTriggerDetailsObjectResponseBody
    from .safety_behavior_trigger_details_object_response_body_behaviors_item import (
        SafetyBehaviorTriggerDetailsObjectResponseBodyBehaviorsItem,
    )
    from .safety_behavior_trigger_details_object_response_body_severities_item import (
        SafetyBehaviorTriggerDetailsObjectResponseBodySeveritiesItem,
    )
    from .safety_behavior_trigger_details_object_response_body_statuses_item import (
        SafetyBehaviorTriggerDetailsObjectResponseBodyStatusesItem,
    )
    from .safety_event import SafetyEvent
    from .safety_event_activity_feed_item_response_body import SafetyEventActivityFeedItemResponseBody
    from .safety_event_activity_feed_item_response_body_type import SafetyEventActivityFeedItemResponseBodyType
    from .safety_event_behavior_label import SafetyEventBehaviorLabel
    from .safety_event_behavior_label_name import SafetyEventBehaviorLabelName
    from .safety_event_behavior_label_source import SafetyEventBehaviorLabelSource
    from .safety_event_behavior_label_type import SafetyEventBehaviorLabelType
    from .safety_event_behavior_labels import SafetyEventBehaviorLabels
    from .safety_event_behavior_labels_response_body import SafetyEventBehaviorLabelsResponseBody
    from .safety_event_behavior_labels_response_body_type import SafetyEventBehaviorLabelsResponseBodyType
    from .safety_event_coaching_state import SafetyEventCoachingState
    from .safety_event_dismissal_reason_response_body import SafetyEventDismissalReasonResponseBody
    from .safety_event_dismissal_reason_response_body_code import SafetyEventDismissalReasonResponseBodyCode
    from .safety_event_download_forward_video_url import SafetyEventDownloadForwardVideoUrl
    from .safety_event_download_inward_video_url import SafetyEventDownloadInwardVideoUrl
    from .safety_event_download_tracked_inward_video_url import SafetyEventDownloadTrackedInwardVideoUrl
    from .safety_event_driver_object_response_body import SafetyEventDriverObjectResponseBody
    from .safety_event_id import SafetyEventId
    from .safety_event_max_acceleration_g_force import SafetyEventMaxAccelerationGForce
    from .safety_event_object_response_body import SafetyEventObjectResponseBody
    from .safety_event_speeding_metadata_response_body import SafetyEventSpeedingMetadataResponseBody
    from .safety_event_time import SafetyEventTime
    from .safety_event_v_2_asset_object_response_body import SafetyEventV2AssetObjectResponseBody
    from .safety_event_v_2_asset_object_response_body_type import SafetyEventV2AssetObjectResponseBodyType
    from .safety_event_v_2_behavior_labels_response_body import SafetyEventV2BehaviorLabelsResponseBody
    from .safety_event_v_2_behavior_labels_response_body_label import SafetyEventV2BehaviorLabelsResponseBodyLabel
    from .safety_event_v_2_behavior_labels_response_body_source import SafetyEventV2BehaviorLabelsResponseBodySource
    from .safety_event_v_2_context_labels_response_body import SafetyEventV2ContextLabelsResponseBody
    from .safety_event_v_2_driver_object_response_body import SafetyEventV2DriverObjectResponseBody
    from .safety_event_v_2_media_response_body import SafetyEventV2MediaResponseBody
    from .safety_event_v_2_media_response_body_camera_role import SafetyEventV2MediaResponseBodyCameraRole
    from .safety_event_v_2_media_response_body_input import SafetyEventV2MediaResponseBodyInput
    from .safety_event_v_2_object_response_body import SafetyEventV2ObjectResponseBody
    from .safety_event_v_2_object_response_body_event_state import SafetyEventV2ObjectResponseBodyEventState
    from .safety_event_vehicle_object_response_body import SafetyEventVehicleObjectResponseBody
    from .safety_events_get_safety_activity_event_feed_bad_gateway_error_response_body import (
        SafetyEventsGetSafetyActivityEventFeedBadGatewayErrorResponseBody,
    )
    from .safety_events_get_safety_activity_event_feed_gateway_timeout_error_response_body import (
        SafetyEventsGetSafetyActivityEventFeedGatewayTimeoutErrorResponseBody,
    )
    from .safety_events_get_safety_activity_event_feed_internal_server_error_response_body import (
        SafetyEventsGetSafetyActivityEventFeedInternalServerErrorResponseBody,
    )
    from .safety_events_get_safety_activity_event_feed_method_not_allowed_error_response_body import (
        SafetyEventsGetSafetyActivityEventFeedMethodNotAllowedErrorResponseBody,
    )
    from .safety_events_get_safety_activity_event_feed_not_found_error_response_body import (
        SafetyEventsGetSafetyActivityEventFeedNotFoundErrorResponseBody,
    )
    from .safety_events_get_safety_activity_event_feed_not_implemented_error_response_body import (
        SafetyEventsGetSafetyActivityEventFeedNotImplementedErrorResponseBody,
    )
    from .safety_events_get_safety_activity_event_feed_response_body import (
        SafetyEventsGetSafetyActivityEventFeedResponseBody,
    )
    from .safety_events_get_safety_activity_event_feed_service_unavailable_error_response_body import (
        SafetyEventsGetSafetyActivityEventFeedServiceUnavailableErrorResponseBody,
    )
    from .safety_events_get_safety_activity_event_feed_too_many_requests_error_response_body import (
        SafetyEventsGetSafetyActivityEventFeedTooManyRequestsErrorResponseBody,
    )
    from .safety_events_get_safety_activity_event_feed_unauthorized_error_response_body import (
        SafetyEventsGetSafetyActivityEventFeedUnauthorizedErrorResponseBody,
    )
    from .safety_events_list_response import SafetyEventsListResponse
    from .safety_events_v_2_get_safety_events_v_2_bad_gateway_error_response_body import (
        SafetyEventsV2GetSafetyEventsV2BadGatewayErrorResponseBody,
    )
    from .safety_events_v_2_get_safety_events_v_2_gateway_timeout_error_response_body import (
        SafetyEventsV2GetSafetyEventsV2GatewayTimeoutErrorResponseBody,
    )
    from .safety_events_v_2_get_safety_events_v_2_internal_server_error_response_body import (
        SafetyEventsV2GetSafetyEventsV2InternalServerErrorResponseBody,
    )
    from .safety_events_v_2_get_safety_events_v_2_method_not_allowed_error_response_body import (
        SafetyEventsV2GetSafetyEventsV2MethodNotAllowedErrorResponseBody,
    )
    from .safety_events_v_2_get_safety_events_v_2_not_found_error_response_body import (
        SafetyEventsV2GetSafetyEventsV2NotFoundErrorResponseBody,
    )
    from .safety_events_v_2_get_safety_events_v_2_not_implemented_error_response_body import (
        SafetyEventsV2GetSafetyEventsV2NotImplementedErrorResponseBody,
    )
    from .safety_events_v_2_get_safety_events_v_2_response_body import SafetyEventsV2GetSafetyEventsV2ResponseBody
    from .safety_events_v_2_get_safety_events_v_2_service_unavailable_error_response_body import (
        SafetyEventsV2GetSafetyEventsV2ServiceUnavailableErrorResponseBody,
    )
    from .safety_events_v_2_get_safety_events_v_2_stream_bad_gateway_error_response_body import (
        SafetyEventsV2GetSafetyEventsV2StreamBadGatewayErrorResponseBody,
    )
    from .safety_events_v_2_get_safety_events_v_2_stream_gateway_timeout_error_response_body import (
        SafetyEventsV2GetSafetyEventsV2StreamGatewayTimeoutErrorResponseBody,
    )
    from .safety_events_v_2_get_safety_events_v_2_stream_internal_server_error_response_body import (
        SafetyEventsV2GetSafetyEventsV2StreamInternalServerErrorResponseBody,
    )
    from .safety_events_v_2_get_safety_events_v_2_stream_method_not_allowed_error_response_body import (
        SafetyEventsV2GetSafetyEventsV2StreamMethodNotAllowedErrorResponseBody,
    )
    from .safety_events_v_2_get_safety_events_v_2_stream_not_found_error_response_body import (
        SafetyEventsV2GetSafetyEventsV2StreamNotFoundErrorResponseBody,
    )
    from .safety_events_v_2_get_safety_events_v_2_stream_not_implemented_error_response_body import (
        SafetyEventsV2GetSafetyEventsV2StreamNotImplementedErrorResponseBody,
    )
    from .safety_events_v_2_get_safety_events_v_2_stream_response_body import (
        SafetyEventsV2GetSafetyEventsV2StreamResponseBody,
    )
    from .safety_events_v_2_get_safety_events_v_2_stream_service_unavailable_error_response_body import (
        SafetyEventsV2GetSafetyEventsV2StreamServiceUnavailableErrorResponseBody,
    )
    from .safety_events_v_2_get_safety_events_v_2_stream_too_many_requests_error_response_body import (
        SafetyEventsV2GetSafetyEventsV2StreamTooManyRequestsErrorResponseBody,
    )
    from .safety_events_v_2_get_safety_events_v_2_stream_unauthorized_error_response_body import (
        SafetyEventsV2GetSafetyEventsV2StreamUnauthorizedErrorResponseBody,
    )
    from .safety_events_v_2_get_safety_events_v_2_too_many_requests_error_response_body import (
        SafetyEventsV2GetSafetyEventsV2TooManyRequestsErrorResponseBody,
    )
    from .safety_events_v_2_get_safety_events_v_2_unauthorized_error_response_body import (
        SafetyEventsV2GetSafetyEventsV2UnauthorizedErrorResponseBody,
    )
    from .safety_score_behavior_object_response_body import SafetyScoreBehaviorObjectResponseBody
    from .safety_score_behavior_object_response_body_behavior_type import (
        SafetyScoreBehaviorObjectResponseBodyBehaviorType,
    )
    from .safety_score_configuration_settings_object_response_body import (
        SafetyScoreConfigurationSettingsObjectResponseBody,
    )
    from .safety_score_details_request_body import SafetyScoreDetailsRequestBody
    from .safety_score_details_request_body_comparison import SafetyScoreDetailsRequestBodyComparison
    from .safety_score_details_response_body import SafetyScoreDetailsResponseBody
    from .safety_score_details_response_body_comparison import SafetyScoreDetailsResponseBodyComparison
    from .safety_score_speeding_object_response_body import SafetyScoreSpeedingObjectResponseBody
    from .safety_score_speeding_object_response_body_speeding_type import (
        SafetyScoreSpeedingObjectResponseBodySpeedingType,
    )
    from .safety_scores_get_driver_safety_score_trips_bad_gateway_error_response_body import (
        SafetyScoresGetDriverSafetyScoreTripsBadGatewayErrorResponseBody,
    )
    from .safety_scores_get_driver_safety_score_trips_gateway_timeout_error_response_body import (
        SafetyScoresGetDriverSafetyScoreTripsGatewayTimeoutErrorResponseBody,
    )
    from .safety_scores_get_driver_safety_score_trips_internal_server_error_response_body import (
        SafetyScoresGetDriverSafetyScoreTripsInternalServerErrorResponseBody,
    )
    from .safety_scores_get_driver_safety_score_trips_method_not_allowed_error_response_body import (
        SafetyScoresGetDriverSafetyScoreTripsMethodNotAllowedErrorResponseBody,
    )
    from .safety_scores_get_driver_safety_score_trips_not_found_error_response_body import (
        SafetyScoresGetDriverSafetyScoreTripsNotFoundErrorResponseBody,
    )
    from .safety_scores_get_driver_safety_score_trips_not_implemented_error_response_body import (
        SafetyScoresGetDriverSafetyScoreTripsNotImplementedErrorResponseBody,
    )
    from .safety_scores_get_driver_safety_score_trips_response_body import (
        SafetyScoresGetDriverSafetyScoreTripsResponseBody,
    )
    from .safety_scores_get_driver_safety_score_trips_service_unavailable_error_response_body import (
        SafetyScoresGetDriverSafetyScoreTripsServiceUnavailableErrorResponseBody,
    )
    from .safety_scores_get_driver_safety_score_trips_too_many_requests_error_response_body import (
        SafetyScoresGetDriverSafetyScoreTripsTooManyRequestsErrorResponseBody,
    )
    from .safety_scores_get_driver_safety_score_trips_unauthorized_error_response_body import (
        SafetyScoresGetDriverSafetyScoreTripsUnauthorizedErrorResponseBody,
    )
    from .safety_scores_get_driver_safety_scores_bad_gateway_error_response_body import (
        SafetyScoresGetDriverSafetyScoresBadGatewayErrorResponseBody,
    )
    from .safety_scores_get_driver_safety_scores_gateway_timeout_error_response_body import (
        SafetyScoresGetDriverSafetyScoresGatewayTimeoutErrorResponseBody,
    )
    from .safety_scores_get_driver_safety_scores_internal_server_error_response_body import (
        SafetyScoresGetDriverSafetyScoresInternalServerErrorResponseBody,
    )
    from .safety_scores_get_driver_safety_scores_method_not_allowed_error_response_body import (
        SafetyScoresGetDriverSafetyScoresMethodNotAllowedErrorResponseBody,
    )
    from .safety_scores_get_driver_safety_scores_not_found_error_response_body import (
        SafetyScoresGetDriverSafetyScoresNotFoundErrorResponseBody,
    )
    from .safety_scores_get_driver_safety_scores_not_implemented_error_response_body import (
        SafetyScoresGetDriverSafetyScoresNotImplementedErrorResponseBody,
    )
    from .safety_scores_get_driver_safety_scores_response_body import SafetyScoresGetDriverSafetyScoresResponseBody
    from .safety_scores_get_driver_safety_scores_service_unavailable_error_response_body import (
        SafetyScoresGetDriverSafetyScoresServiceUnavailableErrorResponseBody,
    )
    from .safety_scores_get_driver_safety_scores_too_many_requests_error_response_body import (
        SafetyScoresGetDriverSafetyScoresTooManyRequestsErrorResponseBody,
    )
    from .safety_scores_get_driver_safety_scores_unauthorized_error_response_body import (
        SafetyScoresGetDriverSafetyScoresUnauthorizedErrorResponseBody,
    )
    from .safety_scores_get_tag_group_safety_scores_bad_gateway_error_response_body import (
        SafetyScoresGetTagGroupSafetyScoresBadGatewayErrorResponseBody,
    )
    from .safety_scores_get_tag_group_safety_scores_gateway_timeout_error_response_body import (
        SafetyScoresGetTagGroupSafetyScoresGatewayTimeoutErrorResponseBody,
    )
    from .safety_scores_get_tag_group_safety_scores_internal_server_error_response_body import (
        SafetyScoresGetTagGroupSafetyScoresInternalServerErrorResponseBody,
    )
    from .safety_scores_get_tag_group_safety_scores_method_not_allowed_error_response_body import (
        SafetyScoresGetTagGroupSafetyScoresMethodNotAllowedErrorResponseBody,
    )
    from .safety_scores_get_tag_group_safety_scores_not_found_error_response_body import (
        SafetyScoresGetTagGroupSafetyScoresNotFoundErrorResponseBody,
    )
    from .safety_scores_get_tag_group_safety_scores_not_implemented_error_response_body import (
        SafetyScoresGetTagGroupSafetyScoresNotImplementedErrorResponseBody,
    )
    from .safety_scores_get_tag_group_safety_scores_response_body import SafetyScoresGetTagGroupSafetyScoresResponseBody
    from .safety_scores_get_tag_group_safety_scores_service_unavailable_error_response_body import (
        SafetyScoresGetTagGroupSafetyScoresServiceUnavailableErrorResponseBody,
    )
    from .safety_scores_get_tag_group_safety_scores_too_many_requests_error_response_body import (
        SafetyScoresGetTagGroupSafetyScoresTooManyRequestsErrorResponseBody,
    )
    from .safety_scores_get_tag_group_safety_scores_unauthorized_error_response_body import (
        SafetyScoresGetTagGroupSafetyScoresUnauthorizedErrorResponseBody,
    )
    from .safety_scores_get_tag_safety_scores_bad_gateway_error_response_body import (
        SafetyScoresGetTagSafetyScoresBadGatewayErrorResponseBody,
    )
    from .safety_scores_get_tag_safety_scores_gateway_timeout_error_response_body import (
        SafetyScoresGetTagSafetyScoresGatewayTimeoutErrorResponseBody,
    )
    from .safety_scores_get_tag_safety_scores_internal_server_error_response_body import (
        SafetyScoresGetTagSafetyScoresInternalServerErrorResponseBody,
    )
    from .safety_scores_get_tag_safety_scores_method_not_allowed_error_response_body import (
        SafetyScoresGetTagSafetyScoresMethodNotAllowedErrorResponseBody,
    )
    from .safety_scores_get_tag_safety_scores_not_found_error_response_body import (
        SafetyScoresGetTagSafetyScoresNotFoundErrorResponseBody,
    )
    from .safety_scores_get_tag_safety_scores_not_implemented_error_response_body import (
        SafetyScoresGetTagSafetyScoresNotImplementedErrorResponseBody,
    )
    from .safety_scores_get_tag_safety_scores_response_body import SafetyScoresGetTagSafetyScoresResponseBody
    from .safety_scores_get_tag_safety_scores_service_unavailable_error_response_body import (
        SafetyScoresGetTagSafetyScoresServiceUnavailableErrorResponseBody,
    )
    from .safety_scores_get_tag_safety_scores_too_many_requests_error_response_body import (
        SafetyScoresGetTagSafetyScoresTooManyRequestsErrorResponseBody,
    )
    from .safety_scores_get_tag_safety_scores_unauthorized_error_response_body import (
        SafetyScoresGetTagSafetyScoresUnauthorizedErrorResponseBody,
    )
    from .safety_scores_get_vehicle_safety_score_trips_bad_gateway_error_response_body import (
        SafetyScoresGetVehicleSafetyScoreTripsBadGatewayErrorResponseBody,
    )
    from .safety_scores_get_vehicle_safety_score_trips_gateway_timeout_error_response_body import (
        SafetyScoresGetVehicleSafetyScoreTripsGatewayTimeoutErrorResponseBody,
    )
    from .safety_scores_get_vehicle_safety_score_trips_internal_server_error_response_body import (
        SafetyScoresGetVehicleSafetyScoreTripsInternalServerErrorResponseBody,
    )
    from .safety_scores_get_vehicle_safety_score_trips_method_not_allowed_error_response_body import (
        SafetyScoresGetVehicleSafetyScoreTripsMethodNotAllowedErrorResponseBody,
    )
    from .safety_scores_get_vehicle_safety_score_trips_not_found_error_response_body import (
        SafetyScoresGetVehicleSafetyScoreTripsNotFoundErrorResponseBody,
    )
    from .safety_scores_get_vehicle_safety_score_trips_not_implemented_error_response_body import (
        SafetyScoresGetVehicleSafetyScoreTripsNotImplementedErrorResponseBody,
    )
    from .safety_scores_get_vehicle_safety_score_trips_response_body import (
        SafetyScoresGetVehicleSafetyScoreTripsResponseBody,
    )
    from .safety_scores_get_vehicle_safety_score_trips_service_unavailable_error_response_body import (
        SafetyScoresGetVehicleSafetyScoreTripsServiceUnavailableErrorResponseBody,
    )
    from .safety_scores_get_vehicle_safety_score_trips_too_many_requests_error_response_body import (
        SafetyScoresGetVehicleSafetyScoreTripsTooManyRequestsErrorResponseBody,
    )
    from .safety_scores_get_vehicle_safety_score_trips_unauthorized_error_response_body import (
        SafetyScoresGetVehicleSafetyScoreTripsUnauthorizedErrorResponseBody,
    )
    from .safety_scores_get_vehicle_safety_scores_bad_gateway_error_response_body import (
        SafetyScoresGetVehicleSafetyScoresBadGatewayErrorResponseBody,
    )
    from .safety_scores_get_vehicle_safety_scores_gateway_timeout_error_response_body import (
        SafetyScoresGetVehicleSafetyScoresGatewayTimeoutErrorResponseBody,
    )
    from .safety_scores_get_vehicle_safety_scores_internal_server_error_response_body import (
        SafetyScoresGetVehicleSafetyScoresInternalServerErrorResponseBody,
    )
    from .safety_scores_get_vehicle_safety_scores_method_not_allowed_error_response_body import (
        SafetyScoresGetVehicleSafetyScoresMethodNotAllowedErrorResponseBody,
    )
    from .safety_scores_get_vehicle_safety_scores_not_found_error_response_body import (
        SafetyScoresGetVehicleSafetyScoresNotFoundErrorResponseBody,
    )
    from .safety_scores_get_vehicle_safety_scores_not_implemented_error_response_body import (
        SafetyScoresGetVehicleSafetyScoresNotImplementedErrorResponseBody,
    )
    from .safety_scores_get_vehicle_safety_scores_response_body import SafetyScoresGetVehicleSafetyScoresResponseBody
    from .safety_scores_get_vehicle_safety_scores_service_unavailable_error_response_body import (
        SafetyScoresGetVehicleSafetyScoresServiceUnavailableErrorResponseBody,
    )
    from .safety_scores_get_vehicle_safety_scores_too_many_requests_error_response_body import (
        SafetyScoresGetVehicleSafetyScoresTooManyRequestsErrorResponseBody,
    )
    from .safety_scores_get_vehicle_safety_scores_unauthorized_error_response_body import (
        SafetyScoresGetVehicleSafetyScoresUnauthorizedErrorResponseBody,
    )
    from .safety_settings_get_safety_settings_bad_gateway_error_response_body import (
        SafetySettingsGetSafetySettingsBadGatewayErrorResponseBody,
    )
    from .safety_settings_get_safety_settings_gateway_timeout_error_response_body import (
        SafetySettingsGetSafetySettingsGatewayTimeoutErrorResponseBody,
    )
    from .safety_settings_get_safety_settings_internal_server_error_response_body import (
        SafetySettingsGetSafetySettingsInternalServerErrorResponseBody,
    )
    from .safety_settings_get_safety_settings_method_not_allowed_error_response_body import (
        SafetySettingsGetSafetySettingsMethodNotAllowedErrorResponseBody,
    )
    from .safety_settings_get_safety_settings_not_found_error_response_body import (
        SafetySettingsGetSafetySettingsNotFoundErrorResponseBody,
    )
    from .safety_settings_get_safety_settings_not_implemented_error_response_body import (
        SafetySettingsGetSafetySettingsNotImplementedErrorResponseBody,
    )
    from .safety_settings_get_safety_settings_response_body import SafetySettingsGetSafetySettingsResponseBody
    from .safety_settings_get_safety_settings_service_unavailable_error_response_body import (
        SafetySettingsGetSafetySettingsServiceUnavailableErrorResponseBody,
    )
    from .safety_settings_get_safety_settings_too_many_requests_error_response_body import (
        SafetySettingsGetSafetySettingsTooManyRequestsErrorResponseBody,
    )
    from .safety_settings_get_safety_settings_unauthorized_error_response_body import (
        SafetySettingsGetSafetySettingsUnauthorizedErrorResponseBody,
    )
    from .safety_settings_object_response_body import SafetySettingsObjectResponseBody
    from .safety_settings_object_response_body_default_vehicle_type import (
        SafetySettingsObjectResponseBodyDefaultVehicleType,
    )
    from .scanned_document_value_object_request_body import ScannedDocumentValueObjectRequestBody
    from .scanned_document_value_object_response_body import ScannedDocumentValueObjectResponseBody
    from .scheduled_maintenance_by_engine_hours_details_object_request_body import (
        ScheduledMaintenanceByEngineHoursDetailsObjectRequestBody,
    )
    from .scheduled_maintenance_by_engine_hours_details_object_response_body import (
        ScheduledMaintenanceByEngineHoursDetailsObjectResponseBody,
    )
    from .scheduled_maintenance_by_engine_hours_response_body import ScheduledMaintenanceByEngineHoursResponseBody
    from .scheduled_maintenance_data_response_body import ScheduledMaintenanceDataResponseBody
    from .scheduled_maintenance_odometer_data_response_body import ScheduledMaintenanceOdometerDataResponseBody
    from .scheduled_maintenance_odometer_trigger_details_object_request_body import (
        ScheduledMaintenanceOdometerTriggerDetailsObjectRequestBody,
    )
    from .scheduled_maintenance_odometer_trigger_details_object_response_body import (
        ScheduledMaintenanceOdometerTriggerDetailsObjectResponseBody,
    )
    from .scheduled_maintenance_trigger_details_object_request_body import (
        ScheduledMaintenanceTriggerDetailsObjectRequestBody,
    )
    from .scheduled_maintenance_trigger_details_object_response_body import (
        ScheduledMaintenanceTriggerDetailsObjectResponseBody,
    )
    from .scope_object_request_body import ScopeObjectRequestBody
    from .scope_object_response_body import ScopeObjectResponseBody
    from .sensor import Sensor
    from .sensor_response_body import SensorResponseBody
    from .serial import Serial
    from .service_task_definition_object_response_body import ServiceTaskDefinitionObjectResponseBody
    from .service_task_instance_input_object_request_body import ServiceTaskInstanceInputObjectRequestBody
    from .service_task_instance_input_object_request_body_status import ServiceTaskInstanceInputObjectRequestBodyStatus
    from .service_task_instance_object_response_body import ServiceTaskInstanceObjectResponseBody
    from .service_task_instance_object_response_body_status import ServiceTaskInstanceObjectResponseBodyStatus
    from .service_window_object_response_body import ServiceWindowObjectResponseBody
    from .settings_compliance_response_object_response_body import SettingsComplianceResponseObjectResponseBody
    from .settings_get_compliance_settings_bad_gateway_error_response_body import (
        SettingsGetComplianceSettingsBadGatewayErrorResponseBody,
    )
    from .settings_get_compliance_settings_gateway_timeout_error_response_body import (
        SettingsGetComplianceSettingsGatewayTimeoutErrorResponseBody,
    )
    from .settings_get_compliance_settings_internal_server_error_response_body import (
        SettingsGetComplianceSettingsInternalServerErrorResponseBody,
    )
    from .settings_get_compliance_settings_method_not_allowed_error_response_body import (
        SettingsGetComplianceSettingsMethodNotAllowedErrorResponseBody,
    )
    from .settings_get_compliance_settings_not_found_error_response_body import (
        SettingsGetComplianceSettingsNotFoundErrorResponseBody,
    )
    from .settings_get_compliance_settings_not_implemented_error_response_body import (
        SettingsGetComplianceSettingsNotImplementedErrorResponseBody,
    )
    from .settings_get_compliance_settings_response_body import SettingsGetComplianceSettingsResponseBody
    from .settings_get_compliance_settings_service_unavailable_error_response_body import (
        SettingsGetComplianceSettingsServiceUnavailableErrorResponseBody,
    )
    from .settings_get_compliance_settings_too_many_requests_error_response_body import (
        SettingsGetComplianceSettingsTooManyRequestsErrorResponseBody,
    )
    from .settings_get_compliance_settings_unauthorized_error_response_body import (
        SettingsGetComplianceSettingsUnauthorizedErrorResponseBody,
    )
    from .settings_get_driver_app_settings_bad_gateway_error_response_body import (
        SettingsGetDriverAppSettingsBadGatewayErrorResponseBody,
    )
    from .settings_get_driver_app_settings_gateway_timeout_error_response_body import (
        SettingsGetDriverAppSettingsGatewayTimeoutErrorResponseBody,
    )
    from .settings_get_driver_app_settings_internal_server_error_response_body import (
        SettingsGetDriverAppSettingsInternalServerErrorResponseBody,
    )
    from .settings_get_driver_app_settings_method_not_allowed_error_response_body import (
        SettingsGetDriverAppSettingsMethodNotAllowedErrorResponseBody,
    )
    from .settings_get_driver_app_settings_not_found_error_response_body import (
        SettingsGetDriverAppSettingsNotFoundErrorResponseBody,
    )
    from .settings_get_driver_app_settings_not_implemented_error_response_body import (
        SettingsGetDriverAppSettingsNotImplementedErrorResponseBody,
    )
    from .settings_get_driver_app_settings_response_body import SettingsGetDriverAppSettingsResponseBody
    from .settings_get_driver_app_settings_service_unavailable_error_response_body import (
        SettingsGetDriverAppSettingsServiceUnavailableErrorResponseBody,
    )
    from .settings_get_driver_app_settings_too_many_requests_error_response_body import (
        SettingsGetDriverAppSettingsTooManyRequestsErrorResponseBody,
    )
    from .settings_get_driver_app_settings_unauthorized_error_response_body import (
        SettingsGetDriverAppSettingsUnauthorizedErrorResponseBody,
    )
    from .settings_patch_compliance_settings_bad_gateway_error_response_body import (
        SettingsPatchComplianceSettingsBadGatewayErrorResponseBody,
    )
    from .settings_patch_compliance_settings_gateway_timeout_error_response_body import (
        SettingsPatchComplianceSettingsGatewayTimeoutErrorResponseBody,
    )
    from .settings_patch_compliance_settings_internal_server_error_response_body import (
        SettingsPatchComplianceSettingsInternalServerErrorResponseBody,
    )
    from .settings_patch_compliance_settings_method_not_allowed_error_response_body import (
        SettingsPatchComplianceSettingsMethodNotAllowedErrorResponseBody,
    )
    from .settings_patch_compliance_settings_not_found_error_response_body import (
        SettingsPatchComplianceSettingsNotFoundErrorResponseBody,
    )
    from .settings_patch_compliance_settings_not_implemented_error_response_body import (
        SettingsPatchComplianceSettingsNotImplementedErrorResponseBody,
    )
    from .settings_patch_compliance_settings_response_body import SettingsPatchComplianceSettingsResponseBody
    from .settings_patch_compliance_settings_service_unavailable_error_response_body import (
        SettingsPatchComplianceSettingsServiceUnavailableErrorResponseBody,
    )
    from .settings_patch_compliance_settings_too_many_requests_error_response_body import (
        SettingsPatchComplianceSettingsTooManyRequestsErrorResponseBody,
    )
    from .settings_patch_compliance_settings_unauthorized_error_response_body import (
        SettingsPatchComplianceSettingsUnauthorizedErrorResponseBody,
    )
    from .settings_patch_driver_app_settings_bad_gateway_error_response_body import (
        SettingsPatchDriverAppSettingsBadGatewayErrorResponseBody,
    )
    from .settings_patch_driver_app_settings_gateway_timeout_error_response_body import (
        SettingsPatchDriverAppSettingsGatewayTimeoutErrorResponseBody,
    )
    from .settings_patch_driver_app_settings_internal_server_error_response_body import (
        SettingsPatchDriverAppSettingsInternalServerErrorResponseBody,
    )
    from .settings_patch_driver_app_settings_method_not_allowed_error_response_body import (
        SettingsPatchDriverAppSettingsMethodNotAllowedErrorResponseBody,
    )
    from .settings_patch_driver_app_settings_not_found_error_response_body import (
        SettingsPatchDriverAppSettingsNotFoundErrorResponseBody,
    )
    from .settings_patch_driver_app_settings_not_implemented_error_response_body import (
        SettingsPatchDriverAppSettingsNotImplementedErrorResponseBody,
    )
    from .settings_patch_driver_app_settings_response_body import SettingsPatchDriverAppSettingsResponseBody
    from .settings_patch_driver_app_settings_service_unavailable_error_response_body import (
        SettingsPatchDriverAppSettingsServiceUnavailableErrorResponseBody,
    )
    from .settings_patch_driver_app_settings_too_many_requests_error_response_body import (
        SettingsPatchDriverAppSettingsTooManyRequestsErrorResponseBody,
    )
    from .settings_patch_driver_app_settings_unauthorized_error_response_body import (
        SettingsPatchDriverAppSettingsUnauthorizedErrorResponseBody,
    )
    from .settings_response_body import SettingsResponseBody
    from .severe_speeding_started_object_response_body import SevereSpeedingStartedObjectResponseBody
    from .severe_speeding_started_response_object_response_body import SevereSpeedingStartedResponseObjectResponseBody
    from .signatory_user_object_response_body import SignatoryUserObjectResponseBody
    from .signature_field_type_meta_data_object_response_body import SignatureFieldTypeMetaDataObjectResponseBody
    from .signature_value_object_request_body import SignatureValueObjectRequestBody
    from .signature_value_object_response_body import SignatureValueObjectResponseBody
    from .single_approval_requirements_object_response_body import SingleApprovalRequirementsObjectResponseBody
    from .single_driver_efficiency_by_driver_data_object_response_body import (
        SingleDriverEfficiencyByDriverDataObjectResponseBody,
    )
    from .single_driver_efficiency_by_vehicle_data_object_response_body import (
        SingleDriverEfficiencyByVehicleDataObjectResponseBody,
    )
    from .single_use_location_object_response_body import SingleUseLocationObjectResponseBody
    from .site_gateway_disconnected_response_body import SiteGatewayDisconnectedResponseBody
    from .skill_object_response_body import SkillObjectResponseBody
    from .specific_vehicle_fault_code_object_request_body import SpecificVehicleFaultCodeObjectRequestBody
    from .specific_vehicle_fault_code_object_request_body_type import SpecificVehicleFaultCodeObjectRequestBodyType
    from .specific_vehicle_fault_code_object_response_body import SpecificVehicleFaultCodeObjectResponseBody
    from .specific_vehicle_fault_code_object_response_body_type import SpecificVehicleFaultCodeObjectResponseBodyType
    from .speed_data_response_body import SpeedDataResponseBody
    from .speed_data_response_body_operation import SpeedDataResponseBodyOperation
    from .speed_response_response_body import SpeedResponseResponseBody
    from .speed_trigger_details_object_request_body import SpeedTriggerDetailsObjectRequestBody
    from .speed_trigger_details_object_request_body_operation import SpeedTriggerDetailsObjectRequestBodyOperation
    from .speed_trigger_details_object_response_body import SpeedTriggerDetailsObjectResponseBody
    from .speed_trigger_details_object_response_body_operation import SpeedTriggerDetailsObjectResponseBodyOperation
    from .speeding_interval_location_response_response_body import SpeedingIntervalLocationResponseResponseBody
    from .speeding_interval_response_body import SpeedingIntervalResponseBody
    from .speeding_interval_response_body_severity_level import SpeedingIntervalResponseBodySeverityLevel
    from .speeding_intervals_get_speeding_intervals_bad_gateway_error_response_body import (
        SpeedingIntervalsGetSpeedingIntervalsBadGatewayErrorResponseBody,
    )
    from .speeding_intervals_get_speeding_intervals_gateway_timeout_error_response_body import (
        SpeedingIntervalsGetSpeedingIntervalsGatewayTimeoutErrorResponseBody,
    )
    from .speeding_intervals_get_speeding_intervals_internal_server_error_response_body import (
        SpeedingIntervalsGetSpeedingIntervalsInternalServerErrorResponseBody,
    )
    from .speeding_intervals_get_speeding_intervals_method_not_allowed_error_response_body import (
        SpeedingIntervalsGetSpeedingIntervalsMethodNotAllowedErrorResponseBody,
    )
    from .speeding_intervals_get_speeding_intervals_not_found_error_response_body import (
        SpeedingIntervalsGetSpeedingIntervalsNotFoundErrorResponseBody,
    )
    from .speeding_intervals_get_speeding_intervals_not_implemented_error_response_body import (
        SpeedingIntervalsGetSpeedingIntervalsNotImplementedErrorResponseBody,
    )
    from .speeding_intervals_get_speeding_intervals_response_body import (
        SpeedingIntervalsGetSpeedingIntervalsResponseBody,
    )
    from .speeding_intervals_get_speeding_intervals_service_unavailable_error_response_body import (
        SpeedingIntervalsGetSpeedingIntervalsServiceUnavailableErrorResponseBody,
    )
    from .speeding_intervals_get_speeding_intervals_too_many_requests_error_response_body import (
        SpeedingIntervalsGetSpeedingIntervalsTooManyRequestsErrorResponseBody,
    )
    from .speeding_intervals_get_speeding_intervals_unauthorized_error_response_body import (
        SpeedingIntervalsGetSpeedingIntervalsUnauthorizedErrorResponseBody,
    )
    from .speeding_settings_object_response_body import SpeedingSettingsObjectResponseBody
    from .speeding_settings_object_response_body_unit import SpeedingSettingsObjectResponseBodyUnit
    from .speeding_severity_level_response_body import SpeedingSeverityLevelResponseBody
    from .speeding_severity_level_response_body_severity_level import SpeedingSeverityLevelResponseBodySeverityLevel
    from .start_function_run_response_body_response_body import StartFunctionRunResponseBodyResponseBody
    from .stop_eta_updated_event_details_response_body import StopEtaUpdatedEventDetailsResponseBody
    from .stop_task_completed_event_details_response_body import StopTaskCompletedEventDetailsResponseBody
    from .stop_task_completed_event_details_response_body_task_type import (
        StopTaskCompletedEventDetailsResponseBodyTaskType,
    )
    from .stop_task_skipped_event_details_response_body import StopTaskSkippedEventDetailsResponseBody
    from .stop_task_skipped_event_details_response_body_task_type import StopTaskSkippedEventDetailsResponseBodyTaskType
    from .string_data_point import StringDataPoint
    from .sudden_fuel_level_drop_response_body import SuddenFuelLevelDropResponseBody
    from .sudden_fuel_level_drop_trigger_details_object_request_body import (
        SuddenFuelLevelDropTriggerDetailsObjectRequestBody,
    )
    from .sudden_fuel_level_drop_trigger_details_object_response_body import (
        SuddenFuelLevelDropTriggerDetailsObjectResponseBody,
    )
    from .sudden_fuel_level_rise_response_body import SuddenFuelLevelRiseResponseBody
    from .sudden_fuel_level_rise_trigger_details_object_request_body import (
        SuddenFuelLevelRiseTriggerDetailsObjectRequestBody,
    )
    from .sudden_fuel_level_rise_trigger_details_object_response_body import (
        SuddenFuelLevelRiseTriggerDetailsObjectResponseBody,
    )
    from .tachograph_activity import TachographActivity
    from .tachograph_activity_list import TachographActivityList
    from .tachograph_activity_list_wrapper import TachographActivityListWrapper
    from .tachograph_activity_state import TachographActivityState
    from .tachograph_driver_file import TachographDriverFile
    from .tachograph_driver_file_data import TachographDriverFileData
    from .tachograph_driver_file_list import TachographDriverFileList
    from .tachograph_driver_file_list_wrapper import TachographDriverFileListWrapper
    from .tachograph_driver_files_response import TachographDriverFilesResponse
    from .tachograph_vehicle_file import TachographVehicleFile
    from .tachograph_vehicle_file_data import TachographVehicleFileData
    from .tachograph_vehicle_file_list import TachographVehicleFileList
    from .tachograph_vehicle_file_list_wrapper import TachographVehicleFileListWrapper
    from .tachograph_vehicle_files_response import TachographVehicleFilesResponse
    from .tag import Tag
    from .tag_all_of import TagAllOf
    from .tag_all_of_external_ids import TagAllOfExternalIds
    from .tag_group_safety_score_response_body import TagGroupSafetyScoreResponseBody
    from .tag_id import TagId
    from .tag_ids import TagIds
    from .tag_name import TagName
    from .tag_response import TagResponse
    from .tag_safety_score_response_body import TagSafetyScoreResponseBody
    from .tag_tiny_response import TagTinyResponse
    from .tagged_object import TaggedObject
    from .tagged_object_id import TaggedObjectId
    from .tagged_object_name import TaggedObjectName
    from .tampering_detected_response_body import TamperingDetectedResponseBody
    from .time import Time
    from .time_range_object_request_body import TimeRangeObjectRequestBody
    from .time_range_object_request_body_days_of_week_item import TimeRangeObjectRequestBodyDaysOfWeekItem
    from .time_range_object_response_body import TimeRangeObjectResponseBody
    from .time_range_object_response_body_days_of_week_item import TimeRangeObjectResponseBodyDaysOfWeekItem
    from .tiny_asset_object_request_body import TinyAssetObjectRequestBody
    from .tiny_asset_object_request_body_asset_type import TinyAssetObjectRequestBodyAssetType
    from .tiny_asset_object_response_body import TinyAssetObjectResponseBody
    from .tiny_asset_object_response_body_asset_type import TinyAssetObjectResponseBodyAssetType
    from .tiny_driver_object_request_body import TinyDriverObjectRequestBody
    from .tiny_driver_object_response_body import TinyDriverObjectResponseBody
    from .tiny_tag import TinyTag
    from .tiny_widget_object_request_body import TinyWidgetObjectRequestBody
    from .tiny_widget_object_response_body import TinyWidgetObjectResponseBody
    from .tire_fault_code_details_object_request_body import TireFaultCodeDetailsObjectRequestBody
    from .tire_fault_code_details_object_request_body_manufacturer import (
        TireFaultCodeDetailsObjectRequestBodyManufacturer,
    )
    from .tire_fault_code_details_object_request_body_specific_tire_fault_codes_item import (
        TireFaultCodeDetailsObjectRequestBodySpecificTireFaultCodesItem,
    )
    from .tire_fault_code_details_object_response_body import TireFaultCodeDetailsObjectResponseBody
    from .tire_fault_code_details_object_response_body_manufacturer import (
        TireFaultCodeDetailsObjectResponseBodyManufacturer,
    )
    from .tire_fault_code_details_object_response_body_specific_tire_fault_codes_item import (
        TireFaultCodeDetailsObjectResponseBodySpecificTireFaultCodesItem,
    )
    from .tire_faults_response_body import TireFaultsResponseBody
    from .total_brake_event_count import TotalBrakeEventCount
    from .trailer_assignments_create_driver_trailer_assignment_bad_gateway_error_response_body import (
        TrailerAssignmentsCreateDriverTrailerAssignmentBadGatewayErrorResponseBody,
    )
    from .trailer_assignments_create_driver_trailer_assignment_gateway_timeout_error_response_body import (
        TrailerAssignmentsCreateDriverTrailerAssignmentGatewayTimeoutErrorResponseBody,
    )
    from .trailer_assignments_create_driver_trailer_assignment_internal_server_error_response_body import (
        TrailerAssignmentsCreateDriverTrailerAssignmentInternalServerErrorResponseBody,
    )
    from .trailer_assignments_create_driver_trailer_assignment_method_not_allowed_error_response_body import (
        TrailerAssignmentsCreateDriverTrailerAssignmentMethodNotAllowedErrorResponseBody,
    )
    from .trailer_assignments_create_driver_trailer_assignment_not_found_error_response_body import (
        TrailerAssignmentsCreateDriverTrailerAssignmentNotFoundErrorResponseBody,
    )
    from .trailer_assignments_create_driver_trailer_assignment_not_implemented_error_response_body import (
        TrailerAssignmentsCreateDriverTrailerAssignmentNotImplementedErrorResponseBody,
    )
    from .trailer_assignments_create_driver_trailer_assignment_response_body import (
        TrailerAssignmentsCreateDriverTrailerAssignmentResponseBody,
    )
    from .trailer_assignments_create_driver_trailer_assignment_service_unavailable_error_response_body import (
        TrailerAssignmentsCreateDriverTrailerAssignmentServiceUnavailableErrorResponseBody,
    )
    from .trailer_assignments_create_driver_trailer_assignment_too_many_requests_error_response_body import (
        TrailerAssignmentsCreateDriverTrailerAssignmentTooManyRequestsErrorResponseBody,
    )
    from .trailer_assignments_create_driver_trailer_assignment_unauthorized_error_response_body import (
        TrailerAssignmentsCreateDriverTrailerAssignmentUnauthorizedErrorResponseBody,
    )
    from .trailer_assignments_get_driver_trailer_assignments_bad_gateway_error_response_body import (
        TrailerAssignmentsGetDriverTrailerAssignmentsBadGatewayErrorResponseBody,
    )
    from .trailer_assignments_get_driver_trailer_assignments_gateway_timeout_error_response_body import (
        TrailerAssignmentsGetDriverTrailerAssignmentsGatewayTimeoutErrorResponseBody,
    )
    from .trailer_assignments_get_driver_trailer_assignments_internal_server_error_response_body import (
        TrailerAssignmentsGetDriverTrailerAssignmentsInternalServerErrorResponseBody,
    )
    from .trailer_assignments_get_driver_trailer_assignments_method_not_allowed_error_response_body import (
        TrailerAssignmentsGetDriverTrailerAssignmentsMethodNotAllowedErrorResponseBody,
    )
    from .trailer_assignments_get_driver_trailer_assignments_not_found_error_response_body import (
        TrailerAssignmentsGetDriverTrailerAssignmentsNotFoundErrorResponseBody,
    )
    from .trailer_assignments_get_driver_trailer_assignments_not_implemented_error_response_body import (
        TrailerAssignmentsGetDriverTrailerAssignmentsNotImplementedErrorResponseBody,
    )
    from .trailer_assignments_get_driver_trailer_assignments_response_body import (
        TrailerAssignmentsGetDriverTrailerAssignmentsResponseBody,
    )
    from .trailer_assignments_get_driver_trailer_assignments_service_unavailable_error_response_body import (
        TrailerAssignmentsGetDriverTrailerAssignmentsServiceUnavailableErrorResponseBody,
    )
    from .trailer_assignments_get_driver_trailer_assignments_too_many_requests_error_response_body import (
        TrailerAssignmentsGetDriverTrailerAssignmentsTooManyRequestsErrorResponseBody,
    )
    from .trailer_assignments_get_driver_trailer_assignments_unauthorized_error_response_body import (
        TrailerAssignmentsGetDriverTrailerAssignmentsUnauthorizedErrorResponseBody,
    )
    from .trailer_assignments_update_driver_trailer_assignment_bad_gateway_error_response_body import (
        TrailerAssignmentsUpdateDriverTrailerAssignmentBadGatewayErrorResponseBody,
    )
    from .trailer_assignments_update_driver_trailer_assignment_gateway_timeout_error_response_body import (
        TrailerAssignmentsUpdateDriverTrailerAssignmentGatewayTimeoutErrorResponseBody,
    )
    from .trailer_assignments_update_driver_trailer_assignment_internal_server_error_response_body import (
        TrailerAssignmentsUpdateDriverTrailerAssignmentInternalServerErrorResponseBody,
    )
    from .trailer_assignments_update_driver_trailer_assignment_method_not_allowed_error_response_body import (
        TrailerAssignmentsUpdateDriverTrailerAssignmentMethodNotAllowedErrorResponseBody,
    )
    from .trailer_assignments_update_driver_trailer_assignment_not_found_error_response_body import (
        TrailerAssignmentsUpdateDriverTrailerAssignmentNotFoundErrorResponseBody,
    )
    from .trailer_assignments_update_driver_trailer_assignment_not_implemented_error_response_body import (
        TrailerAssignmentsUpdateDriverTrailerAssignmentNotImplementedErrorResponseBody,
    )
    from .trailer_assignments_update_driver_trailer_assignment_response_body import (
        TrailerAssignmentsUpdateDriverTrailerAssignmentResponseBody,
    )
    from .trailer_assignments_update_driver_trailer_assignment_service_unavailable_error_response_body import (
        TrailerAssignmentsUpdateDriverTrailerAssignmentServiceUnavailableErrorResponseBody,
    )
    from .trailer_assignments_update_driver_trailer_assignment_too_many_requests_error_response_body import (
        TrailerAssignmentsUpdateDriverTrailerAssignmentTooManyRequestsErrorResponseBody,
    )
    from .trailer_assignments_update_driver_trailer_assignment_unauthorized_error_response_body import (
        TrailerAssignmentsUpdateDriverTrailerAssignmentUnauthorizedErrorResponseBody,
    )
    from .trailer_dvir_object_response_body import TrailerDvirObjectResponseBody
    from .trailer_goa_gateway_tiny_response_response_body import TrailerGoaGatewayTinyResponseResponseBody
    from .trailer_goa_gateway_tiny_response_response_body_model import TrailerGoaGatewayTinyResponseResponseBodyModel
    from .trailer_object_response_body import TrailerObjectResponseBody
    from .trailer_response_object_response_body import TrailerResponseObjectResponseBody
    from .trailer_stat_decoration_response_body import TrailerStatDecorationResponseBody
    from .trailer_stat_gps_odometer_meters_type_response_body import TrailerStatGpsOdometerMetersTypeResponseBody
    from .trailer_stat_gps_odometer_meters_with_decorations_type_response_body import (
        TrailerStatGpsOdometerMetersWithDecorationsTypeResponseBody,
    )
    from .trailer_stat_gps_type_response_body import TrailerStatGpsTypeResponseBody
    from .trailer_stat_gps_with_decorations_type_response_body import TrailerStatGpsWithDecorationsTypeResponseBody
    from .trailer_stat_reefer_alarm_response_body import TrailerStatReeferAlarmResponseBody
    from .trailer_stat_reefer_alarm_type_response_body import TrailerStatReeferAlarmTypeResponseBody
    from .trailer_stat_reefer_alarm_with_decorations_type_response_body import (
        TrailerStatReeferAlarmWithDecorationsTypeResponseBody,
    )
    from .trailer_stat_reefer_ambient_air_temperature_milli_c_type_response_body import (
        TrailerStatReeferAmbientAirTemperatureMilliCTypeResponseBody,
    )
    from .trailer_stat_reefer_ambient_air_temperature_with_decorations_type_response_body import (
        TrailerStatReeferAmbientAirTemperatureWithDecorationsTypeResponseBody,
    )
    from .trailer_stat_reefer_door_state_zone_1_type_response_body import (
        TrailerStatReeferDoorStateZone1TypeResponseBody,
    )
    from .trailer_stat_reefer_door_state_zone_1_type_response_body_value import (
        TrailerStatReeferDoorStateZone1TypeResponseBodyValue,
    )
    from .trailer_stat_reefer_door_state_zone_1_with_decorations_type_response_body import (
        TrailerStatReeferDoorStateZone1WithDecorationsTypeResponseBody,
    )
    from .trailer_stat_reefer_door_state_zone_1_with_decorations_type_response_body_value import (
        TrailerStatReeferDoorStateZone1WithDecorationsTypeResponseBodyValue,
    )
    from .trailer_stat_reefer_door_state_zone_2_type_response_body import (
        TrailerStatReeferDoorStateZone2TypeResponseBody,
    )
    from .trailer_stat_reefer_door_state_zone_2_type_response_body_value import (
        TrailerStatReeferDoorStateZone2TypeResponseBodyValue,
    )
    from .trailer_stat_reefer_door_state_zone_2_with_decorations_type_response_body import (
        TrailerStatReeferDoorStateZone2WithDecorationsTypeResponseBody,
    )
    from .trailer_stat_reefer_door_state_zone_2_with_decorations_type_response_body_value import (
        TrailerStatReeferDoorStateZone2WithDecorationsTypeResponseBodyValue,
    )
    from .trailer_stat_reefer_door_state_zone_3_type_response_body import (
        TrailerStatReeferDoorStateZone3TypeResponseBody,
    )
    from .trailer_stat_reefer_door_state_zone_3_type_response_body_value import (
        TrailerStatReeferDoorStateZone3TypeResponseBodyValue,
    )
    from .trailer_stat_reefer_door_state_zone_3_with_decorations_type_response_body import (
        TrailerStatReeferDoorStateZone3WithDecorationsTypeResponseBody,
    )
    from .trailer_stat_reefer_door_state_zone_3_with_decorations_type_response_body_value import (
        TrailerStatReeferDoorStateZone3WithDecorationsTypeResponseBodyValue,
    )
    from .trailer_stat_reefer_fuel_percent_type_response_body import TrailerStatReeferFuelPercentTypeResponseBody
    from .trailer_stat_reefer_fuel_percent_with_decorations_type_response_body import (
        TrailerStatReeferFuelPercentWithDecorationsTypeResponseBody,
    )
    from .trailer_stat_reefer_obd_engine_seconds_type_response_body import (
        TrailerStatReeferObdEngineSecondsTypeResponseBody,
    )
    from .trailer_stat_reefer_obd_engine_seconds_with_decorations_type_response_body import (
        TrailerStatReeferObdEngineSecondsWithDecorationsTypeResponseBody,
    )
    from .trailer_stat_reefer_return_air_temperature_milli_c_zone_1_type_response_body import (
        TrailerStatReeferReturnAirTemperatureMilliCZone1TypeResponseBody,
    )
    from .trailer_stat_reefer_return_air_temperature_milli_c_zone_1_with_decorations_type_response_body import (
        TrailerStatReeferReturnAirTemperatureMilliCZone1WithDecorationsTypeResponseBody,
    )
    from .trailer_stat_reefer_return_air_temperature_milli_c_zone_2_type_response_body import (
        TrailerStatReeferReturnAirTemperatureMilliCZone2TypeResponseBody,
    )
    from .trailer_stat_reefer_return_air_temperature_milli_c_zone_2_with_decorations_type_response_body import (
        TrailerStatReeferReturnAirTemperatureMilliCZone2WithDecorationsTypeResponseBody,
    )
    from .trailer_stat_reefer_return_air_temperature_milli_c_zone_3_type_response_body import (
        TrailerStatReeferReturnAirTemperatureMilliCZone3TypeResponseBody,
    )
    from .trailer_stat_reefer_return_air_temperature_milli_c_zone_3_with_decorations_type_response_body import (
        TrailerStatReeferReturnAirTemperatureMilliCZone3WithDecorationsTypeResponseBody,
    )
    from .trailer_stat_reefer_run_mode_type_response_body import TrailerStatReeferRunModeTypeResponseBody
    from .trailer_stat_reefer_run_mode_with_decorations_type_response_body import (
        TrailerStatReeferRunModeWithDecorationsTypeResponseBody,
    )
    from .trailer_stat_reefer_set_point_temperature_milli_c_zone_1_type_response_body import (
        TrailerStatReeferSetPointTemperatureMilliCZone1TypeResponseBody,
    )
    from .trailer_stat_reefer_set_point_temperature_milli_c_zone_1_with_decorations_type_response_body import (
        TrailerStatReeferSetPointTemperatureMilliCZone1WithDecorationsTypeResponseBody,
    )
    from .trailer_stat_reefer_set_point_temperature_milli_c_zone_2_type_response_body import (
        TrailerStatReeferSetPointTemperatureMilliCZone2TypeResponseBody,
    )
    from .trailer_stat_reefer_set_point_temperature_milli_c_zone_2_with_decorations_type_response_body import (
        TrailerStatReeferSetPointTemperatureMilliCZone2WithDecorationsTypeResponseBody,
    )
    from .trailer_stat_reefer_set_point_temperature_milli_c_zone_3_type_response_body import (
        TrailerStatReeferSetPointTemperatureMilliCZone3TypeResponseBody,
    )
    from .trailer_stat_reefer_set_point_temperature_milli_c_zone_3_with_decorations_type_response_body import (
        TrailerStatReeferSetPointTemperatureMilliCZone3WithDecorationsTypeResponseBody,
    )
    from .trailer_stat_reefer_state_type_response_body import TrailerStatReeferStateTypeResponseBody
    from .trailer_stat_reefer_state_with_decorations_type_response_body import (
        TrailerStatReeferStateWithDecorationsTypeResponseBody,
    )
    from .trailer_stat_reefer_state_zone_1_type_response_body import TrailerStatReeferStateZone1TypeResponseBody
    from .trailer_stat_reefer_state_zone_1_with_decorations_type_response_body import (
        TrailerStatReeferStateZone1WithDecorationsTypeResponseBody,
    )
    from .trailer_stat_reefer_state_zone_2_type_response_body import TrailerStatReeferStateZone2TypeResponseBody
    from .trailer_stat_reefer_state_zone_2_with_decorations_type_response_body import (
        TrailerStatReeferStateZone2WithDecorationsTypeResponseBody,
    )
    from .trailer_stat_reefer_state_zone_3_type_response_body import TrailerStatReeferStateZone3TypeResponseBody
    from .trailer_stat_reefer_state_zone_3_with_decorations_type_response_body import (
        TrailerStatReeferStateZone3WithDecorationsTypeResponseBody,
    )
    from .trailer_stat_reefer_supply_air_temperature_milli_c_zone_1_type_response_body import (
        TrailerStatReeferSupplyAirTemperatureMilliCZone1TypeResponseBody,
    )
    from .trailer_stat_reefer_supply_air_temperature_milli_c_zone_1_with_decorations_type_response_body import (
        TrailerStatReeferSupplyAirTemperatureMilliCZone1WithDecorationsTypeResponseBody,
    )
    from .trailer_stat_reefer_supply_air_temperature_milli_c_zone_2_type_response_body import (
        TrailerStatReeferSupplyAirTemperatureMilliCZone2TypeResponseBody,
    )
    from .trailer_stat_reefer_supply_air_temperature_milli_c_zone_2_with_decorations_type_response_body import (
        TrailerStatReeferSupplyAirTemperatureMilliCZone2WithDecorationsTypeResponseBody,
    )
    from .trailer_stat_reefer_supply_air_temperature_milli_c_zone_3_type_response_body import (
        TrailerStatReeferSupplyAirTemperatureMilliCZone3TypeResponseBody,
    )
    from .trailer_stat_reefer_supply_air_temperature_milli_c_zone_3_with_decorations_type_response_body import (
        TrailerStatReeferSupplyAirTemperatureMilliCZone3WithDecorationsTypeResponseBody,
    )
    from .trailer_stats_get_trailer_stats_feed_bad_gateway_error_response_body import (
        TrailerStatsGetTrailerStatsFeedBadGatewayErrorResponseBody,
    )
    from .trailer_stats_get_trailer_stats_feed_gateway_timeout_error_response_body import (
        TrailerStatsGetTrailerStatsFeedGatewayTimeoutErrorResponseBody,
    )
    from .trailer_stats_get_trailer_stats_feed_internal_server_error_response_body import (
        TrailerStatsGetTrailerStatsFeedInternalServerErrorResponseBody,
    )
    from .trailer_stats_get_trailer_stats_feed_method_not_allowed_error_response_body import (
        TrailerStatsGetTrailerStatsFeedMethodNotAllowedErrorResponseBody,
    )
    from .trailer_stats_get_trailer_stats_feed_not_found_error_response_body import (
        TrailerStatsGetTrailerStatsFeedNotFoundErrorResponseBody,
    )
    from .trailer_stats_get_trailer_stats_feed_not_implemented_error_response_body import (
        TrailerStatsGetTrailerStatsFeedNotImplementedErrorResponseBody,
    )
    from .trailer_stats_get_trailer_stats_feed_response_body import TrailerStatsGetTrailerStatsFeedResponseBody
    from .trailer_stats_get_trailer_stats_feed_service_unavailable_error_response_body import (
        TrailerStatsGetTrailerStatsFeedServiceUnavailableErrorResponseBody,
    )
    from .trailer_stats_get_trailer_stats_feed_too_many_requests_error_response_body import (
        TrailerStatsGetTrailerStatsFeedTooManyRequestsErrorResponseBody,
    )
    from .trailer_stats_get_trailer_stats_feed_unauthorized_error_response_body import (
        TrailerStatsGetTrailerStatsFeedUnauthorizedErrorResponseBody,
    )
    from .trailer_stats_get_trailer_stats_history_bad_gateway_error_response_body import (
        TrailerStatsGetTrailerStatsHistoryBadGatewayErrorResponseBody,
    )
    from .trailer_stats_get_trailer_stats_history_gateway_timeout_error_response_body import (
        TrailerStatsGetTrailerStatsHistoryGatewayTimeoutErrorResponseBody,
    )
    from .trailer_stats_get_trailer_stats_history_internal_server_error_response_body import (
        TrailerStatsGetTrailerStatsHistoryInternalServerErrorResponseBody,
    )
    from .trailer_stats_get_trailer_stats_history_method_not_allowed_error_response_body import (
        TrailerStatsGetTrailerStatsHistoryMethodNotAllowedErrorResponseBody,
    )
    from .trailer_stats_get_trailer_stats_history_not_found_error_response_body import (
        TrailerStatsGetTrailerStatsHistoryNotFoundErrorResponseBody,
    )
    from .trailer_stats_get_trailer_stats_history_not_implemented_error_response_body import (
        TrailerStatsGetTrailerStatsHistoryNotImplementedErrorResponseBody,
    )
    from .trailer_stats_get_trailer_stats_history_response_body import TrailerStatsGetTrailerStatsHistoryResponseBody
    from .trailer_stats_get_trailer_stats_history_service_unavailable_error_response_body import (
        TrailerStatsGetTrailerStatsHistoryServiceUnavailableErrorResponseBody,
    )
    from .trailer_stats_get_trailer_stats_history_too_many_requests_error_response_body import (
        TrailerStatsGetTrailerStatsHistoryTooManyRequestsErrorResponseBody,
    )
    from .trailer_stats_get_trailer_stats_history_unauthorized_error_response_body import (
        TrailerStatsGetTrailerStatsHistoryUnauthorizedErrorResponseBody,
    )
    from .trailer_stats_get_trailer_stats_snapshot_bad_gateway_error_response_body import (
        TrailerStatsGetTrailerStatsSnapshotBadGatewayErrorResponseBody,
    )
    from .trailer_stats_get_trailer_stats_snapshot_gateway_timeout_error_response_body import (
        TrailerStatsGetTrailerStatsSnapshotGatewayTimeoutErrorResponseBody,
    )
    from .trailer_stats_get_trailer_stats_snapshot_internal_server_error_response_body import (
        TrailerStatsGetTrailerStatsSnapshotInternalServerErrorResponseBody,
    )
    from .trailer_stats_get_trailer_stats_snapshot_method_not_allowed_error_response_body import (
        TrailerStatsGetTrailerStatsSnapshotMethodNotAllowedErrorResponseBody,
    )
    from .trailer_stats_get_trailer_stats_snapshot_not_found_error_response_body import (
        TrailerStatsGetTrailerStatsSnapshotNotFoundErrorResponseBody,
    )
    from .trailer_stats_get_trailer_stats_snapshot_not_implemented_error_response_body import (
        TrailerStatsGetTrailerStatsSnapshotNotImplementedErrorResponseBody,
    )
    from .trailer_stats_get_trailer_stats_snapshot_response_body import TrailerStatsGetTrailerStatsSnapshotResponseBody
    from .trailer_stats_get_trailer_stats_snapshot_service_unavailable_error_response_body import (
        TrailerStatsGetTrailerStatsSnapshotServiceUnavailableErrorResponseBody,
    )
    from .trailer_stats_get_trailer_stats_snapshot_too_many_requests_error_response_body import (
        TrailerStatsGetTrailerStatsSnapshotTooManyRequestsErrorResponseBody,
    )
    from .trailer_stats_get_trailer_stats_snapshot_unauthorized_error_response_body import (
        TrailerStatsGetTrailerStatsSnapshotUnauthorizedErrorResponseBody,
    )
    from .trailer_stats_object_response_body import TrailerStatsObjectResponseBody
    from .trailer_stats_snapshot_object_response_body import TrailerStatsSnapshotObjectResponseBody
    from .trailer_tiny_response import TrailerTinyResponse
    from .trailer_with_attributes_response_object_response_body import TrailerWithAttributesResponseObjectResponseBody
    from .trailers_create_trailer_bad_gateway_error_response_body import (
        TrailersCreateTrailerBadGatewayErrorResponseBody,
    )
    from .trailers_create_trailer_gateway_timeout_error_response_body import (
        TrailersCreateTrailerGatewayTimeoutErrorResponseBody,
    )
    from .trailers_create_trailer_internal_server_error_response_body import (
        TrailersCreateTrailerInternalServerErrorResponseBody,
    )
    from .trailers_create_trailer_method_not_allowed_error_response_body import (
        TrailersCreateTrailerMethodNotAllowedErrorResponseBody,
    )
    from .trailers_create_trailer_not_found_error_response_body import TrailersCreateTrailerNotFoundErrorResponseBody
    from .trailers_create_trailer_not_implemented_error_response_body import (
        TrailersCreateTrailerNotImplementedErrorResponseBody,
    )
    from .trailers_create_trailer_response_body import TrailersCreateTrailerResponseBody
    from .trailers_create_trailer_service_unavailable_error_response_body import (
        TrailersCreateTrailerServiceUnavailableErrorResponseBody,
    )
    from .trailers_create_trailer_too_many_requests_error_response_body import (
        TrailersCreateTrailerTooManyRequestsErrorResponseBody,
    )
    from .trailers_create_trailer_unauthorized_error_response_body import (
        TrailersCreateTrailerUnauthorizedErrorResponseBody,
    )
    from .trailers_delete_trailer_bad_gateway_error_response_body import (
        TrailersDeleteTrailerBadGatewayErrorResponseBody,
    )
    from .trailers_delete_trailer_gateway_timeout_error_response_body import (
        TrailersDeleteTrailerGatewayTimeoutErrorResponseBody,
    )
    from .trailers_delete_trailer_internal_server_error_response_body import (
        TrailersDeleteTrailerInternalServerErrorResponseBody,
    )
    from .trailers_delete_trailer_method_not_allowed_error_response_body import (
        TrailersDeleteTrailerMethodNotAllowedErrorResponseBody,
    )
    from .trailers_delete_trailer_not_found_error_response_body import TrailersDeleteTrailerNotFoundErrorResponseBody
    from .trailers_delete_trailer_not_implemented_error_response_body import (
        TrailersDeleteTrailerNotImplementedErrorResponseBody,
    )
    from .trailers_delete_trailer_service_unavailable_error_response_body import (
        TrailersDeleteTrailerServiceUnavailableErrorResponseBody,
    )
    from .trailers_delete_trailer_too_many_requests_error_response_body import (
        TrailersDeleteTrailerTooManyRequestsErrorResponseBody,
    )
    from .trailers_delete_trailer_unauthorized_error_response_body import (
        TrailersDeleteTrailerUnauthorizedErrorResponseBody,
    )
    from .trailers_get_trailer_bad_gateway_error_response_body import TrailersGetTrailerBadGatewayErrorResponseBody
    from .trailers_get_trailer_gateway_timeout_error_response_body import (
        TrailersGetTrailerGatewayTimeoutErrorResponseBody,
    )
    from .trailers_get_trailer_internal_server_error_response_body import (
        TrailersGetTrailerInternalServerErrorResponseBody,
    )
    from .trailers_get_trailer_method_not_allowed_error_response_body import (
        TrailersGetTrailerMethodNotAllowedErrorResponseBody,
    )
    from .trailers_get_trailer_not_found_error_response_body import TrailersGetTrailerNotFoundErrorResponseBody
    from .trailers_get_trailer_not_implemented_error_response_body import (
        TrailersGetTrailerNotImplementedErrorResponseBody,
    )
    from .trailers_get_trailer_response_body import TrailersGetTrailerResponseBody
    from .trailers_get_trailer_service_unavailable_error_response_body import (
        TrailersGetTrailerServiceUnavailableErrorResponseBody,
    )
    from .trailers_get_trailer_too_many_requests_error_response_body import (
        TrailersGetTrailerTooManyRequestsErrorResponseBody,
    )
    from .trailers_get_trailer_unauthorized_error_response_body import TrailersGetTrailerUnauthorizedErrorResponseBody
    from .trailers_list_trailers_bad_gateway_error_response_body import TrailersListTrailersBadGatewayErrorResponseBody
    from .trailers_list_trailers_gateway_timeout_error_response_body import (
        TrailersListTrailersGatewayTimeoutErrorResponseBody,
    )
    from .trailers_list_trailers_internal_server_error_response_body import (
        TrailersListTrailersInternalServerErrorResponseBody,
    )
    from .trailers_list_trailers_method_not_allowed_error_response_body import (
        TrailersListTrailersMethodNotAllowedErrorResponseBody,
    )
    from .trailers_list_trailers_not_found_error_response_body import TrailersListTrailersNotFoundErrorResponseBody
    from .trailers_list_trailers_not_implemented_error_response_body import (
        TrailersListTrailersNotImplementedErrorResponseBody,
    )
    from .trailers_list_trailers_response_body import TrailersListTrailersResponseBody
    from .trailers_list_trailers_service_unavailable_error_response_body import (
        TrailersListTrailersServiceUnavailableErrorResponseBody,
    )
    from .trailers_list_trailers_too_many_requests_error_response_body import (
        TrailersListTrailersTooManyRequestsErrorResponseBody,
    )
    from .trailers_list_trailers_unauthorized_error_response_body import (
        TrailersListTrailersUnauthorizedErrorResponseBody,
    )
    from .trailers_update_trailer_bad_gateway_error_response_body import (
        TrailersUpdateTrailerBadGatewayErrorResponseBody,
    )
    from .trailers_update_trailer_gateway_timeout_error_response_body import (
        TrailersUpdateTrailerGatewayTimeoutErrorResponseBody,
    )
    from .trailers_update_trailer_internal_server_error_response_body import (
        TrailersUpdateTrailerInternalServerErrorResponseBody,
    )
    from .trailers_update_trailer_method_not_allowed_error_response_body import (
        TrailersUpdateTrailerMethodNotAllowedErrorResponseBody,
    )
    from .trailers_update_trailer_not_found_error_response_body import TrailersUpdateTrailerNotFoundErrorResponseBody
    from .trailers_update_trailer_not_implemented_error_response_body import (
        TrailersUpdateTrailerNotImplementedErrorResponseBody,
    )
    from .trailers_update_trailer_response_body import TrailersUpdateTrailerResponseBody
    from .trailers_update_trailer_service_unavailable_error_response_body import (
        TrailersUpdateTrailerServiceUnavailableErrorResponseBody,
    )
    from .trailers_update_trailer_too_many_requests_error_response_body import (
        TrailersUpdateTrailerTooManyRequestsErrorResponseBody,
    )
    from .trailers_update_trailer_unauthorized_error_response_body import (
        TrailersUpdateTrailerUnauthorizedErrorResponseBody,
    )
    from .training_assignment_near_due_date_trigger_assignment_group_object_request_body import (
        TrainingAssignmentNearDueDateTriggerAssignmentGroupObjectRequestBody,
    )
    from .training_assignment_near_due_date_trigger_assignment_group_object_request_body_assignment_group_type import (
        TrainingAssignmentNearDueDateTriggerAssignmentGroupObjectRequestBodyAssignmentGroupType,
    )
    from .training_assignment_near_due_date_trigger_assignment_group_object_response_body import (
        TrainingAssignmentNearDueDateTriggerAssignmentGroupObjectResponseBody,
    )
    from .training_assignment_near_due_date_trigger_assignment_group_object_response_body_assignment_group_type import (
        TrainingAssignmentNearDueDateTriggerAssignmentGroupObjectResponseBodyAssignmentGroupType,
    )
    from .training_assignment_near_due_date_trigger_details_object_request_body import (
        TrainingAssignmentNearDueDateTriggerDetailsObjectRequestBody,
    )
    from .training_assignment_near_due_date_trigger_details_object_request_body_condition_units import (
        TrainingAssignmentNearDueDateTriggerDetailsObjectRequestBodyConditionUnits,
    )
    from .training_assignment_near_due_date_trigger_details_object_response_body import (
        TrainingAssignmentNearDueDateTriggerDetailsObjectResponseBody,
    )
    from .training_assignment_near_due_date_trigger_details_object_response_body_condition_units import (
        TrainingAssignmentNearDueDateTriggerDetailsObjectResponseBodyConditionUnits,
    )
    from .training_assignment_post_response_object_response_body import TrainingAssignmentPostResponseObjectResponseBody
    from .training_assignment_response_object_response_body import TrainingAssignmentResponseObjectResponseBody
    from .training_assignment_response_object_response_body_status import (
        TrainingAssignmentResponseObjectResponseBodyStatus,
    )
    from .training_assignments_delete_training_assignments_bad_gateway_error_response_body import (
        TrainingAssignmentsDeleteTrainingAssignmentsBadGatewayErrorResponseBody,
    )
    from .training_assignments_delete_training_assignments_gateway_timeout_error_response_body import (
        TrainingAssignmentsDeleteTrainingAssignmentsGatewayTimeoutErrorResponseBody,
    )
    from .training_assignments_delete_training_assignments_internal_server_error_response_body import (
        TrainingAssignmentsDeleteTrainingAssignmentsInternalServerErrorResponseBody,
    )
    from .training_assignments_delete_training_assignments_method_not_allowed_error_response_body import (
        TrainingAssignmentsDeleteTrainingAssignmentsMethodNotAllowedErrorResponseBody,
    )
    from .training_assignments_delete_training_assignments_not_found_error_response_body import (
        TrainingAssignmentsDeleteTrainingAssignmentsNotFoundErrorResponseBody,
    )
    from .training_assignments_delete_training_assignments_not_implemented_error_response_body import (
        TrainingAssignmentsDeleteTrainingAssignmentsNotImplementedErrorResponseBody,
    )
    from .training_assignments_delete_training_assignments_service_unavailable_error_response_body import (
        TrainingAssignmentsDeleteTrainingAssignmentsServiceUnavailableErrorResponseBody,
    )
    from .training_assignments_delete_training_assignments_too_many_requests_error_response_body import (
        TrainingAssignmentsDeleteTrainingAssignmentsTooManyRequestsErrorResponseBody,
    )
    from .training_assignments_delete_training_assignments_unauthorized_error_response_body import (
        TrainingAssignmentsDeleteTrainingAssignmentsUnauthorizedErrorResponseBody,
    )
    from .training_assignments_get_training_assignments_stream_bad_gateway_error_response_body import (
        TrainingAssignmentsGetTrainingAssignmentsStreamBadGatewayErrorResponseBody,
    )
    from .training_assignments_get_training_assignments_stream_gateway_timeout_error_response_body import (
        TrainingAssignmentsGetTrainingAssignmentsStreamGatewayTimeoutErrorResponseBody,
    )
    from .training_assignments_get_training_assignments_stream_internal_server_error_response_body import (
        TrainingAssignmentsGetTrainingAssignmentsStreamInternalServerErrorResponseBody,
    )
    from .training_assignments_get_training_assignments_stream_method_not_allowed_error_response_body import (
        TrainingAssignmentsGetTrainingAssignmentsStreamMethodNotAllowedErrorResponseBody,
    )
    from .training_assignments_get_training_assignments_stream_not_found_error_response_body import (
        TrainingAssignmentsGetTrainingAssignmentsStreamNotFoundErrorResponseBody,
    )
    from .training_assignments_get_training_assignments_stream_not_implemented_error_response_body import (
        TrainingAssignmentsGetTrainingAssignmentsStreamNotImplementedErrorResponseBody,
    )
    from .training_assignments_get_training_assignments_stream_response_body import (
        TrainingAssignmentsGetTrainingAssignmentsStreamResponseBody,
    )
    from .training_assignments_get_training_assignments_stream_service_unavailable_error_response_body import (
        TrainingAssignmentsGetTrainingAssignmentsStreamServiceUnavailableErrorResponseBody,
    )
    from .training_assignments_get_training_assignments_stream_too_many_requests_error_response_body import (
        TrainingAssignmentsGetTrainingAssignmentsStreamTooManyRequestsErrorResponseBody,
    )
    from .training_assignments_get_training_assignments_stream_unauthorized_error_response_body import (
        TrainingAssignmentsGetTrainingAssignmentsStreamUnauthorizedErrorResponseBody,
    )
    from .training_assignments_patch_training_assignments_bad_gateway_error_response_body import (
        TrainingAssignmentsPatchTrainingAssignmentsBadGatewayErrorResponseBody,
    )
    from .training_assignments_patch_training_assignments_gateway_timeout_error_response_body import (
        TrainingAssignmentsPatchTrainingAssignmentsGatewayTimeoutErrorResponseBody,
    )
    from .training_assignments_patch_training_assignments_internal_server_error_response_body import (
        TrainingAssignmentsPatchTrainingAssignmentsInternalServerErrorResponseBody,
    )
    from .training_assignments_patch_training_assignments_method_not_allowed_error_response_body import (
        TrainingAssignmentsPatchTrainingAssignmentsMethodNotAllowedErrorResponseBody,
    )
    from .training_assignments_patch_training_assignments_not_found_error_response_body import (
        TrainingAssignmentsPatchTrainingAssignmentsNotFoundErrorResponseBody,
    )
    from .training_assignments_patch_training_assignments_not_implemented_error_response_body import (
        TrainingAssignmentsPatchTrainingAssignmentsNotImplementedErrorResponseBody,
    )
    from .training_assignments_patch_training_assignments_response_body import (
        TrainingAssignmentsPatchTrainingAssignmentsResponseBody,
    )
    from .training_assignments_patch_training_assignments_service_unavailable_error_response_body import (
        TrainingAssignmentsPatchTrainingAssignmentsServiceUnavailableErrorResponseBody,
    )
    from .training_assignments_patch_training_assignments_too_many_requests_error_response_body import (
        TrainingAssignmentsPatchTrainingAssignmentsTooManyRequestsErrorResponseBody,
    )
    from .training_assignments_patch_training_assignments_unauthorized_error_response_body import (
        TrainingAssignmentsPatchTrainingAssignmentsUnauthorizedErrorResponseBody,
    )
    from .training_assignments_post_training_assignments_bad_gateway_error_response_body import (
        TrainingAssignmentsPostTrainingAssignmentsBadGatewayErrorResponseBody,
    )
    from .training_assignments_post_training_assignments_gateway_timeout_error_response_body import (
        TrainingAssignmentsPostTrainingAssignmentsGatewayTimeoutErrorResponseBody,
    )
    from .training_assignments_post_training_assignments_internal_server_error_response_body import (
        TrainingAssignmentsPostTrainingAssignmentsInternalServerErrorResponseBody,
    )
    from .training_assignments_post_training_assignments_method_not_allowed_error_response_body import (
        TrainingAssignmentsPostTrainingAssignmentsMethodNotAllowedErrorResponseBody,
    )
    from .training_assignments_post_training_assignments_not_found_error_response_body import (
        TrainingAssignmentsPostTrainingAssignmentsNotFoundErrorResponseBody,
    )
    from .training_assignments_post_training_assignments_not_implemented_error_response_body import (
        TrainingAssignmentsPostTrainingAssignmentsNotImplementedErrorResponseBody,
    )
    from .training_assignments_post_training_assignments_response_body import (
        TrainingAssignmentsPostTrainingAssignmentsResponseBody,
    )
    from .training_assignments_post_training_assignments_service_unavailable_error_response_body import (
        TrainingAssignmentsPostTrainingAssignmentsServiceUnavailableErrorResponseBody,
    )
    from .training_assignments_post_training_assignments_too_many_requests_error_response_body import (
        TrainingAssignmentsPostTrainingAssignmentsTooManyRequestsErrorResponseBody,
    )
    from .training_assignments_post_training_assignments_unauthorized_error_response_body import (
        TrainingAssignmentsPostTrainingAssignmentsUnauthorizedErrorResponseBody,
    )
    from .training_category_object_response_body import TrainingCategoryObjectResponseBody
    from .training_course_label_object_response_body import TrainingCourseLabelObjectResponseBody
    from .training_course_object_response_body import TrainingCourseObjectResponseBody
    from .training_course_response_object_response_body import TrainingCourseResponseObjectResponseBody
    from .training_course_response_object_response_body_status import TrainingCourseResponseObjectResponseBodyStatus
    from .training_courses_get_training_courses_bad_gateway_error_response_body import (
        TrainingCoursesGetTrainingCoursesBadGatewayErrorResponseBody,
    )
    from .training_courses_get_training_courses_gateway_timeout_error_response_body import (
        TrainingCoursesGetTrainingCoursesGatewayTimeoutErrorResponseBody,
    )
    from .training_courses_get_training_courses_internal_server_error_response_body import (
        TrainingCoursesGetTrainingCoursesInternalServerErrorResponseBody,
    )
    from .training_courses_get_training_courses_method_not_allowed_error_response_body import (
        TrainingCoursesGetTrainingCoursesMethodNotAllowedErrorResponseBody,
    )
    from .training_courses_get_training_courses_not_found_error_response_body import (
        TrainingCoursesGetTrainingCoursesNotFoundErrorResponseBody,
    )
    from .training_courses_get_training_courses_not_implemented_error_response_body import (
        TrainingCoursesGetTrainingCoursesNotImplementedErrorResponseBody,
    )
    from .training_courses_get_training_courses_response_body import TrainingCoursesGetTrainingCoursesResponseBody
    from .training_courses_get_training_courses_service_unavailable_error_response_body import (
        TrainingCoursesGetTrainingCoursesServiceUnavailableErrorResponseBody,
    )
    from .training_courses_get_training_courses_too_many_requests_error_response_body import (
        TrainingCoursesGetTrainingCoursesTooManyRequestsErrorResponseBody,
    )
    from .training_courses_get_training_courses_unauthorized_error_response_body import (
        TrainingCoursesGetTrainingCoursesUnauthorizedErrorResponseBody,
    )
    from .training_learner_object_response_body import TrainingLearnerObjectResponseBody
    from .training_learner_object_response_body_type import TrainingLearnerObjectResponseBodyType
    from .trigger_params_object_request_body import TriggerParamsObjectRequestBody
    from .trigger_params_object_response_body import TriggerParamsObjectResponseBody
    from .trip_asset_response_body import TripAssetResponseBody
    from .trip_asset_response_body_type import TripAssetResponseBodyType
    from .trip_response_body import TripResponseBody
    from .trip_response_body_completion_status import TripResponseBodyCompletionStatus
    from .trip_speeding_intervals_response_body import TripSpeedingIntervalsResponseBody
    from .trips_breakdown_response_body import TripsBreakdownResponseBody
    from .trips_get_trips_bad_gateway_error_response_body import TripsGetTripsBadGatewayErrorResponseBody
    from .trips_get_trips_gateway_timeout_error_response_body import TripsGetTripsGatewayTimeoutErrorResponseBody
    from .trips_get_trips_internal_server_error_response_body import TripsGetTripsInternalServerErrorResponseBody
    from .trips_get_trips_method_not_allowed_error_response_body import TripsGetTripsMethodNotAllowedErrorResponseBody
    from .trips_get_trips_not_found_error_response_body import TripsGetTripsNotFoundErrorResponseBody
    from .trips_get_trips_not_implemented_error_response_body import TripsGetTripsNotImplementedErrorResponseBody
    from .trips_get_trips_response_body import TripsGetTripsResponseBody
    from .trips_get_trips_service_unavailable_error_response_body import (
        TripsGetTripsServiceUnavailableErrorResponseBody,
    )
    from .trips_get_trips_too_many_requests_error_response_body import TripsGetTripsTooManyRequestsErrorResponseBody
    from .trips_get_trips_unauthorized_error_response_body import TripsGetTripsUnauthorizedErrorResponseBody
    from .unassigned_driving_data_response_body import UnassignedDrivingDataResponseBody
    from .unassigned_driving_trigger_details_object_request_body import UnassignedDrivingTriggerDetailsObjectRequestBody
    from .unassigned_driving_trigger_details_object_response_body import (
        UnassignedDrivingTriggerDetailsObjectResponseBody,
    )
    from .update_address_request_geofence import UpdateAddressRequestGeofence
    from .update_driver_request_attributes import UpdateDriverRequestAttributes
    from .update_driver_request_hos_setting import UpdateDriverRequestHosSetting
    from .update_engine_immobilizer_relay_state_request_body_request_body import (
        UpdateEngineImmobilizerRelayStateRequestBodyRequestBody,
    )
    from .update_engine_immobilizer_relay_state_request_body_request_body_id import (
        UpdateEngineImmobilizerRelayStateRequestBodyRequestBodyId,
    )
    from .update_hub_location_request_body_request_body import UpdateHubLocationRequestBodyRequestBody
    from .update_routes_stop_request_object_request_body import UpdateRoutesStopRequestObjectRequestBody
    from .uploaded_media_object_response_body import UploadedMediaObjectResponseBody
    from .uploaded_media_object_response_body_camera_role import UploadedMediaObjectResponseBodyCameraRole
    from .uploaded_media_object_response_body_input import UploadedMediaObjectResponseBodyInput
    from .uploaded_media_object_response_body_media_type import UploadedMediaObjectResponseBodyMediaType
    from .uploaded_media_object_response_body_trigger_reason import UploadedMediaObjectResponseBodyTriggerReason
    from .url_info_object_response_body import UrlInfoObjectResponseBody
    from .us_driver_ruleset_override import UsDriverRulesetOverride
    from .us_driver_ruleset_override_cycle import UsDriverRulesetOverrideCycle
    from .us_driver_ruleset_override_restart import UsDriverRulesetOverrideRestart
    from .us_driver_ruleset_override_restbreak import UsDriverRulesetOverrideRestbreak
    from .us_driver_ruleset_override_us_state_to_override import UsDriverRulesetOverrideUsStateToOverride
    from .user import User
    from .user_auth_type import UserAuthType
    from .user_email import UserEmail
    from .user_expire_at import UserExpireAt
    from .user_id import UserId
    from .user_identifier_serial import UserIdentifierSerial
    from .user_name import UserName
    from .user_response import UserResponse
    from .user_role import UserRole
    from .user_role_assignment import UserRoleAssignment
    from .user_roles import UserRoles
    from .user_tiny_response import UserTinyResponse
    from .v_1_asset import V1Asset
    from .v_1_asset_cable import V1AssetCable
    from .v_1_asset_current_location import V1AssetCurrentLocation
    from .v_1_asset_current_locations_response import V1AssetCurrentLocationsResponse
    from .v_1_asset_location_response import V1AssetLocationResponse
    from .v_1_asset_location_response_item import V1AssetLocationResponseItem
    from .v_1_asset_reefer_response import V1AssetReeferResponse
    from .v_1_asset_reefer_response_reefer_stats import V1AssetReeferResponseReeferStats
    from .v_1_asset_reefer_response_reefer_stats_alarms import V1AssetReeferResponseReeferStatsAlarms
    from .v_1_asset_reefer_response_reefer_stats_alarms_1 import V1AssetReeferResponseReeferStatsAlarms1
    from .v_1_asset_reefer_response_reefer_stats_engine_hours import V1AssetReeferResponseReeferStatsEngineHours
    from .v_1_asset_reefer_response_reefer_stats_fuel_percentage import V1AssetReeferResponseReeferStatsFuelPercentage
    from .v_1_asset_reefer_response_reefer_stats_power_status import V1AssetReeferResponseReeferStatsPowerStatus
    from .v_1_asset_reefer_response_reefer_stats_return_air_temp import V1AssetReeferResponseReeferStatsReturnAirTemp
    from .v_1_asset_reefer_response_reefer_stats_set_point import V1AssetReeferResponseReeferStatsSetPoint
    from .v_1_assets_reefer import V1AssetsReefer
    from .v_1_assets_reefer_reefer_stats import V1AssetsReeferReeferStats
    from .v_1_assets_reefer_reefer_stats_ambient_air_temperature import V1AssetsReeferReeferStatsAmbientAirTemperature
    from .v_1_assets_reefer_reefer_stats_discharge_air_temperature import (
        V1AssetsReeferReeferStatsDischargeAirTemperature,
    )
    from .v_1_assets_reefer_reefer_stats_power_status import V1AssetsReeferReeferStatsPowerStatus
    from .v_1_assets_reefer_reefer_stats_power_status_status import V1AssetsReeferReeferStatsPowerStatusStatus
    from .v_1_cargo_response import V1CargoResponse
    from .v_1_cargo_response_sensors import V1CargoResponseSensors
    from .v_1_door_response import V1DoorResponse
    from .v_1_door_response_sensors import V1DoorResponseSensors
    from .v_1_driver_safety_score_response import V1DriverSafetyScoreResponse
    from .v_1_hos_authentication_logs_response import V1HosAuthenticationLogsResponse
    from .v_1_hos_authentication_logs_response_authentication_logs import (
        V1HosAuthenticationLogsResponseAuthenticationLogs,
    )
    from .v_1_humidity_response import V1HumidityResponse
    from .v_1_humidity_response_sensors import V1HumidityResponseSensors
    from .v_1_machine import V1Machine
    from .v_1_machine_history_response import V1MachineHistoryResponse
    from .v_1_machine_history_response_machines import V1MachineHistoryResponseMachines
    from .v_1_machine_history_response_vibrations import V1MachineHistoryResponseVibrations
    from .v_1_message import V1Message
    from .v_1_message_response import V1MessageResponse
    from .v_1_message_sender import V1MessageSender
    from .v_1_messages import V1Messages
    from .v_1_messages_response import V1MessagesResponse
    from .v_1_pagination import V1Pagination
    from .v_1_programs_for_the_camera_response import V1ProgramsForTheCameraResponse
    from .v_1_programs_for_the_camera_response_item import V1ProgramsForTheCameraResponseItem
    from .v_1_safety_report_harsh_event import V1SafetyReportHarshEvent
    from .v_1_sensor import V1Sensor
    from .v_1_sensor_history_response import V1SensorHistoryResponse
    from .v_1_sensor_history_response_results import V1SensorHistoryResponseResults
    from .v_1_sensors_history_series import V1SensorsHistorySeries
    from .v_1_sensors_history_series_field import V1SensorsHistorySeriesField
    from .v_1_temperature_response import V1TemperatureResponse
    from .v_1_temperature_response_sensors import V1TemperatureResponseSensors
    from .v_1_trailer_assignment_response import V1TrailerAssignmentResponse
    from .v_1_trailer_assignments_response import V1TrailerAssignmentsResponse
    from .v_1_trailer_assignments_response_all_of import V1TrailerAssignmentsResponseAllOf
    from .v_1_trailer_base import V1TrailerBase
    from .v_1_trip_response import V1TripResponse
    from .v_1_trip_response_end_address import V1TripResponseEndAddress
    from .v_1_trip_response_end_coordinates import V1TripResponseEndCoordinates
    from .v_1_trip_response_start_address import V1TripResponseStartAddress
    from .v_1_trip_response_start_coordinates import V1TripResponseStartCoordinates
    from .v_1_trip_response_trips import V1TripResponseTrips
    from .v_1_vehicle_harsh_event_response import V1VehicleHarshEventResponse
    from .v_1_vehicle_harsh_event_response_location import V1VehicleHarshEventResponseLocation
    from .v_1_vehicle_maintenance import V1VehicleMaintenance
    from .v_1_vehicle_maintenance_j_1939 import V1VehicleMaintenanceJ1939
    from .v_1_vehicle_maintenance_j_1939_check_engine_light import V1VehicleMaintenanceJ1939CheckEngineLight
    from .v_1_vehicle_maintenance_j_1939_diagnostic_trouble_codes import V1VehicleMaintenanceJ1939DiagnosticTroubleCodes
    from .v_1_vehicle_maintenance_passenger import V1VehicleMaintenancePassenger
    from .v_1_vehicle_maintenance_passenger_check_engine_light import V1VehicleMaintenancePassengerCheckEngineLight
    from .v_1_vehicle_maintenance_passenger_diagnostic_trouble_codes import (
        V1VehicleMaintenancePassengerDiagnosticTroubleCodes,
    )
    from .v_1_vehicle_safety_score_response import V1VehicleSafetyScoreResponse
    from .v_1_vision_cameras_response import V1VisionCamerasResponse
    from .v_1_vision_cameras_response_item import V1VisionCamerasResponseItem
    from .v_1_vision_run_by_camera_response import V1VisionRunByCameraResponse
    from .v_1_vision_run_by_camera_response_inspection_results import V1VisionRunByCameraResponseInspectionResults
    from .v_1_vision_run_by_camera_response_program import V1VisionRunByCameraResponseProgram
    from .v_1_vision_run_by_camera_response_run_summary import V1VisionRunByCameraResponseRunSummary
    from .v_1_vision_runs_by_camera_and_program_response import V1VisionRunsByCameraAndProgramResponse
    from .v_1_vision_runs_by_camera_response import V1VisionRunsByCameraResponse
    from .v_1_vision_runs_by_camera_response_item import V1VisionRunsByCameraResponseItem
    from .v_1_vision_runs_by_camera_response_item_program import V1VisionRunsByCameraResponseItemProgram
    from .v_1_vision_runs_by_camera_response_item_report_metadata import V1VisionRunsByCameraResponseItemReportMetadata
    from .v_1_vision_runs_response import V1VisionRunsResponse
    from .v_1_vision_runs_response_report_metadata import V1VisionRunsResponseReportMetadata
    from .v_1_vision_runs_response_vision_runs import V1VisionRunsResponseVisionRuns
    from .v_1_vision_step_results import V1VisionStepResults
    from .v_1_vision_step_results_item import V1VisionStepResultsItem
    from .v_1_vision_step_results_item_angle_check import V1VisionStepResultsItemAngleCheck
    from .v_1_vision_step_results_item_angle_check_angle_configured import (
        V1VisionStepResultsItemAngleCheckAngleConfigured,
    )
    from .v_1_vision_step_results_item_barcode_item import V1VisionStepResultsItemBarcodeItem
    from .v_1_vision_step_results_item_boolean_logic import V1VisionStepResultsItemBooleanLogic
    from .v_1_vision_step_results_item_boolean_logic_steps_item import V1VisionStepResultsItemBooleanLogicStepsItem
    from .v_1_vision_step_results_item_caliper import V1VisionStepResultsItemCaliper
    from .v_1_vision_step_results_item_caliper_angle_range import V1VisionStepResultsItemCaliperAngleRange
    from .v_1_vision_step_results_item_caliper_contrast_range import V1VisionStepResultsItemCaliperContrastRange
    from .v_1_vision_step_results_item_caliper_filter_polarity import V1VisionStepResultsItemCaliperFilterPolarity
    from .v_1_vision_step_results_item_caliper_sharpness_range import V1VisionStepResultsItemCaliperSharpnessRange
    from .v_1_vision_step_results_item_caliper_straightness_range import V1VisionStepResultsItemCaliperStraightnessRange
    from .v_1_vision_step_results_item_contour import V1VisionStepResultsItemContour
    from .v_1_vision_step_results_item_distance import V1VisionStepResultsItemDistance
    from .v_1_vision_step_results_item_expiration_date import V1VisionStepResultsItemExpirationDate
    from .v_1_vision_step_results_item_find_copies import V1VisionStepResultsItemFindCopies
    from .v_1_vision_step_results_item_find_edge import V1VisionStepResultsItemFindEdge
    from .v_1_vision_step_results_item_find_edge_angle_range import V1VisionStepResultsItemFindEdgeAngleRange
    from .v_1_vision_step_results_item_find_edge_contrast_range import V1VisionStepResultsItemFindEdgeContrastRange
    from .v_1_vision_step_results_item_find_edge_sharpness_range import V1VisionStepResultsItemFindEdgeSharpnessRange
    from .v_1_vision_step_results_item_find_edge_straightness_range import (
        V1VisionStepResultsItemFindEdgeStraightnessRange,
    )
    from .v_1_vision_step_results_item_find_shapes import V1VisionStepResultsItemFindShapes
    from .v_1_vision_step_results_item_fixture import V1VisionStepResultsItemFixture
    from .v_1_vision_step_results_item_fixture_coordinates import V1VisionStepResultsItemFixtureCoordinates
    from .v_1_vision_step_results_item_label_match import V1VisionStepResultsItemLabelMatch
    from .v_1_vision_step_results_item_presence_absence import V1VisionStepResultsItemPresenceAbsence
    from .v_1_vision_step_results_item_presence_absence_blue_range import (
        V1VisionStepResultsItemPresenceAbsenceBlueRange,
    )
    from .v_1_vision_step_results_item_presence_absence_grayscale_range import (
        V1VisionStepResultsItemPresenceAbsenceGrayscaleRange,
    )
    from .v_1_vision_step_results_item_presence_absence_green_range import (
        V1VisionStepResultsItemPresenceAbsenceGreenRange,
    )
    from .v_1_vision_step_results_item_presence_absence_hue_range import V1VisionStepResultsItemPresenceAbsenceHueRange
    from .v_1_vision_step_results_item_presence_absence_red_range import V1VisionStepResultsItemPresenceAbsenceRedRange
    from .v_1_vision_step_results_item_presence_absence_saturation_range import (
        V1VisionStepResultsItemPresenceAbsenceSaturationRange,
    )
    from .v_1_vision_step_results_item_presence_absence_value_range import (
        V1VisionStepResultsItemPresenceAbsenceValueRange,
    )
    from .v_1_vision_step_results_item_text_match import V1VisionStepResultsItemTextMatch
    from .vehicle import Vehicle
    from .vehicle_assignment_object_response_body import VehicleAssignmentObjectResponseBody
    from .vehicle_assignment_object_response_body_assignment_type import (
        VehicleAssignmentObjectResponseBodyAssignmentType,
    )
    from .vehicle_aux_input_name import VehicleAuxInputName
    from .vehicle_aux_input_type import VehicleAuxInputType
    from .vehicle_batter_voltage_details_object_request_body import VehicleBatterVoltageDetailsObjectRequestBody
    from .vehicle_batter_voltage_details_object_request_body_operation import (
        VehicleBatterVoltageDetailsObjectRequestBodyOperation,
    )
    from .vehicle_batter_voltage_details_object_response_body import VehicleBatterVoltageDetailsObjectResponseBody
    from .vehicle_batter_voltage_details_object_response_body_operation import (
        VehicleBatterVoltageDetailsObjectResponseBodyOperation,
    )
    from .vehicle_battery_voltage_response_body import VehicleBatteryVoltageResponseBody
    from .vehicle_def_level_percentage_response_body import VehicleDefLevelPercentageResponseBody
    from .vehicle_detected_response_body import VehicleDetectedResponseBody
    from .vehicle_dvir_object_response_body import VehicleDvirObjectResponseBody
    from .vehicle_esn import VehicleEsn
    from .vehicle_external_ids import VehicleExternalIds
    from .vehicle_fault_code_details_object_request_body import VehicleFaultCodeDetailsObjectRequestBody
    from .vehicle_fault_code_details_object_response_body import VehicleFaultCodeDetailsObjectResponseBody
    from .vehicle_faults_response_body import VehicleFaultsResponseBody
    from .vehicle_harsh_acceleration_setting_type import VehicleHarshAccelerationSettingType
    from .vehicle_id import VehicleId
    from .vehicle_license_plate import VehicleLicensePlate
    from .vehicle_location import VehicleLocation
    from .vehicle_location_address import VehicleLocationAddress
    from .vehicle_location_heading import VehicleLocationHeading
    from .vehicle_location_is_ecu_speed import VehicleLocationIsEcuSpeed
    from .vehicle_location_latitude import VehicleLocationLatitude
    from .vehicle_location_longitude import VehicleLocationLongitude
    from .vehicle_location_speed import VehicleLocationSpeed
    from .vehicle_locations_list_response import VehicleLocationsListResponse
    from .vehicle_locations_list_response_data import VehicleLocationsListResponseData
    from .vehicle_locations_response import VehicleLocationsResponse
    from .vehicle_locations_response_data import VehicleLocationsResponseData
    from .vehicle_make import VehicleMake
    from .vehicle_model import VehicleModel
    from .vehicle_name import VehicleName
    from .vehicle_notes import VehicleNotes
    from .vehicle_regulation_mode import VehicleRegulationMode
    from .vehicle_response import VehicleResponse
    from .vehicle_response_object_response_body import VehicleResponseObjectResponseBody
    from .vehicle_response_object_response_body_vehicle_regulation_mode import (
        VehicleResponseObjectResponseBodyVehicleRegulationMode,
    )
    from .vehicle_response_object_response_body_vehicle_type import VehicleResponseObjectResponseBodyVehicleType
    from .vehicle_response_response_body import VehicleResponseResponseBody
    from .vehicle_response_response_body_asset_type import VehicleResponseResponseBodyAssetType
    from .vehicle_safety_score_response_body import VehicleSafetyScoreResponseBody
    from .vehicle_sensor_configuration import VehicleSensorConfiguration
    from .vehicle_sensor_configuration_area import VehicleSensorConfigurationArea
    from .vehicle_sensor_configuration_area_position import VehicleSensorConfigurationAreaPosition
    from .vehicle_sensor_configuration_area_response_body import VehicleSensorConfigurationAreaResponseBody
    from .vehicle_sensor_configuration_area_response_body_position import (
        VehicleSensorConfigurationAreaResponseBodyPosition,
    )
    from .vehicle_sensor_configuration_door import VehicleSensorConfigurationDoor
    from .vehicle_sensor_configuration_door_position import VehicleSensorConfigurationDoorPosition
    from .vehicle_sensor_configuration_door_response_body import VehicleSensorConfigurationDoorResponseBody
    from .vehicle_sensor_configuration_door_response_body_position import (
        VehicleSensorConfigurationDoorResponseBodyPosition,
    )
    from .vehicle_sensor_configuration_response_body import VehicleSensorConfigurationResponseBody
    from .vehicle_stats_ambient_air_temp_milli_c import VehicleStatsAmbientAirTempMilliC
    from .vehicle_stats_ambient_air_temp_milli_c_value import VehicleStatsAmbientAirTempMilliCValue
    from .vehicle_stats_ambient_air_temp_milli_c_with_decoration import VehicleStatsAmbientAirTempMilliCWithDecoration
    from .vehicle_stats_aux_input import VehicleStatsAuxInput
    from .vehicle_stats_aux_input_decoration import VehicleStatsAuxInputDecoration
    from .vehicle_stats_aux_input_time import VehicleStatsAuxInputTime
    from .vehicle_stats_aux_input_value import VehicleStatsAuxInputValue
    from .vehicle_stats_aux_input_with_decoration import VehicleStatsAuxInputWithDecoration
    from .vehicle_stats_barometric_pressure_pa import VehicleStatsBarometricPressurePa
    from .vehicle_stats_barometric_pressure_pa_value import VehicleStatsBarometricPressurePaValue
    from .vehicle_stats_barometric_pressure_pa_with_decoration import VehicleStatsBarometricPressurePaWithDecoration
    from .vehicle_stats_battery_milli_volts_value import VehicleStatsBatteryMilliVoltsValue
    from .vehicle_stats_battery_voltage import VehicleStatsBatteryVoltage
    from .vehicle_stats_battery_voltage_with_decoration import VehicleStatsBatteryVoltageWithDecoration
    from .vehicle_stats_decorations import VehicleStatsDecorations
    from .vehicle_stats_decorations_ambient_air_temperature_milli_c import (
        VehicleStatsDecorationsAmbientAirTemperatureMilliC,
    )
    from .vehicle_stats_decorations_barometric_pressure_pa import VehicleStatsDecorationsBarometricPressurePa
    from .vehicle_stats_decorations_battery_milli_volts import VehicleStatsDecorationsBatteryMilliVolts
    from .vehicle_stats_decorations_def_level_milli_percent import VehicleStatsDecorationsDefLevelMilliPercent
    from .vehicle_stats_decorations_ecu_speed_mph import VehicleStatsDecorationsEcuSpeedMph
    from .vehicle_stats_decorations_engine_coolant_temperature_milli_c import (
        VehicleStatsDecorationsEngineCoolantTemperatureMilliC,
    )
    from .vehicle_stats_decorations_engine_load_percent import VehicleStatsDecorationsEngineLoadPercent
    from .vehicle_stats_decorations_engine_oil_pressure_k_pa import VehicleStatsDecorationsEngineOilPressureKPa
    from .vehicle_stats_decorations_engine_rpm import VehicleStatsDecorationsEngineRpm
    from .vehicle_stats_decorations_engine_states import VehicleStatsDecorationsEngineStates
    from .vehicle_stats_decorations_engine_states_value import VehicleStatsDecorationsEngineStatesValue
    from .vehicle_stats_decorations_fuel_consumed_milliliters import VehicleStatsDecorationsFuelConsumedMilliliters
    from .vehicle_stats_decorations_fuel_percents import VehicleStatsDecorationsFuelPercents
    from .vehicle_stats_decorations_gps import VehicleStatsDecorationsGps
    from .vehicle_stats_decorations_gps_distance_meters import VehicleStatsDecorationsGpsDistanceMeters
    from .vehicle_stats_decorations_gps_odometer_meters import VehicleStatsDecorationsGpsOdometerMeters
    from .vehicle_stats_decorations_idling_duration_milliseconds import (
        VehicleStatsDecorationsIdlingDurationMilliseconds,
    )
    from .vehicle_stats_decorations_intake_manifold_temperature_milli_c import (
        VehicleStatsDecorationsIntakeManifoldTemperatureMilliC,
    )
    from .vehicle_stats_decorations_obd_engine_seconds import VehicleStatsDecorationsObdEngineSeconds
    from .vehicle_stats_decorations_obd_odometer_meters import VehicleStatsDecorationsObdOdometerMeters
    from .vehicle_stats_def_level_milli_percent import VehicleStatsDefLevelMilliPercent
    from .vehicle_stats_def_level_milli_percent_value import VehicleStatsDefLevelMilliPercentValue
    from .vehicle_stats_def_level_milli_percent_with_decoration import VehicleStatsDefLevelMilliPercentWithDecoration
    from .vehicle_stats_ecu_door_status import VehicleStatsEcuDoorStatus
    from .vehicle_stats_ecu_door_status_value import VehicleStatsEcuDoorStatusValue
    from .vehicle_stats_ecu_speed_mph import VehicleStatsEcuSpeedMph
    from .vehicle_stats_ecu_speed_mph_value import VehicleStatsEcuSpeedMphValue
    from .vehicle_stats_ecu_speed_mph_with_decoration import VehicleStatsEcuSpeedMphWithDecoration
    from .vehicle_stats_engine_coolant_temp_milli_c import VehicleStatsEngineCoolantTempMilliC
    from .vehicle_stats_engine_coolant_temp_milli_c_value import VehicleStatsEngineCoolantTempMilliCValue
    from .vehicle_stats_engine_coolant_temp_milli_c_with_decoration import (
        VehicleStatsEngineCoolantTempMilliCWithDecoration,
    )
    from .vehicle_stats_engine_immobilizer import VehicleStatsEngineImmobilizer
    from .vehicle_stats_engine_immobilizer_state import VehicleStatsEngineImmobilizerState
    from .vehicle_stats_engine_immobilizer_with_decoration import VehicleStatsEngineImmobilizerWithDecoration
    from .vehicle_stats_engine_immobilizer_with_decoration_state import VehicleStatsEngineImmobilizerWithDecorationState
    from .vehicle_stats_engine_load_percent import VehicleStatsEngineLoadPercent
    from .vehicle_stats_engine_load_percent_value import VehicleStatsEngineLoadPercentValue
    from .vehicle_stats_engine_load_percent_with_decoration import VehicleStatsEngineLoadPercentWithDecoration
    from .vehicle_stats_engine_oil_pressure_k_pa import VehicleStatsEngineOilPressureKPa
    from .vehicle_stats_engine_oil_pressure_k_pa_value import VehicleStatsEngineOilPressureKPaValue
    from .vehicle_stats_engine_oil_pressure_k_pa_with_decoration import VehicleStatsEngineOilPressureKPaWithDecoration
    from .vehicle_stats_engine_rpm import VehicleStatsEngineRpm
    from .vehicle_stats_engine_rpm_value import VehicleStatsEngineRpmValue
    from .vehicle_stats_engine_rpm_with_decoration import VehicleStatsEngineRpmWithDecoration
    from .vehicle_stats_engine_state import VehicleStatsEngineState
    from .vehicle_stats_engine_state_setting import VehicleStatsEngineStateSetting
    from .vehicle_stats_engine_state_with_decoration import VehicleStatsEngineStateWithDecoration
    from .vehicle_stats_ev_average_battery_temperature_milli_celsius import (
        VehicleStatsEvAverageBatteryTemperatureMilliCelsius,
    )
    from .vehicle_stats_ev_battery_current_milli_amp import VehicleStatsEvBatteryCurrentMilliAmp
    from .vehicle_stats_ev_battery_state_of_health_milli_percent import VehicleStatsEvBatteryStateOfHealthMilliPercent
    from .vehicle_stats_ev_battery_voltage_milli_volt import VehicleStatsEvBatteryVoltageMilliVolt
    from .vehicle_stats_ev_charging_current_milli_amp import VehicleStatsEvChargingCurrentMilliAmp
    from .vehicle_stats_ev_charging_energy_micro_wh import VehicleStatsEvChargingEnergyMicroWh
    from .vehicle_stats_ev_charging_status import VehicleStatsEvChargingStatus
    from .vehicle_stats_ev_charging_voltage_milli_volt import VehicleStatsEvChargingVoltageMilliVolt
    from .vehicle_stats_ev_consumed_energy_micro_wh import VehicleStatsEvConsumedEnergyMicroWh
    from .vehicle_stats_ev_distance_driven_meters import VehicleStatsEvDistanceDrivenMeters
    from .vehicle_stats_ev_regenerated_energy_micro_wh import VehicleStatsEvRegeneratedEnergyMicroWh
    from .vehicle_stats_ev_state_of_charge_milli_percent import VehicleStatsEvStateOfChargeMilliPercent
    from .vehicle_stats_fault_codes import VehicleStatsFaultCodes
    from .vehicle_stats_fault_codes_can_bus_type import VehicleStatsFaultCodesCanBusType
    from .vehicle_stats_fault_codes_ignition_type import VehicleStatsFaultCodesIgnitionType
    from .vehicle_stats_fault_codes_j_1939 import VehicleStatsFaultCodesJ1939
    from .vehicle_stats_fault_codes_j_1939_lights import VehicleStatsFaultCodesJ1939Lights
    from .vehicle_stats_fault_codes_j_1939_trouble_code import VehicleStatsFaultCodesJ1939TroubleCode
    from .vehicle_stats_fault_codes_j_1939_trouble_codes import VehicleStatsFaultCodesJ1939TroubleCodes
    from .vehicle_stats_fault_codes_obdii import VehicleStatsFaultCodesObdii
    from .vehicle_stats_fault_codes_obdii_trouble_code import VehicleStatsFaultCodesObdiiTroubleCode
    from .vehicle_stats_fault_codes_oem import VehicleStatsFaultCodesOem
    from .vehicle_stats_fault_codes_oem_trouble_code import VehicleStatsFaultCodesOemTroubleCode
    from .vehicle_stats_fault_codes_oem_trouble_codes import VehicleStatsFaultCodesOemTroubleCodes
    from .vehicle_stats_fault_codes_passenger_dtc import VehicleStatsFaultCodesPassengerDtc
    from .vehicle_stats_fault_codes_passenger_monitor_status import VehicleStatsFaultCodesPassengerMonitorStatus
    from .vehicle_stats_fault_codes_passenger_monitor_status_value import (
        VehicleStatsFaultCodesPassengerMonitorStatusValue,
    )
    from .vehicle_stats_fault_codes_tx_id import VehicleStatsFaultCodesTxId
    from .vehicle_stats_fault_codes_value import VehicleStatsFaultCodesValue
    from .vehicle_stats_fault_codes_value_j_1939 import VehicleStatsFaultCodesValueJ1939
    from .vehicle_stats_fault_codes_value_j_1939_check_engine_lights import (
        VehicleStatsFaultCodesValueJ1939CheckEngineLights,
    )
    from .vehicle_stats_fault_codes_value_j_1939_diagnostic_trouble_codes import (
        VehicleStatsFaultCodesValueJ1939DiagnosticTroubleCodes,
    )
    from .vehicle_stats_fault_codes_value_j_1939_vendor_specific_fields import (
        VehicleStatsFaultCodesValueJ1939VendorSpecificFields,
    )
    from .vehicle_stats_fault_codes_value_obdii import VehicleStatsFaultCodesValueObdii
    from .vehicle_stats_fault_codes_value_obdii_confirmed_dtcs import VehicleStatsFaultCodesValueObdiiConfirmedDtcs
    from .vehicle_stats_fault_codes_value_obdii_diagnostic_trouble_codes import (
        VehicleStatsFaultCodesValueObdiiDiagnosticTroubleCodes,
    )
    from .vehicle_stats_fault_codes_value_obdii_diagnostic_trouble_codes_ignition_type import (
        VehicleStatsFaultCodesValueObdiiDiagnosticTroubleCodesIgnitionType,
    )
    from .vehicle_stats_fault_codes_value_obdii_monitor_status import VehicleStatsFaultCodesValueObdiiMonitorStatus
    from .vehicle_stats_fault_codes_value_obdii_monitor_status_catalyst import (
        VehicleStatsFaultCodesValueObdiiMonitorStatusCatalyst,
    )
    from .vehicle_stats_fault_codes_value_obdii_monitor_status_comprehensive import (
        VehicleStatsFaultCodesValueObdiiMonitorStatusComprehensive,
    )
    from .vehicle_stats_fault_codes_value_obdii_monitor_status_egr import (
        VehicleStatsFaultCodesValueObdiiMonitorStatusEgr,
    )
    from .vehicle_stats_fault_codes_value_obdii_monitor_status_evap_system import (
        VehicleStatsFaultCodesValueObdiiMonitorStatusEvapSystem,
    )
    from .vehicle_stats_fault_codes_value_obdii_monitor_status_fuel import (
        VehicleStatsFaultCodesValueObdiiMonitorStatusFuel,
    )
    from .vehicle_stats_fault_codes_value_obdii_monitor_status_heated_catalyst import (
        VehicleStatsFaultCodesValueObdiiMonitorStatusHeatedCatalyst,
    )
    from .vehicle_stats_fault_codes_value_obdii_monitor_status_heated_o_2_sensor import (
        VehicleStatsFaultCodesValueObdiiMonitorStatusHeatedO2Sensor,
    )
    from .vehicle_stats_fault_codes_value_obdii_monitor_status_iso_sae_reserved import (
        VehicleStatsFaultCodesValueObdiiMonitorStatusIsoSaeReserved,
    )
    from .vehicle_stats_fault_codes_value_obdii_monitor_status_misfire import (
        VehicleStatsFaultCodesValueObdiiMonitorStatusMisfire,
    )
    from .vehicle_stats_fault_codes_value_obdii_monitor_status_o_2_sensor import (
        VehicleStatsFaultCodesValueObdiiMonitorStatusO2Sensor,
    )
    from .vehicle_stats_fault_codes_value_obdii_monitor_status_secondary_air import (
        VehicleStatsFaultCodesValueObdiiMonitorStatusSecondaryAir,
    )
    from .vehicle_stats_fault_codes_value_oem import VehicleStatsFaultCodesValueOem
    from .vehicle_stats_fault_codes_value_oem_diagnostic_trouble_codes import (
        VehicleStatsFaultCodesValueOemDiagnosticTroubleCodes,
    )
    from .vehicle_stats_fault_codes_vendor_specific_fields import VehicleStatsFaultCodesVendorSpecificFields
    from .vehicle_stats_fault_codes_with_decoration import VehicleStatsFaultCodesWithDecoration
    from .vehicle_stats_fuel_consumed_milliliters import VehicleStatsFuelConsumedMilliliters
    from .vehicle_stats_fuel_consumed_milliliters_value import VehicleStatsFuelConsumedMillilitersValue
    from .vehicle_stats_fuel_consumed_milliliters_with_decoration import (
        VehicleStatsFuelConsumedMillilitersWithDecoration,
    )
    from .vehicle_stats_fuel_percent import VehicleStatsFuelPercent
    from .vehicle_stats_fuel_percent_value import VehicleStatsFuelPercentValue
    from .vehicle_stats_fuel_percent_with_decoration import VehicleStatsFuelPercentWithDecoration
    from .vehicle_stats_gps import VehicleStatsGps
    from .vehicle_stats_gps_distance_meters import VehicleStatsGpsDistanceMeters
    from .vehicle_stats_gps_distance_meters_value import VehicleStatsGpsDistanceMetersValue
    from .vehicle_stats_gps_distance_meters_with_decoration import VehicleStatsGpsDistanceMetersWithDecoration
    from .vehicle_stats_gps_odometer_meters import VehicleStatsGpsOdometerMeters
    from .vehicle_stats_gps_odometer_meters_value import VehicleStatsGpsOdometerMetersValue
    from .vehicle_stats_gps_odometer_meters_with_decoration import VehicleStatsGpsOdometerMetersWithDecoration
    from .vehicle_stats_idling_duration_milliseconds import VehicleStatsIdlingDurationMilliseconds
    from .vehicle_stats_idling_duration_milliseconds_value import VehicleStatsIdlingDurationMillisecondsValue
    from .vehicle_stats_idling_duration_milliseconds_with_decoration import (
        VehicleStatsIdlingDurationMillisecondsWithDecoration,
    )
    from .vehicle_stats_intake_manifold_temp_milli_c import VehicleStatsIntakeManifoldTempMilliC
    from .vehicle_stats_intake_manifold_temp_milli_c_value import VehicleStatsIntakeManifoldTempMilliCValue
    from .vehicle_stats_intake_manifold_temp_milli_c_with_decoration import (
        VehicleStatsIntakeManifoldTempMilliCWithDecoration,
    )
    from .vehicle_stats_list_gps import VehicleStatsListGps
    from .vehicle_stats_list_response import VehicleStatsListResponse
    from .vehicle_stats_list_response_data import VehicleStatsListResponseData
    from .vehicle_stats_list_synthetic_engine_seconds import VehicleStatsListSyntheticEngineSeconds
    from .vehicle_stats_nfc_card_scan import VehicleStatsNfcCardScan
    from .vehicle_stats_nfc_card_scan_card import VehicleStatsNfcCardScanCard
    from .vehicle_stats_nfc_card_scan_with_decoration import VehicleStatsNfcCardScanWithDecoration
    from .vehicle_stats_obd_engine_seconds import VehicleStatsObdEngineSeconds
    from .vehicle_stats_obd_engine_seconds_value import VehicleStatsObdEngineSecondsValue
    from .vehicle_stats_obd_engine_seconds_with_decoration import VehicleStatsObdEngineSecondsWithDecoration
    from .vehicle_stats_obd_odometer_meters import VehicleStatsObdOdometerMeters
    from .vehicle_stats_obd_odometer_meters_value import VehicleStatsObdOdometerMetersValue
    from .vehicle_stats_obd_odometer_meters_with_decoration import VehicleStatsObdOdometerMetersWithDecoration
    from .vehicle_stats_response import VehicleStatsResponse
    from .vehicle_stats_response_data import VehicleStatsResponseData
    from .vehicle_stats_response_ecu_door_status import VehicleStatsResponseEcuDoorStatus
    from .vehicle_stats_response_ecu_door_status_value import VehicleStatsResponseEcuDoorStatusValue
    from .vehicle_stats_response_ev_average_battery_temperature_milli_celsius import (
        VehicleStatsResponseEvAverageBatteryTemperatureMilliCelsius,
    )
    from .vehicle_stats_response_ev_battery_current_milli_amp import VehicleStatsResponseEvBatteryCurrentMilliAmp
    from .vehicle_stats_response_ev_battery_state_of_health_milli_percent import (
        VehicleStatsResponseEvBatteryStateOfHealthMilliPercent,
    )
    from .vehicle_stats_response_ev_battery_voltage_milli_volt import VehicleStatsResponseEvBatteryVoltageMilliVolt
    from .vehicle_stats_response_ev_charging_current_milli_amp import VehicleStatsResponseEvChargingCurrentMilliAmp
    from .vehicle_stats_response_ev_charging_energy_micro_wh import VehicleStatsResponseEvChargingEnergyMicroWh
    from .vehicle_stats_response_ev_charging_status import VehicleStatsResponseEvChargingStatus
    from .vehicle_stats_response_ev_charging_voltage_milli_volt import VehicleStatsResponseEvChargingVoltageMilliVolt
    from .vehicle_stats_response_ev_consumed_energy_micro_wh import VehicleStatsResponseEvConsumedEnergyMicroWh
    from .vehicle_stats_response_ev_distance_driven_meters import VehicleStatsResponseEvDistanceDrivenMeters
    from .vehicle_stats_response_ev_regenerated_energy_micro_wh import VehicleStatsResponseEvRegeneratedEnergyMicroWh
    from .vehicle_stats_response_ev_state_of_charge_milli_percent import VehicleStatsResponseEvStateOfChargeMilliPercent
    from .vehicle_stats_response_seatbelt_driver import VehicleStatsResponseSeatbeltDriver
    from .vehicle_stats_response_seatbelt_driver_value import VehicleStatsResponseSeatbeltDriverValue
    from .vehicle_stats_response_spreader_active import VehicleStatsResponseSpreaderActive
    from .vehicle_stats_response_spreader_active_value import VehicleStatsResponseSpreaderActiveValue
    from .vehicle_stats_response_spreader_air_temp import VehicleStatsResponseSpreaderAirTemp
    from .vehicle_stats_response_spreader_blast_state import VehicleStatsResponseSpreaderBlastState
    from .vehicle_stats_response_spreader_blast_state_value import VehicleStatsResponseSpreaderBlastStateValue
    from .vehicle_stats_response_spreader_granular_name import VehicleStatsResponseSpreaderGranularName
    from .vehicle_stats_response_spreader_granular_rate import VehicleStatsResponseSpreaderGranularRate
    from .vehicle_stats_response_spreader_liquid_name import VehicleStatsResponseSpreaderLiquidName
    from .vehicle_stats_response_spreader_liquid_rate import VehicleStatsResponseSpreaderLiquidRate
    from .vehicle_stats_response_spreader_on_state import VehicleStatsResponseSpreaderOnState
    from .vehicle_stats_response_spreader_on_state_value import VehicleStatsResponseSpreaderOnStateValue
    from .vehicle_stats_response_spreader_plow_status import VehicleStatsResponseSpreaderPlowStatus
    from .vehicle_stats_response_spreader_plow_status_value import VehicleStatsResponseSpreaderPlowStatusValue
    from .vehicle_stats_response_spreader_prewet_name import VehicleStatsResponseSpreaderPrewetName
    from .vehicle_stats_response_spreader_prewet_rate import VehicleStatsResponseSpreaderPrewetRate
    from .vehicle_stats_response_spreader_road_temp import VehicleStatsResponseSpreaderRoadTemp
    from .vehicle_stats_seatbelt_driver import VehicleStatsSeatbeltDriver
    from .vehicle_stats_seatbelt_driver_value import VehicleStatsSeatbeltDriverValue
    from .vehicle_stats_spreader_active import VehicleStatsSpreaderActive
    from .vehicle_stats_spreader_active_value import VehicleStatsSpreaderActiveValue
    from .vehicle_stats_spreader_air_temp import VehicleStatsSpreaderAirTemp
    from .vehicle_stats_spreader_blast_state import VehicleStatsSpreaderBlastState
    from .vehicle_stats_spreader_blast_state_value import VehicleStatsSpreaderBlastStateValue
    from .vehicle_stats_spreader_granular_name import VehicleStatsSpreaderGranularName
    from .vehicle_stats_spreader_granular_rate import VehicleStatsSpreaderGranularRate
    from .vehicle_stats_spreader_liquid_name import VehicleStatsSpreaderLiquidName
    from .vehicle_stats_spreader_liquid_rate import VehicleStatsSpreaderLiquidRate
    from .vehicle_stats_spreader_on_state import VehicleStatsSpreaderOnState
    from .vehicle_stats_spreader_on_state_value import VehicleStatsSpreaderOnStateValue
    from .vehicle_stats_spreader_plow_status import VehicleStatsSpreaderPlowStatus
    from .vehicle_stats_spreader_plow_status_value import VehicleStatsSpreaderPlowStatusValue
    from .vehicle_stats_spreader_prewet_name import VehicleStatsSpreaderPrewetName
    from .vehicle_stats_spreader_prewet_rate import VehicleStatsSpreaderPrewetRate
    from .vehicle_stats_spreader_road_temp import VehicleStatsSpreaderRoadTemp
    from .vehicle_stats_synthetic_engine_seconds import VehicleStatsSyntheticEngineSeconds
    from .vehicle_stats_synthetic_engine_seconds_value import VehicleStatsSyntheticEngineSecondsValue
    from .vehicle_stats_tire_pressures import VehicleStatsTirePressures
    from .vehicle_summary import VehicleSummary
    from .vehicle_tags import VehicleTags
    from .vehicle_tiny_response import VehicleTinyResponse
    from .vehicle_type import VehicleType
    from .vehicle_vin import VehicleVin
    from .vehicle_with_gateway_tiny_response_response_body import VehicleWithGatewayTinyResponseResponseBody
    from .vehicle_with_gateway_tiny_response_response_body_asset_type import (
        VehicleWithGatewayTinyResponseResponseBodyAssetType,
    )
    from .vehicle_year import VehicleYear
    from .vehicles_driver_assignments_get_vehicles_driver_assignments_bad_gateway_error_response_body import (
        VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsBadGatewayErrorResponseBody,
    )
    from .vehicles_driver_assignments_get_vehicles_driver_assignments_gateway_timeout_error_response_body import (
        VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsGatewayTimeoutErrorResponseBody,
    )
    from .vehicles_driver_assignments_get_vehicles_driver_assignments_internal_server_error_response_body import (
        VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsInternalServerErrorResponseBody,
    )
    from .vehicles_driver_assignments_get_vehicles_driver_assignments_method_not_allowed_error_response_body import (
        VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsMethodNotAllowedErrorResponseBody,
    )
    from .vehicles_driver_assignments_get_vehicles_driver_assignments_not_found_error_response_body import (
        VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsNotFoundErrorResponseBody,
    )
    from .vehicles_driver_assignments_get_vehicles_driver_assignments_not_implemented_error_response_body import (
        VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsNotImplementedErrorResponseBody,
    )
    from .vehicles_driver_assignments_get_vehicles_driver_assignments_response_body import (
        VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsResponseBody,
    )
    from .vehicles_driver_assignments_get_vehicles_driver_assignments_service_unavailable_error_response_body import (
        VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsServiceUnavailableErrorResponseBody,
    )
    from .vehicles_driver_assignments_get_vehicles_driver_assignments_too_many_requests_error_response_body import (
        VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsTooManyRequestsErrorResponseBody,
    )
    from .vehicles_driver_assignments_get_vehicles_driver_assignments_unauthorized_error_response_body import (
        VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsUnauthorizedErrorResponseBody,
    )
    from .vehicles_driver_assignments_object_response_body import VehiclesDriverAssignmentsObjectResponseBody
    from .vehicles_list_vehicles_bad_gateway_error_response_body import VehiclesListVehiclesBadGatewayErrorResponseBody
    from .vehicles_list_vehicles_gateway_timeout_error_response_body import (
        VehiclesListVehiclesGatewayTimeoutErrorResponseBody,
    )
    from .vehicles_list_vehicles_internal_server_error_response_body import (
        VehiclesListVehiclesInternalServerErrorResponseBody,
    )
    from .vehicles_list_vehicles_method_not_allowed_error_response_body import (
        VehiclesListVehiclesMethodNotAllowedErrorResponseBody,
    )
    from .vehicles_list_vehicles_not_found_error_response_body import VehiclesListVehiclesNotFoundErrorResponseBody
    from .vehicles_list_vehicles_not_implemented_error_response_body import (
        VehiclesListVehiclesNotImplementedErrorResponseBody,
    )
    from .vehicles_list_vehicles_response_body import VehiclesListVehiclesResponseBody
    from .vehicles_list_vehicles_service_unavailable_error_response_body import (
        VehiclesListVehiclesServiceUnavailableErrorResponseBody,
    )
    from .vehicles_list_vehicles_too_many_requests_error_response_body import (
        VehiclesListVehiclesTooManyRequestsErrorResponseBody,
    )
    from .vehicles_list_vehicles_unauthorized_error_response_body import (
        VehiclesListVehiclesUnauthorizedErrorResponseBody,
    )
    from .vehicles_lock_lock_vehicle_bad_gateway_error_response_body import (
        VehiclesLockLockVehicleBadGatewayErrorResponseBody,
    )
    from .vehicles_lock_lock_vehicle_gateway_timeout_error_response_body import (
        VehiclesLockLockVehicleGatewayTimeoutErrorResponseBody,
    )
    from .vehicles_lock_lock_vehicle_internal_server_error_response_body import (
        VehiclesLockLockVehicleInternalServerErrorResponseBody,
    )
    from .vehicles_lock_lock_vehicle_method_not_allowed_error_response_body import (
        VehiclesLockLockVehicleMethodNotAllowedErrorResponseBody,
    )
    from .vehicles_lock_lock_vehicle_not_found_error_response_body import (
        VehiclesLockLockVehicleNotFoundErrorResponseBody,
    )
    from .vehicles_lock_lock_vehicle_not_implemented_error_response_body import (
        VehiclesLockLockVehicleNotImplementedErrorResponseBody,
    )
    from .vehicles_lock_lock_vehicle_service_unavailable_error_response_body import (
        VehiclesLockLockVehicleServiceUnavailableErrorResponseBody,
    )
    from .vehicles_lock_lock_vehicle_too_many_requests_error_response_body import (
        VehiclesLockLockVehicleTooManyRequestsErrorResponseBody,
    )
    from .vehicles_lock_lock_vehicle_unauthorized_error_response_body import (
        VehiclesLockLockVehicleUnauthorizedErrorResponseBody,
    )
    from .vehicles_lock_unlock_vehicle_bad_gateway_error_response_body import (
        VehiclesLockUnlockVehicleBadGatewayErrorResponseBody,
    )
    from .vehicles_lock_unlock_vehicle_gateway_timeout_error_response_body import (
        VehiclesLockUnlockVehicleGatewayTimeoutErrorResponseBody,
    )
    from .vehicles_lock_unlock_vehicle_internal_server_error_response_body import (
        VehiclesLockUnlockVehicleInternalServerErrorResponseBody,
    )
    from .vehicles_lock_unlock_vehicle_method_not_allowed_error_response_body import (
        VehiclesLockUnlockVehicleMethodNotAllowedErrorResponseBody,
    )
    from .vehicles_lock_unlock_vehicle_not_found_error_response_body import (
        VehiclesLockUnlockVehicleNotFoundErrorResponseBody,
    )
    from .vehicles_lock_unlock_vehicle_not_implemented_error_response_body import (
        VehiclesLockUnlockVehicleNotImplementedErrorResponseBody,
    )
    from .vehicles_lock_unlock_vehicle_service_unavailable_error_response_body import (
        VehiclesLockUnlockVehicleServiceUnavailableErrorResponseBody,
    )
    from .vehicles_lock_unlock_vehicle_too_many_requests_error_response_body import (
        VehiclesLockUnlockVehicleTooManyRequestsErrorResponseBody,
    )
    from .vehicles_lock_unlock_vehicle_unauthorized_error_response_body import (
        VehiclesLockUnlockVehicleUnauthorizedErrorResponseBody,
    )
    from .vertex_request_body import VertexRequestBody
    from .vertex_response_body import VertexResponseBody
    from .voice_coaching_settings_object_response_body import VoiceCoachingSettingsObjectResponseBody
    from .voice_coaching_settings_object_response_body_events_to_coach_item import (
        VoiceCoachingSettingsObjectResponseBodyEventsToCoachItem,
    )
    from .voice_coaching_settings_object_response_body_language import VoiceCoachingSettingsObjectResponseBodyLanguage
    from .walkaround_photo_object_response_body import WalkaroundPhotoObjectResponseBody
    from .webhook_params_object_request_body import WebhookParamsObjectRequestBody
    from .webhook_params_object_request_body_payload_type import WebhookParamsObjectRequestBodyPayloadType
    from .webhook_params_object_response_body import WebhookParamsObjectResponseBody
    from .webhook_params_object_response_body_payload_type import WebhookParamsObjectResponseBodyPayloadType
    from .webhook_response_response_body import WebhookResponseResponseBody
    from .webhook_response_response_body_event_types_item import WebhookResponseResponseBodyEventTypesItem
    from .webhook_response_response_body_version import WebhookResponseResponseBodyVersion
    from .webhook_route_response_object_response_body import WebhookRouteResponseObjectResponseBody
    from .webhooks_delete_webhook_bad_gateway_error_response_body import (
        WebhooksDeleteWebhookBadGatewayErrorResponseBody,
    )
    from .webhooks_delete_webhook_gateway_timeout_error_response_body import (
        WebhooksDeleteWebhookGatewayTimeoutErrorResponseBody,
    )
    from .webhooks_delete_webhook_internal_server_error_response_body import (
        WebhooksDeleteWebhookInternalServerErrorResponseBody,
    )
    from .webhooks_delete_webhook_method_not_allowed_error_response_body import (
        WebhooksDeleteWebhookMethodNotAllowedErrorResponseBody,
    )
    from .webhooks_delete_webhook_not_found_error_response_body import WebhooksDeleteWebhookNotFoundErrorResponseBody
    from .webhooks_delete_webhook_not_implemented_error_response_body import (
        WebhooksDeleteWebhookNotImplementedErrorResponseBody,
    )
    from .webhooks_delete_webhook_service_unavailable_error_response_body import (
        WebhooksDeleteWebhookServiceUnavailableErrorResponseBody,
    )
    from .webhooks_delete_webhook_too_many_requests_error_response_body import (
        WebhooksDeleteWebhookTooManyRequestsErrorResponseBody,
    )
    from .webhooks_delete_webhook_unauthorized_error_response_body import (
        WebhooksDeleteWebhookUnauthorizedErrorResponseBody,
    )
    from .webhooks_get_webhook_bad_gateway_error_response_body import WebhooksGetWebhookBadGatewayErrorResponseBody
    from .webhooks_get_webhook_gateway_timeout_error_response_body import (
        WebhooksGetWebhookGatewayTimeoutErrorResponseBody,
    )
    from .webhooks_get_webhook_internal_server_error_response_body import (
        WebhooksGetWebhookInternalServerErrorResponseBody,
    )
    from .webhooks_get_webhook_method_not_allowed_error_response_body import (
        WebhooksGetWebhookMethodNotAllowedErrorResponseBody,
    )
    from .webhooks_get_webhook_not_found_error_response_body import WebhooksGetWebhookNotFoundErrorResponseBody
    from .webhooks_get_webhook_not_implemented_error_response_body import (
        WebhooksGetWebhookNotImplementedErrorResponseBody,
    )
    from .webhooks_get_webhook_response_body import WebhooksGetWebhookResponseBody
    from .webhooks_get_webhook_response_body_event_types_item import WebhooksGetWebhookResponseBodyEventTypesItem
    from .webhooks_get_webhook_response_body_version import WebhooksGetWebhookResponseBodyVersion
    from .webhooks_get_webhook_service_unavailable_error_response_body import (
        WebhooksGetWebhookServiceUnavailableErrorResponseBody,
    )
    from .webhooks_get_webhook_too_many_requests_error_response_body import (
        WebhooksGetWebhookTooManyRequestsErrorResponseBody,
    )
    from .webhooks_get_webhook_unauthorized_error_response_body import WebhooksGetWebhookUnauthorizedErrorResponseBody
    from .webhooks_list_webhooks_bad_gateway_error_response_body import WebhooksListWebhooksBadGatewayErrorResponseBody
    from .webhooks_list_webhooks_gateway_timeout_error_response_body import (
        WebhooksListWebhooksGatewayTimeoutErrorResponseBody,
    )
    from .webhooks_list_webhooks_internal_server_error_response_body import (
        WebhooksListWebhooksInternalServerErrorResponseBody,
    )
    from .webhooks_list_webhooks_method_not_allowed_error_response_body import (
        WebhooksListWebhooksMethodNotAllowedErrorResponseBody,
    )
    from .webhooks_list_webhooks_not_found_error_response_body import WebhooksListWebhooksNotFoundErrorResponseBody
    from .webhooks_list_webhooks_not_implemented_error_response_body import (
        WebhooksListWebhooksNotImplementedErrorResponseBody,
    )
    from .webhooks_list_webhooks_response_body import WebhooksListWebhooksResponseBody
    from .webhooks_list_webhooks_service_unavailable_error_response_body import (
        WebhooksListWebhooksServiceUnavailableErrorResponseBody,
    )
    from .webhooks_list_webhooks_too_many_requests_error_response_body import (
        WebhooksListWebhooksTooManyRequestsErrorResponseBody,
    )
    from .webhooks_list_webhooks_unauthorized_error_response_body import (
        WebhooksListWebhooksUnauthorizedErrorResponseBody,
    )
    from .webhooks_patch_webhook_bad_gateway_error_response_body import WebhooksPatchWebhookBadGatewayErrorResponseBody
    from .webhooks_patch_webhook_gateway_timeout_error_response_body import (
        WebhooksPatchWebhookGatewayTimeoutErrorResponseBody,
    )
    from .webhooks_patch_webhook_internal_server_error_response_body import (
        WebhooksPatchWebhookInternalServerErrorResponseBody,
    )
    from .webhooks_patch_webhook_method_not_allowed_error_response_body import (
        WebhooksPatchWebhookMethodNotAllowedErrorResponseBody,
    )
    from .webhooks_patch_webhook_not_found_error_response_body import WebhooksPatchWebhookNotFoundErrorResponseBody
    from .webhooks_patch_webhook_not_implemented_error_response_body import (
        WebhooksPatchWebhookNotImplementedErrorResponseBody,
    )
    from .webhooks_patch_webhook_response_body import WebhooksPatchWebhookResponseBody
    from .webhooks_patch_webhook_response_body_event_types_item import WebhooksPatchWebhookResponseBodyEventTypesItem
    from .webhooks_patch_webhook_response_body_version import WebhooksPatchWebhookResponseBodyVersion
    from .webhooks_patch_webhook_service_unavailable_error_response_body import (
        WebhooksPatchWebhookServiceUnavailableErrorResponseBody,
    )
    from .webhooks_patch_webhook_too_many_requests_error_response_body import (
        WebhooksPatchWebhookTooManyRequestsErrorResponseBody,
    )
    from .webhooks_patch_webhook_unauthorized_error_response_body import (
        WebhooksPatchWebhookUnauthorizedErrorResponseBody,
    )
    from .webhooks_post_webhooks_bad_gateway_error_response_body import WebhooksPostWebhooksBadGatewayErrorResponseBody
    from .webhooks_post_webhooks_gateway_timeout_error_response_body import (
        WebhooksPostWebhooksGatewayTimeoutErrorResponseBody,
    )
    from .webhooks_post_webhooks_internal_server_error_response_body import (
        WebhooksPostWebhooksInternalServerErrorResponseBody,
    )
    from .webhooks_post_webhooks_method_not_allowed_error_response_body import (
        WebhooksPostWebhooksMethodNotAllowedErrorResponseBody,
    )
    from .webhooks_post_webhooks_not_found_error_response_body import WebhooksPostWebhooksNotFoundErrorResponseBody
    from .webhooks_post_webhooks_not_implemented_error_response_body import (
        WebhooksPostWebhooksNotImplementedErrorResponseBody,
    )
    from .webhooks_post_webhooks_response_body import WebhooksPostWebhooksResponseBody
    from .webhooks_post_webhooks_response_body_event_types_item import WebhooksPostWebhooksResponseBodyEventTypesItem
    from .webhooks_post_webhooks_response_body_version import WebhooksPostWebhooksResponseBodyVersion
    from .webhooks_post_webhooks_service_unavailable_error_response_body import (
        WebhooksPostWebhooksServiceUnavailableErrorResponseBody,
    )
    from .webhooks_post_webhooks_too_many_requests_error_response_body import (
        WebhooksPostWebhooksTooManyRequestsErrorResponseBody,
    )
    from .webhooks_post_webhooks_unauthorized_error_response_body import (
        WebhooksPostWebhooksUnauthorizedErrorResponseBody,
    )
    from .work_order_attachment_object_response_body import WorkOrderAttachmentObjectResponseBody
    from .work_order_attachment_object_response_body_processing_status import (
        WorkOrderAttachmentObjectResponseBodyProcessingStatus,
    )
    from .work_order_discount_object_request_body import WorkOrderDiscountObjectRequestBody
    from .work_order_discount_object_response_body import WorkOrderDiscountObjectResponseBody
    from .work_order_item_object_request_body import WorkOrderItemObjectRequestBody
    from .work_order_item_object_request_body_type import WorkOrderItemObjectRequestBodyType
    from .work_order_item_object_response_body import WorkOrderItemObjectResponseBody
    from .work_order_item_object_response_body_type import WorkOrderItemObjectResponseBodyType
    from .work_order_money_object_request_body import WorkOrderMoneyObjectRequestBody
    from .work_order_money_object_request_body_currency import WorkOrderMoneyObjectRequestBodyCurrency
    from .work_order_money_object_response_body import WorkOrderMoneyObjectResponseBody
    from .work_order_money_object_response_body_currency import WorkOrderMoneyObjectResponseBodyCurrency
    from .work_order_object_response_body import WorkOrderObjectResponseBody
    from .work_order_object_response_body_priority import WorkOrderObjectResponseBodyPriority
    from .work_order_object_response_body_status import WorkOrderObjectResponseBodyStatus
    from .work_order_tax_create_object_request_body import WorkOrderTaxCreateObjectRequestBody
    from .work_order_tax_object_request_body import WorkOrderTaxObjectRequestBody
    from .work_order_tax_object_response_body import WorkOrderTaxObjectResponseBody
    from .work_order_unallocated_labor_object_response_body import WorkOrderUnallocatedLaborObjectResponseBody
    from .work_orders_delete_work_orders_bad_gateway_error_response_body import (
        WorkOrdersDeleteWorkOrdersBadGatewayErrorResponseBody,
    )
    from .work_orders_delete_work_orders_gateway_timeout_error_response_body import (
        WorkOrdersDeleteWorkOrdersGatewayTimeoutErrorResponseBody,
    )
    from .work_orders_delete_work_orders_internal_server_error_response_body import (
        WorkOrdersDeleteWorkOrdersInternalServerErrorResponseBody,
    )
    from .work_orders_delete_work_orders_method_not_allowed_error_response_body import (
        WorkOrdersDeleteWorkOrdersMethodNotAllowedErrorResponseBody,
    )
    from .work_orders_delete_work_orders_not_found_error_response_body import (
        WorkOrdersDeleteWorkOrdersNotFoundErrorResponseBody,
    )
    from .work_orders_delete_work_orders_not_implemented_error_response_body import (
        WorkOrdersDeleteWorkOrdersNotImplementedErrorResponseBody,
    )
    from .work_orders_delete_work_orders_service_unavailable_error_response_body import (
        WorkOrdersDeleteWorkOrdersServiceUnavailableErrorResponseBody,
    )
    from .work_orders_delete_work_orders_too_many_requests_error_response_body import (
        WorkOrdersDeleteWorkOrdersTooManyRequestsErrorResponseBody,
    )
    from .work_orders_delete_work_orders_unauthorized_error_response_body import (
        WorkOrdersDeleteWorkOrdersUnauthorizedErrorResponseBody,
    )
    from .work_orders_get_service_tasks_bad_gateway_error_response_body import (
        WorkOrdersGetServiceTasksBadGatewayErrorResponseBody,
    )
    from .work_orders_get_service_tasks_gateway_timeout_error_response_body import (
        WorkOrdersGetServiceTasksGatewayTimeoutErrorResponseBody,
    )
    from .work_orders_get_service_tasks_internal_server_error_response_body import (
        WorkOrdersGetServiceTasksInternalServerErrorResponseBody,
    )
    from .work_orders_get_service_tasks_method_not_allowed_error_response_body import (
        WorkOrdersGetServiceTasksMethodNotAllowedErrorResponseBody,
    )
    from .work_orders_get_service_tasks_not_found_error_response_body import (
        WorkOrdersGetServiceTasksNotFoundErrorResponseBody,
    )
    from .work_orders_get_service_tasks_not_implemented_error_response_body import (
        WorkOrdersGetServiceTasksNotImplementedErrorResponseBody,
    )
    from .work_orders_get_service_tasks_response_body import WorkOrdersGetServiceTasksResponseBody
    from .work_orders_get_service_tasks_service_unavailable_error_response_body import (
        WorkOrdersGetServiceTasksServiceUnavailableErrorResponseBody,
    )
    from .work_orders_get_service_tasks_too_many_requests_error_response_body import (
        WorkOrdersGetServiceTasksTooManyRequestsErrorResponseBody,
    )
    from .work_orders_get_service_tasks_unauthorized_error_response_body import (
        WorkOrdersGetServiceTasksUnauthorizedErrorResponseBody,
    )
    from .work_orders_get_work_orders_bad_gateway_error_response_body import (
        WorkOrdersGetWorkOrdersBadGatewayErrorResponseBody,
    )
    from .work_orders_get_work_orders_gateway_timeout_error_response_body import (
        WorkOrdersGetWorkOrdersGatewayTimeoutErrorResponseBody,
    )
    from .work_orders_get_work_orders_internal_server_error_response_body import (
        WorkOrdersGetWorkOrdersInternalServerErrorResponseBody,
    )
    from .work_orders_get_work_orders_method_not_allowed_error_response_body import (
        WorkOrdersGetWorkOrdersMethodNotAllowedErrorResponseBody,
    )
    from .work_orders_get_work_orders_not_found_error_response_body import (
        WorkOrdersGetWorkOrdersNotFoundErrorResponseBody,
    )
    from .work_orders_get_work_orders_not_implemented_error_response_body import (
        WorkOrdersGetWorkOrdersNotImplementedErrorResponseBody,
    )
    from .work_orders_get_work_orders_response_body import WorkOrdersGetWorkOrdersResponseBody
    from .work_orders_get_work_orders_service_unavailable_error_response_body import (
        WorkOrdersGetWorkOrdersServiceUnavailableErrorResponseBody,
    )
    from .work_orders_get_work_orders_too_many_requests_error_response_body import (
        WorkOrdersGetWorkOrdersTooManyRequestsErrorResponseBody,
    )
    from .work_orders_get_work_orders_unauthorized_error_response_body import (
        WorkOrdersGetWorkOrdersUnauthorizedErrorResponseBody,
    )
    from .work_orders_patch_work_orders_bad_gateway_error_response_body import (
        WorkOrdersPatchWorkOrdersBadGatewayErrorResponseBody,
    )
    from .work_orders_patch_work_orders_gateway_timeout_error_response_body import (
        WorkOrdersPatchWorkOrdersGatewayTimeoutErrorResponseBody,
    )
    from .work_orders_patch_work_orders_internal_server_error_response_body import (
        WorkOrdersPatchWorkOrdersInternalServerErrorResponseBody,
    )
    from .work_orders_patch_work_orders_method_not_allowed_error_response_body import (
        WorkOrdersPatchWorkOrdersMethodNotAllowedErrorResponseBody,
    )
    from .work_orders_patch_work_orders_not_found_error_response_body import (
        WorkOrdersPatchWorkOrdersNotFoundErrorResponseBody,
    )
    from .work_orders_patch_work_orders_not_implemented_error_response_body import (
        WorkOrdersPatchWorkOrdersNotImplementedErrorResponseBody,
    )
    from .work_orders_patch_work_orders_response_body import WorkOrdersPatchWorkOrdersResponseBody
    from .work_orders_patch_work_orders_service_unavailable_error_response_body import (
        WorkOrdersPatchWorkOrdersServiceUnavailableErrorResponseBody,
    )
    from .work_orders_patch_work_orders_too_many_requests_error_response_body import (
        WorkOrdersPatchWorkOrdersTooManyRequestsErrorResponseBody,
    )
    from .work_orders_patch_work_orders_unauthorized_error_response_body import (
        WorkOrdersPatchWorkOrdersUnauthorizedErrorResponseBody,
    )
    from .work_orders_post_invoice_scan_bad_gateway_error_response_body import (
        WorkOrdersPostInvoiceScanBadGatewayErrorResponseBody,
    )
    from .work_orders_post_invoice_scan_gateway_timeout_error_response_body import (
        WorkOrdersPostInvoiceScanGatewayTimeoutErrorResponseBody,
    )
    from .work_orders_post_invoice_scan_internal_server_error_response_body import (
        WorkOrdersPostInvoiceScanInternalServerErrorResponseBody,
    )
    from .work_orders_post_invoice_scan_method_not_allowed_error_response_body import (
        WorkOrdersPostInvoiceScanMethodNotAllowedErrorResponseBody,
    )
    from .work_orders_post_invoice_scan_not_found_error_response_body import (
        WorkOrdersPostInvoiceScanNotFoundErrorResponseBody,
    )
    from .work_orders_post_invoice_scan_not_implemented_error_response_body import (
        WorkOrdersPostInvoiceScanNotImplementedErrorResponseBody,
    )
    from .work_orders_post_invoice_scan_response_body import WorkOrdersPostInvoiceScanResponseBody
    from .work_orders_post_invoice_scan_service_unavailable_error_response_body import (
        WorkOrdersPostInvoiceScanServiceUnavailableErrorResponseBody,
    )
    from .work_orders_post_invoice_scan_too_many_requests_error_response_body import (
        WorkOrdersPostInvoiceScanTooManyRequestsErrorResponseBody,
    )
    from .work_orders_post_invoice_scan_unauthorized_error_response_body import (
        WorkOrdersPostInvoiceScanUnauthorizedErrorResponseBody,
    )
    from .work_orders_post_work_orders_bad_gateway_error_response_body import (
        WorkOrdersPostWorkOrdersBadGatewayErrorResponseBody,
    )
    from .work_orders_post_work_orders_gateway_timeout_error_response_body import (
        WorkOrdersPostWorkOrdersGatewayTimeoutErrorResponseBody,
    )
    from .work_orders_post_work_orders_internal_server_error_response_body import (
        WorkOrdersPostWorkOrdersInternalServerErrorResponseBody,
    )
    from .work_orders_post_work_orders_method_not_allowed_error_response_body import (
        WorkOrdersPostWorkOrdersMethodNotAllowedErrorResponseBody,
    )
    from .work_orders_post_work_orders_not_found_error_response_body import (
        WorkOrdersPostWorkOrdersNotFoundErrorResponseBody,
    )
    from .work_orders_post_work_orders_not_implemented_error_response_body import (
        WorkOrdersPostWorkOrdersNotImplementedErrorResponseBody,
    )
    from .work_orders_post_work_orders_response_body import WorkOrdersPostWorkOrdersResponseBody
    from .work_orders_post_work_orders_service_unavailable_error_response_body import (
        WorkOrdersPostWorkOrdersServiceUnavailableErrorResponseBody,
    )
    from .work_orders_post_work_orders_too_many_requests_error_response_body import (
        WorkOrdersPostWorkOrdersTooManyRequestsErrorResponseBody,
    )
    from .work_orders_post_work_orders_unauthorized_error_response_body import (
        WorkOrdersPostWorkOrdersUnauthorizedErrorResponseBody,
    )
    from .work_orders_stream_work_orders_bad_gateway_error_response_body import (
        WorkOrdersStreamWorkOrdersBadGatewayErrorResponseBody,
    )
    from .work_orders_stream_work_orders_gateway_timeout_error_response_body import (
        WorkOrdersStreamWorkOrdersGatewayTimeoutErrorResponseBody,
    )
    from .work_orders_stream_work_orders_internal_server_error_response_body import (
        WorkOrdersStreamWorkOrdersInternalServerErrorResponseBody,
    )
    from .work_orders_stream_work_orders_method_not_allowed_error_response_body import (
        WorkOrdersStreamWorkOrdersMethodNotAllowedErrorResponseBody,
    )
    from .work_orders_stream_work_orders_not_found_error_response_body import (
        WorkOrdersStreamWorkOrdersNotFoundErrorResponseBody,
    )
    from .work_orders_stream_work_orders_not_implemented_error_response_body import (
        WorkOrdersStreamWorkOrdersNotImplementedErrorResponseBody,
    )
    from .work_orders_stream_work_orders_response_body import WorkOrdersStreamWorkOrdersResponseBody
    from .work_orders_stream_work_orders_service_unavailable_error_response_body import (
        WorkOrdersStreamWorkOrdersServiceUnavailableErrorResponseBody,
    )
    from .work_orders_stream_work_orders_too_many_requests_error_response_body import (
        WorkOrdersStreamWorkOrdersTooManyRequestsErrorResponseBody,
    )
    from .work_orders_stream_work_orders_unauthorized_error_response_body import (
        WorkOrdersStreamWorkOrdersUnauthorizedErrorResponseBody,
    )
    from .worker_safety_sos_data_response_body import WorkerSafetySosDataResponseBody
    from .worker_safety_sos_data_response_body_source_type import WorkerSafetySosDataResponseBodySourceType
    from .workflow_address_event_with_geofence_object_response_body import (
        WorkflowAddressEventWithGeofenceObjectResponseBody,
    )
    from .workflow_author_signature_object_response_body import WorkflowAuthorSignatureObjectResponseBody
    from .workflow_author_signature_object_response_body_type import WorkflowAuthorSignatureObjectResponseBodyType
    from .workflow_circle_response_body import WorkflowCircleResponseBody
    from .workflow_dvir_object_response_body import WorkflowDvirObjectResponseBody
    from .workflow_dvir_object_response_body_safety_status import WorkflowDvirObjectResponseBodySafetyStatus
    from .workflow_dvir_object_response_body_type import WorkflowDvirObjectResponseBodyType
    from .workflow_dvir_submitted_response_object_response_body import WorkflowDvirSubmittedResponseObjectResponseBody
    from .workflow_geofence_event_response_object_response_body import WorkflowGeofenceEventResponseObjectResponseBody
    from .workflow_geofence_response_body import WorkflowGeofenceResponseBody
    from .workflow_incident_condition_object_response_body import WorkflowIncidentConditionObjectResponseBody
    from .workflow_incident_details_object_response_body import WorkflowIncidentDetailsObjectResponseBody
    from .workflow_polygon_response_body import WorkflowPolygonResponseBody
    from .workflow_signatory_user_object_response_body import WorkflowSignatoryUserObjectResponseBody
    from .workflow_trigger_object_request_body import WorkflowTriggerObjectRequestBody
    from .workflow_trigger_object_response_body import WorkflowTriggerObjectResponseBody
_dynamic_imports: typing.Dict[str, str] = {
    "AccessoryResponseObjectResponseBody": ".accessory_response_object_response_body",
    "ActionObjectRequestBody": ".action_object_request_body",
    "ActionObjectResponseBody": ".action_object_response_body",
    "ActionParamsObjectRequestBody": ".action_params_object_request_body",
    "ActionParamsObjectResponseBody": ".action_params_object_response_body",
    "Address": ".address",
    "AddressAddressTypesItem": ".address_address_types_item",
    "AddressExternalIds": ".address_external_ids",
    "AddressGeofence": ".address_geofence",
    "AddressGeofenceCircle": ".address_geofence_circle",
    "AddressGeofencePolygon": ".address_geofence_polygon",
    "AddressGeofencePolygonVertices": ".address_geofence_polygon_vertices",
    "AddressGeofenceSettings": ".address_geofence_settings",
    "AddressResponse": ".address_response",
    "AddressResponseResponseBody": ".address_response_response_body",
    "AddressTinyResponse": ".address_tiny_response",
    "AdvancedIdlingGetIdlingEventsBadGatewayErrorResponseBody": ".advanced_idling_get_idling_events_bad_gateway_error_response_body",
    "AdvancedIdlingGetIdlingEventsGatewayTimeoutErrorResponseBody": ".advanced_idling_get_idling_events_gateway_timeout_error_response_body",
    "AdvancedIdlingGetIdlingEventsInternalServerErrorResponseBody": ".advanced_idling_get_idling_events_internal_server_error_response_body",
    "AdvancedIdlingGetIdlingEventsMethodNotAllowedErrorResponseBody": ".advanced_idling_get_idling_events_method_not_allowed_error_response_body",
    "AdvancedIdlingGetIdlingEventsNotFoundErrorResponseBody": ".advanced_idling_get_idling_events_not_found_error_response_body",
    "AdvancedIdlingGetIdlingEventsNotImplementedErrorResponseBody": ".advanced_idling_get_idling_events_not_implemented_error_response_body",
    "AdvancedIdlingGetIdlingEventsResponseBody": ".advanced_idling_get_idling_events_response_body",
    "AdvancedIdlingGetIdlingEventsServiceUnavailableErrorResponseBody": ".advanced_idling_get_idling_events_service_unavailable_error_response_body",
    "AdvancedIdlingGetIdlingEventsTooManyRequestsErrorResponseBody": ".advanced_idling_get_idling_events_too_many_requests_error_response_body",
    "AdvancedIdlingGetIdlingEventsUnauthorizedErrorResponseBody": ".advanced_idling_get_idling_events_unauthorized_error_response_body",
    "AempEquipmentGetAempEquipmentListBadGatewayErrorResponseBody": ".aemp_equipment_get_aemp_equipment_list_bad_gateway_error_response_body",
    "AempEquipmentGetAempEquipmentListGatewayTimeoutErrorResponseBody": ".aemp_equipment_get_aemp_equipment_list_gateway_timeout_error_response_body",
    "AempEquipmentGetAempEquipmentListInternalServerErrorResponseBody": ".aemp_equipment_get_aemp_equipment_list_internal_server_error_response_body",
    "AempEquipmentGetAempEquipmentListMethodNotAllowedErrorResponseBody": ".aemp_equipment_get_aemp_equipment_list_method_not_allowed_error_response_body",
    "AempEquipmentGetAempEquipmentListNotFoundErrorResponseBody": ".aemp_equipment_get_aemp_equipment_list_not_found_error_response_body",
    "AempEquipmentGetAempEquipmentListNotImplementedErrorResponseBody": ".aemp_equipment_get_aemp_equipment_list_not_implemented_error_response_body",
    "AempEquipmentGetAempEquipmentListResponseBody": ".aemp_equipment_get_aemp_equipment_list_response_body",
    "AempEquipmentGetAempEquipmentListServiceUnavailableErrorResponseBody": ".aemp_equipment_get_aemp_equipment_list_service_unavailable_error_response_body",
    "AempEquipmentGetAempEquipmentListTooManyRequestsErrorResponseBody": ".aemp_equipment_get_aemp_equipment_list_too_many_requests_error_response_body",
    "AempEquipmentGetAempEquipmentListUnauthorizedErrorResponseBody": ".aemp_equipment_get_aemp_equipment_list_unauthorized_error_response_body",
    "AempEquipmentWithAdditionalFieldsResponseBody": ".aemp_equipment_with_additional_fields_response_body",
    "AempFleetListResponseBody": ".aemp_fleet_list_response_body",
    "AempLinkResponseBody": ".aemp_link_response_body",
    "AlertObjectAssetResponseBody": ".alert_object_asset_response_body",
    "AlertObjectAssetResponseBodyType": ".alert_object_asset_response_body_type",
    "AlertObjectDriverResponseBody": ".alert_object_driver_response_body",
    "AlertObjectMachineInputResponseBody": ".alert_object_machine_input_response_body",
    "AlertObjectOnvifCameraStreamResponseBody": ".alert_object_onvif_camera_stream_response_body",
    "AlertObjectProductResponseBody": ".alert_object_product_response_body",
    "AlertObjectSensorResponseBody": ".alert_object_sensor_response_body",
    "AlertObjectSitesResponseBody": ".alert_object_sites_response_body",
    "AlertObjectTrailerResponseBody": ".alert_object_trailer_response_body",
    "AlertObjectVehicleResponseBody": ".alert_object_vehicle_response_body",
    "AlertObjectWorkforceCameraDeviceResponseBody": ".alert_object_workforce_camera_device_response_body",
    "AlertsDeleteConfigurationsBadGatewayErrorResponseBody": ".alerts_delete_configurations_bad_gateway_error_response_body",
    "AlertsDeleteConfigurationsGatewayTimeoutErrorResponseBody": ".alerts_delete_configurations_gateway_timeout_error_response_body",
    "AlertsDeleteConfigurationsInternalServerErrorResponseBody": ".alerts_delete_configurations_internal_server_error_response_body",
    "AlertsDeleteConfigurationsMethodNotAllowedErrorResponseBody": ".alerts_delete_configurations_method_not_allowed_error_response_body",
    "AlertsDeleteConfigurationsNotFoundErrorResponseBody": ".alerts_delete_configurations_not_found_error_response_body",
    "AlertsDeleteConfigurationsNotImplementedErrorResponseBody": ".alerts_delete_configurations_not_implemented_error_response_body",
    "AlertsDeleteConfigurationsServiceUnavailableErrorResponseBody": ".alerts_delete_configurations_service_unavailable_error_response_body",
    "AlertsDeleteConfigurationsTooManyRequestsErrorResponseBody": ".alerts_delete_configurations_too_many_requests_error_response_body",
    "AlertsDeleteConfigurationsUnauthorizedErrorResponseBody": ".alerts_delete_configurations_unauthorized_error_response_body",
    "AlertsGetConfigurationsBadGatewayErrorResponseBody": ".alerts_get_configurations_bad_gateway_error_response_body",
    "AlertsGetConfigurationsGatewayTimeoutErrorResponseBody": ".alerts_get_configurations_gateway_timeout_error_response_body",
    "AlertsGetConfigurationsInternalServerErrorResponseBody": ".alerts_get_configurations_internal_server_error_response_body",
    "AlertsGetConfigurationsMethodNotAllowedErrorResponseBody": ".alerts_get_configurations_method_not_allowed_error_response_body",
    "AlertsGetConfigurationsNotFoundErrorResponseBody": ".alerts_get_configurations_not_found_error_response_body",
    "AlertsGetConfigurationsNotImplementedErrorResponseBody": ".alerts_get_configurations_not_implemented_error_response_body",
    "AlertsGetConfigurationsResponseBody": ".alerts_get_configurations_response_body",
    "AlertsGetConfigurationsServiceUnavailableErrorResponseBody": ".alerts_get_configurations_service_unavailable_error_response_body",
    "AlertsGetConfigurationsTooManyRequestsErrorResponseBody": ".alerts_get_configurations_too_many_requests_error_response_body",
    "AlertsGetConfigurationsUnauthorizedErrorResponseBody": ".alerts_get_configurations_unauthorized_error_response_body",
    "AlertsGetIncidentsBadGatewayErrorResponseBody": ".alerts_get_incidents_bad_gateway_error_response_body",
    "AlertsGetIncidentsGatewayTimeoutErrorResponseBody": ".alerts_get_incidents_gateway_timeout_error_response_body",
    "AlertsGetIncidentsInternalServerErrorResponseBody": ".alerts_get_incidents_internal_server_error_response_body",
    "AlertsGetIncidentsMethodNotAllowedErrorResponseBody": ".alerts_get_incidents_method_not_allowed_error_response_body",
    "AlertsGetIncidentsNotFoundErrorResponseBody": ".alerts_get_incidents_not_found_error_response_body",
    "AlertsGetIncidentsNotImplementedErrorResponseBody": ".alerts_get_incidents_not_implemented_error_response_body",
    "AlertsGetIncidentsResponseBody": ".alerts_get_incidents_response_body",
    "AlertsGetIncidentsServiceUnavailableErrorResponseBody": ".alerts_get_incidents_service_unavailable_error_response_body",
    "AlertsGetIncidentsTooManyRequestsErrorResponseBody": ".alerts_get_incidents_too_many_requests_error_response_body",
    "AlertsGetIncidentsUnauthorizedErrorResponseBody": ".alerts_get_incidents_unauthorized_error_response_body",
    "AlertsPatchConfigurationsBadGatewayErrorResponseBody": ".alerts_patch_configurations_bad_gateway_error_response_body",
    "AlertsPatchConfigurationsGatewayTimeoutErrorResponseBody": ".alerts_patch_configurations_gateway_timeout_error_response_body",
    "AlertsPatchConfigurationsInternalServerErrorResponseBody": ".alerts_patch_configurations_internal_server_error_response_body",
    "AlertsPatchConfigurationsMethodNotAllowedErrorResponseBody": ".alerts_patch_configurations_method_not_allowed_error_response_body",
    "AlertsPatchConfigurationsNotFoundErrorResponseBody": ".alerts_patch_configurations_not_found_error_response_body",
    "AlertsPatchConfigurationsNotImplementedErrorResponseBody": ".alerts_patch_configurations_not_implemented_error_response_body",
    "AlertsPatchConfigurationsResponseBody": ".alerts_patch_configurations_response_body",
    "AlertsPatchConfigurationsServiceUnavailableErrorResponseBody": ".alerts_patch_configurations_service_unavailable_error_response_body",
    "AlertsPatchConfigurationsTooManyRequestsErrorResponseBody": ".alerts_patch_configurations_too_many_requests_error_response_body",
    "AlertsPatchConfigurationsUnauthorizedErrorResponseBody": ".alerts_patch_configurations_unauthorized_error_response_body",
    "AlertsPostConfigurationsBadGatewayErrorResponseBody": ".alerts_post_configurations_bad_gateway_error_response_body",
    "AlertsPostConfigurationsGatewayTimeoutErrorResponseBody": ".alerts_post_configurations_gateway_timeout_error_response_body",
    "AlertsPostConfigurationsInternalServerErrorResponseBody": ".alerts_post_configurations_internal_server_error_response_body",
    "AlertsPostConfigurationsMethodNotAllowedErrorResponseBody": ".alerts_post_configurations_method_not_allowed_error_response_body",
    "AlertsPostConfigurationsNotFoundErrorResponseBody": ".alerts_post_configurations_not_found_error_response_body",
    "AlertsPostConfigurationsNotImplementedErrorResponseBody": ".alerts_post_configurations_not_implemented_error_response_body",
    "AlertsPostConfigurationsResponseBody": ".alerts_post_configurations_response_body",
    "AlertsPostConfigurationsServiceUnavailableErrorResponseBody": ".alerts_post_configurations_service_unavailable_error_response_body",
    "AlertsPostConfigurationsTooManyRequestsErrorResponseBody": ".alerts_post_configurations_too_many_requests_error_response_body",
    "AlertsPostConfigurationsUnauthorizedErrorResponseBody": ".alerts_post_configurations_unauthorized_error_response_body",
    "AmbientTemperatureDetailsObjectRequestBody": ".ambient_temperature_details_object_request_body",
    "AmbientTemperatureDetailsObjectRequestBodyOperation": ".ambient_temperature_details_object_request_body_operation",
    "AmbientTemperatureDetailsObjectResponseBody": ".ambient_temperature_details_object_response_body",
    "AmbientTemperatureDetailsObjectResponseBodyOperation": ".ambient_temperature_details_object_response_body_operation",
    "AmbientTemperatureResponseBody": ".ambient_temperature_response_body",
    "AnticipationBrakeEventCount": ".anticipation_brake_event_count",
    "AppointmentWindowRequestBody": ".appointment_window_request_body",
    "AppointmentWindowResponseBody": ".appointment_window_response_body",
    "AssetDataInput": ".asset_data_input",
    "AssetDataInputLastPoint": ".asset_data_input_last_point",
    "AssetDataOutput": ".asset_data_output",
    "AssetDataOutputsPatchAssetDataOutputsBadGatewayErrorResponseBody": ".asset_data_outputs_patch_asset_data_outputs_bad_gateway_error_response_body",
    "AssetDataOutputsPatchAssetDataOutputsGatewayTimeoutErrorResponseBody": ".asset_data_outputs_patch_asset_data_outputs_gateway_timeout_error_response_body",
    "AssetDataOutputsPatchAssetDataOutputsInternalServerErrorResponseBody": ".asset_data_outputs_patch_asset_data_outputs_internal_server_error_response_body",
    "AssetDataOutputsPatchAssetDataOutputsMethodNotAllowedErrorResponseBody": ".asset_data_outputs_patch_asset_data_outputs_method_not_allowed_error_response_body",
    "AssetDataOutputsPatchAssetDataOutputsNotFoundErrorResponseBody": ".asset_data_outputs_patch_asset_data_outputs_not_found_error_response_body",
    "AssetDataOutputsPatchAssetDataOutputsNotImplementedErrorResponseBody": ".asset_data_outputs_patch_asset_data_outputs_not_implemented_error_response_body",
    "AssetDataOutputsPatchAssetDataOutputsResponseBody": ".asset_data_outputs_patch_asset_data_outputs_response_body",
    "AssetDataOutputsPatchAssetDataOutputsServiceUnavailableErrorResponseBody": ".asset_data_outputs_patch_asset_data_outputs_service_unavailable_error_response_body",
    "AssetDataOutputsPatchAssetDataOutputsTooManyRequestsErrorResponseBody": ".asset_data_outputs_patch_asset_data_outputs_too_many_requests_error_response_body",
    "AssetDataOutputsPatchAssetDataOutputsUnauthorizedErrorResponseBody": ".asset_data_outputs_patch_asset_data_outputs_unauthorized_error_response_body",
    "AssetLocation": ".asset_location",
    "AssetLocationHeading": ".asset_location_heading",
    "AssetLocationSpeed": ".asset_location_speed",
    "AssetName": ".asset_name",
    "AssetResponse": ".asset_response",
    "AssetResponseBody": ".asset_response_body",
    "AssetResponseBodyRegulationMode": ".asset_response_body_regulation_mode",
    "AssetResponseBodyType": ".asset_response_body_type",
    "AssetResponseLocationDataInput": ".asset_response_location_data_input",
    "AssetResponseParentAsset": ".asset_response_parent_asset",
    "AssetResponseResponseBody": ".asset_response_response_body",
    "AssetResponseRunningStatusDataInput": ".asset_response_running_status_data_input",
    "AssetsCreateAssetBadGatewayErrorResponseBody": ".assets_create_asset_bad_gateway_error_response_body",
    "AssetsCreateAssetGatewayTimeoutErrorResponseBody": ".assets_create_asset_gateway_timeout_error_response_body",
    "AssetsCreateAssetInternalServerErrorResponseBody": ".assets_create_asset_internal_server_error_response_body",
    "AssetsCreateAssetMethodNotAllowedErrorResponseBody": ".assets_create_asset_method_not_allowed_error_response_body",
    "AssetsCreateAssetNotFoundErrorResponseBody": ".assets_create_asset_not_found_error_response_body",
    "AssetsCreateAssetNotImplementedErrorResponseBody": ".assets_create_asset_not_implemented_error_response_body",
    "AssetsCreateAssetResponseBody": ".assets_create_asset_response_body",
    "AssetsCreateAssetServiceUnavailableErrorResponseBody": ".assets_create_asset_service_unavailable_error_response_body",
    "AssetsCreateAssetTooManyRequestsErrorResponseBody": ".assets_create_asset_too_many_requests_error_response_body",
    "AssetsCreateAssetUnauthorizedErrorResponseBody": ".assets_create_asset_unauthorized_error_response_body",
    "AssetsDeleteAssetBadGatewayErrorResponseBody": ".assets_delete_asset_bad_gateway_error_response_body",
    "AssetsDeleteAssetGatewayTimeoutErrorResponseBody": ".assets_delete_asset_gateway_timeout_error_response_body",
    "AssetsDeleteAssetInternalServerErrorResponseBody": ".assets_delete_asset_internal_server_error_response_body",
    "AssetsDeleteAssetMethodNotAllowedErrorResponseBody": ".assets_delete_asset_method_not_allowed_error_response_body",
    "AssetsDeleteAssetNotFoundErrorResponseBody": ".assets_delete_asset_not_found_error_response_body",
    "AssetsDeleteAssetNotImplementedErrorResponseBody": ".assets_delete_asset_not_implemented_error_response_body",
    "AssetsDeleteAssetServiceUnavailableErrorResponseBody": ".assets_delete_asset_service_unavailable_error_response_body",
    "AssetsDeleteAssetTooManyRequestsErrorResponseBody": ".assets_delete_asset_too_many_requests_error_response_body",
    "AssetsDeleteAssetUnauthorizedErrorResponseBody": ".assets_delete_asset_unauthorized_error_response_body",
    "AssetsInputsAssetResponseResponseBody": ".assets_inputs_asset_response_response_body",
    "AssetsInputsAuxInputResponseBody": ".assets_inputs_aux_input_response_body",
    "AssetsInputsGetAssetsInputsBadGatewayErrorResponseBody": ".assets_inputs_get_assets_inputs_bad_gateway_error_response_body",
    "AssetsInputsGetAssetsInputsGatewayTimeoutErrorResponseBody": ".assets_inputs_get_assets_inputs_gateway_timeout_error_response_body",
    "AssetsInputsGetAssetsInputsInternalServerErrorResponseBody": ".assets_inputs_get_assets_inputs_internal_server_error_response_body",
    "AssetsInputsGetAssetsInputsMethodNotAllowedErrorResponseBody": ".assets_inputs_get_assets_inputs_method_not_allowed_error_response_body",
    "AssetsInputsGetAssetsInputsNotFoundErrorResponseBody": ".assets_inputs_get_assets_inputs_not_found_error_response_body",
    "AssetsInputsGetAssetsInputsNotImplementedErrorResponseBody": ".assets_inputs_get_assets_inputs_not_implemented_error_response_body",
    "AssetsInputsGetAssetsInputsResponseBody": ".assets_inputs_get_assets_inputs_response_body",
    "AssetsInputsGetAssetsInputsServiceUnavailableErrorResponseBody": ".assets_inputs_get_assets_inputs_service_unavailable_error_response_body",
    "AssetsInputsGetAssetsInputsTooManyRequestsErrorResponseBody": ".assets_inputs_get_assets_inputs_too_many_requests_error_response_body",
    "AssetsInputsGetAssetsInputsUnauthorizedErrorResponseBody": ".assets_inputs_get_assets_inputs_unauthorized_error_response_body",
    "AssetsInputsResponseResponseBody": ".assets_inputs_response_response_body",
    "AssetsInputsResponseResponseBodyUnits": ".assets_inputs_response_response_body_units",
    "AssetsListAssetsBadGatewayErrorResponseBody": ".assets_list_assets_bad_gateway_error_response_body",
    "AssetsListAssetsGatewayTimeoutErrorResponseBody": ".assets_list_assets_gateway_timeout_error_response_body",
    "AssetsListAssetsInternalServerErrorResponseBody": ".assets_list_assets_internal_server_error_response_body",
    "AssetsListAssetsMethodNotAllowedErrorResponseBody": ".assets_list_assets_method_not_allowed_error_response_body",
    "AssetsListAssetsNotFoundErrorResponseBody": ".assets_list_assets_not_found_error_response_body",
    "AssetsListAssetsNotImplementedErrorResponseBody": ".assets_list_assets_not_implemented_error_response_body",
    "AssetsListAssetsResponseBody": ".assets_list_assets_response_body",
    "AssetsListAssetsServiceUnavailableErrorResponseBody": ".assets_list_assets_service_unavailable_error_response_body",
    "AssetsListAssetsTooManyRequestsErrorResponseBody": ".assets_list_assets_too_many_requests_error_response_body",
    "AssetsListAssetsUnauthorizedErrorResponseBody": ".assets_list_assets_unauthorized_error_response_body",
    "AssetsLocationLinkConfigAddressDetailsObject": ".assets_location_link_config_address_details_object",
    "AssetsLocationLinkConfigAddressDetailsObjectResponseBody": ".assets_location_link_config_address_details_object_response_body",
    "AssetsLocationLinkRequestConfigObject": ".assets_location_link_request_config_object",
    "AssetsLocationLinkResponseConfigObjectResponseBody": ".assets_location_link_response_config_object_response_body",
    "AssetsNearLocationLinkConfigObject": ".assets_near_location_link_config_object",
    "AssetsNearLocationLinkConfigObjectResponseBody": ".assets_near_location_link_config_object_response_body",
    "AssetsOnRouteLinkConfigObject": ".assets_on_route_link_config_object",
    "AssetsOnRouteLinkConfigObjectResponseBody": ".assets_on_route_link_config_object_response_body",
    "AssetsUpdateAssetBadGatewayErrorResponseBody": ".assets_update_asset_bad_gateway_error_response_body",
    "AssetsUpdateAssetGatewayTimeoutErrorResponseBody": ".assets_update_asset_gateway_timeout_error_response_body",
    "AssetsUpdateAssetInternalServerErrorResponseBody": ".assets_update_asset_internal_server_error_response_body",
    "AssetsUpdateAssetMethodNotAllowedErrorResponseBody": ".assets_update_asset_method_not_allowed_error_response_body",
    "AssetsUpdateAssetNotFoundErrorResponseBody": ".assets_update_asset_not_found_error_response_body",
    "AssetsUpdateAssetNotImplementedErrorResponseBody": ".assets_update_asset_not_implemented_error_response_body",
    "AssetsUpdateAssetResponseBody": ".assets_update_asset_response_body",
    "AssetsUpdateAssetServiceUnavailableErrorResponseBody": ".assets_update_asset_service_unavailable_error_response_body",
    "AssetsUpdateAssetTooManyRequestsErrorResponseBody": ".assets_update_asset_too_many_requests_error_response_body",
    "AssetsUpdateAssetUnauthorizedErrorResponseBody": ".assets_update_asset_unauthorized_error_response_body",
    "Attribute": ".attribute",
    "AttributeAttributeType": ".attribute_attribute_type",
    "AttributeEntity": ".attribute_entity",
    "AttributeEntityExternalIds": ".attribute_entity_external_ids",
    "AttributeEntityType": ".attribute_entity_type",
    "AttributeExpanded": ".attribute_expanded",
    "AttributeExpandedAllOf": ".attribute_expanded_all_of",
    "AttributeExpandedResponse": ".attribute_expanded_response",
    "AttributeTiny": ".attribute_tiny",
    "AttributeUnit": ".attribute_unit",
    "AttributeValueTiny": ".attribute_value_tiny",
    "AuthTokenAuthTokenBadGatewayErrorResponseBody": ".auth_token_auth_token_bad_gateway_error_response_body",
    "AuthTokenAuthTokenGatewayTimeoutErrorResponseBody": ".auth_token_auth_token_gateway_timeout_error_response_body",
    "AuthTokenAuthTokenInternalServerErrorResponseBody": ".auth_token_auth_token_internal_server_error_response_body",
    "AuthTokenAuthTokenMethodNotAllowedErrorResponseBody": ".auth_token_auth_token_method_not_allowed_error_response_body",
    "AuthTokenAuthTokenNotFoundErrorResponseBody": ".auth_token_auth_token_not_found_error_response_body",
    "AuthTokenAuthTokenNotImplementedErrorResponseBody": ".auth_token_auth_token_not_implemented_error_response_body",
    "AuthTokenAuthTokenResponseBody": ".auth_token_auth_token_response_body",
    "AuthTokenAuthTokenServiceUnavailableErrorResponseBody": ".auth_token_auth_token_service_unavailable_error_response_body",
    "AuthTokenAuthTokenTooManyRequestsErrorResponseBody": ".auth_token_auth_token_too_many_requests_error_response_body",
    "AuthTokenAuthTokenUnauthorizedErrorResponseBody": ".auth_token_auth_token_unauthorized_error_response_body",
    "AuthTokenForDriverResponseResponseBody": ".auth_token_for_driver_response_response_body",
    "AuthorSignatureObjectResponseBody": ".author_signature_object_response_body",
    "AuthorSignatureObjectResponseBodyType": ".author_signature_object_response_body_type",
    "BarcodeValueObjectRequestBody": ".barcode_value_object_request_body",
    "BarcodeValueObjectResponseBody": ".barcode_value_object_response_body",
    "BaseRouteResponseObjectResponseBody": ".base_route_response_object_response_body",
    "BehaviorCountDetailsRequestBody": ".behavior_count_details_request_body",
    "BehaviorCountDetailsRequestBodyComparison": ".behavior_count_details_request_body_comparison",
    "BehaviorCountDetailsResponseBody": ".behavior_count_details_response_body",
    "BehaviorCountDetailsResponseBodyComparison": ".behavior_count_details_response_body_comparison",
    "BehaviorResponseBody": ".behavior_response_body",
    "BehaviorResponseBodyCoachableBehaviorType": ".behavior_response_body_coachable_behavior_type",
    "CameraConnectorDisconectedResponseBody": ".camera_connector_disconected_response_body",
    "CameraDetailsResponseResponseBody": ".camera_details_response_response_body",
    "CameraSerial": ".camera_serial",
    "CameraStreamIssueResponseBody": ".camera_stream_issue_response_body",
    "CarrierProposedAssignment": ".carrier_proposed_assignment",
    "CarrierProposedAssignmentAcceptedTime": ".carrier_proposed_assignment_accepted_time",
    "CarrierProposedAssignmentActiveTime": ".carrier_proposed_assignment_active_time",
    "CarrierProposedAssignmentDriver": ".carrier_proposed_assignment_driver",
    "CarrierProposedAssignmentDriverAllOf": ".carrier_proposed_assignment_driver_all_of",
    "CarrierProposedAssignmentDriverAllOf2ExternalIds": ".carrier_proposed_assignment_driver_all_of_2_external_ids",
    "CarrierProposedAssignmentFirstSeenTime": ".carrier_proposed_assignment_first_seen_time",
    "CarrierProposedAssignmentId": ".carrier_proposed_assignment_id",
    "CarrierProposedAssignmentRejectedTime": ".carrier_proposed_assignment_rejected_time",
    "CarrierProposedAssignmentResponse": ".carrier_proposed_assignment_response",
    "CarrierProposedAssignmentShippingDocs": ".carrier_proposed_assignment_shipping_docs",
    "CarrierProposedAssignmentTrailer": ".carrier_proposed_assignment_trailer",
    "CarrierProposedAssignmentTrailers": ".carrier_proposed_assignment_trailers",
    "CarrierProposedAssignmentVehicle": ".carrier_proposed_assignment_vehicle",
    "CellConnectivityResponseResponseBody": ".cell_connectivity_response_response_body",
    "CellConnectivityResponseResponseBodySignalBar": ".cell_connectivity_response_response_body_signal_bar",
    "CellSignalLossDetailsObjectRequestBody": ".cell_signal_loss_details_object_request_body",
    "CellSignalLossDetailsObjectResponseBody": ".cell_signal_loss_details_object_response_body",
    "CellSignalLossResponseBody": ".cell_signal_loss_response_body",
    "CircleRequestBody": ".circle_request_body",
    "CircleResponseBody": ".circle_response_body",
    "CloudBackupUploadIssueResponseBody": ".cloud_backup_upload_issue_response_body",
    "CoachAssignmentWithDriverExternalIdsResponseResponseBody": ".coach_assignment_with_driver_external_ids_response_response_body",
    "CoachAssignmentWithoutDriverExternalIdsResponseResponseBody": ".coach_assignment_without_driver_external_ids_response_response_body",
    "CoachableEventResponseBody": ".coachable_event_response_body",
    "CoachingSessionsGetCoachingSessionsBadGatewayErrorResponseBody": ".coaching_sessions_get_coaching_sessions_bad_gateway_error_response_body",
    "CoachingSessionsGetCoachingSessionsGatewayTimeoutErrorResponseBody": ".coaching_sessions_get_coaching_sessions_gateway_timeout_error_response_body",
    "CoachingSessionsGetCoachingSessionsInternalServerErrorResponseBody": ".coaching_sessions_get_coaching_sessions_internal_server_error_response_body",
    "CoachingSessionsGetCoachingSessionsMethodNotAllowedErrorResponseBody": ".coaching_sessions_get_coaching_sessions_method_not_allowed_error_response_body",
    "CoachingSessionsGetCoachingSessionsNotFoundErrorResponseBody": ".coaching_sessions_get_coaching_sessions_not_found_error_response_body",
    "CoachingSessionsGetCoachingSessionsNotImplementedErrorResponseBody": ".coaching_sessions_get_coaching_sessions_not_implemented_error_response_body",
    "CoachingSessionsGetCoachingSessionsResponseBody": ".coaching_sessions_get_coaching_sessions_response_body",
    "CoachingSessionsGetCoachingSessionsServiceUnavailableErrorResponseBody": ".coaching_sessions_get_coaching_sessions_service_unavailable_error_response_body",
    "CoachingSessionsGetCoachingSessionsTooManyRequestsErrorResponseBody": ".coaching_sessions_get_coaching_sessions_too_many_requests_error_response_body",
    "CoachingSessionsGetCoachingSessionsUnauthorizedErrorResponseBody": ".coaching_sessions_get_coaching_sessions_unauthorized_error_response_body",
    "CoachingSessionsResponseResponseBody": ".coaching_sessions_response_response_body",
    "CoachingSessionsResponseResponseBodyCoachingType": ".coaching_sessions_response_response_body_coaching_type",
    "CoachingSessionsResponseResponseBodySessionStatus": ".coaching_sessions_response_response_body_session_status",
    "CoastingDurationMs": ".coasting_duration_ms",
    "ColumnResponseBody": ".column_response_body",
    "ColumnResponseBodyDataType": ".column_response_body_data_type",
    "ColumnResponseBodyUnit": ".column_response_body_unit",
    "ConditionalFieldSectionObjectResponseBody": ".conditional_field_section_object_response_body",
    "ConnectionStatusResponseObjectResponseBody": ".connection_status_response_object_response_body",
    "ConnectionStatusResponseObjectResponseBodyHealthStatus": ".connection_status_response_object_response_body_health_status",
    "Contact": ".contact",
    "ContactEmail": ".contact_email",
    "ContactFirstName": ".contact_first_name",
    "ContactId": ".contact_id",
    "ContactLastName": ".contact_last_name",
    "ContactPhone": ".contact_phone",
    "ContactResponse": ".contact_response",
    "ContactTinyResponse": ".contact_tiny_response",
    "ContinuousReadingAlertThresholdResponseBody": ".continuous_reading_alert_threshold_response_body",
    "ContinuousReadingAlertThresholdResponseBodyOperation": ".continuous_reading_alert_threshold_response_body_operation",
    "ContinuousReadingAlertThresholdResponseBodyUnit": ".continuous_reading_alert_threshold_response_body_unit",
    "CreateAddressRequestGeofence": ".create_address_request_geofence",
    "CreateAddressRequestGeofenceSettings": ".create_address_request_geofence_settings",
    "CreateAttributeRequestEntities": ".create_attribute_request_entities",
    "CreateDriverAuthTokenResponseResponseBody": ".create_driver_auth_token_response_response_body",
    "CreateDriverRequestAttributes": ".create_driver_request_attributes",
    "CreateReportConfigColumnRequestBody": ".create_report_config_column_request_body",
    "CreateReportConfigObjectRequestBody": ".create_report_config_object_request_body",
    "CreateRoutesStopRequestObjectRequestBody": ".create_routes_stop_request_object_request_body",
    "CreateUserRequestRoles": ".create_user_request_roles",
    "CruiseControlDurationMs": ".cruise_control_duration_ms",
    "CumulativeOperatingHoursResponseBody": ".cumulative_operating_hours_response_body",
    "CurrentDutyStatus": ".current_duty_status",
    "CurrentDutyStatusHosStatusType": ".current_duty_status_hos_status_type",
    "CustomHeadersObjectRequestBody": ".custom_headers_object_request_body",
    "CustomHeadersObjectResponseBody": ".custom_headers_object_response_body",
    "CustomMetadata": ".custom_metadata",
    "DashcamDisconnectedResponseBody": ".dashcam_disconnected_response_body",
    "DataInputListResponse": ".data_input_list_response",
    "DataInputResponse": ".data_input_response",
    "DataInputResponseAllOf": ".data_input_response_all_of",
    "DataInputSnapshot": ".data_input_snapshot",
    "DataInputSnapshotAllOf": ".data_input_snapshot_all_of",
    "DataInputSnapshotResponse": ".data_input_snapshot_response",
    "DataInputTinyResponse": ".data_input_tiny_response",
    "DataInputValueResponseBody": ".data_input_value_response_body",
    "DataInputsTinyResponse": ".data_inputs_tiny_response",
    "DataUsageResponseObjectResponseBody": ".data_usage_response_object_response_body",
    "DateTimeValueObjectRequestBody": ".date_time_value_object_request_body",
    "DateTimeValueObjectResponseBody": ".date_time_value_object_response_body",
    "DefLevelTriggerDetailsObjectRequestBody": ".def_level_trigger_details_object_request_body",
    "DefLevelTriggerDetailsObjectRequestBodyOperation": ".def_level_trigger_details_object_request_body_operation",
    "DefLevelTriggerDetailsObjectResponseBody": ".def_level_trigger_details_object_response_body",
    "DefLevelTriggerDetailsObjectResponseBodyOperation": ".def_level_trigger_details_object_response_body_operation",
    "DefRemainingResponseBody": ".def_remaining_response_body",
    "Defect": ".defect",
    "DefectPhotoResponseResponseBody": ".defect_photo_response_response_body",
    "DefectResolvedBy": ".defect_resolved_by",
    "DefectResolvedByType": ".defect_resolved_by_type",
    "DefectResponse": ".defect_response",
    "DefectTrailer": ".defect_trailer",
    "DefectTrailerResponseResponseBody": ".defect_trailer_response_response_body",
    "DefectTypesResponseDataResponseBody": ".defect_types_response_data_response_body",
    "DefectTypesResponseDataResponseBodySectionType": ".defect_types_response_data_response_body_section_type",
    "DefectVehicle": ".defect_vehicle",
    "DefectVehicleResponseResponseBody": ".defect_vehicle_response_response_body",
    "DefectsResponse": ".defects_response",
    "DefectsResponseDataResponseBody": ".defects_response_data_response_body",
    "DepreciationGetDepreciationTransactionsBadGatewayErrorResponseBody": ".depreciation_get_depreciation_transactions_bad_gateway_error_response_body",
    "DepreciationGetDepreciationTransactionsGatewayTimeoutErrorResponseBody": ".depreciation_get_depreciation_transactions_gateway_timeout_error_response_body",
    "DepreciationGetDepreciationTransactionsInternalServerErrorResponseBody": ".depreciation_get_depreciation_transactions_internal_server_error_response_body",
    "DepreciationGetDepreciationTransactionsMethodNotAllowedErrorResponseBody": ".depreciation_get_depreciation_transactions_method_not_allowed_error_response_body",
    "DepreciationGetDepreciationTransactionsNotFoundErrorResponseBody": ".depreciation_get_depreciation_transactions_not_found_error_response_body",
    "DepreciationGetDepreciationTransactionsNotImplementedErrorResponseBody": ".depreciation_get_depreciation_transactions_not_implemented_error_response_body",
    "DepreciationGetDepreciationTransactionsResponseBody": ".depreciation_get_depreciation_transactions_response_body",
    "DepreciationGetDepreciationTransactionsServiceUnavailableErrorResponseBody": ".depreciation_get_depreciation_transactions_service_unavailable_error_response_body",
    "DepreciationGetDepreciationTransactionsTooManyRequestsErrorResponseBody": ".depreciation_get_depreciation_transactions_too_many_requests_error_response_body",
    "DepreciationGetDepreciationTransactionsUnauthorizedErrorResponseBody": ".depreciation_get_depreciation_transactions_unauthorized_error_response_body",
    "DepreciationTransactionMoneyObjectResponseBody": ".depreciation_transaction_money_object_response_body",
    "DepreciationTransactionMoneyObjectResponseBodyCurrency": ".depreciation_transaction_money_object_response_body_currency",
    "DepreciationTransactionObjectResponseBody": ".depreciation_transaction_object_response_body",
    "DepreciationTransactionObjectResponseBodyTransactionType": ".depreciation_transaction_object_response_body_transaction_type",
    "DetectionLogAssetObjectResponseBody": ".detection_log_asset_object_response_body",
    "DetectionLogDetectionObjectResponseBody": ".detection_log_detection_object_response_body",
    "DetectionLogDetectionObjectResponseBodyTriggerDetectionLabel": ".detection_log_detection_object_response_body_trigger_detection_label",
    "DetectionLogDriverObjectResponseBody": ".detection_log_driver_object_response_body",
    "DetectionLogGetDetectionsBadGatewayErrorResponseBody": ".detection_log_get_detections_bad_gateway_error_response_body",
    "DetectionLogGetDetectionsGatewayTimeoutErrorResponseBody": ".detection_log_get_detections_gateway_timeout_error_response_body",
    "DetectionLogGetDetectionsInternalServerErrorResponseBody": ".detection_log_get_detections_internal_server_error_response_body",
    "DetectionLogGetDetectionsMethodNotAllowedErrorResponseBody": ".detection_log_get_detections_method_not_allowed_error_response_body",
    "DetectionLogGetDetectionsNotFoundErrorResponseBody": ".detection_log_get_detections_not_found_error_response_body",
    "DetectionLogGetDetectionsNotImplementedErrorResponseBody": ".detection_log_get_detections_not_implemented_error_response_body",
    "DetectionLogGetDetectionsResponseBody": ".detection_log_get_detections_response_body",
    "DetectionLogGetDetectionsServiceUnavailableErrorResponseBody": ".detection_log_get_detections_service_unavailable_error_response_body",
    "DetectionLogGetDetectionsTooManyRequestsErrorResponseBody": ".detection_log_get_detections_too_many_requests_error_response_body",
    "DetectionLogGetDetectionsUnauthorizedErrorResponseBody": ".detection_log_get_detections_unauthorized_error_response_body",
    "DetectionLogSafetyEventObjectResponseBody": ".detection_log_safety_event_object_response_body",
    "DetectionLogSafetyEventObjectResponseBodyInboxFilterReason": ".detection_log_safety_event_object_response_body_inbox_filter_reason",
    "DeviceAssetResponseResponseBody": ".device_asset_response_response_body",
    "DeviceMovementDataResponseBody": ".device_movement_data_response_body",
    "DeviceMovementStoppedDataResponseBody": ".device_movement_stopped_data_response_body",
    "DeviceMovementTriggerDetailsObjectRequestBody": ".device_movement_trigger_details_object_request_body",
    "DeviceMovementTriggerDetailsObjectResponseBody": ".device_movement_trigger_details_object_response_body",
    "DeviceResponseResponseBody": ".device_response_response_body",
    "DeviceResponseResponseBodyModel": ".device_response_response_body_model",
    "DevicesGetDevicesBadGatewayErrorResponseBody": ".devices_get_devices_bad_gateway_error_response_body",
    "DevicesGetDevicesGatewayTimeoutErrorResponseBody": ".devices_get_devices_gateway_timeout_error_response_body",
    "DevicesGetDevicesInternalServerErrorResponseBody": ".devices_get_devices_internal_server_error_response_body",
    "DevicesGetDevicesMethodNotAllowedErrorResponseBody": ".devices_get_devices_method_not_allowed_error_response_body",
    "DevicesGetDevicesNotFoundErrorResponseBody": ".devices_get_devices_not_found_error_response_body",
    "DevicesGetDevicesNotImplementedErrorResponseBody": ".devices_get_devices_not_implemented_error_response_body",
    "DevicesGetDevicesResponseBody": ".devices_get_devices_response_body",
    "DevicesGetDevicesServiceUnavailableErrorResponseBody": ".devices_get_devices_service_unavailable_error_response_body",
    "DevicesGetDevicesTooManyRequestsErrorResponseBody": ".devices_get_devices_too_many_requests_error_response_body",
    "DevicesGetDevicesUnauthorizedErrorResponseBody": ".devices_get_devices_unauthorized_error_response_body",
    "DistanceDrivenMeters": ".distance_driven_meters",
    "DistanceResponseBody": ".distance_response_body",
    "DistanceTraveledObjectResponseBody": ".distance_traveled_object_response_body",
    "DistractedDrivingDetectionAlertSettingsObjectResponseBody": ".distracted_driving_detection_alert_settings_object_response_body",
    "DocumentPdfGenerationResponse": ".document_pdf_generation_response",
    "DocumentPdfGenerationResponseData": ".document_pdf_generation_response_data",
    "DocumentPdfQueryResponse": ".document_pdf_query_response",
    "DocumentPdfQueryResponseData": ".document_pdf_query_response_data",
    "DocumentPdfQueryResponseDataJobStatus": ".document_pdf_query_response_data_job_status",
    "DocumentResponseObjectResponseBody": ".document_response_object_response_body",
    "DocumentResponseObjectResponseBodyState": ".document_response_object_response_body_state",
    "DocumentTypesGetDocumentTypesBadGatewayErrorResponseBody": ".document_types_get_document_types_bad_gateway_error_response_body",
    "DocumentTypesGetDocumentTypesGatewayTimeoutErrorResponseBody": ".document_types_get_document_types_gateway_timeout_error_response_body",
    "DocumentTypesGetDocumentTypesInternalServerErrorResponseBody": ".document_types_get_document_types_internal_server_error_response_body",
    "DocumentTypesGetDocumentTypesMethodNotAllowedErrorResponseBody": ".document_types_get_document_types_method_not_allowed_error_response_body",
    "DocumentTypesGetDocumentTypesNotFoundErrorResponseBody": ".document_types_get_document_types_not_found_error_response_body",
    "DocumentTypesGetDocumentTypesNotImplementedErrorResponseBody": ".document_types_get_document_types_not_implemented_error_response_body",
    "DocumentTypesGetDocumentTypesResponseBody": ".document_types_get_document_types_response_body",
    "DocumentTypesGetDocumentTypesServiceUnavailableErrorResponseBody": ".document_types_get_document_types_service_unavailable_error_response_body",
    "DocumentTypesGetDocumentTypesTooManyRequestsErrorResponseBody": ".document_types_get_document_types_too_many_requests_error_response_body",
    "DocumentTypesGetDocumentTypesUnauthorizedErrorResponseBody": ".document_types_get_document_types_unauthorized_error_response_body",
    "DocumentsDeleteDocumentBadGatewayErrorResponseBody": ".documents_delete_document_bad_gateway_error_response_body",
    "DocumentsDeleteDocumentGatewayTimeoutErrorResponseBody": ".documents_delete_document_gateway_timeout_error_response_body",
    "DocumentsDeleteDocumentInternalServerErrorResponseBody": ".documents_delete_document_internal_server_error_response_body",
    "DocumentsDeleteDocumentMethodNotAllowedErrorResponseBody": ".documents_delete_document_method_not_allowed_error_response_body",
    "DocumentsDeleteDocumentNotFoundErrorResponseBody": ".documents_delete_document_not_found_error_response_body",
    "DocumentsDeleteDocumentNotImplementedErrorResponseBody": ".documents_delete_document_not_implemented_error_response_body",
    "DocumentsDeleteDocumentServiceUnavailableErrorResponseBody": ".documents_delete_document_service_unavailable_error_response_body",
    "DocumentsDeleteDocumentTooManyRequestsErrorResponseBody": ".documents_delete_document_too_many_requests_error_response_body",
    "DocumentsDeleteDocumentUnauthorizedErrorResponseBody": ".documents_delete_document_unauthorized_error_response_body",
    "DocumentsGetDocumentBadGatewayErrorResponseBody": ".documents_get_document_bad_gateway_error_response_body",
    "DocumentsGetDocumentGatewayTimeoutErrorResponseBody": ".documents_get_document_gateway_timeout_error_response_body",
    "DocumentsGetDocumentInternalServerErrorResponseBody": ".documents_get_document_internal_server_error_response_body",
    "DocumentsGetDocumentMethodNotAllowedErrorResponseBody": ".documents_get_document_method_not_allowed_error_response_body",
    "DocumentsGetDocumentNotFoundErrorResponseBody": ".documents_get_document_not_found_error_response_body",
    "DocumentsGetDocumentNotImplementedErrorResponseBody": ".documents_get_document_not_implemented_error_response_body",
    "DocumentsGetDocumentResponseBody": ".documents_get_document_response_body",
    "DocumentsGetDocumentServiceUnavailableErrorResponseBody": ".documents_get_document_service_unavailable_error_response_body",
    "DocumentsGetDocumentTooManyRequestsErrorResponseBody": ".documents_get_document_too_many_requests_error_response_body",
    "DocumentsGetDocumentUnauthorizedErrorResponseBody": ".documents_get_document_unauthorized_error_response_body",
    "DocumentsGetDocumentsBadGatewayErrorResponseBody": ".documents_get_documents_bad_gateway_error_response_body",
    "DocumentsGetDocumentsGatewayTimeoutErrorResponseBody": ".documents_get_documents_gateway_timeout_error_response_body",
    "DocumentsGetDocumentsInternalServerErrorResponseBody": ".documents_get_documents_internal_server_error_response_body",
    "DocumentsGetDocumentsMethodNotAllowedErrorResponseBody": ".documents_get_documents_method_not_allowed_error_response_body",
    "DocumentsGetDocumentsNotFoundErrorResponseBody": ".documents_get_documents_not_found_error_response_body",
    "DocumentsGetDocumentsNotImplementedErrorResponseBody": ".documents_get_documents_not_implemented_error_response_body",
    "DocumentsGetDocumentsResponseBody": ".documents_get_documents_response_body",
    "DocumentsGetDocumentsServiceUnavailableErrorResponseBody": ".documents_get_documents_service_unavailable_error_response_body",
    "DocumentsGetDocumentsTooManyRequestsErrorResponseBody": ".documents_get_documents_too_many_requests_error_response_body",
    "DocumentsGetDocumentsUnauthorizedErrorResponseBody": ".documents_get_documents_unauthorized_error_response_body",
    "DocumentsPostDocumentBadGatewayErrorResponseBody": ".documents_post_document_bad_gateway_error_response_body",
    "DocumentsPostDocumentGatewayTimeoutErrorResponseBody": ".documents_post_document_gateway_timeout_error_response_body",
    "DocumentsPostDocumentInternalServerErrorResponseBody": ".documents_post_document_internal_server_error_response_body",
    "DocumentsPostDocumentMethodNotAllowedErrorResponseBody": ".documents_post_document_method_not_allowed_error_response_body",
    "DocumentsPostDocumentNotFoundErrorResponseBody": ".documents_post_document_not_found_error_response_body",
    "DocumentsPostDocumentNotImplementedErrorResponseBody": ".documents_post_document_not_implemented_error_response_body",
    "DocumentsPostDocumentResponseBody": ".documents_post_document_response_body",
    "DocumentsPostDocumentServiceUnavailableErrorResponseBody": ".documents_post_document_service_unavailable_error_response_body",
    "DocumentsPostDocumentTooManyRequestsErrorResponseBody": ".documents_post_document_too_many_requests_error_response_body",
    "DocumentsPostDocumentUnauthorizedErrorResponseBody": ".documents_post_document_unauthorized_error_response_body",
    "DoorOpenResponseBody": ".door_open_response_body",
    "DriveTimeDurationMs": ".drive_time_duration_ms",
    "Driver": ".driver",
    "DriverActivationStatus": ".driver_activation_status",
    "DriverAppNotificationObjectRequestBody": ".driver_app_notification_object_request_body",
    "DriverAppNotificationObjectResponseBody": ".driver_app_notification_object_response_body",
    "DriverAppSettingsGamificationConfigTinyObjectRequestBody": ".driver_app_settings_gamification_config_tiny_object_request_body",
    "DriverAppSettingsGamificationConfigTinyObjectResponseBody": ".driver_app_settings_gamification_config_tiny_object_response_body",
    "DriverAppSettingsResponseObjectResponseBody": ".driver_app_settings_response_object_response_body",
    "DriverAppSettingsTrailerSelectionConfigTinyObjectRequestBody": ".driver_app_settings_trailer_selection_config_tiny_object_request_body",
    "DriverAppSettingsTrailerSelectionConfigTinyObjectResponseBody": ".driver_app_settings_trailer_selection_config_tiny_object_response_body",
    "DriverAppSignInResponseBody": ".driver_app_sign_in_response_body",
    "DriverAppSignOutResponseBody": ".driver_app_sign_out_response_body",
    "DriverAssignmentMetadataTinyObjectResponseBody": ".driver_assignment_metadata_tiny_object_response_body",
    "DriverAssignmentObjectResponseBody": ".driver_assignment_object_response_body",
    "DriverAssignmentObjectResponseBodyAssignmentType": ".driver_assignment_object_response_body_assignment_type",
    "DriverCarrierSettings": ".driver_carrier_settings",
    "DriverCoachAssignmentsGetDriverCoachAssignmentBadGatewayErrorResponseBody": ".driver_coach_assignments_get_driver_coach_assignment_bad_gateway_error_response_body",
    "DriverCoachAssignmentsGetDriverCoachAssignmentGatewayTimeoutErrorResponseBody": ".driver_coach_assignments_get_driver_coach_assignment_gateway_timeout_error_response_body",
    "DriverCoachAssignmentsGetDriverCoachAssignmentInternalServerErrorResponseBody": ".driver_coach_assignments_get_driver_coach_assignment_internal_server_error_response_body",
    "DriverCoachAssignmentsGetDriverCoachAssignmentMethodNotAllowedErrorResponseBody": ".driver_coach_assignments_get_driver_coach_assignment_method_not_allowed_error_response_body",
    "DriverCoachAssignmentsGetDriverCoachAssignmentNotFoundErrorResponseBody": ".driver_coach_assignments_get_driver_coach_assignment_not_found_error_response_body",
    "DriverCoachAssignmentsGetDriverCoachAssignmentNotImplementedErrorResponseBody": ".driver_coach_assignments_get_driver_coach_assignment_not_implemented_error_response_body",
    "DriverCoachAssignmentsGetDriverCoachAssignmentResponseBody": ".driver_coach_assignments_get_driver_coach_assignment_response_body",
    "DriverCoachAssignmentsGetDriverCoachAssignmentServiceUnavailableErrorResponseBody": ".driver_coach_assignments_get_driver_coach_assignment_service_unavailable_error_response_body",
    "DriverCoachAssignmentsGetDriverCoachAssignmentTooManyRequestsErrorResponseBody": ".driver_coach_assignments_get_driver_coach_assignment_too_many_requests_error_response_body",
    "DriverCoachAssignmentsGetDriverCoachAssignmentUnauthorizedErrorResponseBody": ".driver_coach_assignments_get_driver_coach_assignment_unauthorized_error_response_body",
    "DriverCoachAssignmentsPutDriverCoachAssignmentBadGatewayErrorResponseBody": ".driver_coach_assignments_put_driver_coach_assignment_bad_gateway_error_response_body",
    "DriverCoachAssignmentsPutDriverCoachAssignmentGatewayTimeoutErrorResponseBody": ".driver_coach_assignments_put_driver_coach_assignment_gateway_timeout_error_response_body",
    "DriverCoachAssignmentsPutDriverCoachAssignmentInternalServerErrorResponseBody": ".driver_coach_assignments_put_driver_coach_assignment_internal_server_error_response_body",
    "DriverCoachAssignmentsPutDriverCoachAssignmentMethodNotAllowedErrorResponseBody": ".driver_coach_assignments_put_driver_coach_assignment_method_not_allowed_error_response_body",
    "DriverCoachAssignmentsPutDriverCoachAssignmentNotFoundErrorResponseBody": ".driver_coach_assignments_put_driver_coach_assignment_not_found_error_response_body",
    "DriverCoachAssignmentsPutDriverCoachAssignmentNotImplementedErrorResponseBody": ".driver_coach_assignments_put_driver_coach_assignment_not_implemented_error_response_body",
    "DriverCoachAssignmentsPutDriverCoachAssignmentResponseBody": ".driver_coach_assignments_put_driver_coach_assignment_response_body",
    "DriverCoachAssignmentsPutDriverCoachAssignmentServiceUnavailableErrorResponseBody": ".driver_coach_assignments_put_driver_coach_assignment_service_unavailable_error_response_body",
    "DriverCoachAssignmentsPutDriverCoachAssignmentTooManyRequestsErrorResponseBody": ".driver_coach_assignments_put_driver_coach_assignment_too_many_requests_error_response_body",
    "DriverCoachAssignmentsPutDriverCoachAssignmentUnauthorizedErrorResponseBody": ".driver_coach_assignments_put_driver_coach_assignment_unauthorized_error_response_body",
    "DriverCreatedAtTime": ".driver_created_at_time",
    "DriverDocumentSubmittedDetailsObjectRequestBody": ".driver_document_submitted_details_object_request_body",
    "DriverDocumentSubmittedDetailsObjectResponseBody": ".driver_document_submitted_details_object_response_body",
    "DriverDocumentSubmittedResponseBody": ".driver_document_submitted_response_body",
    "DriverEfficienciesResponse": ".driver_efficiencies_response",
    "DriverEfficienciesResponseData": ".driver_efficiencies_response_data",
    "DriverEfficiency": ".driver_efficiency",
    "DriverEfficiencyDataObjectResponseBody": ".driver_efficiency_data_object_response_body",
    "DriverEfficiencyDifficultyScoreDataObjectResponseBody": ".driver_efficiency_difficulty_score_data_object_response_body",
    "DriverEfficiencyGetDriverEfficiencyByDriversBadGatewayErrorResponseBody": ".driver_efficiency_get_driver_efficiency_by_drivers_bad_gateway_error_response_body",
    "DriverEfficiencyGetDriverEfficiencyByDriversGatewayTimeoutErrorResponseBody": ".driver_efficiency_get_driver_efficiency_by_drivers_gateway_timeout_error_response_body",
    "DriverEfficiencyGetDriverEfficiencyByDriversInternalServerErrorResponseBody": ".driver_efficiency_get_driver_efficiency_by_drivers_internal_server_error_response_body",
    "DriverEfficiencyGetDriverEfficiencyByDriversMethodNotAllowedErrorResponseBody": ".driver_efficiency_get_driver_efficiency_by_drivers_method_not_allowed_error_response_body",
    "DriverEfficiencyGetDriverEfficiencyByDriversNotFoundErrorResponseBody": ".driver_efficiency_get_driver_efficiency_by_drivers_not_found_error_response_body",
    "DriverEfficiencyGetDriverEfficiencyByDriversNotImplementedErrorResponseBody": ".driver_efficiency_get_driver_efficiency_by_drivers_not_implemented_error_response_body",
    "DriverEfficiencyGetDriverEfficiencyByDriversResponseBody": ".driver_efficiency_get_driver_efficiency_by_drivers_response_body",
    "DriverEfficiencyGetDriverEfficiencyByDriversServiceUnavailableErrorResponseBody": ".driver_efficiency_get_driver_efficiency_by_drivers_service_unavailable_error_response_body",
    "DriverEfficiencyGetDriverEfficiencyByDriversTooManyRequestsErrorResponseBody": ".driver_efficiency_get_driver_efficiency_by_drivers_too_many_requests_error_response_body",
    "DriverEfficiencyGetDriverEfficiencyByDriversUnauthorizedErrorResponseBody": ".driver_efficiency_get_driver_efficiency_by_drivers_unauthorized_error_response_body",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesBadGatewayErrorResponseBody": ".driver_efficiency_get_driver_efficiency_by_vehicles_bad_gateway_error_response_body",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesGatewayTimeoutErrorResponseBody": ".driver_efficiency_get_driver_efficiency_by_vehicles_gateway_timeout_error_response_body",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesInternalServerErrorResponseBody": ".driver_efficiency_get_driver_efficiency_by_vehicles_internal_server_error_response_body",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesMethodNotAllowedErrorResponseBody": ".driver_efficiency_get_driver_efficiency_by_vehicles_method_not_allowed_error_response_body",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesNotFoundErrorResponseBody": ".driver_efficiency_get_driver_efficiency_by_vehicles_not_found_error_response_body",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesNotImplementedErrorResponseBody": ".driver_efficiency_get_driver_efficiency_by_vehicles_not_implemented_error_response_body",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesResponseBody": ".driver_efficiency_get_driver_efficiency_by_vehicles_response_body",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesServiceUnavailableErrorResponseBody": ".driver_efficiency_get_driver_efficiency_by_vehicles_service_unavailable_error_response_body",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesTooManyRequestsErrorResponseBody": ".driver_efficiency_get_driver_efficiency_by_vehicles_too_many_requests_error_response_body",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesUnauthorizedErrorResponseBody": ".driver_efficiency_get_driver_efficiency_by_vehicles_unauthorized_error_response_body",
    "DriverEfficiencyPercentageDataObjectResponseBody": ".driver_efficiency_percentage_data_object_response_body",
    "DriverEfficiencyRawDataObjectResponseBody": ".driver_efficiency_raw_data_object_response_body",
    "DriverEldAdverseWeatherExemptionEnabled": ".driver_eld_adverse_weather_exemption_enabled",
    "DriverEldBigDayExemptionEnabled": ".driver_eld_big_day_exemption_enabled",
    "DriverEldDayStartHour": ".driver_eld_day_start_hour",
    "DriverEldExempt": ".driver_eld_exempt",
    "DriverEldExemptReason": ".driver_eld_exempt_reason",
    "DriverEldPcEnabled": ".driver_eld_pc_enabled",
    "DriverEldRuleset": ".driver_eld_ruleset",
    "DriverEldRulesetCycle": ".driver_eld_ruleset_cycle",
    "DriverEldRulesetJurisdiction": ".driver_eld_ruleset_jurisdiction",
    "DriverEldRulesetRestBreak": ".driver_eld_ruleset_rest_break",
    "DriverEldRulesetRestart": ".driver_eld_ruleset_restart",
    "DriverEldRulesetShift": ".driver_eld_ruleset_shift",
    "DriverEldRulesets": ".driver_eld_rulesets",
    "DriverEldSettings": ".driver_eld_settings",
    "DriverEldYmEnabled": ".driver_eld_ym_enabled",
    "DriverExternalIds": ".driver_external_ids",
    "DriverHasDrivingFeaturesHidden": ".driver_has_driving_features_hidden",
    "DriverHasVehicleUnpinningEnabled": ".driver_has_vehicle_unpinning_enabled",
    "DriverHeavyHaulExemptionToggleEnabled": ".driver_heavy_haul_exemption_toggle_enabled",
    "DriverHomeTerminalAddress": ".driver_home_terminal_address",
    "DriverHomeTerminalName": ".driver_home_terminal_name",
    "DriverHosSetting": ".driver_hos_setting",
    "DriverId": ".driver_id",
    "DriverIdCardCode": ".driver_id_card_code",
    "DriverIsDeactivated": ".driver_is_deactivated",
    "DriverLicenseNumber": ".driver_license_number",
    "DriverLicenseState": ".driver_license_state",
    "DriverLocale": ".driver_locale",
    "DriverMessageReceivedResponseBody": ".driver_message_received_response_body",
    "DriverMessageSentResponseBody": ".driver_message_sent_response_body",
    "DriverName": ".driver_name",
    "DriverNotes": ".driver_notes",
    "DriverObjectResponseBody": ".driver_object_response_body",
    "DriverOrTagIdsDetailsRequestBody": ".driver_or_tag_ids_details_request_body",
    "DriverOrTagIdsDetailsResponseBody": ".driver_or_tag_ids_details_response_body",
    "DriverPhone": ".driver_phone",
    "DriverProfileImageBase64": ".driver_profile_image_base_64",
    "DriverProfileImageUrl": ".driver_profile_image_url",
    "DriverQrCodesCreateDriverQrCodeBadGatewayErrorResponseBody": ".driver_qr_codes_create_driver_qr_code_bad_gateway_error_response_body",
    "DriverQrCodesCreateDriverQrCodeGatewayTimeoutErrorResponseBody": ".driver_qr_codes_create_driver_qr_code_gateway_timeout_error_response_body",
    "DriverQrCodesCreateDriverQrCodeInternalServerErrorResponseBody": ".driver_qr_codes_create_driver_qr_code_internal_server_error_response_body",
    "DriverQrCodesCreateDriverQrCodeMethodNotAllowedErrorResponseBody": ".driver_qr_codes_create_driver_qr_code_method_not_allowed_error_response_body",
    "DriverQrCodesCreateDriverQrCodeNotFoundErrorResponseBody": ".driver_qr_codes_create_driver_qr_code_not_found_error_response_body",
    "DriverQrCodesCreateDriverQrCodeNotImplementedErrorResponseBody": ".driver_qr_codes_create_driver_qr_code_not_implemented_error_response_body",
    "DriverQrCodesCreateDriverQrCodeResponseBody": ".driver_qr_codes_create_driver_qr_code_response_body",
    "DriverQrCodesCreateDriverQrCodeServiceUnavailableErrorResponseBody": ".driver_qr_codes_create_driver_qr_code_service_unavailable_error_response_body",
    "DriverQrCodesCreateDriverQrCodeTooManyRequestsErrorResponseBody": ".driver_qr_codes_create_driver_qr_code_too_many_requests_error_response_body",
    "DriverQrCodesCreateDriverQrCodeUnauthorizedErrorResponseBody": ".driver_qr_codes_create_driver_qr_code_unauthorized_error_response_body",
    "DriverQrCodesDeleteDriverQrCodeBadGatewayErrorResponseBody": ".driver_qr_codes_delete_driver_qr_code_bad_gateway_error_response_body",
    "DriverQrCodesDeleteDriverQrCodeGatewayTimeoutErrorResponseBody": ".driver_qr_codes_delete_driver_qr_code_gateway_timeout_error_response_body",
    "DriverQrCodesDeleteDriverQrCodeInternalServerErrorResponseBody": ".driver_qr_codes_delete_driver_qr_code_internal_server_error_response_body",
    "DriverQrCodesDeleteDriverQrCodeMethodNotAllowedErrorResponseBody": ".driver_qr_codes_delete_driver_qr_code_method_not_allowed_error_response_body",
    "DriverQrCodesDeleteDriverQrCodeNotFoundErrorResponseBody": ".driver_qr_codes_delete_driver_qr_code_not_found_error_response_body",
    "DriverQrCodesDeleteDriverQrCodeNotImplementedErrorResponseBody": ".driver_qr_codes_delete_driver_qr_code_not_implemented_error_response_body",
    "DriverQrCodesDeleteDriverQrCodeServiceUnavailableErrorResponseBody": ".driver_qr_codes_delete_driver_qr_code_service_unavailable_error_response_body",
    "DriverQrCodesDeleteDriverQrCodeTooManyRequestsErrorResponseBody": ".driver_qr_codes_delete_driver_qr_code_too_many_requests_error_response_body",
    "DriverQrCodesDeleteDriverQrCodeUnauthorizedErrorResponseBody": ".driver_qr_codes_delete_driver_qr_code_unauthorized_error_response_body",
    "DriverQrCodesGetDriversQrCodesBadGatewayErrorResponseBody": ".driver_qr_codes_get_drivers_qr_codes_bad_gateway_error_response_body",
    "DriverQrCodesGetDriversQrCodesGatewayTimeoutErrorResponseBody": ".driver_qr_codes_get_drivers_qr_codes_gateway_timeout_error_response_body",
    "DriverQrCodesGetDriversQrCodesInternalServerErrorResponseBody": ".driver_qr_codes_get_drivers_qr_codes_internal_server_error_response_body",
    "DriverQrCodesGetDriversQrCodesMethodNotAllowedErrorResponseBody": ".driver_qr_codes_get_drivers_qr_codes_method_not_allowed_error_response_body",
    "DriverQrCodesGetDriversQrCodesNotFoundErrorResponseBody": ".driver_qr_codes_get_drivers_qr_codes_not_found_error_response_body",
    "DriverQrCodesGetDriversQrCodesNotImplementedErrorResponseBody": ".driver_qr_codes_get_drivers_qr_codes_not_implemented_error_response_body",
    "DriverQrCodesGetDriversQrCodesResponseBody": ".driver_qr_codes_get_drivers_qr_codes_response_body",
    "DriverQrCodesGetDriversQrCodesServiceUnavailableErrorResponseBody": ".driver_qr_codes_get_drivers_qr_codes_service_unavailable_error_response_body",
    "DriverQrCodesGetDriversQrCodesTooManyRequestsErrorResponseBody": ".driver_qr_codes_get_drivers_qr_codes_too_many_requests_error_response_body",
    "DriverQrCodesGetDriversQrCodesUnauthorizedErrorResponseBody": ".driver_qr_codes_get_drivers_qr_codes_unauthorized_error_response_body",
    "DriverRecordedResponseBody": ".driver_recorded_response_body",
    "DriverRemoteSignoutPostDriverRemoteSignoutBadGatewayErrorResponseBody": ".driver_remote_signout_post_driver_remote_signout_bad_gateway_error_response_body",
    "DriverRemoteSignoutPostDriverRemoteSignoutGatewayTimeoutErrorResponseBody": ".driver_remote_signout_post_driver_remote_signout_gateway_timeout_error_response_body",
    "DriverRemoteSignoutPostDriverRemoteSignoutInternalServerErrorResponseBody": ".driver_remote_signout_post_driver_remote_signout_internal_server_error_response_body",
    "DriverRemoteSignoutPostDriverRemoteSignoutMethodNotAllowedErrorResponseBody": ".driver_remote_signout_post_driver_remote_signout_method_not_allowed_error_response_body",
    "DriverRemoteSignoutPostDriverRemoteSignoutNotFoundErrorResponseBody": ".driver_remote_signout_post_driver_remote_signout_not_found_error_response_body",
    "DriverRemoteSignoutPostDriverRemoteSignoutNotImplementedErrorResponseBody": ".driver_remote_signout_post_driver_remote_signout_not_implemented_error_response_body",
    "DriverRemoteSignoutPostDriverRemoteSignoutResponseBody": ".driver_remote_signout_post_driver_remote_signout_response_body",
    "DriverRemoteSignoutPostDriverRemoteSignoutServiceUnavailableErrorResponseBody": ".driver_remote_signout_post_driver_remote_signout_service_unavailable_error_response_body",
    "DriverRemoteSignoutPostDriverRemoteSignoutTooManyRequestsErrorResponseBody": ".driver_remote_signout_post_driver_remote_signout_too_many_requests_error_response_body",
    "DriverRemoteSignoutPostDriverRemoteSignoutUnauthorizedErrorResponseBody": ".driver_remote_signout_post_driver_remote_signout_unauthorized_error_response_body",
    "DriverResponse": ".driver_response",
    "DriverRulesetObjectResponseBody": ".driver_ruleset_object_response_body",
    "DriverRulesetObjectResponseBodyBreak": ".driver_ruleset_object_response_body_break",
    "DriverRulesetObjectResponseBodyCycle": ".driver_ruleset_object_response_body_cycle",
    "DriverRulesetObjectResponseBodyRestart": ".driver_ruleset_object_response_body_restart",
    "DriverRulesetObjectResponseBodyShift": ".driver_ruleset_object_response_body_shift",
    "DriverSafetyScoreResponseBody": ".driver_safety_score_response_body",
    "DriverStaticAssignedVehicle": ".driver_static_assigned_vehicle",
    "DriverTachographActivityData": ".driver_tachograph_activity_data",
    "DriverTachographActivityResponse": ".driver_tachograph_activity_response",
    "DriverTachographCardNumber": ".driver_tachograph_card_number",
    "DriverTags": ".driver_tags",
    "DriverTimezone": ".driver_timezone",
    "DriverTinyResponse": ".driver_tiny_response",
    "DriverUpdatedAtTime": ".driver_updated_at_time",
    "DriverUsername": ".driver_username",
    "DriverVehicleAssignmentV2ObjectResponseBody": ".driver_vehicle_assignment_v_2_object_response_body",
    "DriverVehicleAssignmentV2ObjectResponseBodyAssignmentType": ".driver_vehicle_assignment_v_2_object_response_body_assignment_type",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentBadGatewayErrorResponseBody": ".driver_vehicle_assignments_v_2_create_driver_vehicle_assignment_bad_gateway_error_response_body",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentGatewayTimeoutErrorResponseBody": ".driver_vehicle_assignments_v_2_create_driver_vehicle_assignment_gateway_timeout_error_response_body",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentInternalServerErrorResponseBody": ".driver_vehicle_assignments_v_2_create_driver_vehicle_assignment_internal_server_error_response_body",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentMethodNotAllowedErrorResponseBody": ".driver_vehicle_assignments_v_2_create_driver_vehicle_assignment_method_not_allowed_error_response_body",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentNotFoundErrorResponseBody": ".driver_vehicle_assignments_v_2_create_driver_vehicle_assignment_not_found_error_response_body",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentNotImplementedErrorResponseBody": ".driver_vehicle_assignments_v_2_create_driver_vehicle_assignment_not_implemented_error_response_body",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentResponseBody": ".driver_vehicle_assignments_v_2_create_driver_vehicle_assignment_response_body",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentServiceUnavailableErrorResponseBody": ".driver_vehicle_assignments_v_2_create_driver_vehicle_assignment_service_unavailable_error_response_body",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentTooManyRequestsErrorResponseBody": ".driver_vehicle_assignments_v_2_create_driver_vehicle_assignment_too_many_requests_error_response_body",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentUnauthorizedErrorResponseBody": ".driver_vehicle_assignments_v_2_create_driver_vehicle_assignment_unauthorized_error_response_body",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsBadGatewayErrorResponseBody": ".driver_vehicle_assignments_v_2_delete_driver_vehicle_assignments_bad_gateway_error_response_body",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsGatewayTimeoutErrorResponseBody": ".driver_vehicle_assignments_v_2_delete_driver_vehicle_assignments_gateway_timeout_error_response_body",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsInternalServerErrorResponseBody": ".driver_vehicle_assignments_v_2_delete_driver_vehicle_assignments_internal_server_error_response_body",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsMethodNotAllowedErrorResponseBody": ".driver_vehicle_assignments_v_2_delete_driver_vehicle_assignments_method_not_allowed_error_response_body",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsNotFoundErrorResponseBody": ".driver_vehicle_assignments_v_2_delete_driver_vehicle_assignments_not_found_error_response_body",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsNotImplementedErrorResponseBody": ".driver_vehicle_assignments_v_2_delete_driver_vehicle_assignments_not_implemented_error_response_body",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsServiceUnavailableErrorResponseBody": ".driver_vehicle_assignments_v_2_delete_driver_vehicle_assignments_service_unavailable_error_response_body",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsTooManyRequestsErrorResponseBody": ".driver_vehicle_assignments_v_2_delete_driver_vehicle_assignments_too_many_requests_error_response_body",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsUnauthorizedErrorResponseBody": ".driver_vehicle_assignments_v_2_delete_driver_vehicle_assignments_unauthorized_error_response_body",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsBadGatewayErrorResponseBody": ".driver_vehicle_assignments_v_2_get_driver_vehicle_assignments_bad_gateway_error_response_body",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsGatewayTimeoutErrorResponseBody": ".driver_vehicle_assignments_v_2_get_driver_vehicle_assignments_gateway_timeout_error_response_body",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsInternalServerErrorResponseBody": ".driver_vehicle_assignments_v_2_get_driver_vehicle_assignments_internal_server_error_response_body",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsMethodNotAllowedErrorResponseBody": ".driver_vehicle_assignments_v_2_get_driver_vehicle_assignments_method_not_allowed_error_response_body",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsNotFoundErrorResponseBody": ".driver_vehicle_assignments_v_2_get_driver_vehicle_assignments_not_found_error_response_body",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsNotImplementedErrorResponseBody": ".driver_vehicle_assignments_v_2_get_driver_vehicle_assignments_not_implemented_error_response_body",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsResponseBody": ".driver_vehicle_assignments_v_2_get_driver_vehicle_assignments_response_body",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsServiceUnavailableErrorResponseBody": ".driver_vehicle_assignments_v_2_get_driver_vehicle_assignments_service_unavailable_error_response_body",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsTooManyRequestsErrorResponseBody": ".driver_vehicle_assignments_v_2_get_driver_vehicle_assignments_too_many_requests_error_response_body",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsUnauthorizedErrorResponseBody": ".driver_vehicle_assignments_v_2_get_driver_vehicle_assignments_unauthorized_error_response_body",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentBadGatewayErrorResponseBody": ".driver_vehicle_assignments_v_2_update_driver_vehicle_assignment_bad_gateway_error_response_body",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentGatewayTimeoutErrorResponseBody": ".driver_vehicle_assignments_v_2_update_driver_vehicle_assignment_gateway_timeout_error_response_body",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentInternalServerErrorResponseBody": ".driver_vehicle_assignments_v_2_update_driver_vehicle_assignment_internal_server_error_response_body",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentMethodNotAllowedErrorResponseBody": ".driver_vehicle_assignments_v_2_update_driver_vehicle_assignment_method_not_allowed_error_response_body",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentNotFoundErrorResponseBody": ".driver_vehicle_assignments_v_2_update_driver_vehicle_assignment_not_found_error_response_body",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentNotImplementedErrorResponseBody": ".driver_vehicle_assignments_v_2_update_driver_vehicle_assignment_not_implemented_error_response_body",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentResponseBody": ".driver_vehicle_assignments_v_2_update_driver_vehicle_assignment_response_body",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentServiceUnavailableErrorResponseBody": ".driver_vehicle_assignments_v_2_update_driver_vehicle_assignment_service_unavailable_error_response_body",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentTooManyRequestsErrorResponseBody": ".driver_vehicle_assignments_v_2_update_driver_vehicle_assignment_too_many_requests_error_response_body",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentUnauthorizedErrorResponseBody": ".driver_vehicle_assignments_v_2_update_driver_vehicle_assignment_unauthorized_error_response_body",
    "DriverVehicleGroupTag": ".driver_vehicle_group_tag",
    "DriverWaitingTimeDutyStatusEnabled": ".driver_waiting_time_duty_status_enabled",
    "DriverWithExternalIdObjectResponseBody": ".driver_with_external_id_object_response_body",
    "DriverWithTimezoneEldSettingsObjectResponseBody": ".driver_with_timezone_eld_settings_object_response_body",
    "DriversAuthTokenCreateDriverAuthTokenBadGatewayErrorResponseBody": ".drivers_auth_token_create_driver_auth_token_bad_gateway_error_response_body",
    "DriversAuthTokenCreateDriverAuthTokenGatewayTimeoutErrorResponseBody": ".drivers_auth_token_create_driver_auth_token_gateway_timeout_error_response_body",
    "DriversAuthTokenCreateDriverAuthTokenInternalServerErrorResponseBody": ".drivers_auth_token_create_driver_auth_token_internal_server_error_response_body",
    "DriversAuthTokenCreateDriverAuthTokenMethodNotAllowedErrorResponseBody": ".drivers_auth_token_create_driver_auth_token_method_not_allowed_error_response_body",
    "DriversAuthTokenCreateDriverAuthTokenNotFoundErrorResponseBody": ".drivers_auth_token_create_driver_auth_token_not_found_error_response_body",
    "DriversAuthTokenCreateDriverAuthTokenNotImplementedErrorResponseBody": ".drivers_auth_token_create_driver_auth_token_not_implemented_error_response_body",
    "DriversAuthTokenCreateDriverAuthTokenResponseBody": ".drivers_auth_token_create_driver_auth_token_response_body",
    "DriversAuthTokenCreateDriverAuthTokenServiceUnavailableErrorResponseBody": ".drivers_auth_token_create_driver_auth_token_service_unavailable_error_response_body",
    "DriversAuthTokenCreateDriverAuthTokenTooManyRequestsErrorResponseBody": ".drivers_auth_token_create_driver_auth_token_too_many_requests_error_response_body",
    "DriversAuthTokenCreateDriverAuthTokenUnauthorizedErrorResponseBody": ".drivers_auth_token_create_driver_auth_token_unauthorized_error_response_body",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsBadGatewayErrorResponseBody": ".drivers_vehicle_assignments_get_drivers_vehicle_assignments_bad_gateway_error_response_body",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsGatewayTimeoutErrorResponseBody": ".drivers_vehicle_assignments_get_drivers_vehicle_assignments_gateway_timeout_error_response_body",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsInternalServerErrorResponseBody": ".drivers_vehicle_assignments_get_drivers_vehicle_assignments_internal_server_error_response_body",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsMethodNotAllowedErrorResponseBody": ".drivers_vehicle_assignments_get_drivers_vehicle_assignments_method_not_allowed_error_response_body",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsNotFoundErrorResponseBody": ".drivers_vehicle_assignments_get_drivers_vehicle_assignments_not_found_error_response_body",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsNotImplementedErrorResponseBody": ".drivers_vehicle_assignments_get_drivers_vehicle_assignments_not_implemented_error_response_body",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsResponseBody": ".drivers_vehicle_assignments_get_drivers_vehicle_assignments_response_body",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsServiceUnavailableErrorResponseBody": ".drivers_vehicle_assignments_get_drivers_vehicle_assignments_service_unavailable_error_response_body",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsTooManyRequestsErrorResponseBody": ".drivers_vehicle_assignments_get_drivers_vehicle_assignments_too_many_requests_error_response_body",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsUnauthorizedErrorResponseBody": ".drivers_vehicle_assignments_get_drivers_vehicle_assignments_unauthorized_error_response_body",
    "DriversVehicleAssignmentsObjectResponseBody": ".drivers_vehicle_assignments_object_response_body",
    "DriversVehicleAssignmentsObjectResponseBodyDriverActivationStatus": ".drivers_vehicle_assignments_object_response_body_driver_activation_status",
    "DutyStatusDurationObjectResponseBody": ".duty_status_duration_object_response_body",
    "Dvir": ".dvir",
    "Dvir2AssignedToPolymorphicUserObjectResponseBody": ".dvir_2_assigned_to_polymorphic_user_object_response_body",
    "Dvir2DeviceObjectResponseBody": ".dvir_2_device_object_response_body",
    "Dvir2FormSubmissionObjectResponseBody": ".dvir_2_form_submission_object_response_body",
    "Dvir2RelatedDeviceObjectResponseBody": ".dvir_2_related_device_object_response_body",
    "Dvir2RelatedDeviceObjectResponseBodyAssetType": ".dvir_2_related_device_object_response_body_asset_type",
    "Dvir2SubmissionResponseObjectResponseBody": ".dvir_2_submission_response_object_response_body",
    "Dvir2SubmissionResponseObjectResponseBodyInspectionType": ".dvir_2_submission_response_object_response_body_inspection_type",
    "DvirAuthorSignature": ".dvir_author_signature",
    "DvirDefectGetDefectBadGatewayErrorResponseBody": ".dvir_defect_get_defect_bad_gateway_error_response_body",
    "DvirDefectGetDefectGatewayTimeoutErrorResponseBody": ".dvir_defect_get_defect_gateway_timeout_error_response_body",
    "DvirDefectGetDefectInternalServerErrorResponseBody": ".dvir_defect_get_defect_internal_server_error_response_body",
    "DvirDefectGetDefectMethodNotAllowedErrorResponseBody": ".dvir_defect_get_defect_method_not_allowed_error_response_body",
    "DvirDefectGetDefectNotFoundErrorResponseBody": ".dvir_defect_get_defect_not_found_error_response_body",
    "DvirDefectGetDefectNotImplementedErrorResponseBody": ".dvir_defect_get_defect_not_implemented_error_response_body",
    "DvirDefectGetDefectResponseBody": ".dvir_defect_get_defect_response_body",
    "DvirDefectGetDefectServiceUnavailableErrorResponseBody": ".dvir_defect_get_defect_service_unavailable_error_response_body",
    "DvirDefectGetDefectTooManyRequestsErrorResponseBody": ".dvir_defect_get_defect_too_many_requests_error_response_body",
    "DvirDefectGetDefectUnauthorizedErrorResponseBody": ".dvir_defect_get_defect_unauthorized_error_response_body",
    "DvirDefectStreamDefectsBadGatewayErrorResponseBody": ".dvir_defect_stream_defects_bad_gateway_error_response_body",
    "DvirDefectStreamDefectsGatewayTimeoutErrorResponseBody": ".dvir_defect_stream_defects_gateway_timeout_error_response_body",
    "DvirDefectStreamDefectsInternalServerErrorResponseBody": ".dvir_defect_stream_defects_internal_server_error_response_body",
    "DvirDefectStreamDefectsMethodNotAllowedErrorResponseBody": ".dvir_defect_stream_defects_method_not_allowed_error_response_body",
    "DvirDefectStreamDefectsNotFoundErrorResponseBody": ".dvir_defect_stream_defects_not_found_error_response_body",
    "DvirDefectStreamDefectsNotImplementedErrorResponseBody": ".dvir_defect_stream_defects_not_implemented_error_response_body",
    "DvirDefectStreamDefectsResponseBody": ".dvir_defect_stream_defects_response_body",
    "DvirDefectStreamDefectsServiceUnavailableErrorResponseBody": ".dvir_defect_stream_defects_service_unavailable_error_response_body",
    "DvirDefectStreamDefectsTooManyRequestsErrorResponseBody": ".dvir_defect_stream_defects_too_many_requests_error_response_body",
    "DvirDefectStreamDefectsUnauthorizedErrorResponseBody": ".dvir_defect_stream_defects_unauthorized_error_response_body",
    "DvirDefectTypeGetDefectTypesBadGatewayErrorResponseBody": ".dvir_defect_type_get_defect_types_bad_gateway_error_response_body",
    "DvirDefectTypeGetDefectTypesGatewayTimeoutErrorResponseBody": ".dvir_defect_type_get_defect_types_gateway_timeout_error_response_body",
    "DvirDefectTypeGetDefectTypesInternalServerErrorResponseBody": ".dvir_defect_type_get_defect_types_internal_server_error_response_body",
    "DvirDefectTypeGetDefectTypesMethodNotAllowedErrorResponseBody": ".dvir_defect_type_get_defect_types_method_not_allowed_error_response_body",
    "DvirDefectTypeGetDefectTypesNotFoundErrorResponseBody": ".dvir_defect_type_get_defect_types_not_found_error_response_body",
    "DvirDefectTypeGetDefectTypesNotImplementedErrorResponseBody": ".dvir_defect_type_get_defect_types_not_implemented_error_response_body",
    "DvirDefectTypeGetDefectTypesResponseBody": ".dvir_defect_type_get_defect_types_response_body",
    "DvirDefectTypeGetDefectTypesServiceUnavailableErrorResponseBody": ".dvir_defect_type_get_defect_types_service_unavailable_error_response_body",
    "DvirDefectTypeGetDefectTypesTooManyRequestsErrorResponseBody": ".dvir_defect_type_get_defect_types_too_many_requests_error_response_body",
    "DvirDefectTypeGetDefectTypesUnauthorizedErrorResponseBody": ".dvir_defect_type_get_defect_types_unauthorized_error_response_body",
    "DvirDefectsObjectV20220913ResponseBody": ".dvir_defects_object_v_20220913_response_body",
    "DvirGetDvirBadGatewayErrorResponseBody": ".dvir_get_dvir_bad_gateway_error_response_body",
    "DvirGetDvirGatewayTimeoutErrorResponseBody": ".dvir_get_dvir_gateway_timeout_error_response_body",
    "DvirGetDvirInternalServerErrorResponseBody": ".dvir_get_dvir_internal_server_error_response_body",
    "DvirGetDvirMethodNotAllowedErrorResponseBody": ".dvir_get_dvir_method_not_allowed_error_response_body",
    "DvirGetDvirNotFoundErrorResponseBody": ".dvir_get_dvir_not_found_error_response_body",
    "DvirGetDvirNotImplementedErrorResponseBody": ".dvir_get_dvir_not_implemented_error_response_body",
    "DvirGetDvirResponseBody": ".dvir_get_dvir_response_body",
    "DvirGetDvirResponseBodySafetyStatus": ".dvir_get_dvir_response_body_safety_status",
    "DvirGetDvirResponseBodyType": ".dvir_get_dvir_response_body_type",
    "DvirGetDvirServiceUnavailableErrorResponseBody": ".dvir_get_dvir_service_unavailable_error_response_body",
    "DvirGetDvirTooManyRequestsErrorResponseBody": ".dvir_get_dvir_too_many_requests_error_response_body",
    "DvirGetDvirUnauthorizedErrorResponseBody": ".dvir_get_dvir_unauthorized_error_response_body",
    "DvirGetDvirsBadGatewayErrorResponseBody": ".dvir_get_dvirs_bad_gateway_error_response_body",
    "DvirGetDvirsGatewayTimeoutErrorResponseBody": ".dvir_get_dvirs_gateway_timeout_error_response_body",
    "DvirGetDvirsInternalServerErrorResponseBody": ".dvir_get_dvirs_internal_server_error_response_body",
    "DvirGetDvirsMethodNotAllowedErrorResponseBody": ".dvir_get_dvirs_method_not_allowed_error_response_body",
    "DvirGetDvirsNotFoundErrorResponseBody": ".dvir_get_dvirs_not_found_error_response_body",
    "DvirGetDvirsNotImplementedErrorResponseBody": ".dvir_get_dvirs_not_implemented_error_response_body",
    "DvirGetDvirsResponseBody": ".dvir_get_dvirs_response_body",
    "DvirGetDvirsServiceUnavailableErrorResponseBody": ".dvir_get_dvirs_service_unavailable_error_response_body",
    "DvirGetDvirsTooManyRequestsErrorResponseBody": ".dvir_get_dvirs_too_many_requests_error_response_body",
    "DvirGetDvirsUnauthorizedErrorResponseBody": ".dvir_get_dvirs_unauthorized_error_response_body",
    "DvirLicensePlate": ".dvir_license_plate",
    "DvirLocation": ".dvir_location",
    "DvirMechanicNotes": ".dvir_mechanic_notes",
    "DvirOdometerMeters": ".dvir_odometer_meters",
    "DvirResolvedByObjectResponseBody": ".dvir_resolved_by_object_response_body",
    "DvirResolvedByObjectResponseBodyType": ".dvir_resolved_by_object_response_body_type",
    "DvirResponse": ".dvir_response",
    "DvirSafetyStatus": ".dvir_safety_status",
    "DvirSecondSignature": ".dvir_second_signature",
    "DvirSignature": ".dvir_signature",
    "DvirSignatureSignatoryUser": ".dvir_signature_signatory_user",
    "DvirSignatureType": ".dvir_signature_type",
    "DvirStreamResponseDataResponseBody": ".dvir_stream_response_data_response_body",
    "DvirStreamResponseDataResponseBodySafetyStatus": ".dvir_stream_response_data_response_body_safety_status",
    "DvirStreamResponseDataResponseBodyType": ".dvir_stream_response_data_response_body_type",
    "DvirSubmittedDeviceTriggerDetailsObjectRequestBody": ".dvir_submitted_device_trigger_details_object_request_body",
    "DvirSubmittedDeviceTriggerDetailsObjectRequestBodyDvirSubmissionTypesItem": ".dvir_submitted_device_trigger_details_object_request_body_dvir_submission_types_item",
    "DvirSubmittedDeviceTriggerDetailsObjectResponseBody": ".dvir_submitted_device_trigger_details_object_response_body",
    "DvirSubmittedDeviceTriggerDetailsObjectResponseBodyDvirSubmissionTypesItem": ".dvir_submitted_device_trigger_details_object_response_body_dvir_submission_types_item",
    "DvirThirdSignature": ".dvir_third_signature",
    "DvirTrailer": ".dvir_trailer",
    "DvirTrailerDefects": ".dvir_trailer_defects",
    "DvirTrailerDefectsItems": ".dvir_trailer_defects_items",
    "DvirTrailerDefectsItemsTrailer": ".dvir_trailer_defects_items_trailer",
    "DvirTrailerDefectsItemsVehicle": ".dvir_trailer_defects_items_vehicle",
    "DvirType": ".dvir_type",
    "DvirVehicle": ".dvir_vehicle",
    "DvirVehicleDefects": ".dvir_vehicle_defects",
    "DvirsListResponse": ".dvirs_list_response",
    "EldSettingsObjectResponseBody": ".eld_settings_object_response_body",
    "EngineIdleDataResponseBody": ".engine_idle_data_response_body",
    "EngineIdleTriggerDetailsObjectRequestBody": ".engine_idle_trigger_details_object_request_body",
    "EngineIdleTriggerDetailsObjectResponseBody": ".engine_idle_trigger_details_object_response_body",
    "EngineImmobilizerGetEngineImmobilizerStatesBadGatewayErrorResponseBody": ".engine_immobilizer_get_engine_immobilizer_states_bad_gateway_error_response_body",
    "EngineImmobilizerGetEngineImmobilizerStatesGatewayTimeoutErrorResponseBody": ".engine_immobilizer_get_engine_immobilizer_states_gateway_timeout_error_response_body",
    "EngineImmobilizerGetEngineImmobilizerStatesInternalServerErrorResponseBody": ".engine_immobilizer_get_engine_immobilizer_states_internal_server_error_response_body",
    "EngineImmobilizerGetEngineImmobilizerStatesMethodNotAllowedErrorResponseBody": ".engine_immobilizer_get_engine_immobilizer_states_method_not_allowed_error_response_body",
    "EngineImmobilizerGetEngineImmobilizerStatesNotFoundErrorResponseBody": ".engine_immobilizer_get_engine_immobilizer_states_not_found_error_response_body",
    "EngineImmobilizerGetEngineImmobilizerStatesNotImplementedErrorResponseBody": ".engine_immobilizer_get_engine_immobilizer_states_not_implemented_error_response_body",
    "EngineImmobilizerGetEngineImmobilizerStatesResponseBody": ".engine_immobilizer_get_engine_immobilizer_states_response_body",
    "EngineImmobilizerGetEngineImmobilizerStatesServiceUnavailableErrorResponseBody": ".engine_immobilizer_get_engine_immobilizer_states_service_unavailable_error_response_body",
    "EngineImmobilizerGetEngineImmobilizerStatesTooManyRequestsErrorResponseBody": ".engine_immobilizer_get_engine_immobilizer_states_too_many_requests_error_response_body",
    "EngineImmobilizerGetEngineImmobilizerStatesUnauthorizedErrorResponseBody": ".engine_immobilizer_get_engine_immobilizer_states_unauthorized_error_response_body",
    "EngineImmobilizerRelayStateResponseBody": ".engine_immobilizer_relay_state_response_body",
    "EngineImmobilizerRelayStateResponseBodyId": ".engine_immobilizer_relay_state_response_body_id",
    "EngineImmobilizerStateResponseBody": ".engine_immobilizer_state_response_body",
    "EngineImmobilizerUpdateEngineImmobilizerStateBadGatewayErrorResponseBody": ".engine_immobilizer_update_engine_immobilizer_state_bad_gateway_error_response_body",
    "EngineImmobilizerUpdateEngineImmobilizerStateGatewayTimeoutErrorResponseBody": ".engine_immobilizer_update_engine_immobilizer_state_gateway_timeout_error_response_body",
    "EngineImmobilizerUpdateEngineImmobilizerStateInternalServerErrorResponseBody": ".engine_immobilizer_update_engine_immobilizer_state_internal_server_error_response_body",
    "EngineImmobilizerUpdateEngineImmobilizerStateMethodNotAllowedErrorResponseBody": ".engine_immobilizer_update_engine_immobilizer_state_method_not_allowed_error_response_body",
    "EngineImmobilizerUpdateEngineImmobilizerStateNotFoundErrorResponseBody": ".engine_immobilizer_update_engine_immobilizer_state_not_found_error_response_body",
    "EngineImmobilizerUpdateEngineImmobilizerStateNotImplementedErrorResponseBody": ".engine_immobilizer_update_engine_immobilizer_state_not_implemented_error_response_body",
    "EngineImmobilizerUpdateEngineImmobilizerStateServiceUnavailableErrorResponseBody": ".engine_immobilizer_update_engine_immobilizer_state_service_unavailable_error_response_body",
    "EngineImmobilizerUpdateEngineImmobilizerStateTooManyRequestsErrorResponseBody": ".engine_immobilizer_update_engine_immobilizer_state_too_many_requests_error_response_body",
    "EngineImmobilizerUpdateEngineImmobilizerStateUnauthorizedErrorResponseBody": ".engine_immobilizer_update_engine_immobilizer_state_unauthorized_error_response_body",
    "EngineOffDetailsObjectRequestBody": ".engine_off_details_object_request_body",
    "EngineOffDetailsObjectResponseBody": ".engine_off_details_object_response_body",
    "EngineOffResponseBody": ".engine_off_response_body",
    "EngineOnDetailsObjectRequestBody": ".engine_on_details_object_request_body",
    "EngineOnDetailsObjectResponseBody": ".engine_on_details_object_response_body",
    "EngineOnResponseBody": ".engine_on_response_body",
    "EngineStatusResponseBody": ".engine_status_response_body",
    "EnumReadingAlertThresholdResponseBody": ".enum_reading_alert_threshold_response_body",
    "EnumValueResponseBody": ".enum_value_response_body",
    "EquipmentEngineRpm": ".equipment_engine_rpm",
    "EquipmentEngineSeconds": ".equipment_engine_seconds",
    "EquipmentEngineState": ".equipment_engine_state",
    "EquipmentEngineStateValue": ".equipment_engine_state_value",
    "EquipmentEngineTotalIdleTimeMinutes": ".equipment_engine_total_idle_time_minutes",
    "EquipmentFuelPercent": ".equipment_fuel_percent",
    "EquipmentGatewayEngineSeconds": ".equipment_gateway_engine_seconds",
    "EquipmentGatewayEngineState": ".equipment_gateway_engine_state",
    "EquipmentGatewayEngineStateValue": ".equipment_gateway_engine_state_value",
    "EquipmentGatewayJ1939EngineSeconds": ".equipment_gateway_j_1939_engine_seconds",
    "EquipmentGpsOdometerMeters": ".equipment_gps_odometer_meters",
    "EquipmentHeaderWithAdditionalFieldsResponseBody": ".equipment_header_with_additional_fields_response_body",
    "EquipmentId": ".equipment_id",
    "EquipmentInstalledGateway": ".equipment_installed_gateway",
    "EquipmentListResponse": ".equipment_list_response",
    "EquipmentLocation": ".equipment_location",
    "EquipmentLocationsListResponse": ".equipment_locations_list_response",
    "EquipmentLocationsListResponseData": ".equipment_locations_list_response_data",
    "EquipmentLocationsResponse": ".equipment_locations_response",
    "EquipmentLocationsResponseData": ".equipment_locations_response_data",
    "EquipmentName": ".equipment_name",
    "EquipmentObdEngineSeconds": ".equipment_obd_engine_seconds",
    "EquipmentObdEngineState": ".equipment_obd_engine_state",
    "EquipmentObdEngineStateValue": ".equipment_obd_engine_state_value",
    "EquipmentObject": ".equipment_object",
    "EquipmentPatchEquipmentBadGatewayErrorResponseBody": ".equipment_patch_equipment_bad_gateway_error_response_body",
    "EquipmentPatchEquipmentGatewayTimeoutErrorResponseBody": ".equipment_patch_equipment_gateway_timeout_error_response_body",
    "EquipmentPatchEquipmentInternalServerErrorResponseBody": ".equipment_patch_equipment_internal_server_error_response_body",
    "EquipmentPatchEquipmentMethodNotAllowedErrorResponseBody": ".equipment_patch_equipment_method_not_allowed_error_response_body",
    "EquipmentPatchEquipmentNotFoundErrorResponseBody": ".equipment_patch_equipment_not_found_error_response_body",
    "EquipmentPatchEquipmentNotImplementedErrorResponseBody": ".equipment_patch_equipment_not_implemented_error_response_body",
    "EquipmentPatchEquipmentResponseBody": ".equipment_patch_equipment_response_body",
    "EquipmentPatchEquipmentServiceUnavailableErrorResponseBody": ".equipment_patch_equipment_service_unavailable_error_response_body",
    "EquipmentPatchEquipmentTooManyRequestsErrorResponseBody": ".equipment_patch_equipment_too_many_requests_error_response_body",
    "EquipmentPatchEquipmentUnauthorizedErrorResponseBody": ".equipment_patch_equipment_unauthorized_error_response_body",
    "EquipmentResponse": ".equipment_response",
    "EquipmentStatsGps": ".equipment_stats_gps",
    "EquipmentStatsListResponse": ".equipment_stats_list_response",
    "EquipmentStatsListResponseData": ".equipment_stats_list_response_data",
    "EquipmentStatsResponse": ".equipment_stats_response",
    "EquipmentStatsResponseData": ".equipment_stats_response_data",
    "EquipmentTime": ".equipment_time",
    "EquipmentWithAttributesResponseObjectResponseBody": ".equipment_with_attributes_response_object_response_body",
    "EventLocationResponseBody": ".event_location_response_body",
    "ExtendedDriverTinyResponse": ".extended_driver_tiny_response",
    "ExtendedDriverTinyResponseExternalIds": ".extended_driver_tiny_response_external_ids",
    "FftSpectraDataPoint": ".fft_spectra_data_point",
    "FftSpectraDataPointFftSpectra": ".fft_spectra_data_point_fft_spectra",
    "FieldObjectPostRequestBody": ".field_object_post_request_body",
    "FieldObjectPostRequestBodyType": ".field_object_post_request_body_type",
    "FieldObjectResponseBody": ".field_object_response_body",
    "FieldObjectResponseBodyType": ".field_object_response_body_type",
    "FieldObjectValueRequestBody": ".field_object_value_request_body",
    "FieldObjectValueResponseBody": ".field_object_value_response_body",
    "FieldTypesObjectResponseBody": ".field_types_object_response_body",
    "FieldTypesObjectResponseBodyFieldType": ".field_types_object_response_body_field_type",
    "FiltersRequestBody": ".filters_request_body",
    "FiltersResponseBody": ".filters_response_body",
    "FleetDeviceObjectResponseBody": ".fleet_device_object_response_body",
    "FollowingDistanceDetectionAlertSettingsObjectResponseBody": ".following_distance_detection_alert_settings_object_response_body",
    "FormSubmissionPdfExportResponseObjectResponseBody": ".form_submission_pdf_export_response_object_response_body",
    "FormSubmissionPdfExportResponseObjectResponseBodyJobStatus": ".form_submission_pdf_export_response_object_response_body_job_status",
    "FormSubmissionRequestApprovalDetailsRequestBody": ".form_submission_request_approval_details_request_body",
    "FormSubmissionRequestAssetObjectRequestBody": ".form_submission_request_asset_object_request_body",
    "FormSubmissionRequestAssetValueObjectRequestBody": ".form_submission_request_asset_value_object_request_body",
    "FormSubmissionRequestAssignedToRequestBody": ".form_submission_request_assigned_to_request_body",
    "FormSubmissionRequestAssignedToRequestBodyType": ".form_submission_request_assigned_to_request_body_type",
    "FormSubmissionRequestCheckBoxesValueObjectRequestBody": ".form_submission_request_check_boxes_value_object_request_body",
    "FormSubmissionRequestDateTimeValueObjectRequestBody": ".form_submission_request_date_time_value_object_request_body",
    "FormSubmissionRequestFieldInputObjectRequestBody": ".form_submission_request_field_input_object_request_body",
    "FormSubmissionRequestFieldInputObjectRequestBodyType": ".form_submission_request_field_input_object_request_body_type",
    "FormSubmissionRequestGeofenceObjectRequestBody": ".form_submission_request_geofence_object_request_body",
    "FormSubmissionRequestGeofenceValueObjectRequestBody": ".form_submission_request_geofence_value_object_request_body",
    "FormSubmissionRequestMediaItemObjectRequestBody": ".form_submission_request_media_item_object_request_body",
    "FormSubmissionRequestMediaValueObjectRequestBody": ".form_submission_request_media_value_object_request_body",
    "FormSubmissionRequestMultipleChoiceValueObjectRequestBody": ".form_submission_request_multiple_choice_value_object_request_body",
    "FormSubmissionRequestNumberValueObjectRequestBody": ".form_submission_request_number_value_object_request_body",
    "FormSubmissionRequestPersonObjectRequestBody": ".form_submission_request_person_object_request_body",
    "FormSubmissionRequestPersonValueObjectRequestBody": ".form_submission_request_person_value_object_request_body",
    "FormSubmissionRequestSignatureValueObjectRequestBody": ".form_submission_request_signature_value_object_request_body",
    "FormSubmissionRequestTableCellObjectRequestBody": ".form_submission_request_table_cell_object_request_body",
    "FormSubmissionRequestTableCellObjectRequestBodyType": ".form_submission_request_table_cell_object_request_body_type",
    "FormSubmissionRequestTableRowObjectRequestBody": ".form_submission_request_table_row_object_request_body",
    "FormSubmissionRequestTableValueObjectRequestBody": ".form_submission_request_table_value_object_request_body",
    "FormSubmissionRequestTextValueObjectRequestBody": ".form_submission_request_text_value_object_request_body",
    "FormSubmissionResponseObjectResponseBody": ".form_submission_response_object_response_body",
    "FormSubmissionResponseObjectResponseBodyStatus": ".form_submission_response_object_response_body_status",
    "FormSubmissionsGetFormSubmissionsBadGatewayErrorResponseBody": ".form_submissions_get_form_submissions_bad_gateway_error_response_body",
    "FormSubmissionsGetFormSubmissionsGatewayTimeoutErrorResponseBody": ".form_submissions_get_form_submissions_gateway_timeout_error_response_body",
    "FormSubmissionsGetFormSubmissionsInternalServerErrorResponseBody": ".form_submissions_get_form_submissions_internal_server_error_response_body",
    "FormSubmissionsGetFormSubmissionsMethodNotAllowedErrorResponseBody": ".form_submissions_get_form_submissions_method_not_allowed_error_response_body",
    "FormSubmissionsGetFormSubmissionsNotFoundErrorResponseBody": ".form_submissions_get_form_submissions_not_found_error_response_body",
    "FormSubmissionsGetFormSubmissionsNotImplementedErrorResponseBody": ".form_submissions_get_form_submissions_not_implemented_error_response_body",
    "FormSubmissionsGetFormSubmissionsPdfExportsBadGatewayErrorResponseBody": ".form_submissions_get_form_submissions_pdf_exports_bad_gateway_error_response_body",
    "FormSubmissionsGetFormSubmissionsPdfExportsGatewayTimeoutErrorResponseBody": ".form_submissions_get_form_submissions_pdf_exports_gateway_timeout_error_response_body",
    "FormSubmissionsGetFormSubmissionsPdfExportsInternalServerErrorResponseBody": ".form_submissions_get_form_submissions_pdf_exports_internal_server_error_response_body",
    "FormSubmissionsGetFormSubmissionsPdfExportsMethodNotAllowedErrorResponseBody": ".form_submissions_get_form_submissions_pdf_exports_method_not_allowed_error_response_body",
    "FormSubmissionsGetFormSubmissionsPdfExportsNotFoundErrorResponseBody": ".form_submissions_get_form_submissions_pdf_exports_not_found_error_response_body",
    "FormSubmissionsGetFormSubmissionsPdfExportsNotImplementedErrorResponseBody": ".form_submissions_get_form_submissions_pdf_exports_not_implemented_error_response_body",
    "FormSubmissionsGetFormSubmissionsPdfExportsResponseBody": ".form_submissions_get_form_submissions_pdf_exports_response_body",
    "FormSubmissionsGetFormSubmissionsPdfExportsServiceUnavailableErrorResponseBody": ".form_submissions_get_form_submissions_pdf_exports_service_unavailable_error_response_body",
    "FormSubmissionsGetFormSubmissionsPdfExportsTooManyRequestsErrorResponseBody": ".form_submissions_get_form_submissions_pdf_exports_too_many_requests_error_response_body",
    "FormSubmissionsGetFormSubmissionsPdfExportsUnauthorizedErrorResponseBody": ".form_submissions_get_form_submissions_pdf_exports_unauthorized_error_response_body",
    "FormSubmissionsGetFormSubmissionsResponseBody": ".form_submissions_get_form_submissions_response_body",
    "FormSubmissionsGetFormSubmissionsServiceUnavailableErrorResponseBody": ".form_submissions_get_form_submissions_service_unavailable_error_response_body",
    "FormSubmissionsGetFormSubmissionsStreamBadGatewayErrorResponseBody": ".form_submissions_get_form_submissions_stream_bad_gateway_error_response_body",
    "FormSubmissionsGetFormSubmissionsStreamGatewayTimeoutErrorResponseBody": ".form_submissions_get_form_submissions_stream_gateway_timeout_error_response_body",
    "FormSubmissionsGetFormSubmissionsStreamInternalServerErrorResponseBody": ".form_submissions_get_form_submissions_stream_internal_server_error_response_body",
    "FormSubmissionsGetFormSubmissionsStreamMethodNotAllowedErrorResponseBody": ".form_submissions_get_form_submissions_stream_method_not_allowed_error_response_body",
    "FormSubmissionsGetFormSubmissionsStreamNotFoundErrorResponseBody": ".form_submissions_get_form_submissions_stream_not_found_error_response_body",
    "FormSubmissionsGetFormSubmissionsStreamNotImplementedErrorResponseBody": ".form_submissions_get_form_submissions_stream_not_implemented_error_response_body",
    "FormSubmissionsGetFormSubmissionsStreamResponseBody": ".form_submissions_get_form_submissions_stream_response_body",
    "FormSubmissionsGetFormSubmissionsStreamServiceUnavailableErrorResponseBody": ".form_submissions_get_form_submissions_stream_service_unavailable_error_response_body",
    "FormSubmissionsGetFormSubmissionsStreamTooManyRequestsErrorResponseBody": ".form_submissions_get_form_submissions_stream_too_many_requests_error_response_body",
    "FormSubmissionsGetFormSubmissionsStreamUnauthorizedErrorResponseBody": ".form_submissions_get_form_submissions_stream_unauthorized_error_response_body",
    "FormSubmissionsGetFormSubmissionsTooManyRequestsErrorResponseBody": ".form_submissions_get_form_submissions_too_many_requests_error_response_body",
    "FormSubmissionsGetFormSubmissionsUnauthorizedErrorResponseBody": ".form_submissions_get_form_submissions_unauthorized_error_response_body",
    "FormSubmissionsPatchFormSubmissionBadGatewayErrorResponseBody": ".form_submissions_patch_form_submission_bad_gateway_error_response_body",
    "FormSubmissionsPatchFormSubmissionGatewayTimeoutErrorResponseBody": ".form_submissions_patch_form_submission_gateway_timeout_error_response_body",
    "FormSubmissionsPatchFormSubmissionInternalServerErrorResponseBody": ".form_submissions_patch_form_submission_internal_server_error_response_body",
    "FormSubmissionsPatchFormSubmissionMethodNotAllowedErrorResponseBody": ".form_submissions_patch_form_submission_method_not_allowed_error_response_body",
    "FormSubmissionsPatchFormSubmissionNotFoundErrorResponseBody": ".form_submissions_patch_form_submission_not_found_error_response_body",
    "FormSubmissionsPatchFormSubmissionNotImplementedErrorResponseBody": ".form_submissions_patch_form_submission_not_implemented_error_response_body",
    "FormSubmissionsPatchFormSubmissionResponseBody": ".form_submissions_patch_form_submission_response_body",
    "FormSubmissionsPatchFormSubmissionServiceUnavailableErrorResponseBody": ".form_submissions_patch_form_submission_service_unavailable_error_response_body",
    "FormSubmissionsPatchFormSubmissionTooManyRequestsErrorResponseBody": ".form_submissions_patch_form_submission_too_many_requests_error_response_body",
    "FormSubmissionsPatchFormSubmissionUnauthorizedErrorResponseBody": ".form_submissions_patch_form_submission_unauthorized_error_response_body",
    "FormSubmissionsPostFormSubmissionBadGatewayErrorResponseBody": ".form_submissions_post_form_submission_bad_gateway_error_response_body",
    "FormSubmissionsPostFormSubmissionGatewayTimeoutErrorResponseBody": ".form_submissions_post_form_submission_gateway_timeout_error_response_body",
    "FormSubmissionsPostFormSubmissionInternalServerErrorResponseBody": ".form_submissions_post_form_submission_internal_server_error_response_body",
    "FormSubmissionsPostFormSubmissionMethodNotAllowedErrorResponseBody": ".form_submissions_post_form_submission_method_not_allowed_error_response_body",
    "FormSubmissionsPostFormSubmissionNotFoundErrorResponseBody": ".form_submissions_post_form_submission_not_found_error_response_body",
    "FormSubmissionsPostFormSubmissionNotImplementedErrorResponseBody": ".form_submissions_post_form_submission_not_implemented_error_response_body",
    "FormSubmissionsPostFormSubmissionResponseBody": ".form_submissions_post_form_submission_response_body",
    "FormSubmissionsPostFormSubmissionServiceUnavailableErrorResponseBody": ".form_submissions_post_form_submission_service_unavailable_error_response_body",
    "FormSubmissionsPostFormSubmissionTooManyRequestsErrorResponseBody": ".form_submissions_post_form_submission_too_many_requests_error_response_body",
    "FormSubmissionsPostFormSubmissionUnauthorizedErrorResponseBody": ".form_submissions_post_form_submission_unauthorized_error_response_body",
    "FormSubmissionsPostFormSubmissionsPdfExportsBadGatewayErrorResponseBody": ".form_submissions_post_form_submissions_pdf_exports_bad_gateway_error_response_body",
    "FormSubmissionsPostFormSubmissionsPdfExportsGatewayTimeoutErrorResponseBody": ".form_submissions_post_form_submissions_pdf_exports_gateway_timeout_error_response_body",
    "FormSubmissionsPostFormSubmissionsPdfExportsInternalServerErrorResponseBody": ".form_submissions_post_form_submissions_pdf_exports_internal_server_error_response_body",
    "FormSubmissionsPostFormSubmissionsPdfExportsMethodNotAllowedErrorResponseBody": ".form_submissions_post_form_submissions_pdf_exports_method_not_allowed_error_response_body",
    "FormSubmissionsPostFormSubmissionsPdfExportsNotFoundErrorResponseBody": ".form_submissions_post_form_submissions_pdf_exports_not_found_error_response_body",
    "FormSubmissionsPostFormSubmissionsPdfExportsNotImplementedErrorResponseBody": ".form_submissions_post_form_submissions_pdf_exports_not_implemented_error_response_body",
    "FormSubmissionsPostFormSubmissionsPdfExportsResponseBody": ".form_submissions_post_form_submissions_pdf_exports_response_body",
    "FormSubmissionsPostFormSubmissionsPdfExportsServiceUnavailableErrorResponseBody": ".form_submissions_post_form_submissions_pdf_exports_service_unavailable_error_response_body",
    "FormSubmissionsPostFormSubmissionsPdfExportsTooManyRequestsErrorResponseBody": ".form_submissions_post_form_submissions_pdf_exports_too_many_requests_error_response_body",
    "FormSubmissionsPostFormSubmissionsPdfExportsUnauthorizedErrorResponseBody": ".form_submissions_post_form_submissions_pdf_exports_unauthorized_error_response_body",
    "FormSubmittedResponseBody": ".form_submitted_response_body",
    "FormTemplateReferenceObjectResponseBody": ".form_template_reference_object_response_body",
    "FormTemplateRequestObjectRequestBody": ".form_template_request_object_request_body",
    "FormTemplateResponseObjectResponseBody": ".form_template_response_object_response_body",
    "FormTemplateResponseObjectResponseBodyFormCategory": ".form_template_response_object_response_body_form_category",
    "FormTemplateSectionObjectResponseBody": ".form_template_section_object_response_body",
    "FormTemplatesGetFormTemplatesBadGatewayErrorResponseBody": ".form_templates_get_form_templates_bad_gateway_error_response_body",
    "FormTemplatesGetFormTemplatesGatewayTimeoutErrorResponseBody": ".form_templates_get_form_templates_gateway_timeout_error_response_body",
    "FormTemplatesGetFormTemplatesInternalServerErrorResponseBody": ".form_templates_get_form_templates_internal_server_error_response_body",
    "FormTemplatesGetFormTemplatesMethodNotAllowedErrorResponseBody": ".form_templates_get_form_templates_method_not_allowed_error_response_body",
    "FormTemplatesGetFormTemplatesNotFoundErrorResponseBody": ".form_templates_get_form_templates_not_found_error_response_body",
    "FormTemplatesGetFormTemplatesNotImplementedErrorResponseBody": ".form_templates_get_form_templates_not_implemented_error_response_body",
    "FormTemplatesGetFormTemplatesResponseBody": ".form_templates_get_form_templates_response_body",
    "FormTemplatesGetFormTemplatesServiceUnavailableErrorResponseBody": ".form_templates_get_form_templates_service_unavailable_error_response_body",
    "FormTemplatesGetFormTemplatesTooManyRequestsErrorResponseBody": ".form_templates_get_form_templates_too_many_requests_error_response_body",
    "FormTemplatesGetFormTemplatesUnauthorizedErrorResponseBody": ".form_templates_get_form_templates_unauthorized_error_response_body",
    "FormUpdatedResponseBody": ".form_updated_response_body",
    "FormsActionObjectResponseBody": ".forms_action_object_response_body",
    "FormsActionObjectResponseBodyType": ".forms_action_object_response_body_type",
    "FormsApprovalConfigObjectResponseBody": ".forms_approval_config_object_response_body",
    "FormsApprovalConfigObjectResponseBodyType": ".forms_approval_config_object_response_body_type",
    "FormsAssetObjectResponseBody": ".forms_asset_object_response_body",
    "FormsAssetObjectResponseBodyEntryType": ".forms_asset_object_response_body_entry_type",
    "FormsAssetValueObjectResponseBody": ".forms_asset_value_object_response_body",
    "FormsCheckBoxesValueObjectResponseBody": ".forms_check_boxes_value_object_response_body",
    "FormsConditionObjectResponseBody": ".forms_condition_object_response_body",
    "FormsConditionObjectResponseBodyType": ".forms_condition_object_response_body_type",
    "FormsConditionalActionObjectResponseBody": ".forms_conditional_action_object_response_body",
    "FormsDateTimeValueObjectResponseBody": ".forms_date_time_value_object_response_body",
    "FormsDateTimeValueObjectResponseBodyType": ".forms_date_time_value_object_response_body_type",
    "FormsFieldDefinitionObjectResponseBody": ".forms_field_definition_object_response_body",
    "FormsFieldDefinitionObjectResponseBodyAllowedAssetTypesItem": ".forms_field_definition_object_response_body_allowed_asset_types_item",
    "FormsFieldDefinitionObjectResponseBodyAllowedDateTimeValueType": ".forms_field_definition_object_response_body_allowed_date_time_value_type",
    "FormsFieldDefinitionObjectResponseBodyType": ".forms_field_definition_object_response_body_type",
    "FormsFieldInputObjectResponseBody": ".forms_field_input_object_response_body",
    "FormsFieldInputObjectResponseBodyType": ".forms_field_input_object_response_body_type",
    "FormsGeofenceObjectResponseBody": ".forms_geofence_object_response_body",
    "FormsGeofenceObjectResponseBodyEntryType": ".forms_geofence_object_response_body_entry_type",
    "FormsGeofenceValueObjectResponseBody": ".forms_geofence_value_object_response_body",
    "FormsIssueCreatedByFieldObjectResponseBody": ".forms_issue_created_by_field_object_response_body",
    "FormsLocationObjectResponseBody": ".forms_location_object_response_body",
    "FormsMediaRecordObjectResponseBody": ".forms_media_record_object_response_body",
    "FormsMediaRecordObjectResponseBodyProcessingStatus": ".forms_media_record_object_response_body_processing_status",
    "FormsMediaValueObjectResponseBody": ".forms_media_value_object_response_body",
    "FormsMultipleChoiceValueObjectResponseBody": ".forms_multiple_choice_value_object_response_body",
    "FormsNumberValueObjectResponseBody": ".forms_number_value_object_response_body",
    "FormsPersonObjectResponseBody": ".forms_person_object_response_body",
    "FormsPersonObjectResponseBodyEntryType": ".forms_person_object_response_body_entry_type",
    "FormsPersonValueObjectResponseBody": ".forms_person_value_object_response_body",
    "FormsPolymorphicUserObjectResponseBody": ".forms_polymorphic_user_object_response_body",
    "FormsPolymorphicUserObjectResponseBodyType": ".forms_polymorphic_user_object_response_body_type",
    "FormsProductSubmissionApprovalDetailsObjectResponseBody": ".forms_product_submission_approval_details_object_response_body",
    "FormsScoreObjectResponseBody": ".forms_score_object_response_body",
    "FormsSelectOptionObjectResponseBody": ".forms_select_option_object_response_body",
    "FormsSignatureValueObjectResponseBody": ".forms_signature_value_object_response_body",
    "FormsSingleApprovalConfigObjectResponseBody": ".forms_single_approval_config_object_response_body",
    "FormsTableCellObjectResponseBody": ".forms_table_cell_object_response_body",
    "FormsTableCellObjectResponseBodyType": ".forms_table_cell_object_response_body_type",
    "FormsTableColumnObjectResponseBody": ".forms_table_column_object_response_body",
    "FormsTableColumnObjectResponseBodyType": ".forms_table_column_object_response_body_type",
    "FormsTableFieldDefinitionObjectResponseBody": ".forms_table_field_definition_object_response_body",
    "FormsTableFieldDefinitionObjectResponseBodyAllowedDateTimeValueType": ".forms_table_field_definition_object_response_body_allowed_date_time_value_type",
    "FormsTableFieldDefinitionObjectResponseBodyType": ".forms_table_field_definition_object_response_body_type",
    "FormsTableRowObjectResponseBody": ".forms_table_row_object_response_body",
    "FormsTableValueObjectResponseBody": ".forms_table_value_object_response_body",
    "FormsTextValueObjectResponseBody": ".forms_text_value_object_response_body",
    "ForwardCollisionDetectionAlertSettingsObjectResponseBody": ".forward_collision_detection_alert_settings_object_response_body",
    "ForwardCollisionDetectionAlertSettingsObjectResponseBodySensitivity": ".forward_collision_detection_alert_settings_object_response_body_sensitivity",
    "FuelConsumedMl": ".fuel_consumed_ml",
    "FuelCostObjectResponseBody": ".fuel_cost_object_response_body",
    "FuelCostObjectResponseBodyCurrency": ".fuel_cost_object_response_body_currency",
    "FuelEnergyCostResponseResponseBody": ".fuel_energy_cost_response_response_body",
    "FuelEnergyDriverReportDataObjectResponseBody": ".fuel_energy_driver_report_data_object_response_body",
    "FuelEnergyDriverReportObjectResponseBody": ".fuel_energy_driver_report_object_response_body",
    "FuelEnergyGetFuelEnergyDriverReportsBadGatewayErrorResponseBody": ".fuel_energy_get_fuel_energy_driver_reports_bad_gateway_error_response_body",
    "FuelEnergyGetFuelEnergyDriverReportsGatewayTimeoutErrorResponseBody": ".fuel_energy_get_fuel_energy_driver_reports_gateway_timeout_error_response_body",
    "FuelEnergyGetFuelEnergyDriverReportsInternalServerErrorResponseBody": ".fuel_energy_get_fuel_energy_driver_reports_internal_server_error_response_body",
    "FuelEnergyGetFuelEnergyDriverReportsMethodNotAllowedErrorResponseBody": ".fuel_energy_get_fuel_energy_driver_reports_method_not_allowed_error_response_body",
    "FuelEnergyGetFuelEnergyDriverReportsNotFoundErrorResponseBody": ".fuel_energy_get_fuel_energy_driver_reports_not_found_error_response_body",
    "FuelEnergyGetFuelEnergyDriverReportsNotImplementedErrorResponseBody": ".fuel_energy_get_fuel_energy_driver_reports_not_implemented_error_response_body",
    "FuelEnergyGetFuelEnergyDriverReportsResponseBody": ".fuel_energy_get_fuel_energy_driver_reports_response_body",
    "FuelEnergyGetFuelEnergyDriverReportsServiceUnavailableErrorResponseBody": ".fuel_energy_get_fuel_energy_driver_reports_service_unavailable_error_response_body",
    "FuelEnergyGetFuelEnergyDriverReportsTooManyRequestsErrorResponseBody": ".fuel_energy_get_fuel_energy_driver_reports_too_many_requests_error_response_body",
    "FuelEnergyGetFuelEnergyDriverReportsUnauthorizedErrorResponseBody": ".fuel_energy_get_fuel_energy_driver_reports_unauthorized_error_response_body",
    "FuelEnergyGetFuelEnergyVehicleReportsBadGatewayErrorResponseBody": ".fuel_energy_get_fuel_energy_vehicle_reports_bad_gateway_error_response_body",
    "FuelEnergyGetFuelEnergyVehicleReportsGatewayTimeoutErrorResponseBody": ".fuel_energy_get_fuel_energy_vehicle_reports_gateway_timeout_error_response_body",
    "FuelEnergyGetFuelEnergyVehicleReportsInternalServerErrorResponseBody": ".fuel_energy_get_fuel_energy_vehicle_reports_internal_server_error_response_body",
    "FuelEnergyGetFuelEnergyVehicleReportsMethodNotAllowedErrorResponseBody": ".fuel_energy_get_fuel_energy_vehicle_reports_method_not_allowed_error_response_body",
    "FuelEnergyGetFuelEnergyVehicleReportsNotFoundErrorResponseBody": ".fuel_energy_get_fuel_energy_vehicle_reports_not_found_error_response_body",
    "FuelEnergyGetFuelEnergyVehicleReportsNotImplementedErrorResponseBody": ".fuel_energy_get_fuel_energy_vehicle_reports_not_implemented_error_response_body",
    "FuelEnergyGetFuelEnergyVehicleReportsResponseBody": ".fuel_energy_get_fuel_energy_vehicle_reports_response_body",
    "FuelEnergyGetFuelEnergyVehicleReportsServiceUnavailableErrorResponseBody": ".fuel_energy_get_fuel_energy_vehicle_reports_service_unavailable_error_response_body",
    "FuelEnergyGetFuelEnergyVehicleReportsTooManyRequestsErrorResponseBody": ".fuel_energy_get_fuel_energy_vehicle_reports_too_many_requests_error_response_body",
    "FuelEnergyGetFuelEnergyVehicleReportsUnauthorizedErrorResponseBody": ".fuel_energy_get_fuel_energy_vehicle_reports_unauthorized_error_response_body",
    "FuelEnergyVehicleObjectResponseBody": ".fuel_energy_vehicle_object_response_body",
    "FuelEnergyVehicleObjectResponseBodyEnergyType": ".fuel_energy_vehicle_object_response_body_energy_type",
    "FuelEnergyVehicleReportDataObjectResponseBody": ".fuel_energy_vehicle_report_data_object_response_body",
    "FuelEnergyVehicleReportObjectResponseBody": ".fuel_energy_vehicle_report_object_response_body",
    "FuelLevelPercentageResponseBody": ".fuel_level_percentage_response_body",
    "FuelLevelTriggerDetailsObjectRequestBody": ".fuel_level_trigger_details_object_request_body",
    "FuelLevelTriggerDetailsObjectRequestBodyOperation": ".fuel_level_trigger_details_object_request_body_operation",
    "FuelLevelTriggerDetailsObjectResponseBody": ".fuel_level_trigger_details_object_response_body",
    "FuelLevelTriggerDetailsObjectResponseBodyOperation": ".fuel_level_trigger_details_object_response_body_operation",
    "FuelPurchasePostFuelPurchaseBadGatewayErrorResponseBody": ".fuel_purchase_post_fuel_purchase_bad_gateway_error_response_body",
    "FuelPurchasePostFuelPurchaseGatewayTimeoutErrorResponseBody": ".fuel_purchase_post_fuel_purchase_gateway_timeout_error_response_body",
    "FuelPurchasePostFuelPurchaseInternalServerErrorResponseBody": ".fuel_purchase_post_fuel_purchase_internal_server_error_response_body",
    "FuelPurchasePostFuelPurchaseMethodNotAllowedErrorResponseBody": ".fuel_purchase_post_fuel_purchase_method_not_allowed_error_response_body",
    "FuelPurchasePostFuelPurchaseNotFoundErrorResponseBody": ".fuel_purchase_post_fuel_purchase_not_found_error_response_body",
    "FuelPurchasePostFuelPurchaseNotImplementedErrorResponseBody": ".fuel_purchase_post_fuel_purchase_not_implemented_error_response_body",
    "FuelPurchasePostFuelPurchaseResponseBody": ".fuel_purchase_post_fuel_purchase_response_body",
    "FuelPurchasePostFuelPurchaseServiceUnavailableErrorResponseBody": ".fuel_purchase_post_fuel_purchase_service_unavailable_error_response_body",
    "FuelPurchasePostFuelPurchaseTooManyRequestsErrorResponseBody": ".fuel_purchase_post_fuel_purchase_too_many_requests_error_response_body",
    "FuelPurchasePostFuelPurchaseUnauthorizedErrorResponseBody": ".fuel_purchase_post_fuel_purchase_unauthorized_error_response_body",
    "FuelRemainingResponseBody": ".fuel_remaining_response_body",
    "FuelVolumeResponseBody": ".fuel_volume_response_body",
    "FuelVolumeResponseBodyUnit": ".fuel_volume_response_body_unit",
    "FunctionsStartFunctionRunBadGatewayErrorResponseBody": ".functions_start_function_run_bad_gateway_error_response_body",
    "FunctionsStartFunctionRunGatewayTimeoutErrorResponseBody": ".functions_start_function_run_gateway_timeout_error_response_body",
    "FunctionsStartFunctionRunInternalServerErrorResponseBody": ".functions_start_function_run_internal_server_error_response_body",
    "FunctionsStartFunctionRunMethodNotAllowedErrorResponseBody": ".functions_start_function_run_method_not_allowed_error_response_body",
    "FunctionsStartFunctionRunNotFoundErrorResponseBody": ".functions_start_function_run_not_found_error_response_body",
    "FunctionsStartFunctionRunNotImplementedErrorResponseBody": ".functions_start_function_run_not_implemented_error_response_body",
    "FunctionsStartFunctionRunResponseBody": ".functions_start_function_run_response_body",
    "FunctionsStartFunctionRunServiceUnavailableErrorResponseBody": ".functions_start_function_run_service_unavailable_error_response_body",
    "FunctionsStartFunctionRunTooManyRequestsErrorResponseBody": ".functions_start_function_run_too_many_requests_error_response_body",
    "FunctionsStartFunctionRunUnauthorizedErrorResponseBody": ".functions_start_function_run_unauthorized_error_response_body",
    "GaseousFuelCostObjectResponseBody": ".gaseous_fuel_cost_object_response_body",
    "GaseousFuelCostObjectResponseBodyCurrency": ".gaseous_fuel_cost_object_response_body_currency",
    "GatewayAssetResponseObjectResponseBody": ".gateway_asset_response_object_response_body",
    "GatewayDetailsResponseResponseBody": ".gateway_details_response_response_body",
    "GatewayDetailsResponseResponseBodyGatewayBatteryState": ".gateway_details_response_response_body_gateway_battery_state",
    "GatewayDisconnectedDetailsObjectRequestBody": ".gateway_disconnected_details_object_request_body",
    "GatewayDisconnectedDetailsObjectResponseBody": ".gateway_disconnected_details_object_response_body",
    "GatewayDisconnectedResponseBody": ".gateway_disconnected_response_body",
    "GatewayResponseObjectResponseBody": ".gateway_response_object_response_body",
    "GatewayResponseObjectResponseBodyModel": ".gateway_response_object_response_body_model",
    "GatewayTiny": ".gateway_tiny",
    "GatewayUnpluggedTriggerDetailsObjectRequestBody": ".gateway_unplugged_trigger_details_object_request_body",
    "GatewayUnpluggedTriggerDetailsObjectResponseBody": ".gateway_unplugged_trigger_details_object_response_body",
    "GatewayWithVehicleTinyResponseResponseBody": ".gateway_with_vehicle_tiny_response_response_body",
    "GatewayWithVehicleTinyResponseResponseBodyModel": ".gateway_with_vehicle_tiny_response_response_body_model",
    "GatewaysDeleteGatewayBadGatewayErrorResponseBody": ".gateways_delete_gateway_bad_gateway_error_response_body",
    "GatewaysDeleteGatewayGatewayTimeoutErrorResponseBody": ".gateways_delete_gateway_gateway_timeout_error_response_body",
    "GatewaysDeleteGatewayInternalServerErrorResponseBody": ".gateways_delete_gateway_internal_server_error_response_body",
    "GatewaysDeleteGatewayMethodNotAllowedErrorResponseBody": ".gateways_delete_gateway_method_not_allowed_error_response_body",
    "GatewaysDeleteGatewayNotFoundErrorResponseBody": ".gateways_delete_gateway_not_found_error_response_body",
    "GatewaysDeleteGatewayNotImplementedErrorResponseBody": ".gateways_delete_gateway_not_implemented_error_response_body",
    "GatewaysDeleteGatewayServiceUnavailableErrorResponseBody": ".gateways_delete_gateway_service_unavailable_error_response_body",
    "GatewaysDeleteGatewayTooManyRequestsErrorResponseBody": ".gateways_delete_gateway_too_many_requests_error_response_body",
    "GatewaysDeleteGatewayUnauthorizedErrorResponseBody": ".gateways_delete_gateway_unauthorized_error_response_body",
    "GatewaysGetGatewaysBadGatewayErrorResponseBody": ".gateways_get_gateways_bad_gateway_error_response_body",
    "GatewaysGetGatewaysGatewayTimeoutErrorResponseBody": ".gateways_get_gateways_gateway_timeout_error_response_body",
    "GatewaysGetGatewaysInternalServerErrorResponseBody": ".gateways_get_gateways_internal_server_error_response_body",
    "GatewaysGetGatewaysMethodNotAllowedErrorResponseBody": ".gateways_get_gateways_method_not_allowed_error_response_body",
    "GatewaysGetGatewaysNotFoundErrorResponseBody": ".gateways_get_gateways_not_found_error_response_body",
    "GatewaysGetGatewaysNotImplementedErrorResponseBody": ".gateways_get_gateways_not_implemented_error_response_body",
    "GatewaysGetGatewaysResponseBody": ".gateways_get_gateways_response_body",
    "GatewaysGetGatewaysServiceUnavailableErrorResponseBody": ".gateways_get_gateways_service_unavailable_error_response_body",
    "GatewaysGetGatewaysTooManyRequestsErrorResponseBody": ".gateways_get_gateways_too_many_requests_error_response_body",
    "GatewaysGetGatewaysUnauthorizedErrorResponseBody": ".gateways_get_gateways_unauthorized_error_response_body",
    "GatewaysPostGatewayBadGatewayErrorResponseBody": ".gateways_post_gateway_bad_gateway_error_response_body",
    "GatewaysPostGatewayGatewayTimeoutErrorResponseBody": ".gateways_post_gateway_gateway_timeout_error_response_body",
    "GatewaysPostGatewayInternalServerErrorResponseBody": ".gateways_post_gateway_internal_server_error_response_body",
    "GatewaysPostGatewayMethodNotAllowedErrorResponseBody": ".gateways_post_gateway_method_not_allowed_error_response_body",
    "GatewaysPostGatewayNotFoundErrorResponseBody": ".gateways_post_gateway_not_found_error_response_body",
    "GatewaysPostGatewayNotImplementedErrorResponseBody": ".gateways_post_gateway_not_implemented_error_response_body",
    "GatewaysPostGatewayResponseBody": ".gateways_post_gateway_response_body",
    "GatewaysPostGatewayServiceUnavailableErrorResponseBody": ".gateways_post_gateway_service_unavailable_error_response_body",
    "GatewaysPostGatewayTooManyRequestsErrorResponseBody": ".gateways_post_gateway_too_many_requests_error_response_body",
    "GatewaysPostGatewayUnauthorizedErrorResponseBody": ".gateways_post_gateway_unauthorized_error_response_body",
    "GeofenceEntryTriggerDetailsObjectRequestBody": ".geofence_entry_trigger_details_object_request_body",
    "GeofenceEntryTriggerDetailsObjectResponseBody": ".geofence_entry_trigger_details_object_response_body",
    "GeofenceExitTriggerDetailsObjectRequestBody": ".geofence_exit_trigger_details_object_request_body",
    "GeofenceExitTriggerDetailsObjectResponseBody": ".geofence_exit_trigger_details_object_response_body",
    "GeofenceResponseResponseBody": ".geofence_response_response_body",
    "GetAttributesByEntityTypeResponse": ".get_attributes_by_entity_type_response",
    "GetDocumentTypeResponseObjectResponseBody": ".get_document_type_response_object_response_body",
    "GetDriverTrailerAssignmentsResponseBodyResponseBody": ".get_driver_trailer_assignments_response_body_response_body",
    "GetMediaRetrievalObjectResponseBody": ".get_media_retrieval_object_response_body",
    "GetReportRunsDataObjectResponseBody": ".get_report_runs_data_object_response_body",
    "GetReportRunsDataObjectResponseBodyStatus": ".get_report_runs_data_object_response_body_status",
    "GetResponseWorkflowConfigurationObjectResponseBody": ".get_response_workflow_configuration_object_response_body",
    "GetWorkflowIncidentResponseObjectResponseBody": ".get_workflow_incident_response_object_response_body",
    "GoaAddressTinyResponseResponseBody": ".goa_address_tiny_response_response_body",
    "GoaAttributeTiny": ".goa_attribute_tiny",
    "GoaAttributeTinyRequestBody": ".goa_attribute_tiny_request_body",
    "GoaAttributeTinyResponseBody": ".goa_attribute_tiny_response_body",
    "GoaDocumentTinyResponseResponseBody": ".goa_document_tiny_response_response_body",
    "GoaDocumentTypeTinyResponseResponseBody": ".goa_document_type_tiny_response_response_body",
    "GoaDriverTinyResponseResponseBody": ".goa_driver_tiny_response_response_body",
    "GoaFormTinyResponseResponseBody": ".goa_form_tiny_response_response_body",
    "GoaGatewayTinyResponseResponseBody": ".goa_gateway_tiny_response_response_body",
    "GoaGatewayTinyResponseResponseBodyModel": ".goa_gateway_tiny_response_response_body_model",
    "GoaIssueTinyResponseResponseBody": ".goa_issue_tiny_response_response_body",
    "GoaPaginationResponseResponseBody": ".goa_pagination_response_response_body",
    "GoaPaginationWithTokensResponseResponseBody": ".goa_pagination_with_tokens_response_response_body",
    "GoaRouteStopTinyResponseResponseBody": ".goa_route_stop_tiny_response_response_body",
    "GoaRouteTinyResponseResponseBody": ".goa_route_tiny_response_response_body",
    "GoaTagTinyResponseRequestBody": ".goa_tag_tiny_response_request_body",
    "GoaTagTinyResponseResponseBody": ".goa_tag_tiny_response_response_body",
    "GoaTrailerTinyResponseResponseBody": ".goa_trailer_tiny_response_response_body",
    "GoaVehicleTinyResponseResponseBody": ".goa_vehicle_tiny_response_response_body",
    "GpsSignalLossDetailsObjectRequestBody": ".gps_signal_loss_details_object_request_body",
    "GpsSignalLossDetailsObjectResponseBody": ".gps_signal_loss_details_object_response_body",
    "GpsSignalLossResponseBody": ".gps_signal_loss_response_body",
    "GreenBandDrivingDurationMs": ".green_band_driving_duration_ms",
    "GrossVehicleWeight": ".gross_vehicle_weight",
    "GrossVehicleWeightUnit": ".gross_vehicle_weight_unit",
    "HarshAccelSensitivityGForceSettingsObjectResponseBody": ".harsh_accel_sensitivity_g_force_settings_object_response_body",
    "HarshAccelSensitivityV2SettingsObjectResponseBody": ".harsh_accel_sensitivity_v_2_settings_object_response_body",
    "HarshAccelSensitivityV2SettingsObjectResponseBodyHeavyDuty": ".harsh_accel_sensitivity_v_2_settings_object_response_body_heavy_duty",
    "HarshAccelSensitivityV2SettingsObjectResponseBodyLightDuty": ".harsh_accel_sensitivity_v_2_settings_object_response_body_light_duty",
    "HarshAccelSensitivityV2SettingsObjectResponseBodyPassenger": ".harsh_accel_sensitivity_v_2_settings_object_response_body_passenger",
    "HarshBrakeSensitivityGForceSettingsObjectResponseBody": ".harsh_brake_sensitivity_g_force_settings_object_response_body",
    "HarshBrakeSensitivityV2SettingsObjectResponseBody": ".harsh_brake_sensitivity_v_2_settings_object_response_body",
    "HarshBrakeSensitivityV2SettingsObjectResponseBodyHeavyDuty": ".harsh_brake_sensitivity_v_2_settings_object_response_body_heavy_duty",
    "HarshBrakeSensitivityV2SettingsObjectResponseBodyLightDuty": ".harsh_brake_sensitivity_v_2_settings_object_response_body_light_duty",
    "HarshBrakeSensitivityV2SettingsObjectResponseBodyPassenger": ".harsh_brake_sensitivity_v_2_settings_object_response_body_passenger",
    "HarshEventDataResponseBody": ".harsh_event_data_response_body",
    "HarshEventSensitivitySettingsObjectResponseBody": ".harsh_event_sensitivity_settings_object_response_body",
    "HarshEventSensitivityV2SettingsObjectResponseBody": ".harsh_event_sensitivity_v_2_settings_object_response_body",
    "HarshEventTriggerDetailsObjectRequestBody": ".harsh_event_trigger_details_object_request_body",
    "HarshEventTriggerDetailsObjectRequestBodyTypesItem": ".harsh_event_trigger_details_object_request_body_types_item",
    "HarshEventTriggerDetailsObjectResponseBody": ".harsh_event_trigger_details_object_response_body",
    "HarshEventTriggerDetailsObjectResponseBodyTypesItem": ".harsh_event_trigger_details_object_response_body_types_item",
    "HarshTurnSensitivityGForceSettingsObjectResponseBody": ".harsh_turn_sensitivity_g_force_settings_object_response_body",
    "HarshTurnSensitivityV2SettingsObjectResponseBody": ".harsh_turn_sensitivity_v_2_settings_object_response_body",
    "HarshTurnSensitivityV2SettingsObjectResponseBodyHeavyDuty": ".harsh_turn_sensitivity_v_2_settings_object_response_body_heavy_duty",
    "HarshTurnSensitivityV2SettingsObjectResponseBodyLightDuty": ".harsh_turn_sensitivity_v_2_settings_object_response_body_light_duty",
    "HarshTurnSensitivityV2SettingsObjectResponseBodyPassenger": ".harsh_turn_sensitivity_v_2_settings_object_response_body_passenger",
    "HealthDetailsResponseResponseBody": ".health_details_response_response_body",
    "HealthReasonResponseResponseBody": ".health_reason_response_response_body",
    "HealthReasonResponseResponseBodyHealthReasonCode": ".health_reason_response_response_body_health_reason_code",
    "HealthResponseResponseBody": ".health_response_response_body",
    "HealthResponseResponseBodyHealthStatus": ".health_response_response_body_health_status",
    "HealthResponseResponseBodyPrimaryHealthReason": ".health_response_response_body_primary_health_reason",
    "HealthResponseResponseBodyRecommendedAction": ".health_response_response_body_recommended_action",
    "HighTorqueMs": ".high_torque_ms",
    "HosBreak": ".hos_break",
    "HosClocks": ".hos_clocks",
    "HosClocksForDriver": ".hos_clocks_for_driver",
    "HosClocksForDrivers": ".hos_clocks_for_drivers",
    "HosClocksResponse": ".hos_clocks_response",
    "HosCycle": ".hos_cycle",
    "HosDailyLogsGetHosDailyLogsBadGatewayErrorResponseBody": ".hos_daily_logs_get_hos_daily_logs_bad_gateway_error_response_body",
    "HosDailyLogsGetHosDailyLogsGatewayTimeoutErrorResponseBody": ".hos_daily_logs_get_hos_daily_logs_gateway_timeout_error_response_body",
    "HosDailyLogsGetHosDailyLogsInternalServerErrorResponseBody": ".hos_daily_logs_get_hos_daily_logs_internal_server_error_response_body",
    "HosDailyLogsGetHosDailyLogsMethodNotAllowedErrorResponseBody": ".hos_daily_logs_get_hos_daily_logs_method_not_allowed_error_response_body",
    "HosDailyLogsGetHosDailyLogsNotFoundErrorResponseBody": ".hos_daily_logs_get_hos_daily_logs_not_found_error_response_body",
    "HosDailyLogsGetHosDailyLogsNotImplementedErrorResponseBody": ".hos_daily_logs_get_hos_daily_logs_not_implemented_error_response_body",
    "HosDailyLogsGetHosDailyLogsResponseBody": ".hos_daily_logs_get_hos_daily_logs_response_body",
    "HosDailyLogsGetHosDailyLogsServiceUnavailableErrorResponseBody": ".hos_daily_logs_get_hos_daily_logs_service_unavailable_error_response_body",
    "HosDailyLogsGetHosDailyLogsTooManyRequestsErrorResponseBody": ".hos_daily_logs_get_hos_daily_logs_too_many_requests_error_response_body",
    "HosDailyLogsGetHosDailyLogsUnauthorizedErrorResponseBody": ".hos_daily_logs_get_hos_daily_logs_unauthorized_error_response_body",
    "HosDailyLogsObjectResponseBody": ".hos_daily_logs_object_response_body",
    "HosDailyLogsUpdateShippingDocsBadGatewayErrorResponseBody": ".hos_daily_logs_update_shipping_docs_bad_gateway_error_response_body",
    "HosDailyLogsUpdateShippingDocsGatewayTimeoutErrorResponseBody": ".hos_daily_logs_update_shipping_docs_gateway_timeout_error_response_body",
    "HosDailyLogsUpdateShippingDocsInternalServerErrorResponseBody": ".hos_daily_logs_update_shipping_docs_internal_server_error_response_body",
    "HosDailyLogsUpdateShippingDocsMethodNotAllowedErrorResponseBody": ".hos_daily_logs_update_shipping_docs_method_not_allowed_error_response_body",
    "HosDailyLogsUpdateShippingDocsNotFoundErrorResponseBody": ".hos_daily_logs_update_shipping_docs_not_found_error_response_body",
    "HosDailyLogsUpdateShippingDocsNotImplementedErrorResponseBody": ".hos_daily_logs_update_shipping_docs_not_implemented_error_response_body",
    "HosDailyLogsUpdateShippingDocsResponseBody": ".hos_daily_logs_update_shipping_docs_response_body",
    "HosDailyLogsUpdateShippingDocsServiceUnavailableErrorResponseBody": ".hos_daily_logs_update_shipping_docs_service_unavailable_error_response_body",
    "HosDailyLogsUpdateShippingDocsTooManyRequestsErrorResponseBody": ".hos_daily_logs_update_shipping_docs_too_many_requests_error_response_body",
    "HosDailyLogsUpdateShippingDocsUnauthorizedErrorResponseBody": ".hos_daily_logs_update_shipping_docs_unauthorized_error_response_body",
    "HosDrive": ".hos_drive",
    "HosDriversEldEventObjectResponseBody": ".hos_drivers_eld_event_object_response_body",
    "HosDriversEldEventObjectResponseBodyDriverActivationStatus": ".hos_drivers_eld_event_object_response_body_driver_activation_status",
    "HosEldEventLocationObjectResponseBody": ".hos_eld_event_location_object_response_body",
    "HosEldEventObjectResponseBody": ".hos_eld_event_object_response_body",
    "HosEldEventObjectResponseBodyMalfunctionDiagnosticCode": ".hos_eld_event_object_response_body_malfunction_diagnostic_code",
    "HosEldEventRemarkObjectResponseBody": ".hos_eld_event_remark_object_response_body",
    "HosEldEventsGetHosEldEventsBadGatewayErrorResponseBody": ".hos_eld_events_get_hos_eld_events_bad_gateway_error_response_body",
    "HosEldEventsGetHosEldEventsGatewayTimeoutErrorResponseBody": ".hos_eld_events_get_hos_eld_events_gateway_timeout_error_response_body",
    "HosEldEventsGetHosEldEventsInternalServerErrorResponseBody": ".hos_eld_events_get_hos_eld_events_internal_server_error_response_body",
    "HosEldEventsGetHosEldEventsMethodNotAllowedErrorResponseBody": ".hos_eld_events_get_hos_eld_events_method_not_allowed_error_response_body",
    "HosEldEventsGetHosEldEventsNotFoundErrorResponseBody": ".hos_eld_events_get_hos_eld_events_not_found_error_response_body",
    "HosEldEventsGetHosEldEventsNotImplementedErrorResponseBody": ".hos_eld_events_get_hos_eld_events_not_implemented_error_response_body",
    "HosEldEventsGetHosEldEventsResponseBody": ".hos_eld_events_get_hos_eld_events_response_body",
    "HosEldEventsGetHosEldEventsServiceUnavailableErrorResponseBody": ".hos_eld_events_get_hos_eld_events_service_unavailable_error_response_body",
    "HosEldEventsGetHosEldEventsTooManyRequestsErrorResponseBody": ".hos_eld_events_get_hos_eld_events_too_many_requests_error_response_body",
    "HosEldEventsGetHosEldEventsUnauthorizedErrorResponseBody": ".hos_eld_events_get_hos_eld_events_unauthorized_error_response_body",
    "HosLogEntry": ".hos_log_entry",
    "HosLogEntryHosStatusType": ".hos_log_entry_hos_status_type",
    "HosLogLocation": ".hos_log_location",
    "HosLogsForDriver": ".hos_logs_for_driver",
    "HosLogsForDrivers": ".hos_logs_for_drivers",
    "HosLogsList": ".hos_logs_list",
    "HosLogsResponse": ".hos_logs_response",
    "HosShift": ".hos_shift",
    "HosViolationDataResponseBody": ".hos_violation_data_response_body",
    "HosViolationDayObjectResponseBody": ".hos_violation_day_object_response_body",
    "HosViolationObjectResponseBody": ".hos_violation_object_response_body",
    "HosViolationObjectResponseBodyType": ".hos_violation_object_response_body_type",
    "HosViolationTriggerDetailsObjectRequestBody": ".hos_violation_trigger_details_object_request_body",
    "HosViolationTriggerDetailsObjectRequestBodyViolation": ".hos_violation_trigger_details_object_request_body_violation",
    "HosViolationTriggerDetailsObjectResponseBody": ".hos_violation_trigger_details_object_response_body",
    "HosViolationTriggerDetailsObjectResponseBodyViolation": ".hos_violation_trigger_details_object_response_body_violation",
    "HosViolations": ".hos_violations",
    "HosViolationsGetHosViolationsBadGatewayErrorResponseBody": ".hos_violations_get_hos_violations_bad_gateway_error_response_body",
    "HosViolationsGetHosViolationsGatewayTimeoutErrorResponseBody": ".hos_violations_get_hos_violations_gateway_timeout_error_response_body",
    "HosViolationsGetHosViolationsInternalServerErrorResponseBody": ".hos_violations_get_hos_violations_internal_server_error_response_body",
    "HosViolationsGetHosViolationsMethodNotAllowedErrorResponseBody": ".hos_violations_get_hos_violations_method_not_allowed_error_response_body",
    "HosViolationsGetHosViolationsNotFoundErrorResponseBody": ".hos_violations_get_hos_violations_not_found_error_response_body",
    "HosViolationsGetHosViolationsNotImplementedErrorResponseBody": ".hos_violations_get_hos_violations_not_implemented_error_response_body",
    "HosViolationsGetHosViolationsResponseBody": ".hos_violations_get_hos_violations_response_body",
    "HosViolationsGetHosViolationsServiceUnavailableErrorResponseBody": ".hos_violations_get_hos_violations_service_unavailable_error_response_body",
    "HosViolationsGetHosViolationsTooManyRequestsErrorResponseBody": ".hos_violations_get_hos_violations_too_many_requests_error_response_body",
    "HosViolationsGetHosViolationsUnauthorizedErrorResponseBody": ".hos_violations_get_hos_violations_unauthorized_error_response_body",
    "HosViolationsObjectResponseBody": ".hos_violations_object_response_body",
    "HubCapacitiesListHubCapacitiesBadGatewayErrorResponseBody": ".hub_capacities_list_hub_capacities_bad_gateway_error_response_body",
    "HubCapacitiesListHubCapacitiesGatewayTimeoutErrorResponseBody": ".hub_capacities_list_hub_capacities_gateway_timeout_error_response_body",
    "HubCapacitiesListHubCapacitiesInternalServerErrorResponseBody": ".hub_capacities_list_hub_capacities_internal_server_error_response_body",
    "HubCapacitiesListHubCapacitiesMethodNotAllowedErrorResponseBody": ".hub_capacities_list_hub_capacities_method_not_allowed_error_response_body",
    "HubCapacitiesListHubCapacitiesNotFoundErrorResponseBody": ".hub_capacities_list_hub_capacities_not_found_error_response_body",
    "HubCapacitiesListHubCapacitiesNotImplementedErrorResponseBody": ".hub_capacities_list_hub_capacities_not_implemented_error_response_body",
    "HubCapacitiesListHubCapacitiesResponseBody": ".hub_capacities_list_hub_capacities_response_body",
    "HubCapacitiesListHubCapacitiesServiceUnavailableErrorResponseBody": ".hub_capacities_list_hub_capacities_service_unavailable_error_response_body",
    "HubCapacitiesListHubCapacitiesTooManyRequestsErrorResponseBody": ".hub_capacities_list_hub_capacities_too_many_requests_error_response_body",
    "HubCapacitiesListHubCapacitiesUnauthorizedErrorResponseBody": ".hub_capacities_list_hub_capacities_unauthorized_error_response_body",
    "HubCapacityObjectResponseBody": ".hub_capacity_object_response_body",
    "HubCustomPropertiesListHubCustomPropertiesBadGatewayErrorResponseBody": ".hub_custom_properties_list_hub_custom_properties_bad_gateway_error_response_body",
    "HubCustomPropertiesListHubCustomPropertiesGatewayTimeoutErrorResponseBody": ".hub_custom_properties_list_hub_custom_properties_gateway_timeout_error_response_body",
    "HubCustomPropertiesListHubCustomPropertiesInternalServerErrorResponseBody": ".hub_custom_properties_list_hub_custom_properties_internal_server_error_response_body",
    "HubCustomPropertiesListHubCustomPropertiesMethodNotAllowedErrorResponseBody": ".hub_custom_properties_list_hub_custom_properties_method_not_allowed_error_response_body",
    "HubCustomPropertiesListHubCustomPropertiesNotFoundErrorResponseBody": ".hub_custom_properties_list_hub_custom_properties_not_found_error_response_body",
    "HubCustomPropertiesListHubCustomPropertiesNotImplementedErrorResponseBody": ".hub_custom_properties_list_hub_custom_properties_not_implemented_error_response_body",
    "HubCustomPropertiesListHubCustomPropertiesResponseBody": ".hub_custom_properties_list_hub_custom_properties_response_body",
    "HubCustomPropertiesListHubCustomPropertiesServiceUnavailableErrorResponseBody": ".hub_custom_properties_list_hub_custom_properties_service_unavailable_error_response_body",
    "HubCustomPropertiesListHubCustomPropertiesTooManyRequestsErrorResponseBody": ".hub_custom_properties_list_hub_custom_properties_too_many_requests_error_response_body",
    "HubCustomPropertiesListHubCustomPropertiesUnauthorizedErrorResponseBody": ".hub_custom_properties_list_hub_custom_properties_unauthorized_error_response_body",
    "HubCustomPropertyObjectResponseBody": ".hub_custom_property_object_response_body",
    "HubLocationCreatedObjectResponseBody": ".hub_location_created_object_response_body",
    "HubLocationInputObjectRequestBody": ".hub_location_input_object_request_body",
    "HubLocationObjectResponseBody": ".hub_location_object_response_body",
    "HubLocationServiceWindowInputRequestBody": ".hub_location_service_window_input_request_body",
    "HubLocationUpdatedObjectResponseBody": ".hub_location_updated_object_response_body",
    "HubLocationsCreateHubLocationsBadGatewayErrorResponseBody": ".hub_locations_create_hub_locations_bad_gateway_error_response_body",
    "HubLocationsCreateHubLocationsGatewayTimeoutErrorResponseBody": ".hub_locations_create_hub_locations_gateway_timeout_error_response_body",
    "HubLocationsCreateHubLocationsInternalServerErrorResponseBody": ".hub_locations_create_hub_locations_internal_server_error_response_body",
    "HubLocationsCreateHubLocationsMethodNotAllowedErrorResponseBody": ".hub_locations_create_hub_locations_method_not_allowed_error_response_body",
    "HubLocationsCreateHubLocationsNotFoundErrorResponseBody": ".hub_locations_create_hub_locations_not_found_error_response_body",
    "HubLocationsCreateHubLocationsNotImplementedErrorResponseBody": ".hub_locations_create_hub_locations_not_implemented_error_response_body",
    "HubLocationsCreateHubLocationsResponseBody": ".hub_locations_create_hub_locations_response_body",
    "HubLocationsCreateHubLocationsServiceUnavailableErrorResponseBody": ".hub_locations_create_hub_locations_service_unavailable_error_response_body",
    "HubLocationsCreateHubLocationsTooManyRequestsErrorResponseBody": ".hub_locations_create_hub_locations_too_many_requests_error_response_body",
    "HubLocationsCreateHubLocationsUnauthorizedErrorResponseBody": ".hub_locations_create_hub_locations_unauthorized_error_response_body",
    "HubLocationsListHubLocationsBadGatewayErrorResponseBody": ".hub_locations_list_hub_locations_bad_gateway_error_response_body",
    "HubLocationsListHubLocationsGatewayTimeoutErrorResponseBody": ".hub_locations_list_hub_locations_gateway_timeout_error_response_body",
    "HubLocationsListHubLocationsInternalServerErrorResponseBody": ".hub_locations_list_hub_locations_internal_server_error_response_body",
    "HubLocationsListHubLocationsMethodNotAllowedErrorResponseBody": ".hub_locations_list_hub_locations_method_not_allowed_error_response_body",
    "HubLocationsListHubLocationsNotFoundErrorResponseBody": ".hub_locations_list_hub_locations_not_found_error_response_body",
    "HubLocationsListHubLocationsNotImplementedErrorResponseBody": ".hub_locations_list_hub_locations_not_implemented_error_response_body",
    "HubLocationsListHubLocationsResponseBody": ".hub_locations_list_hub_locations_response_body",
    "HubLocationsListHubLocationsServiceUnavailableErrorResponseBody": ".hub_locations_list_hub_locations_service_unavailable_error_response_body",
    "HubLocationsListHubLocationsTooManyRequestsErrorResponseBody": ".hub_locations_list_hub_locations_too_many_requests_error_response_body",
    "HubLocationsListHubLocationsUnauthorizedErrorResponseBody": ".hub_locations_list_hub_locations_unauthorized_error_response_body",
    "HubLocationsUpdateHubLocationBadGatewayErrorResponseBody": ".hub_locations_update_hub_location_bad_gateway_error_response_body",
    "HubLocationsUpdateHubLocationGatewayTimeoutErrorResponseBody": ".hub_locations_update_hub_location_gateway_timeout_error_response_body",
    "HubLocationsUpdateHubLocationInternalServerErrorResponseBody": ".hub_locations_update_hub_location_internal_server_error_response_body",
    "HubLocationsUpdateHubLocationMethodNotAllowedErrorResponseBody": ".hub_locations_update_hub_location_method_not_allowed_error_response_body",
    "HubLocationsUpdateHubLocationNotFoundErrorResponseBody": ".hub_locations_update_hub_location_not_found_error_response_body",
    "HubLocationsUpdateHubLocationNotImplementedErrorResponseBody": ".hub_locations_update_hub_location_not_implemented_error_response_body",
    "HubLocationsUpdateHubLocationResponseBody": ".hub_locations_update_hub_location_response_body",
    "HubLocationsUpdateHubLocationServiceUnavailableErrorResponseBody": ".hub_locations_update_hub_location_service_unavailable_error_response_body",
    "HubLocationsUpdateHubLocationTooManyRequestsErrorResponseBody": ".hub_locations_update_hub_location_too_many_requests_error_response_body",
    "HubLocationsUpdateHubLocationUnauthorizedErrorResponseBody": ".hub_locations_update_hub_location_unauthorized_error_response_body",
    "HubObjectResponseBody": ".hub_object_response_body",
    "HubPlanRoutesListHubPlanRoutesBadGatewayErrorResponseBody": ".hub_plan_routes_list_hub_plan_routes_bad_gateway_error_response_body",
    "HubPlanRoutesListHubPlanRoutesGatewayTimeoutErrorResponseBody": ".hub_plan_routes_list_hub_plan_routes_gateway_timeout_error_response_body",
    "HubPlanRoutesListHubPlanRoutesInternalServerErrorResponseBody": ".hub_plan_routes_list_hub_plan_routes_internal_server_error_response_body",
    "HubPlanRoutesListHubPlanRoutesMethodNotAllowedErrorResponseBody": ".hub_plan_routes_list_hub_plan_routes_method_not_allowed_error_response_body",
    "HubPlanRoutesListHubPlanRoutesNotFoundErrorResponseBody": ".hub_plan_routes_list_hub_plan_routes_not_found_error_response_body",
    "HubPlanRoutesListHubPlanRoutesNotImplementedErrorResponseBody": ".hub_plan_routes_list_hub_plan_routes_not_implemented_error_response_body",
    "HubPlanRoutesListHubPlanRoutesResponseBody": ".hub_plan_routes_list_hub_plan_routes_response_body",
    "HubPlanRoutesListHubPlanRoutesServiceUnavailableErrorResponseBody": ".hub_plan_routes_list_hub_plan_routes_service_unavailable_error_response_body",
    "HubPlanRoutesListHubPlanRoutesTooManyRequestsErrorResponseBody": ".hub_plan_routes_list_hub_plan_routes_too_many_requests_error_response_body",
    "HubPlanRoutesListHubPlanRoutesUnauthorizedErrorResponseBody": ".hub_plan_routes_list_hub_plan_routes_unauthorized_error_response_body",
    "HubPlansCreateHubPlanBadGatewayErrorResponseBody": ".hub_plans_create_hub_plan_bad_gateway_error_response_body",
    "HubPlansCreateHubPlanGatewayTimeoutErrorResponseBody": ".hub_plans_create_hub_plan_gateway_timeout_error_response_body",
    "HubPlansCreateHubPlanInternalServerErrorResponseBody": ".hub_plans_create_hub_plan_internal_server_error_response_body",
    "HubPlansCreateHubPlanMethodNotAllowedErrorResponseBody": ".hub_plans_create_hub_plan_method_not_allowed_error_response_body",
    "HubPlansCreateHubPlanNotFoundErrorResponseBody": ".hub_plans_create_hub_plan_not_found_error_response_body",
    "HubPlansCreateHubPlanNotImplementedErrorResponseBody": ".hub_plans_create_hub_plan_not_implemented_error_response_body",
    "HubPlansCreateHubPlanResponseBody": ".hub_plans_create_hub_plan_response_body",
    "HubPlansCreateHubPlanServiceUnavailableErrorResponseBody": ".hub_plans_create_hub_plan_service_unavailable_error_response_body",
    "HubPlansCreateHubPlanTooManyRequestsErrorResponseBody": ".hub_plans_create_hub_plan_too_many_requests_error_response_body",
    "HubPlansCreateHubPlanUnauthorizedErrorResponseBody": ".hub_plans_create_hub_plan_unauthorized_error_response_body",
    "HubPlansListHubPlansBadGatewayErrorResponseBody": ".hub_plans_list_hub_plans_bad_gateway_error_response_body",
    "HubPlansListHubPlansGatewayTimeoutErrorResponseBody": ".hub_plans_list_hub_plans_gateway_timeout_error_response_body",
    "HubPlansListHubPlansInternalServerErrorResponseBody": ".hub_plans_list_hub_plans_internal_server_error_response_body",
    "HubPlansListHubPlansMethodNotAllowedErrorResponseBody": ".hub_plans_list_hub_plans_method_not_allowed_error_response_body",
    "HubPlansListHubPlansNotFoundErrorResponseBody": ".hub_plans_list_hub_plans_not_found_error_response_body",
    "HubPlansListHubPlansNotImplementedErrorResponseBody": ".hub_plans_list_hub_plans_not_implemented_error_response_body",
    "HubPlansListHubPlansResponseBody": ".hub_plans_list_hub_plans_response_body",
    "HubPlansListHubPlansServiceUnavailableErrorResponseBody": ".hub_plans_list_hub_plans_service_unavailable_error_response_body",
    "HubPlansListHubPlansTooManyRequestsErrorResponseBody": ".hub_plans_list_hub_plans_too_many_requests_error_response_body",
    "HubPlansListHubPlansUnauthorizedErrorResponseBody": ".hub_plans_list_hub_plans_unauthorized_error_response_body",
    "HubSkillObjectResponseBody": ".hub_skill_object_response_body",
    "HubSkillsListHubSkillsBadGatewayErrorResponseBody": ".hub_skills_list_hub_skills_bad_gateway_error_response_body",
    "HubSkillsListHubSkillsGatewayTimeoutErrorResponseBody": ".hub_skills_list_hub_skills_gateway_timeout_error_response_body",
    "HubSkillsListHubSkillsInternalServerErrorResponseBody": ".hub_skills_list_hub_skills_internal_server_error_response_body",
    "HubSkillsListHubSkillsMethodNotAllowedErrorResponseBody": ".hub_skills_list_hub_skills_method_not_allowed_error_response_body",
    "HubSkillsListHubSkillsNotFoundErrorResponseBody": ".hub_skills_list_hub_skills_not_found_error_response_body",
    "HubSkillsListHubSkillsNotImplementedErrorResponseBody": ".hub_skills_list_hub_skills_not_implemented_error_response_body",
    "HubSkillsListHubSkillsResponseBody": ".hub_skills_list_hub_skills_response_body",
    "HubSkillsListHubSkillsServiceUnavailableErrorResponseBody": ".hub_skills_list_hub_skills_service_unavailable_error_response_body",
    "HubSkillsListHubSkillsTooManyRequestsErrorResponseBody": ".hub_skills_list_hub_skills_too_many_requests_error_response_body",
    "HubSkillsListHubSkillsUnauthorizedErrorResponseBody": ".hub_skills_list_hub_skills_unauthorized_error_response_body",
    "HubsListHubsBadGatewayErrorResponseBody": ".hubs_list_hubs_bad_gateway_error_response_body",
    "HubsListHubsGatewayTimeoutErrorResponseBody": ".hubs_list_hubs_gateway_timeout_error_response_body",
    "HubsListHubsInternalServerErrorResponseBody": ".hubs_list_hubs_internal_server_error_response_body",
    "HubsListHubsMethodNotAllowedErrorResponseBody": ".hubs_list_hubs_method_not_allowed_error_response_body",
    "HubsListHubsNotFoundErrorResponseBody": ".hubs_list_hubs_not_found_error_response_body",
    "HubsListHubsNotImplementedErrorResponseBody": ".hubs_list_hubs_not_implemented_error_response_body",
    "HubsListHubsResponseBody": ".hubs_list_hubs_response_body",
    "HubsListHubsServiceUnavailableErrorResponseBody": ".hubs_list_hubs_service_unavailable_error_response_body",
    "HubsListHubsTooManyRequestsErrorResponseBody": ".hubs_list_hubs_too_many_requests_error_response_body",
    "HubsListHubsUnauthorizedErrorResponseBody": ".hubs_list_hubs_unauthorized_error_response_body",
    "IdleTimeDurationMs": ".idle_time_duration_ms",
    "IdlingEventAddressObjectResponseBody": ".idling_event_address_object_response_body",
    "IdlingEventAddressObjectResponseBodyAddressTypesItem": ".idling_event_address_object_response_body_address_types_item",
    "IdlingEventAssetObjectResponseBody": ".idling_event_asset_object_response_body",
    "IdlingEventObjectV20251023ResponseBody": ".idling_event_object_v_20251023_response_body",
    "IdlingEventObjectV20251023ResponseBodyPtoState": ".idling_event_object_v_20251023_response_body_pto_state",
    "IdlingEventOperatorObjectResponseBody": ".idling_event_operator_object_response_body",
    "IdlingReportEventAddressResponseBody": ".idling_report_event_address_response_body",
    "IdlingReportEventResponseBody": ".idling_report_event_response_body",
    "IdlingReportsGetVehicleIdlingReportsBadGatewayErrorResponseBody": ".idling_reports_get_vehicle_idling_reports_bad_gateway_error_response_body",
    "IdlingReportsGetVehicleIdlingReportsGatewayTimeoutErrorResponseBody": ".idling_reports_get_vehicle_idling_reports_gateway_timeout_error_response_body",
    "IdlingReportsGetVehicleIdlingReportsInternalServerErrorResponseBody": ".idling_reports_get_vehicle_idling_reports_internal_server_error_response_body",
    "IdlingReportsGetVehicleIdlingReportsMethodNotAllowedErrorResponseBody": ".idling_reports_get_vehicle_idling_reports_method_not_allowed_error_response_body",
    "IdlingReportsGetVehicleIdlingReportsNotFoundErrorResponseBody": ".idling_reports_get_vehicle_idling_reports_not_found_error_response_body",
    "IdlingReportsGetVehicleIdlingReportsNotImplementedErrorResponseBody": ".idling_reports_get_vehicle_idling_reports_not_implemented_error_response_body",
    "IdlingReportsGetVehicleIdlingReportsResponseBody": ".idling_reports_get_vehicle_idling_reports_response_body",
    "IdlingReportsGetVehicleIdlingReportsServiceUnavailableErrorResponseBody": ".idling_reports_get_vehicle_idling_reports_service_unavailable_error_response_body",
    "IdlingReportsGetVehicleIdlingReportsTooManyRequestsErrorResponseBody": ".idling_reports_get_vehicle_idling_reports_too_many_requests_error_response_body",
    "IdlingReportsGetVehicleIdlingReportsUnauthorizedErrorResponseBody": ".idling_reports_get_vehicle_idling_reports_unauthorized_error_response_body",
    "IftaCreateIftaDetailJobBadGatewayErrorResponseBody": ".ifta_create_ifta_detail_job_bad_gateway_error_response_body",
    "IftaCreateIftaDetailJobGatewayTimeoutErrorResponseBody": ".ifta_create_ifta_detail_job_gateway_timeout_error_response_body",
    "IftaCreateIftaDetailJobInternalServerErrorResponseBody": ".ifta_create_ifta_detail_job_internal_server_error_response_body",
    "IftaCreateIftaDetailJobMethodNotAllowedErrorResponseBody": ".ifta_create_ifta_detail_job_method_not_allowed_error_response_body",
    "IftaCreateIftaDetailJobNotFoundErrorResponseBody": ".ifta_create_ifta_detail_job_not_found_error_response_body",
    "IftaCreateIftaDetailJobNotImplementedErrorResponseBody": ".ifta_create_ifta_detail_job_not_implemented_error_response_body",
    "IftaCreateIftaDetailJobResponseBody": ".ifta_create_ifta_detail_job_response_body",
    "IftaCreateIftaDetailJobServiceUnavailableErrorResponseBody": ".ifta_create_ifta_detail_job_service_unavailable_error_response_body",
    "IftaCreateIftaDetailJobTooManyRequestsErrorResponseBody": ".ifta_create_ifta_detail_job_too_many_requests_error_response_body",
    "IftaCreateIftaDetailJobUnauthorizedErrorResponseBody": ".ifta_create_ifta_detail_job_unauthorized_error_response_body",
    "IftaDetailJobArgsResponseBody": ".ifta_detail_job_args_response_body",
    "IftaDetailJobOutputResponseBody": ".ifta_detail_job_output_response_body",
    "IftaDetailJobResponseBody": ".ifta_detail_job_response_body",
    "IftaDetailJobResponseBodyJobStatus": ".ifta_detail_job_response_body_job_status",
    "IftaGetIftaDetailJobBadGatewayErrorResponseBody": ".ifta_get_ifta_detail_job_bad_gateway_error_response_body",
    "IftaGetIftaDetailJobGatewayTimeoutErrorResponseBody": ".ifta_get_ifta_detail_job_gateway_timeout_error_response_body",
    "IftaGetIftaDetailJobInternalServerErrorResponseBody": ".ifta_get_ifta_detail_job_internal_server_error_response_body",
    "IftaGetIftaDetailJobMethodNotAllowedErrorResponseBody": ".ifta_get_ifta_detail_job_method_not_allowed_error_response_body",
    "IftaGetIftaDetailJobNotFoundErrorResponseBody": ".ifta_get_ifta_detail_job_not_found_error_response_body",
    "IftaGetIftaDetailJobNotImplementedErrorResponseBody": ".ifta_get_ifta_detail_job_not_implemented_error_response_body",
    "IftaGetIftaDetailJobResponseBody": ".ifta_get_ifta_detail_job_response_body",
    "IftaGetIftaDetailJobServiceUnavailableErrorResponseBody": ".ifta_get_ifta_detail_job_service_unavailable_error_response_body",
    "IftaGetIftaDetailJobTooManyRequestsErrorResponseBody": ".ifta_get_ifta_detail_job_too_many_requests_error_response_body",
    "IftaGetIftaDetailJobUnauthorizedErrorResponseBody": ".ifta_get_ifta_detail_job_unauthorized_error_response_body",
    "IftaGetIftaJurisdictionReportsBadGatewayErrorResponseBody": ".ifta_get_ifta_jurisdiction_reports_bad_gateway_error_response_body",
    "IftaGetIftaJurisdictionReportsGatewayTimeoutErrorResponseBody": ".ifta_get_ifta_jurisdiction_reports_gateway_timeout_error_response_body",
    "IftaGetIftaJurisdictionReportsInternalServerErrorResponseBody": ".ifta_get_ifta_jurisdiction_reports_internal_server_error_response_body",
    "IftaGetIftaJurisdictionReportsMethodNotAllowedErrorResponseBody": ".ifta_get_ifta_jurisdiction_reports_method_not_allowed_error_response_body",
    "IftaGetIftaJurisdictionReportsNotFoundErrorResponseBody": ".ifta_get_ifta_jurisdiction_reports_not_found_error_response_body",
    "IftaGetIftaJurisdictionReportsNotImplementedErrorResponseBody": ".ifta_get_ifta_jurisdiction_reports_not_implemented_error_response_body",
    "IftaGetIftaJurisdictionReportsResponseBody": ".ifta_get_ifta_jurisdiction_reports_response_body",
    "IftaGetIftaJurisdictionReportsServiceUnavailableErrorResponseBody": ".ifta_get_ifta_jurisdiction_reports_service_unavailable_error_response_body",
    "IftaGetIftaJurisdictionReportsTooManyRequestsErrorResponseBody": ".ifta_get_ifta_jurisdiction_reports_too_many_requests_error_response_body",
    "IftaGetIftaJurisdictionReportsUnauthorizedErrorResponseBody": ".ifta_get_ifta_jurisdiction_reports_unauthorized_error_response_body",
    "IftaGetIftaVehicleReportsBadGatewayErrorResponseBody": ".ifta_get_ifta_vehicle_reports_bad_gateway_error_response_body",
    "IftaGetIftaVehicleReportsGatewayTimeoutErrorResponseBody": ".ifta_get_ifta_vehicle_reports_gateway_timeout_error_response_body",
    "IftaGetIftaVehicleReportsInternalServerErrorResponseBody": ".ifta_get_ifta_vehicle_reports_internal_server_error_response_body",
    "IftaGetIftaVehicleReportsMethodNotAllowedErrorResponseBody": ".ifta_get_ifta_vehicle_reports_method_not_allowed_error_response_body",
    "IftaGetIftaVehicleReportsNotFoundErrorResponseBody": ".ifta_get_ifta_vehicle_reports_not_found_error_response_body",
    "IftaGetIftaVehicleReportsNotImplementedErrorResponseBody": ".ifta_get_ifta_vehicle_reports_not_implemented_error_response_body",
    "IftaGetIftaVehicleReportsResponseBody": ".ifta_get_ifta_vehicle_reports_response_body",
    "IftaGetIftaVehicleReportsServiceUnavailableErrorResponseBody": ".ifta_get_ifta_vehicle_reports_service_unavailable_error_response_body",
    "IftaGetIftaVehicleReportsTooManyRequestsErrorResponseBody": ".ifta_get_ifta_vehicle_reports_too_many_requests_error_response_body",
    "IftaGetIftaVehicleReportsUnauthorizedErrorResponseBody": ".ifta_get_ifta_vehicle_reports_unauthorized_error_response_body",
    "IftaJurisdictionReportDataObjectResponseBody": ".ifta_jurisdiction_report_data_object_response_body",
    "IftaJurisdictionSummaryObjectResponseBody": ".ifta_jurisdiction_summary_object_response_body",
    "IftaReportTroubleshootingObjectResponseBody": ".ifta_report_troubleshooting_object_response_body",
    "IftaVehicleReportDataObjectResponseBody": ".ifta_vehicle_report_data_object_response_body",
    "IftaVehicleReportObjectResponseBody": ".ifta_vehicle_report_object_response_body",
    "InAppNotificationOptionsObjectRequestBody": ".in_app_notification_options_object_request_body",
    "InAppNotificationOptionsObjectResponseBody": ".in_app_notification_options_object_response_body",
    "InactivityResponseBody": ".inactivity_response_body",
    "InattentiveDrivingDetectionAlertSettingsObjectResponseBody": ".inattentive_driving_detection_alert_settings_object_response_body",
    "InattentiveDrivingDetectionAlertSettingsObjectResponseBodySeverity": ".inattentive_driving_detection_alert_settings_object_response_body_severity",
    "IndustrialAssetObjectResponseBody": ".industrial_asset_object_response_body",
    "InlineResponse200": ".inline_response_200",
    "InlineResponse2001": ".inline_response_2001",
    "InlineResponse2002": ".inline_response_2002",
    "InlineResponse2003": ".inline_response_2003",
    "InlineResponse2004": ".inline_response_2004",
    "InlineResponse2005": ".inline_response_2005",
    "InlineResponse2006": ".inline_response_2006",
    "InlineResponse2007": ".inline_response_2007",
    "InlineResponse2008": ".inline_response_2008",
    "InlineResponse2009": ".inline_response_2009",
    "InsideGeofenceDataResponseBody": ".inside_geofence_data_response_body",
    "InsideGeofenceTriggerDetailsObjectRequestBody": ".inside_geofence_trigger_details_object_request_body",
    "InsideGeofenceTriggerDetailsObjectResponseBody": ".inside_geofence_trigger_details_object_response_body",
    "InvoiceScanFileRequestBody": ".invoice_scan_file_request_body",
    "IssueCreatedResponseBody": ".issue_created_response_body",
    "IssueResponseObjectResponseBody": ".issue_response_object_response_body",
    "IssueResponseObjectResponseBodyPriority": ".issue_response_object_response_body_priority",
    "IssueResponseObjectResponseBodyStatus": ".issue_response_object_response_body_status",
    "IssueSourceObjectResponseBody": ".issue_source_object_response_body",
    "IssueSourceObjectResponseBodyType": ".issue_source_object_response_body_type",
    "IssuesGetIssuesBadGatewayErrorResponseBody": ".issues_get_issues_bad_gateway_error_response_body",
    "IssuesGetIssuesGatewayTimeoutErrorResponseBody": ".issues_get_issues_gateway_timeout_error_response_body",
    "IssuesGetIssuesInternalServerErrorResponseBody": ".issues_get_issues_internal_server_error_response_body",
    "IssuesGetIssuesMethodNotAllowedErrorResponseBody": ".issues_get_issues_method_not_allowed_error_response_body",
    "IssuesGetIssuesNotFoundErrorResponseBody": ".issues_get_issues_not_found_error_response_body",
    "IssuesGetIssuesNotImplementedErrorResponseBody": ".issues_get_issues_not_implemented_error_response_body",
    "IssuesGetIssuesResponseBody": ".issues_get_issues_response_body",
    "IssuesGetIssuesServiceUnavailableErrorResponseBody": ".issues_get_issues_service_unavailable_error_response_body",
    "IssuesGetIssuesStreamBadGatewayErrorResponseBody": ".issues_get_issues_stream_bad_gateway_error_response_body",
    "IssuesGetIssuesStreamGatewayTimeoutErrorResponseBody": ".issues_get_issues_stream_gateway_timeout_error_response_body",
    "IssuesGetIssuesStreamInternalServerErrorResponseBody": ".issues_get_issues_stream_internal_server_error_response_body",
    "IssuesGetIssuesStreamMethodNotAllowedErrorResponseBody": ".issues_get_issues_stream_method_not_allowed_error_response_body",
    "IssuesGetIssuesStreamNotFoundErrorResponseBody": ".issues_get_issues_stream_not_found_error_response_body",
    "IssuesGetIssuesStreamNotImplementedErrorResponseBody": ".issues_get_issues_stream_not_implemented_error_response_body",
    "IssuesGetIssuesStreamResponseBody": ".issues_get_issues_stream_response_body",
    "IssuesGetIssuesStreamServiceUnavailableErrorResponseBody": ".issues_get_issues_stream_service_unavailable_error_response_body",
    "IssuesGetIssuesStreamTooManyRequestsErrorResponseBody": ".issues_get_issues_stream_too_many_requests_error_response_body",
    "IssuesGetIssuesStreamUnauthorizedErrorResponseBody": ".issues_get_issues_stream_unauthorized_error_response_body",
    "IssuesGetIssuesTooManyRequestsErrorResponseBody": ".issues_get_issues_too_many_requests_error_response_body",
    "IssuesGetIssuesUnauthorizedErrorResponseBody": ".issues_get_issues_unauthorized_error_response_body",
    "IssuesPatchIssueBadGatewayErrorResponseBody": ".issues_patch_issue_bad_gateway_error_response_body",
    "IssuesPatchIssueGatewayTimeoutErrorResponseBody": ".issues_patch_issue_gateway_timeout_error_response_body",
    "IssuesPatchIssueInternalServerErrorResponseBody": ".issues_patch_issue_internal_server_error_response_body",
    "IssuesPatchIssueMethodNotAllowedErrorResponseBody": ".issues_patch_issue_method_not_allowed_error_response_body",
    "IssuesPatchIssueNotFoundErrorResponseBody": ".issues_patch_issue_not_found_error_response_body",
    "IssuesPatchIssueNotImplementedErrorResponseBody": ".issues_patch_issue_not_implemented_error_response_body",
    "IssuesPatchIssueResponseBody": ".issues_patch_issue_response_body",
    "IssuesPatchIssueServiceUnavailableErrorResponseBody": ".issues_patch_issue_service_unavailable_error_response_body",
    "IssuesPatchIssueTooManyRequestsErrorResponseBody": ".issues_patch_issue_too_many_requests_error_response_body",
    "IssuesPatchIssueUnauthorizedErrorResponseBody": ".issues_patch_issue_unauthorized_error_response_body",
    "J1939D1StatusDataPoint": ".j_1939_d_1_status_data_point",
    "J1939D1StatusDataPointValue": ".j_1939_d_1_status_data_point_value",
    "JammingDetectedResponseBody": ".jamming_detected_response_body",
    "JobLocationResponseObjectResponseBody": ".job_location_response_object_response_body",
    "JobResponseObjectResponseBody": ".job_response_object_response_body",
    "JobResponseObjectResponseBodyStatus": ".job_response_object_response_body_status",
    "JobsCreateJobBadGatewayErrorResponseBody": ".jobs_create_job_bad_gateway_error_response_body",
    "JobsCreateJobGatewayTimeoutErrorResponseBody": ".jobs_create_job_gateway_timeout_error_response_body",
    "JobsCreateJobInternalServerErrorResponseBody": ".jobs_create_job_internal_server_error_response_body",
    "JobsCreateJobMethodNotAllowedErrorResponseBody": ".jobs_create_job_method_not_allowed_error_response_body",
    "JobsCreateJobNotFoundErrorResponseBody": ".jobs_create_job_not_found_error_response_body",
    "JobsCreateJobNotImplementedErrorResponseBody": ".jobs_create_job_not_implemented_error_response_body",
    "JobsCreateJobResponseBody": ".jobs_create_job_response_body",
    "JobsCreateJobServiceUnavailableErrorResponseBody": ".jobs_create_job_service_unavailable_error_response_body",
    "JobsCreateJobTooManyRequestsErrorResponseBody": ".jobs_create_job_too_many_requests_error_response_body",
    "JobsCreateJobUnauthorizedErrorResponseBody": ".jobs_create_job_unauthorized_error_response_body",
    "JobsDeleteJobBadGatewayErrorResponseBody": ".jobs_delete_job_bad_gateway_error_response_body",
    "JobsDeleteJobGatewayTimeoutErrorResponseBody": ".jobs_delete_job_gateway_timeout_error_response_body",
    "JobsDeleteJobInternalServerErrorResponseBody": ".jobs_delete_job_internal_server_error_response_body",
    "JobsDeleteJobMethodNotAllowedErrorResponseBody": ".jobs_delete_job_method_not_allowed_error_response_body",
    "JobsDeleteJobNotFoundErrorResponseBody": ".jobs_delete_job_not_found_error_response_body",
    "JobsDeleteJobNotImplementedErrorResponseBody": ".jobs_delete_job_not_implemented_error_response_body",
    "JobsDeleteJobResponseBody": ".jobs_delete_job_response_body",
    "JobsDeleteJobServiceUnavailableErrorResponseBody": ".jobs_delete_job_service_unavailable_error_response_body",
    "JobsDeleteJobTooManyRequestsErrorResponseBody": ".jobs_delete_job_too_many_requests_error_response_body",
    "JobsDeleteJobUnauthorizedErrorResponseBody": ".jobs_delete_job_unauthorized_error_response_body",
    "JobsGetJobsBadGatewayErrorResponseBody": ".jobs_get_jobs_bad_gateway_error_response_body",
    "JobsGetJobsGatewayTimeoutErrorResponseBody": ".jobs_get_jobs_gateway_timeout_error_response_body",
    "JobsGetJobsInternalServerErrorResponseBody": ".jobs_get_jobs_internal_server_error_response_body",
    "JobsGetJobsMethodNotAllowedErrorResponseBody": ".jobs_get_jobs_method_not_allowed_error_response_body",
    "JobsGetJobsNotFoundErrorResponseBody": ".jobs_get_jobs_not_found_error_response_body",
    "JobsGetJobsNotImplementedErrorResponseBody": ".jobs_get_jobs_not_implemented_error_response_body",
    "JobsGetJobsResponseBody": ".jobs_get_jobs_response_body",
    "JobsGetJobsServiceUnavailableErrorResponseBody": ".jobs_get_jobs_service_unavailable_error_response_body",
    "JobsGetJobsTooManyRequestsErrorResponseBody": ".jobs_get_jobs_too_many_requests_error_response_body",
    "JobsGetJobsUnauthorizedErrorResponseBody": ".jobs_get_jobs_unauthorized_error_response_body",
    "JobsPatchJobBadGatewayErrorResponseBody": ".jobs_patch_job_bad_gateway_error_response_body",
    "JobsPatchJobGatewayTimeoutErrorResponseBody": ".jobs_patch_job_gateway_timeout_error_response_body",
    "JobsPatchJobInternalServerErrorResponseBody": ".jobs_patch_job_internal_server_error_response_body",
    "JobsPatchJobMethodNotAllowedErrorResponseBody": ".jobs_patch_job_method_not_allowed_error_response_body",
    "JobsPatchJobNotFoundErrorResponseBody": ".jobs_patch_job_not_found_error_response_body",
    "JobsPatchJobNotImplementedErrorResponseBody": ".jobs_patch_job_not_implemented_error_response_body",
    "JobsPatchJobResponseBody": ".jobs_patch_job_response_body",
    "JobsPatchJobServiceUnavailableErrorResponseBody": ".jobs_patch_job_service_unavailable_error_response_body",
    "JobsPatchJobTooManyRequestsErrorResponseBody": ".jobs_patch_job_too_many_requests_error_response_body",
    "JobsPatchJobUnauthorizedErrorResponseBody": ".jobs_patch_job_unauthorized_error_response_body",
    "LastKnownLocationResponseResponseBody": ".last_known_location_response_response_body",
    "Latitude": ".latitude",
    "ListAddressesResponse": ".list_addresses_response",
    "ListCarrierProposedAssignmentResponse": ".list_carrier_proposed_assignment_response",
    "ListContactsResponse": ".list_contacts_response",
    "ListDriversResponse": ".list_drivers_response",
    "ListHubCapacitiesResponsePaginationResponseBody": ".list_hub_capacities_response_pagination_response_body",
    "ListHubCustomPropertiesResponsePaginationResponseBody": ".list_hub_custom_properties_response_pagination_response_body",
    "ListHubLocationsResponsePaginationResponseBody": ".list_hub_locations_response_pagination_response_body",
    "ListHubPlanRoutesResponsePaginationResponseBody": ".list_hub_plan_routes_response_pagination_response_body",
    "ListHubPlansResponsePaginationResponseBody": ".list_hub_plans_response_pagination_response_body",
    "ListHubSkillsResponsePaginationResponseBody": ".list_hub_skills_response_pagination_response_body",
    "ListHubsResponsePaginationResponseBody": ".list_hubs_response_pagination_response_body",
    "ListIndustrialAssetsResponse": ".list_industrial_assets_response",
    "ListTagsResponse": ".list_tags_response",
    "ListUploadedMediaObjectResponseBody": ".list_uploaded_media_object_response_body",
    "ListUserRolesResponse": ".list_user_roles_response",
    "ListUsersResponse": ".list_users_response",
    "LiveSharingLinkFullResponseObjectResponseBody": ".live_sharing_link_full_response_object_response_body",
    "LiveSharingLinkFullResponseObjectResponseBodyType": ".live_sharing_link_full_response_object_response_body_type",
    "LiveSharingLinkResponseObjectResponseBody": ".live_sharing_link_response_object_response_body",
    "LiveSharingLinksCreateLiveSharingLinkBadGatewayErrorResponseBody": ".live_sharing_links_create_live_sharing_link_bad_gateway_error_response_body",
    "LiveSharingLinksCreateLiveSharingLinkGatewayTimeoutErrorResponseBody": ".live_sharing_links_create_live_sharing_link_gateway_timeout_error_response_body",
    "LiveSharingLinksCreateLiveSharingLinkInternalServerErrorResponseBody": ".live_sharing_links_create_live_sharing_link_internal_server_error_response_body",
    "LiveSharingLinksCreateLiveSharingLinkMethodNotAllowedErrorResponseBody": ".live_sharing_links_create_live_sharing_link_method_not_allowed_error_response_body",
    "LiveSharingLinksCreateLiveSharingLinkNotFoundErrorResponseBody": ".live_sharing_links_create_live_sharing_link_not_found_error_response_body",
    "LiveSharingLinksCreateLiveSharingLinkNotImplementedErrorResponseBody": ".live_sharing_links_create_live_sharing_link_not_implemented_error_response_body",
    "LiveSharingLinksCreateLiveSharingLinkResponseBody": ".live_sharing_links_create_live_sharing_link_response_body",
    "LiveSharingLinksCreateLiveSharingLinkServiceUnavailableErrorResponseBody": ".live_sharing_links_create_live_sharing_link_service_unavailable_error_response_body",
    "LiveSharingLinksCreateLiveSharingLinkTooManyRequestsErrorResponseBody": ".live_sharing_links_create_live_sharing_link_too_many_requests_error_response_body",
    "LiveSharingLinksCreateLiveSharingLinkUnauthorizedErrorResponseBody": ".live_sharing_links_create_live_sharing_link_unauthorized_error_response_body",
    "LiveSharingLinksDeleteLiveSharingLinkBadGatewayErrorResponseBody": ".live_sharing_links_delete_live_sharing_link_bad_gateway_error_response_body",
    "LiveSharingLinksDeleteLiveSharingLinkGatewayTimeoutErrorResponseBody": ".live_sharing_links_delete_live_sharing_link_gateway_timeout_error_response_body",
    "LiveSharingLinksDeleteLiveSharingLinkInternalServerErrorResponseBody": ".live_sharing_links_delete_live_sharing_link_internal_server_error_response_body",
    "LiveSharingLinksDeleteLiveSharingLinkMethodNotAllowedErrorResponseBody": ".live_sharing_links_delete_live_sharing_link_method_not_allowed_error_response_body",
    "LiveSharingLinksDeleteLiveSharingLinkNotFoundErrorResponseBody": ".live_sharing_links_delete_live_sharing_link_not_found_error_response_body",
    "LiveSharingLinksDeleteLiveSharingLinkNotImplementedErrorResponseBody": ".live_sharing_links_delete_live_sharing_link_not_implemented_error_response_body",
    "LiveSharingLinksDeleteLiveSharingLinkServiceUnavailableErrorResponseBody": ".live_sharing_links_delete_live_sharing_link_service_unavailable_error_response_body",
    "LiveSharingLinksDeleteLiveSharingLinkTooManyRequestsErrorResponseBody": ".live_sharing_links_delete_live_sharing_link_too_many_requests_error_response_body",
    "LiveSharingLinksDeleteLiveSharingLinkUnauthorizedErrorResponseBody": ".live_sharing_links_delete_live_sharing_link_unauthorized_error_response_body",
    "LiveSharingLinksGetLiveSharingLinksBadGatewayErrorResponseBody": ".live_sharing_links_get_live_sharing_links_bad_gateway_error_response_body",
    "LiveSharingLinksGetLiveSharingLinksGatewayTimeoutErrorResponseBody": ".live_sharing_links_get_live_sharing_links_gateway_timeout_error_response_body",
    "LiveSharingLinksGetLiveSharingLinksInternalServerErrorResponseBody": ".live_sharing_links_get_live_sharing_links_internal_server_error_response_body",
    "LiveSharingLinksGetLiveSharingLinksMethodNotAllowedErrorResponseBody": ".live_sharing_links_get_live_sharing_links_method_not_allowed_error_response_body",
    "LiveSharingLinksGetLiveSharingLinksNotFoundErrorResponseBody": ".live_sharing_links_get_live_sharing_links_not_found_error_response_body",
    "LiveSharingLinksGetLiveSharingLinksNotImplementedErrorResponseBody": ".live_sharing_links_get_live_sharing_links_not_implemented_error_response_body",
    "LiveSharingLinksGetLiveSharingLinksResponseBody": ".live_sharing_links_get_live_sharing_links_response_body",
    "LiveSharingLinksGetLiveSharingLinksServiceUnavailableErrorResponseBody": ".live_sharing_links_get_live_sharing_links_service_unavailable_error_response_body",
    "LiveSharingLinksGetLiveSharingLinksTooManyRequestsErrorResponseBody": ".live_sharing_links_get_live_sharing_links_too_many_requests_error_response_body",
    "LiveSharingLinksGetLiveSharingLinksUnauthorizedErrorResponseBody": ".live_sharing_links_get_live_sharing_links_unauthorized_error_response_body",
    "LiveSharingLinksUpdateLiveSharingLinkBadGatewayErrorResponseBody": ".live_sharing_links_update_live_sharing_link_bad_gateway_error_response_body",
    "LiveSharingLinksUpdateLiveSharingLinkGatewayTimeoutErrorResponseBody": ".live_sharing_links_update_live_sharing_link_gateway_timeout_error_response_body",
    "LiveSharingLinksUpdateLiveSharingLinkInternalServerErrorResponseBody": ".live_sharing_links_update_live_sharing_link_internal_server_error_response_body",
    "LiveSharingLinksUpdateLiveSharingLinkMethodNotAllowedErrorResponseBody": ".live_sharing_links_update_live_sharing_link_method_not_allowed_error_response_body",
    "LiveSharingLinksUpdateLiveSharingLinkNotFoundErrorResponseBody": ".live_sharing_links_update_live_sharing_link_not_found_error_response_body",
    "LiveSharingLinksUpdateLiveSharingLinkNotImplementedErrorResponseBody": ".live_sharing_links_update_live_sharing_link_not_implemented_error_response_body",
    "LiveSharingLinksUpdateLiveSharingLinkResponseBody": ".live_sharing_links_update_live_sharing_link_response_body",
    "LiveSharingLinksUpdateLiveSharingLinkServiceUnavailableErrorResponseBody": ".live_sharing_links_update_live_sharing_link_service_unavailable_error_response_body",
    "LiveSharingLinksUpdateLiveSharingLinkTooManyRequestsErrorResponseBody": ".live_sharing_links_update_live_sharing_link_too_many_requests_error_response_body",
    "LiveSharingLinksUpdateLiveSharingLinkUnauthorizedErrorResponseBody": ".live_sharing_links_update_live_sharing_link_unauthorized_error_response_body",
    "Location": ".location",
    "LocationAndSpeedGetLocationAndSpeedBadGatewayErrorResponseBody": ".location_and_speed_get_location_and_speed_bad_gateway_error_response_body",
    "LocationAndSpeedGetLocationAndSpeedGatewayTimeoutErrorResponseBody": ".location_and_speed_get_location_and_speed_gateway_timeout_error_response_body",
    "LocationAndSpeedGetLocationAndSpeedInternalServerErrorResponseBody": ".location_and_speed_get_location_and_speed_internal_server_error_response_body",
    "LocationAndSpeedGetLocationAndSpeedMethodNotAllowedErrorResponseBody": ".location_and_speed_get_location_and_speed_method_not_allowed_error_response_body",
    "LocationAndSpeedGetLocationAndSpeedNotFoundErrorResponseBody": ".location_and_speed_get_location_and_speed_not_found_error_response_body",
    "LocationAndSpeedGetLocationAndSpeedNotImplementedErrorResponseBody": ".location_and_speed_get_location_and_speed_not_implemented_error_response_body",
    "LocationAndSpeedGetLocationAndSpeedResponseBody": ".location_and_speed_get_location_and_speed_response_body",
    "LocationAndSpeedGetLocationAndSpeedServiceUnavailableErrorResponseBody": ".location_and_speed_get_location_and_speed_service_unavailable_error_response_body",
    "LocationAndSpeedGetLocationAndSpeedTooManyRequestsErrorResponseBody": ".location_and_speed_get_location_and_speed_too_many_requests_error_response_body",
    "LocationAndSpeedGetLocationAndSpeedUnauthorizedErrorResponseBody": ".location_and_speed_get_location_and_speed_unauthorized_error_response_body",
    "LocationAndSpeedResponseResponseBody": ".location_and_speed_response_response_body",
    "LocationDataPoint": ".location_data_point",
    "LocationDataPointGpsLocation": ".location_data_point_gps_location",
    "LocationDataPointGpsLocationPlace": ".location_data_point_gps_location_place",
    "LocationObjectRequestBody": ".location_object_request_body",
    "LocationObjectRequestBodyAddressTypesItem": ".location_object_request_body_address_types_item",
    "LocationObjectResponseBody": ".location_object_response_body",
    "LocationObjectResponseBodyAddressTypesItem": ".location_object_response_body_address_types_item",
    "LocationResponseBody": ".location_response_body",
    "LocationResponseResponseBody": ".location_response_response_body",
    "LocationType": ".location_type",
    "LogMetaDataObjectResponseBody": ".log_meta_data_object_response_body",
    "Longitude": ".longitude",
    "MediaObjectResponseBody": ".media_object_response_body",
    "MediaObjectResponseBodyCameraRole": ".media_object_response_body_camera_role",
    "MediaObjectResponseBodyInput": ".media_object_response_body_input",
    "MediaObjectResponseBodyMediaType": ".media_object_response_body_media_type",
    "MediaObjectResponseBodyStatus": ".media_object_response_body_status",
    "MediaRetrievalGetMediaRetrievalBadGatewayErrorResponseBody": ".media_retrieval_get_media_retrieval_bad_gateway_error_response_body",
    "MediaRetrievalGetMediaRetrievalGatewayTimeoutErrorResponseBody": ".media_retrieval_get_media_retrieval_gateway_timeout_error_response_body",
    "MediaRetrievalGetMediaRetrievalInternalServerErrorResponseBody": ".media_retrieval_get_media_retrieval_internal_server_error_response_body",
    "MediaRetrievalGetMediaRetrievalMethodNotAllowedErrorResponseBody": ".media_retrieval_get_media_retrieval_method_not_allowed_error_response_body",
    "MediaRetrievalGetMediaRetrievalNotFoundErrorResponseBody": ".media_retrieval_get_media_retrieval_not_found_error_response_body",
    "MediaRetrievalGetMediaRetrievalNotImplementedErrorResponseBody": ".media_retrieval_get_media_retrieval_not_implemented_error_response_body",
    "MediaRetrievalGetMediaRetrievalResponseBody": ".media_retrieval_get_media_retrieval_response_body",
    "MediaRetrievalGetMediaRetrievalServiceUnavailableErrorResponseBody": ".media_retrieval_get_media_retrieval_service_unavailable_error_response_body",
    "MediaRetrievalGetMediaRetrievalTooManyRequestsErrorResponseBody": ".media_retrieval_get_media_retrieval_too_many_requests_error_response_body",
    "MediaRetrievalGetMediaRetrievalUnauthorizedErrorResponseBody": ".media_retrieval_get_media_retrieval_unauthorized_error_response_body",
    "MediaRetrievalListUploadedMediaBadGatewayErrorResponseBody": ".media_retrieval_list_uploaded_media_bad_gateway_error_response_body",
    "MediaRetrievalListUploadedMediaGatewayTimeoutErrorResponseBody": ".media_retrieval_list_uploaded_media_gateway_timeout_error_response_body",
    "MediaRetrievalListUploadedMediaInternalServerErrorResponseBody": ".media_retrieval_list_uploaded_media_internal_server_error_response_body",
    "MediaRetrievalListUploadedMediaMethodNotAllowedErrorResponseBody": ".media_retrieval_list_uploaded_media_method_not_allowed_error_response_body",
    "MediaRetrievalListUploadedMediaNotFoundErrorResponseBody": ".media_retrieval_list_uploaded_media_not_found_error_response_body",
    "MediaRetrievalListUploadedMediaNotImplementedErrorResponseBody": ".media_retrieval_list_uploaded_media_not_implemented_error_response_body",
    "MediaRetrievalListUploadedMediaResponseBody": ".media_retrieval_list_uploaded_media_response_body",
    "MediaRetrievalListUploadedMediaServiceUnavailableErrorResponseBody": ".media_retrieval_list_uploaded_media_service_unavailable_error_response_body",
    "MediaRetrievalListUploadedMediaTooManyRequestsErrorResponseBody": ".media_retrieval_list_uploaded_media_too_many_requests_error_response_body",
    "MediaRetrievalListUploadedMediaUnauthorizedErrorResponseBody": ".media_retrieval_list_uploaded_media_unauthorized_error_response_body",
    "MediaRetrievalPostMediaRetrievalBadGatewayErrorResponseBody": ".media_retrieval_post_media_retrieval_bad_gateway_error_response_body",
    "MediaRetrievalPostMediaRetrievalGatewayTimeoutErrorResponseBody": ".media_retrieval_post_media_retrieval_gateway_timeout_error_response_body",
    "MediaRetrievalPostMediaRetrievalInternalServerErrorResponseBody": ".media_retrieval_post_media_retrieval_internal_server_error_response_body",
    "MediaRetrievalPostMediaRetrievalMethodNotAllowedErrorResponseBody": ".media_retrieval_post_media_retrieval_method_not_allowed_error_response_body",
    "MediaRetrievalPostMediaRetrievalNotFoundErrorResponseBody": ".media_retrieval_post_media_retrieval_not_found_error_response_body",
    "MediaRetrievalPostMediaRetrievalNotImplementedErrorResponseBody": ".media_retrieval_post_media_retrieval_not_implemented_error_response_body",
    "MediaRetrievalPostMediaRetrievalResponseBody": ".media_retrieval_post_media_retrieval_response_body",
    "MediaRetrievalPostMediaRetrievalServiceUnavailableErrorResponseBody": ".media_retrieval_post_media_retrieval_service_unavailable_error_response_body",
    "MediaRetrievalPostMediaRetrievalTooManyRequestsErrorResponseBody": ".media_retrieval_post_media_retrieval_too_many_requests_error_response_body",
    "MediaRetrievalPostMediaRetrievalUnauthorizedErrorResponseBody": ".media_retrieval_post_media_retrieval_unauthorized_error_response_body",
    "MinimalRouteAuditLogsResponseBody": ".minimal_route_audit_logs_response_body",
    "MinimalRouteStopAuditLogsResponseBody": ".minimal_route_stop_audit_logs_response_body",
    "MinimalRouteStopAuditLogsResponseBodyState": ".minimal_route_stop_audit_logs_response_body_state",
    "MinimalRouteStopResponseBody": ".minimal_route_stop_response_body",
    "MinimalRouteStopResponseBodyState": ".minimal_route_stop_response_body_state",
    "MissingDvirPastDueResponseBody": ".missing_dvir_past_due_response_body",
    "MobileUsageDetectionAlertSettingsObjectResponseBody": ".mobile_usage_detection_alert_settings_object_response_body",
    "MotionDetectedResponseBody": ".motion_detected_response_body",
    "MultipleChoiceFieldTypeMetaDataObjectResponseBody": ".multiple_choice_field_type_meta_data_object_response_body",
    "MultipleChoiceValueObjectRequestBody": ".multiple_choice_value_object_request_body",
    "MultipleChoiceValueObjectResponseBody": ".multiple_choice_value_object_response_body",
    "NumberDataPoint": ".number_data_point",
    "NumberFieldTypeMetaDataObjectResponseBody": ".number_field_type_meta_data_object_response_body",
    "OperationalSettingsObjectRequestBody": ".operational_settings_object_request_body",
    "OperationalSettingsObjectRequestBodyTimeRangeType": ".operational_settings_object_request_body_time_range_type",
    "OperationalSettingsObjectResponseBody": ".operational_settings_object_response_body",
    "OperationalSettingsObjectResponseBodyTimeRangeType": ".operational_settings_object_response_body_time_range_type",
    "OrderCustomPropertyInputRequestBody": ".order_custom_property_input_request_body",
    "OrderCustomPropertyResponseBody": ".order_custom_property_response_body",
    "OrderInputObjectRequestBody": ".order_input_object_request_body",
    "OrderObjectResponseBody": ".order_object_response_body",
    "OrderQuantityInputRequestBody": ".order_quantity_input_request_body",
    "OrderQuantityResponseBody": ".order_quantity_response_body",
    "OrderTaskCustomPropertyObjectResponseBody": ".order_task_custom_property_object_response_body",
    "OrderTaskObjectResponseBody": ".order_task_object_response_body",
    "OrderTaskRequestBody": ".order_task_request_body",
    "OrderTaskRequestBodyPosition": ".order_task_request_body_position",
    "OrderTaskResponseBody": ".order_task_response_body",
    "OrderTaskResponseBodyPosition": ".order_task_response_body_position",
    "OrderTaskSkillObjectResponseBody": ".order_task_skill_object_response_body",
    "OrganizationInfoCarrierSettings": ".organization_info_carrier_settings",
    "OrganizationInfoObject": ".organization_info_object",
    "OrganizationInfoResponse": ".organization_info_response",
    "OutOfRouteDetailsObjectRequestBody": ".out_of_route_details_object_request_body",
    "OutOfRouteDetailsObjectResponseBody": ".out_of_route_details_object_response_body",
    "OutOfRouteResponseBody": ".out_of_route_response_body",
    "OutsideGeofenceDataResponseBody": ".outside_geofence_data_response_body",
    "OutsideGeofenceTriggerDetailsObjectRequestBody": ".outside_geofence_trigger_details_object_request_body",
    "OutsideGeofenceTriggerDetailsObjectResponseBody": ".outside_geofence_trigger_details_object_response_body",
    "OverSpeedMs": ".over_speed_ms",
    "PaginationResponse": ".pagination_response",
    "PanicButtonDetailsObjectRequestBody": ".panic_button_details_object_request_body",
    "PanicButtonDetailsObjectResponseBody": ".panic_button_details_object_response_body",
    "PanicButtonResponseBody": ".panic_button_response_body",
    "ParentId": ".parent_id",
    "ParentTag": ".parent_tag",
    "ParentTagId": ".parent_tag_id",
    "ParentTagName": ".parent_tag_name",
    "PartInstanceInputObjectRequestBody": ".part_instance_input_object_request_body",
    "PartInstanceObjectResponseBody": ".part_instance_object_response_body",
    "PatchAssetDataOutputsSingleResponseResponseBody": ".patch_asset_data_outputs_single_response_response_body",
    "PatchDriverTrailerAssignmentsResponseBodyResponseBody": ".patch_driver_trailer_assignments_response_body_response_body",
    "PatchDriverVehicleAssignmentsV2RequestBodyMetadataRequestBody": ".patch_driver_vehicle_assignments_v_2_request_body_metadata_request_body",
    "PatchDriverVehicleAssignmentsV2ResponseBodyResponseBody": ".patch_driver_vehicle_assignments_v_2_response_body_response_body",
    "PatchIssueRequestBodyAssignedToRequestBody": ".patch_issue_request_body_assigned_to_request_body",
    "PatchIssueRequestBodyAssignedToRequestBodyType": ".patch_issue_request_body_assigned_to_request_body_type",
    "PatchJobObjectRequestBody": ".patch_job_object_request_body",
    "PatchJobObjectjobLocationRequestObjectRequestBody": ".patch_job_objectjob_location_request_object_request_body",
    "PatchResponseWorkflowConfigurationObjectResponseBody": ".patch_response_workflow_configuration_object_response_body",
    "PatchShippingDocsResponseBodyResponseBody": ".patch_shipping_docs_response_body_response_body",
    "PendingDutyStatusDurationsObjectResponseBody": ".pending_duty_status_durations_object_response_body",
    "PersonDetectedResponseBody": ".person_detected_response_body",
    "PhotoValueObjectRequestBody": ".photo_value_object_request_body",
    "PhotoValueObjectResponseBody": ".photo_value_object_response_body",
    "PlanObjectResponseBody": ".plan_object_response_body",
    "PlanOrdersCreatePlanOrdersBadGatewayErrorResponseBody": ".plan_orders_create_plan_orders_bad_gateway_error_response_body",
    "PlanOrdersCreatePlanOrdersGatewayTimeoutErrorResponseBody": ".plan_orders_create_plan_orders_gateway_timeout_error_response_body",
    "PlanOrdersCreatePlanOrdersInternalServerErrorResponseBody": ".plan_orders_create_plan_orders_internal_server_error_response_body",
    "PlanOrdersCreatePlanOrdersMethodNotAllowedErrorResponseBody": ".plan_orders_create_plan_orders_method_not_allowed_error_response_body",
    "PlanOrdersCreatePlanOrdersNotFoundErrorResponseBody": ".plan_orders_create_plan_orders_not_found_error_response_body",
    "PlanOrdersCreatePlanOrdersNotImplementedErrorResponseBody": ".plan_orders_create_plan_orders_not_implemented_error_response_body",
    "PlanOrdersCreatePlanOrdersResponseBody": ".plan_orders_create_plan_orders_response_body",
    "PlanOrdersCreatePlanOrdersServiceUnavailableErrorResponseBody": ".plan_orders_create_plan_orders_service_unavailable_error_response_body",
    "PlanOrdersCreatePlanOrdersTooManyRequestsErrorResponseBody": ".plan_orders_create_plan_orders_too_many_requests_error_response_body",
    "PlanOrdersCreatePlanOrdersUnauthorizedErrorResponseBody": ".plan_orders_create_plan_orders_unauthorized_error_response_body",
    "PolicyViolationsDetectionAlertSettingsObjectResponseBody": ".policy_violations_detection_alert_settings_object_response_body",
    "PolicyViolationsDetectionAlertSettingsObjectResponseBodyEventsAvailableForTestingItem": ".policy_violations_detection_alert_settings_object_response_body_events_available_for_testing_item",
    "PolicyViolationsDetectionAlertSettingsObjectResponseBodyEventsToCoachItem": ".policy_violations_detection_alert_settings_object_response_body_events_to_coach_item",
    "PolygonRequestBody": ".polygon_request_body",
    "PolygonResponseBody": ".polygon_response_body",
    "PostDriverTrailerAssignmentsResponseBodyResponseBody": ".post_driver_trailer_assignments_response_body_response_body",
    "PostDriverVehicleAssignmentsV2RequestBodyMetadataRequestBody": ".post_driver_vehicle_assignments_v_2_request_body_metadata_request_body",
    "PostDriverVehicleAssignmentsV2ResponseBodyResponseBody": ".post_driver_vehicle_assignments_v_2_response_body_response_body",
    "PostFuelPurchaseRequestBodyDiscountRequestBody": ".post_fuel_purchase_request_body_discount_request_body",
    "PostFuelPurchaseRequestBodyDiscountRequestBodyCurrency": ".post_fuel_purchase_request_body_discount_request_body_currency",
    "PostFuelPurchaseRequestBodyPriceRequestBody": ".post_fuel_purchase_request_body_price_request_body",
    "PostFuelPurchaseRequestBodyPriceRequestBodyCurrency": ".post_fuel_purchase_request_body_price_request_body_currency",
    "PostFuelPurchaseResponseBodyResponseBody": ".post_fuel_purchase_response_body_response_body",
    "PostInvoiceScanResponseDataResponseBody": ".post_invoice_scan_response_data_response_body",
    "PostJobObjectRequestBody": ".post_job_object_request_body",
    "PostJobObjectjobLocationRequestObjectRequestBody": ".post_job_objectjob_location_request_object_request_body",
    "PostMediaRetrievalObjectResponseBody": ".post_media_retrieval_object_response_body",
    "PostResponseResWorkflowConfigurationObjectResponseBody": ".post_response_res_workflow_configuration_object_response_body",
    "PowerTakeOffDurationMs": ".power_take_off_duration_ms",
    "PrimaryTimeRangeRequestBody": ".primary_time_range_request_body",
    "PrimaryTimeRangeResponseBody": ".primary_time_range_response_body",
    "PushNotificationOptionsObjectRequestBody": ".push_notification_options_object_request_body",
    "PushNotificationOptionsObjectResponseBody": ".push_notification_options_object_response_body",
    "QrCodeResponseObjectResponseBody": ".qr_code_response_object_response_body",
    "QualificationFieldInputObjectResponseBody": ".qualification_field_input_object_response_body",
    "QualificationFieldInputObjectResponseBodyType": ".qualification_field_input_object_response_body_type",
    "QualificationOwnerObjectResponseBody": ".qualification_owner_object_response_body",
    "QualificationOwnerObjectResponseBodyEntityType": ".qualification_owner_object_response_body_entity_type",
    "QualificationOwnerRequestObjectRequestBody": ".qualification_owner_request_object_request_body",
    "QualificationOwnerRequestObjectRequestBodyEntityType": ".qualification_owner_request_object_request_body_entity_type",
    "QualificationRecordRequestFieldInputObjectRequestBody": ".qualification_record_request_field_input_object_request_body",
    "QualificationRecordRequestFieldInputObjectRequestBodyType": ".qualification_record_request_field_input_object_request_body_type",
    "QualificationRecordResponseObjectResponseBody": ".qualification_record_response_object_response_body",
    "QualificationRecordResponseObjectResponseBodyRecordStatus": ".qualification_record_response_object_response_body_record_status",
    "QualificationTypeReferenceObjectResponseBody": ".qualification_type_reference_object_response_body",
    "QualificationTypeRequestObjectRequestBody": ".qualification_type_request_object_request_body",
    "QualificationTypeResponseObjectResponseBody": ".qualification_type_response_object_response_body",
    "QualificationTypeResponseObjectResponseBodyEntityType": ".qualification_type_response_object_response_body_entity_type",
    "QualificationsArchiveQualificationRecordBadGatewayErrorResponseBody": ".qualifications_archive_qualification_record_bad_gateway_error_response_body",
    "QualificationsArchiveQualificationRecordGatewayTimeoutErrorResponseBody": ".qualifications_archive_qualification_record_gateway_timeout_error_response_body",
    "QualificationsArchiveQualificationRecordInternalServerErrorResponseBody": ".qualifications_archive_qualification_record_internal_server_error_response_body",
    "QualificationsArchiveQualificationRecordMethodNotAllowedErrorResponseBody": ".qualifications_archive_qualification_record_method_not_allowed_error_response_body",
    "QualificationsArchiveQualificationRecordNotFoundErrorResponseBody": ".qualifications_archive_qualification_record_not_found_error_response_body",
    "QualificationsArchiveQualificationRecordNotImplementedErrorResponseBody": ".qualifications_archive_qualification_record_not_implemented_error_response_body",
    "QualificationsArchiveQualificationRecordServiceUnavailableErrorResponseBody": ".qualifications_archive_qualification_record_service_unavailable_error_response_body",
    "QualificationsArchiveQualificationRecordTooManyRequestsErrorResponseBody": ".qualifications_archive_qualification_record_too_many_requests_error_response_body",
    "QualificationsArchiveQualificationRecordUnauthorizedErrorResponseBody": ".qualifications_archive_qualification_record_unauthorized_error_response_body",
    "QualificationsDeleteQualificationRecordBadGatewayErrorResponseBody": ".qualifications_delete_qualification_record_bad_gateway_error_response_body",
    "QualificationsDeleteQualificationRecordGatewayTimeoutErrorResponseBody": ".qualifications_delete_qualification_record_gateway_timeout_error_response_body",
    "QualificationsDeleteQualificationRecordInternalServerErrorResponseBody": ".qualifications_delete_qualification_record_internal_server_error_response_body",
    "QualificationsDeleteQualificationRecordMethodNotAllowedErrorResponseBody": ".qualifications_delete_qualification_record_method_not_allowed_error_response_body",
    "QualificationsDeleteQualificationRecordNotFoundErrorResponseBody": ".qualifications_delete_qualification_record_not_found_error_response_body",
    "QualificationsDeleteQualificationRecordNotImplementedErrorResponseBody": ".qualifications_delete_qualification_record_not_implemented_error_response_body",
    "QualificationsDeleteQualificationRecordServiceUnavailableErrorResponseBody": ".qualifications_delete_qualification_record_service_unavailable_error_response_body",
    "QualificationsDeleteQualificationRecordTooManyRequestsErrorResponseBody": ".qualifications_delete_qualification_record_too_many_requests_error_response_body",
    "QualificationsDeleteQualificationRecordUnauthorizedErrorResponseBody": ".qualifications_delete_qualification_record_unauthorized_error_response_body",
    "QualificationsGetQualificationRecordsBadGatewayErrorResponseBody": ".qualifications_get_qualification_records_bad_gateway_error_response_body",
    "QualificationsGetQualificationRecordsGatewayTimeoutErrorResponseBody": ".qualifications_get_qualification_records_gateway_timeout_error_response_body",
    "QualificationsGetQualificationRecordsInternalServerErrorResponseBody": ".qualifications_get_qualification_records_internal_server_error_response_body",
    "QualificationsGetQualificationRecordsMethodNotAllowedErrorResponseBody": ".qualifications_get_qualification_records_method_not_allowed_error_response_body",
    "QualificationsGetQualificationRecordsNotFoundErrorResponseBody": ".qualifications_get_qualification_records_not_found_error_response_body",
    "QualificationsGetQualificationRecordsNotImplementedErrorResponseBody": ".qualifications_get_qualification_records_not_implemented_error_response_body",
    "QualificationsGetQualificationRecordsResponseBody": ".qualifications_get_qualification_records_response_body",
    "QualificationsGetQualificationRecordsServiceUnavailableErrorResponseBody": ".qualifications_get_qualification_records_service_unavailable_error_response_body",
    "QualificationsGetQualificationRecordsStreamBadGatewayErrorResponseBody": ".qualifications_get_qualification_records_stream_bad_gateway_error_response_body",
    "QualificationsGetQualificationRecordsStreamGatewayTimeoutErrorResponseBody": ".qualifications_get_qualification_records_stream_gateway_timeout_error_response_body",
    "QualificationsGetQualificationRecordsStreamInternalServerErrorResponseBody": ".qualifications_get_qualification_records_stream_internal_server_error_response_body",
    "QualificationsGetQualificationRecordsStreamMethodNotAllowedErrorResponseBody": ".qualifications_get_qualification_records_stream_method_not_allowed_error_response_body",
    "QualificationsGetQualificationRecordsStreamNotFoundErrorResponseBody": ".qualifications_get_qualification_records_stream_not_found_error_response_body",
    "QualificationsGetQualificationRecordsStreamNotImplementedErrorResponseBody": ".qualifications_get_qualification_records_stream_not_implemented_error_response_body",
    "QualificationsGetQualificationRecordsStreamResponseBody": ".qualifications_get_qualification_records_stream_response_body",
    "QualificationsGetQualificationRecordsStreamServiceUnavailableErrorResponseBody": ".qualifications_get_qualification_records_stream_service_unavailable_error_response_body",
    "QualificationsGetQualificationRecordsStreamTooManyRequestsErrorResponseBody": ".qualifications_get_qualification_records_stream_too_many_requests_error_response_body",
    "QualificationsGetQualificationRecordsStreamUnauthorizedErrorResponseBody": ".qualifications_get_qualification_records_stream_unauthorized_error_response_body",
    "QualificationsGetQualificationRecordsTooManyRequestsErrorResponseBody": ".qualifications_get_qualification_records_too_many_requests_error_response_body",
    "QualificationsGetQualificationRecordsUnauthorizedErrorResponseBody": ".qualifications_get_qualification_records_unauthorized_error_response_body",
    "QualificationsGetQualificationTypesBadGatewayErrorResponseBody": ".qualifications_get_qualification_types_bad_gateway_error_response_body",
    "QualificationsGetQualificationTypesGatewayTimeoutErrorResponseBody": ".qualifications_get_qualification_types_gateway_timeout_error_response_body",
    "QualificationsGetQualificationTypesInternalServerErrorResponseBody": ".qualifications_get_qualification_types_internal_server_error_response_body",
    "QualificationsGetQualificationTypesMethodNotAllowedErrorResponseBody": ".qualifications_get_qualification_types_method_not_allowed_error_response_body",
    "QualificationsGetQualificationTypesNotFoundErrorResponseBody": ".qualifications_get_qualification_types_not_found_error_response_body",
    "QualificationsGetQualificationTypesNotImplementedErrorResponseBody": ".qualifications_get_qualification_types_not_implemented_error_response_body",
    "QualificationsGetQualificationTypesResponseBody": ".qualifications_get_qualification_types_response_body",
    "QualificationsGetQualificationTypesServiceUnavailableErrorResponseBody": ".qualifications_get_qualification_types_service_unavailable_error_response_body",
    "QualificationsGetQualificationTypesTooManyRequestsErrorResponseBody": ".qualifications_get_qualification_types_too_many_requests_error_response_body",
    "QualificationsGetQualificationTypesUnauthorizedErrorResponseBody": ".qualifications_get_qualification_types_unauthorized_error_response_body",
    "QualificationsPatchQualificationRecordBadGatewayErrorResponseBody": ".qualifications_patch_qualification_record_bad_gateway_error_response_body",
    "QualificationsPatchQualificationRecordGatewayTimeoutErrorResponseBody": ".qualifications_patch_qualification_record_gateway_timeout_error_response_body",
    "QualificationsPatchQualificationRecordInternalServerErrorResponseBody": ".qualifications_patch_qualification_record_internal_server_error_response_body",
    "QualificationsPatchQualificationRecordMethodNotAllowedErrorResponseBody": ".qualifications_patch_qualification_record_method_not_allowed_error_response_body",
    "QualificationsPatchQualificationRecordNotFoundErrorResponseBody": ".qualifications_patch_qualification_record_not_found_error_response_body",
    "QualificationsPatchQualificationRecordNotImplementedErrorResponseBody": ".qualifications_patch_qualification_record_not_implemented_error_response_body",
    "QualificationsPatchQualificationRecordResponseBody": ".qualifications_patch_qualification_record_response_body",
    "QualificationsPatchQualificationRecordServiceUnavailableErrorResponseBody": ".qualifications_patch_qualification_record_service_unavailable_error_response_body",
    "QualificationsPatchQualificationRecordTooManyRequestsErrorResponseBody": ".qualifications_patch_qualification_record_too_many_requests_error_response_body",
    "QualificationsPatchQualificationRecordUnauthorizedErrorResponseBody": ".qualifications_patch_qualification_record_unauthorized_error_response_body",
    "QualificationsPostQualificationRecordBadGatewayErrorResponseBody": ".qualifications_post_qualification_record_bad_gateway_error_response_body",
    "QualificationsPostQualificationRecordGatewayTimeoutErrorResponseBody": ".qualifications_post_qualification_record_gateway_timeout_error_response_body",
    "QualificationsPostQualificationRecordInternalServerErrorResponseBody": ".qualifications_post_qualification_record_internal_server_error_response_body",
    "QualificationsPostQualificationRecordMethodNotAllowedErrorResponseBody": ".qualifications_post_qualification_record_method_not_allowed_error_response_body",
    "QualificationsPostQualificationRecordNotFoundErrorResponseBody": ".qualifications_post_qualification_record_not_found_error_response_body",
    "QualificationsPostQualificationRecordNotImplementedErrorResponseBody": ".qualifications_post_qualification_record_not_implemented_error_response_body",
    "QualificationsPostQualificationRecordResponseBody": ".qualifications_post_qualification_record_response_body",
    "QualificationsPostQualificationRecordServiceUnavailableErrorResponseBody": ".qualifications_post_qualification_record_service_unavailable_error_response_body",
    "QualificationsPostQualificationRecordTooManyRequestsErrorResponseBody": ".qualifications_post_qualification_record_too_many_requests_error_response_body",
    "QualificationsPostQualificationRecordUnauthorizedErrorResponseBody": ".qualifications_post_qualification_record_unauthorized_error_response_body",
    "QualificationsUnarchiveQualificationRecordBadGatewayErrorResponseBody": ".qualifications_unarchive_qualification_record_bad_gateway_error_response_body",
    "QualificationsUnarchiveQualificationRecordGatewayTimeoutErrorResponseBody": ".qualifications_unarchive_qualification_record_gateway_timeout_error_response_body",
    "QualificationsUnarchiveQualificationRecordInternalServerErrorResponseBody": ".qualifications_unarchive_qualification_record_internal_server_error_response_body",
    "QualificationsUnarchiveQualificationRecordMethodNotAllowedErrorResponseBody": ".qualifications_unarchive_qualification_record_method_not_allowed_error_response_body",
    "QualificationsUnarchiveQualificationRecordNotFoundErrorResponseBody": ".qualifications_unarchive_qualification_record_not_found_error_response_body",
    "QualificationsUnarchiveQualificationRecordNotImplementedErrorResponseBody": ".qualifications_unarchive_qualification_record_not_implemented_error_response_body",
    "QualificationsUnarchiveQualificationRecordServiceUnavailableErrorResponseBody": ".qualifications_unarchive_qualification_record_service_unavailable_error_response_body",
    "QualificationsUnarchiveQualificationRecordTooManyRequestsErrorResponseBody": ".qualifications_unarchive_qualification_record_too_many_requests_error_response_body",
    "QualificationsUnarchiveQualificationRecordUnauthorizedErrorResponseBody": ".qualifications_unarchive_qualification_record_unauthorized_error_response_body",
    "QuantityObjectResponseBody": ".quantity_object_response_body",
    "ReadingDatapointRequestBody": ".reading_datapoint_request_body",
    "ReadingDatapointRequestBodyEntityType": ".reading_datapoint_request_body_entity_type",
    "ReadingDefinitionResponseBody": ".reading_definition_response_body",
    "ReadingHistoryResponseBody": ".reading_history_response_body",
    "ReadingSnapshotResponseBody": ".reading_snapshot_response_body",
    "ReadingTriggerContinuousValueObjectRequestBody": ".reading_trigger_continuous_value_object_request_body",
    "ReadingTriggerContinuousValueObjectRequestBodyOperation": ".reading_trigger_continuous_value_object_request_body_operation",
    "ReadingTriggerContinuousValueObjectRequestBodyUnit": ".reading_trigger_continuous_value_object_request_body_unit",
    "ReadingTriggerContinuousValueObjectResponseBody": ".reading_trigger_continuous_value_object_response_body",
    "ReadingTriggerContinuousValueObjectResponseBodyOperation": ".reading_trigger_continuous_value_object_response_body_operation",
    "ReadingTriggerContinuousValueObjectResponseBodyUnit": ".reading_trigger_continuous_value_object_response_body_unit",
    "ReadingTriggerDetailsObjectRequestBody": ".reading_trigger_details_object_request_body",
    "ReadingTriggerDetailsObjectResponseBody": ".reading_trigger_details_object_response_body",
    "ReadingTriggerDetailsResponseBody": ".reading_trigger_details_response_body",
    "ReadingTriggerEnumValueObjectRequestBody": ".reading_trigger_enum_value_object_request_body",
    "ReadingTriggerEnumValueObjectResponseBody": ".reading_trigger_enum_value_object_response_body",
    "ReadingsGetReadingsHistoryBadGatewayErrorResponseBody": ".readings_get_readings_history_bad_gateway_error_response_body",
    "ReadingsGetReadingsHistoryGatewayTimeoutErrorResponseBody": ".readings_get_readings_history_gateway_timeout_error_response_body",
    "ReadingsGetReadingsHistoryInternalServerErrorResponseBody": ".readings_get_readings_history_internal_server_error_response_body",
    "ReadingsGetReadingsHistoryMethodNotAllowedErrorResponseBody": ".readings_get_readings_history_method_not_allowed_error_response_body",
    "ReadingsGetReadingsHistoryNotFoundErrorResponseBody": ".readings_get_readings_history_not_found_error_response_body",
    "ReadingsGetReadingsHistoryNotImplementedErrorResponseBody": ".readings_get_readings_history_not_implemented_error_response_body",
    "ReadingsGetReadingsHistoryResponseBody": ".readings_get_readings_history_response_body",
    "ReadingsGetReadingsHistoryServiceUnavailableErrorResponseBody": ".readings_get_readings_history_service_unavailable_error_response_body",
    "ReadingsGetReadingsHistoryTooManyRequestsErrorResponseBody": ".readings_get_readings_history_too_many_requests_error_response_body",
    "ReadingsGetReadingsHistoryUnauthorizedErrorResponseBody": ".readings_get_readings_history_unauthorized_error_response_body",
    "ReadingsGetReadingsSnapshotBadGatewayErrorResponseBody": ".readings_get_readings_snapshot_bad_gateway_error_response_body",
    "ReadingsGetReadingsSnapshotGatewayTimeoutErrorResponseBody": ".readings_get_readings_snapshot_gateway_timeout_error_response_body",
    "ReadingsGetReadingsSnapshotInternalServerErrorResponseBody": ".readings_get_readings_snapshot_internal_server_error_response_body",
    "ReadingsGetReadingsSnapshotMethodNotAllowedErrorResponseBody": ".readings_get_readings_snapshot_method_not_allowed_error_response_body",
    "ReadingsGetReadingsSnapshotNotFoundErrorResponseBody": ".readings_get_readings_snapshot_not_found_error_response_body",
    "ReadingsGetReadingsSnapshotNotImplementedErrorResponseBody": ".readings_get_readings_snapshot_not_implemented_error_response_body",
    "ReadingsGetReadingsSnapshotResponseBody": ".readings_get_readings_snapshot_response_body",
    "ReadingsGetReadingsSnapshotServiceUnavailableErrorResponseBody": ".readings_get_readings_snapshot_service_unavailable_error_response_body",
    "ReadingsGetReadingsSnapshotTooManyRequestsErrorResponseBody": ".readings_get_readings_snapshot_too_many_requests_error_response_body",
    "ReadingsGetReadingsSnapshotUnauthorizedErrorResponseBody": ".readings_get_readings_snapshot_unauthorized_error_response_body",
    "ReadingsListReadingsDefinitionsBadGatewayErrorResponseBody": ".readings_list_readings_definitions_bad_gateway_error_response_body",
    "ReadingsListReadingsDefinitionsGatewayTimeoutErrorResponseBody": ".readings_list_readings_definitions_gateway_timeout_error_response_body",
    "ReadingsListReadingsDefinitionsInternalServerErrorResponseBody": ".readings_list_readings_definitions_internal_server_error_response_body",
    "ReadingsListReadingsDefinitionsMethodNotAllowedErrorResponseBody": ".readings_list_readings_definitions_method_not_allowed_error_response_body",
    "ReadingsListReadingsDefinitionsNotFoundErrorResponseBody": ".readings_list_readings_definitions_not_found_error_response_body",
    "ReadingsListReadingsDefinitionsNotImplementedErrorResponseBody": ".readings_list_readings_definitions_not_implemented_error_response_body",
    "ReadingsListReadingsDefinitionsResponseBody": ".readings_list_readings_definitions_response_body",
    "ReadingsListReadingsDefinitionsServiceUnavailableErrorResponseBody": ".readings_list_readings_definitions_service_unavailable_error_response_body",
    "ReadingsListReadingsDefinitionsTooManyRequestsErrorResponseBody": ".readings_list_readings_definitions_too_many_requests_error_response_body",
    "ReadingsListReadingsDefinitionsUnauthorizedErrorResponseBody": ".readings_list_readings_definitions_unauthorized_error_response_body",
    "ReadingsPostReadingsBadGatewayErrorResponseBody": ".readings_post_readings_bad_gateway_error_response_body",
    "ReadingsPostReadingsGatewayTimeoutErrorResponseBody": ".readings_post_readings_gateway_timeout_error_response_body",
    "ReadingsPostReadingsInternalServerErrorResponseBody": ".readings_post_readings_internal_server_error_response_body",
    "ReadingsPostReadingsMethodNotAllowedErrorResponseBody": ".readings_post_readings_method_not_allowed_error_response_body",
    "ReadingsPostReadingsNotFoundErrorResponseBody": ".readings_post_readings_not_found_error_response_body",
    "ReadingsPostReadingsNotImplementedErrorResponseBody": ".readings_post_readings_not_implemented_error_response_body",
    "ReadingsPostReadingsServiceUnavailableErrorResponseBody": ".readings_post_readings_service_unavailable_error_response_body",
    "ReadingsPostReadingsTooManyRequestsErrorResponseBody": ".readings_post_readings_too_many_requests_error_response_body",
    "ReadingsPostReadingsUnauthorizedErrorResponseBody": ".readings_post_readings_unauthorized_error_response_body",
    "RecipientObjectRequestBody": ".recipient_object_request_body",
    "RecipientObjectRequestBodyNotificationTypesItem": ".recipient_object_request_body_notification_types_item",
    "RecipientObjectRequestBodyType": ".recipient_object_request_body_type",
    "RecipientObjectResponseBody": ".recipient_object_response_body",
    "RecipientObjectResponseBodyNotificationTypesItem": ".recipient_object_response_body_notification_types_item",
    "RecipientObjectResponseBodyType": ".recipient_object_response_body_type",
    "ReeferTemperatureResponseBody": ".reefer_temperature_response_body",
    "ReportColumnsObjectResponseBody": ".report_columns_object_response_body",
    "ReportColumnsObjectResponseBodyDataType": ".report_columns_object_response_body_data_type",
    "ReportColumnsObjectResponseBodyUnit": ".report_columns_object_response_body_unit",
    "ReportConfigObjectResponseBody": ".report_config_object_response_body",
    "ReportRunObjectResponseBody": ".report_run_object_response_body",
    "ReportRunObjectResponseBodyStatus": ".report_run_object_response_body_status",
    "ReportsCreateReportRunBadGatewayErrorResponseBody": ".reports_create_report_run_bad_gateway_error_response_body",
    "ReportsCreateReportRunGatewayTimeoutErrorResponseBody": ".reports_create_report_run_gateway_timeout_error_response_body",
    "ReportsCreateReportRunInternalServerErrorResponseBody": ".reports_create_report_run_internal_server_error_response_body",
    "ReportsCreateReportRunMethodNotAllowedErrorResponseBody": ".reports_create_report_run_method_not_allowed_error_response_body",
    "ReportsCreateReportRunNotFoundErrorResponseBody": ".reports_create_report_run_not_found_error_response_body",
    "ReportsCreateReportRunNotImplementedErrorResponseBody": ".reports_create_report_run_not_implemented_error_response_body",
    "ReportsCreateReportRunResponseBody": ".reports_create_report_run_response_body",
    "ReportsCreateReportRunServiceUnavailableErrorResponseBody": ".reports_create_report_run_service_unavailable_error_response_body",
    "ReportsCreateReportRunTooManyRequestsErrorResponseBody": ".reports_create_report_run_too_many_requests_error_response_body",
    "ReportsCreateReportRunUnauthorizedErrorResponseBody": ".reports_create_report_run_unauthorized_error_response_body",
    "ReportsDatasetFieldResponseBody": ".reports_dataset_field_response_body",
    "ReportsDatasetFieldResponseBodyDataType": ".reports_dataset_field_response_body_data_type",
    "ReportsDatasetFieldResponseBodyUnit": ".reports_dataset_field_response_body_unit",
    "ReportsDatasetResponseBody": ".reports_dataset_response_body",
    "ReportsGetDatasetsBadGatewayErrorResponseBody": ".reports_get_datasets_bad_gateway_error_response_body",
    "ReportsGetDatasetsGatewayTimeoutErrorResponseBody": ".reports_get_datasets_gateway_timeout_error_response_body",
    "ReportsGetDatasetsInternalServerErrorResponseBody": ".reports_get_datasets_internal_server_error_response_body",
    "ReportsGetDatasetsMethodNotAllowedErrorResponseBody": ".reports_get_datasets_method_not_allowed_error_response_body",
    "ReportsGetDatasetsNotFoundErrorResponseBody": ".reports_get_datasets_not_found_error_response_body",
    "ReportsGetDatasetsNotImplementedErrorResponseBody": ".reports_get_datasets_not_implemented_error_response_body",
    "ReportsGetDatasetsResponseBody": ".reports_get_datasets_response_body",
    "ReportsGetDatasetsServiceUnavailableErrorResponseBody": ".reports_get_datasets_service_unavailable_error_response_body",
    "ReportsGetDatasetsTooManyRequestsErrorResponseBody": ".reports_get_datasets_too_many_requests_error_response_body",
    "ReportsGetDatasetsUnauthorizedErrorResponseBody": ".reports_get_datasets_unauthorized_error_response_body",
    "ReportsGetReportConfigsBadGatewayErrorResponseBody": ".reports_get_report_configs_bad_gateway_error_response_body",
    "ReportsGetReportConfigsGatewayTimeoutErrorResponseBody": ".reports_get_report_configs_gateway_timeout_error_response_body",
    "ReportsGetReportConfigsInternalServerErrorResponseBody": ".reports_get_report_configs_internal_server_error_response_body",
    "ReportsGetReportConfigsMethodNotAllowedErrorResponseBody": ".reports_get_report_configs_method_not_allowed_error_response_body",
    "ReportsGetReportConfigsNotFoundErrorResponseBody": ".reports_get_report_configs_not_found_error_response_body",
    "ReportsGetReportConfigsNotImplementedErrorResponseBody": ".reports_get_report_configs_not_implemented_error_response_body",
    "ReportsGetReportConfigsResponseBody": ".reports_get_report_configs_response_body",
    "ReportsGetReportConfigsServiceUnavailableErrorResponseBody": ".reports_get_report_configs_service_unavailable_error_response_body",
    "ReportsGetReportConfigsTooManyRequestsErrorResponseBody": ".reports_get_report_configs_too_many_requests_error_response_body",
    "ReportsGetReportConfigsUnauthorizedErrorResponseBody": ".reports_get_report_configs_unauthorized_error_response_body",
    "ReportsGetReportRunDataBadGatewayErrorResponseBody": ".reports_get_report_run_data_bad_gateway_error_response_body",
    "ReportsGetReportRunDataGatewayTimeoutErrorResponseBody": ".reports_get_report_run_data_gateway_timeout_error_response_body",
    "ReportsGetReportRunDataInternalServerErrorResponseBody": ".reports_get_report_run_data_internal_server_error_response_body",
    "ReportsGetReportRunDataMethodNotAllowedErrorResponseBody": ".reports_get_report_run_data_method_not_allowed_error_response_body",
    "ReportsGetReportRunDataNotFoundErrorResponseBody": ".reports_get_report_run_data_not_found_error_response_body",
    "ReportsGetReportRunDataNotImplementedErrorResponseBody": ".reports_get_report_run_data_not_implemented_error_response_body",
    "ReportsGetReportRunDataResponseBody": ".reports_get_report_run_data_response_body",
    "ReportsGetReportRunDataServiceUnavailableErrorResponseBody": ".reports_get_report_run_data_service_unavailable_error_response_body",
    "ReportsGetReportRunDataTooManyRequestsErrorResponseBody": ".reports_get_report_run_data_too_many_requests_error_response_body",
    "ReportsGetReportRunDataUnauthorizedErrorResponseBody": ".reports_get_report_run_data_unauthorized_error_response_body",
    "ReportsGetReportRunsBadGatewayErrorResponseBody": ".reports_get_report_runs_bad_gateway_error_response_body",
    "ReportsGetReportRunsGatewayTimeoutErrorResponseBody": ".reports_get_report_runs_gateway_timeout_error_response_body",
    "ReportsGetReportRunsInternalServerErrorResponseBody": ".reports_get_report_runs_internal_server_error_response_body",
    "ReportsGetReportRunsMethodNotAllowedErrorResponseBody": ".reports_get_report_runs_method_not_allowed_error_response_body",
    "ReportsGetReportRunsNotFoundErrorResponseBody": ".reports_get_report_runs_not_found_error_response_body",
    "ReportsGetReportRunsNotImplementedErrorResponseBody": ".reports_get_report_runs_not_implemented_error_response_body",
    "ReportsGetReportRunsResponseBody": ".reports_get_report_runs_response_body",
    "ReportsGetReportRunsServiceUnavailableErrorResponseBody": ".reports_get_report_runs_service_unavailable_error_response_body",
    "ReportsGetReportRunsTooManyRequestsErrorResponseBody": ".reports_get_report_runs_too_many_requests_error_response_body",
    "ReportsGetReportRunsUnauthorizedErrorResponseBody": ".reports_get_report_runs_unauthorized_error_response_body",
    "ResolvedBy": ".resolved_by",
    "ResolvedByType": ".resolved_by_type",
    "ReverseGeo": ".reverse_geo",
    "ReverseGeoObjectResponseBody": ".reverse_geo_object_response_body",
    "RidershipAccountObjectResponseBody": ".ridership_account_object_response_body",
    "RidershipAccountsCreateRidershipAccountBadGatewayErrorResponseBody": ".ridership_accounts_create_ridership_account_bad_gateway_error_response_body",
    "RidershipAccountsCreateRidershipAccountGatewayTimeoutErrorResponseBody": ".ridership_accounts_create_ridership_account_gateway_timeout_error_response_body",
    "RidershipAccountsCreateRidershipAccountInternalServerErrorResponseBody": ".ridership_accounts_create_ridership_account_internal_server_error_response_body",
    "RidershipAccountsCreateRidershipAccountMethodNotAllowedErrorResponseBody": ".ridership_accounts_create_ridership_account_method_not_allowed_error_response_body",
    "RidershipAccountsCreateRidershipAccountNotFoundErrorResponseBody": ".ridership_accounts_create_ridership_account_not_found_error_response_body",
    "RidershipAccountsCreateRidershipAccountNotImplementedErrorResponseBody": ".ridership_accounts_create_ridership_account_not_implemented_error_response_body",
    "RidershipAccountsCreateRidershipAccountResponseBody": ".ridership_accounts_create_ridership_account_response_body",
    "RidershipAccountsCreateRidershipAccountServiceUnavailableErrorResponseBody": ".ridership_accounts_create_ridership_account_service_unavailable_error_response_body",
    "RidershipAccountsCreateRidershipAccountTooManyRequestsErrorResponseBody": ".ridership_accounts_create_ridership_account_too_many_requests_error_response_body",
    "RidershipAccountsCreateRidershipAccountUnauthorizedErrorResponseBody": ".ridership_accounts_create_ridership_account_unauthorized_error_response_body",
    "RidershipAccountsDeleteRidershipAccountBadGatewayErrorResponseBody": ".ridership_accounts_delete_ridership_account_bad_gateway_error_response_body",
    "RidershipAccountsDeleteRidershipAccountGatewayTimeoutErrorResponseBody": ".ridership_accounts_delete_ridership_account_gateway_timeout_error_response_body",
    "RidershipAccountsDeleteRidershipAccountInternalServerErrorResponseBody": ".ridership_accounts_delete_ridership_account_internal_server_error_response_body",
    "RidershipAccountsDeleteRidershipAccountMethodNotAllowedErrorResponseBody": ".ridership_accounts_delete_ridership_account_method_not_allowed_error_response_body",
    "RidershipAccountsDeleteRidershipAccountNotFoundErrorResponseBody": ".ridership_accounts_delete_ridership_account_not_found_error_response_body",
    "RidershipAccountsDeleteRidershipAccountNotImplementedErrorResponseBody": ".ridership_accounts_delete_ridership_account_not_implemented_error_response_body",
    "RidershipAccountsDeleteRidershipAccountServiceUnavailableErrorResponseBody": ".ridership_accounts_delete_ridership_account_service_unavailable_error_response_body",
    "RidershipAccountsDeleteRidershipAccountTooManyRequestsErrorResponseBody": ".ridership_accounts_delete_ridership_account_too_many_requests_error_response_body",
    "RidershipAccountsDeleteRidershipAccountUnauthorizedErrorResponseBody": ".ridership_accounts_delete_ridership_account_unauthorized_error_response_body",
    "RidershipAccountsGetRidershipAccountBadGatewayErrorResponseBody": ".ridership_accounts_get_ridership_account_bad_gateway_error_response_body",
    "RidershipAccountsGetRidershipAccountGatewayTimeoutErrorResponseBody": ".ridership_accounts_get_ridership_account_gateway_timeout_error_response_body",
    "RidershipAccountsGetRidershipAccountInternalServerErrorResponseBody": ".ridership_accounts_get_ridership_account_internal_server_error_response_body",
    "RidershipAccountsGetRidershipAccountMethodNotAllowedErrorResponseBody": ".ridership_accounts_get_ridership_account_method_not_allowed_error_response_body",
    "RidershipAccountsGetRidershipAccountNotFoundErrorResponseBody": ".ridership_accounts_get_ridership_account_not_found_error_response_body",
    "RidershipAccountsGetRidershipAccountNotImplementedErrorResponseBody": ".ridership_accounts_get_ridership_account_not_implemented_error_response_body",
    "RidershipAccountsGetRidershipAccountResponseBody": ".ridership_accounts_get_ridership_account_response_body",
    "RidershipAccountsGetRidershipAccountServiceUnavailableErrorResponseBody": ".ridership_accounts_get_ridership_account_service_unavailable_error_response_body",
    "RidershipAccountsGetRidershipAccountTooManyRequestsErrorResponseBody": ".ridership_accounts_get_ridership_account_too_many_requests_error_response_body",
    "RidershipAccountsGetRidershipAccountUnauthorizedErrorResponseBody": ".ridership_accounts_get_ridership_account_unauthorized_error_response_body",
    "RidershipAccountsListRidershipAccountsBadGatewayErrorResponseBody": ".ridership_accounts_list_ridership_accounts_bad_gateway_error_response_body",
    "RidershipAccountsListRidershipAccountsGatewayTimeoutErrorResponseBody": ".ridership_accounts_list_ridership_accounts_gateway_timeout_error_response_body",
    "RidershipAccountsListRidershipAccountsInternalServerErrorResponseBody": ".ridership_accounts_list_ridership_accounts_internal_server_error_response_body",
    "RidershipAccountsListRidershipAccountsMethodNotAllowedErrorResponseBody": ".ridership_accounts_list_ridership_accounts_method_not_allowed_error_response_body",
    "RidershipAccountsListRidershipAccountsNotFoundErrorResponseBody": ".ridership_accounts_list_ridership_accounts_not_found_error_response_body",
    "RidershipAccountsListRidershipAccountsNotImplementedErrorResponseBody": ".ridership_accounts_list_ridership_accounts_not_implemented_error_response_body",
    "RidershipAccountsListRidershipAccountsResponseBody": ".ridership_accounts_list_ridership_accounts_response_body",
    "RidershipAccountsListRidershipAccountsServiceUnavailableErrorResponseBody": ".ridership_accounts_list_ridership_accounts_service_unavailable_error_response_body",
    "RidershipAccountsListRidershipAccountsTooManyRequestsErrorResponseBody": ".ridership_accounts_list_ridership_accounts_too_many_requests_error_response_body",
    "RidershipAccountsListRidershipAccountsUnauthorizedErrorResponseBody": ".ridership_accounts_list_ridership_accounts_unauthorized_error_response_body",
    "RidershipAccountsUpdateRidershipAccountBadGatewayErrorResponseBody": ".ridership_accounts_update_ridership_account_bad_gateway_error_response_body",
    "RidershipAccountsUpdateRidershipAccountGatewayTimeoutErrorResponseBody": ".ridership_accounts_update_ridership_account_gateway_timeout_error_response_body",
    "RidershipAccountsUpdateRidershipAccountInternalServerErrorResponseBody": ".ridership_accounts_update_ridership_account_internal_server_error_response_body",
    "RidershipAccountsUpdateRidershipAccountMethodNotAllowedErrorResponseBody": ".ridership_accounts_update_ridership_account_method_not_allowed_error_response_body",
    "RidershipAccountsUpdateRidershipAccountNotFoundErrorResponseBody": ".ridership_accounts_update_ridership_account_not_found_error_response_body",
    "RidershipAccountsUpdateRidershipAccountNotImplementedErrorResponseBody": ".ridership_accounts_update_ridership_account_not_implemented_error_response_body",
    "RidershipAccountsUpdateRidershipAccountResponseBody": ".ridership_accounts_update_ridership_account_response_body",
    "RidershipAccountsUpdateRidershipAccountServiceUnavailableErrorResponseBody": ".ridership_accounts_update_ridership_account_service_unavailable_error_response_body",
    "RidershipAccountsUpdateRidershipAccountTooManyRequestsErrorResponseBody": ".ridership_accounts_update_ridership_account_too_many_requests_error_response_body",
    "RidershipAccountsUpdateRidershipAccountUnauthorizedErrorResponseBody": ".ridership_accounts_update_ridership_account_unauthorized_error_response_body",
    "RidershipPassengerIdentifierInputRequestBody": ".ridership_passenger_identifier_input_request_body",
    "RidershipPassengerIdentifierInputRequestBodyStatus": ".ridership_passenger_identifier_input_request_body_status",
    "RidershipPassengerIdentifierInputRequestBodyType": ".ridership_passenger_identifier_input_request_body_type",
    "RidershipPassengerIdentifierObjectResponseBody": ".ridership_passenger_identifier_object_response_body",
    "RidershipPassengerIdentifierObjectResponseBodyStatus": ".ridership_passenger_identifier_object_response_body_status",
    "RidershipPassengerIdentifierObjectResponseBodyType": ".ridership_passenger_identifier_object_response_body_type",
    "RidershipPassengerObjectResponseBody": ".ridership_passenger_object_response_body",
    "RidershipPassengerSpecialInstructionsInputRequestBody": ".ridership_passenger_special_instructions_input_request_body",
    "RidershipPassengerSpecialInstructionsObjectResponseBody": ".ridership_passenger_special_instructions_object_response_body",
    "RidershipPassengersCreateRidershipPassengerBadGatewayErrorResponseBody": ".ridership_passengers_create_ridership_passenger_bad_gateway_error_response_body",
    "RidershipPassengersCreateRidershipPassengerGatewayTimeoutErrorResponseBody": ".ridership_passengers_create_ridership_passenger_gateway_timeout_error_response_body",
    "RidershipPassengersCreateRidershipPassengerInternalServerErrorResponseBody": ".ridership_passengers_create_ridership_passenger_internal_server_error_response_body",
    "RidershipPassengersCreateRidershipPassengerMethodNotAllowedErrorResponseBody": ".ridership_passengers_create_ridership_passenger_method_not_allowed_error_response_body",
    "RidershipPassengersCreateRidershipPassengerNotFoundErrorResponseBody": ".ridership_passengers_create_ridership_passenger_not_found_error_response_body",
    "RidershipPassengersCreateRidershipPassengerNotImplementedErrorResponseBody": ".ridership_passengers_create_ridership_passenger_not_implemented_error_response_body",
    "RidershipPassengersCreateRidershipPassengerResponseBody": ".ridership_passengers_create_ridership_passenger_response_body",
    "RidershipPassengersCreateRidershipPassengerServiceUnavailableErrorResponseBody": ".ridership_passengers_create_ridership_passenger_service_unavailable_error_response_body",
    "RidershipPassengersCreateRidershipPassengerTooManyRequestsErrorResponseBody": ".ridership_passengers_create_ridership_passenger_too_many_requests_error_response_body",
    "RidershipPassengersCreateRidershipPassengerUnauthorizedErrorResponseBody": ".ridership_passengers_create_ridership_passenger_unauthorized_error_response_body",
    "RidershipPassengersDeleteRidershipPassengerBadGatewayErrorResponseBody": ".ridership_passengers_delete_ridership_passenger_bad_gateway_error_response_body",
    "RidershipPassengersDeleteRidershipPassengerGatewayTimeoutErrorResponseBody": ".ridership_passengers_delete_ridership_passenger_gateway_timeout_error_response_body",
    "RidershipPassengersDeleteRidershipPassengerInternalServerErrorResponseBody": ".ridership_passengers_delete_ridership_passenger_internal_server_error_response_body",
    "RidershipPassengersDeleteRidershipPassengerMethodNotAllowedErrorResponseBody": ".ridership_passengers_delete_ridership_passenger_method_not_allowed_error_response_body",
    "RidershipPassengersDeleteRidershipPassengerNotFoundErrorResponseBody": ".ridership_passengers_delete_ridership_passenger_not_found_error_response_body",
    "RidershipPassengersDeleteRidershipPassengerNotImplementedErrorResponseBody": ".ridership_passengers_delete_ridership_passenger_not_implemented_error_response_body",
    "RidershipPassengersDeleteRidershipPassengerServiceUnavailableErrorResponseBody": ".ridership_passengers_delete_ridership_passenger_service_unavailable_error_response_body",
    "RidershipPassengersDeleteRidershipPassengerTooManyRequestsErrorResponseBody": ".ridership_passengers_delete_ridership_passenger_too_many_requests_error_response_body",
    "RidershipPassengersDeleteRidershipPassengerUnauthorizedErrorResponseBody": ".ridership_passengers_delete_ridership_passenger_unauthorized_error_response_body",
    "RidershipPassengersGetRidershipPassengerBadGatewayErrorResponseBody": ".ridership_passengers_get_ridership_passenger_bad_gateway_error_response_body",
    "RidershipPassengersGetRidershipPassengerGatewayTimeoutErrorResponseBody": ".ridership_passengers_get_ridership_passenger_gateway_timeout_error_response_body",
    "RidershipPassengersGetRidershipPassengerInternalServerErrorResponseBody": ".ridership_passengers_get_ridership_passenger_internal_server_error_response_body",
    "RidershipPassengersGetRidershipPassengerMethodNotAllowedErrorResponseBody": ".ridership_passengers_get_ridership_passenger_method_not_allowed_error_response_body",
    "RidershipPassengersGetRidershipPassengerNotFoundErrorResponseBody": ".ridership_passengers_get_ridership_passenger_not_found_error_response_body",
    "RidershipPassengersGetRidershipPassengerNotImplementedErrorResponseBody": ".ridership_passengers_get_ridership_passenger_not_implemented_error_response_body",
    "RidershipPassengersGetRidershipPassengerResponseBody": ".ridership_passengers_get_ridership_passenger_response_body",
    "RidershipPassengersGetRidershipPassengerServiceUnavailableErrorResponseBody": ".ridership_passengers_get_ridership_passenger_service_unavailable_error_response_body",
    "RidershipPassengersGetRidershipPassengerTooManyRequestsErrorResponseBody": ".ridership_passengers_get_ridership_passenger_too_many_requests_error_response_body",
    "RidershipPassengersGetRidershipPassengerUnauthorizedErrorResponseBody": ".ridership_passengers_get_ridership_passenger_unauthorized_error_response_body",
    "RidershipPassengersListRidershipPassengersBadGatewayErrorResponseBody": ".ridership_passengers_list_ridership_passengers_bad_gateway_error_response_body",
    "RidershipPassengersListRidershipPassengersGatewayTimeoutErrorResponseBody": ".ridership_passengers_list_ridership_passengers_gateway_timeout_error_response_body",
    "RidershipPassengersListRidershipPassengersInternalServerErrorResponseBody": ".ridership_passengers_list_ridership_passengers_internal_server_error_response_body",
    "RidershipPassengersListRidershipPassengersMethodNotAllowedErrorResponseBody": ".ridership_passengers_list_ridership_passengers_method_not_allowed_error_response_body",
    "RidershipPassengersListRidershipPassengersNotFoundErrorResponseBody": ".ridership_passengers_list_ridership_passengers_not_found_error_response_body",
    "RidershipPassengersListRidershipPassengersNotImplementedErrorResponseBody": ".ridership_passengers_list_ridership_passengers_not_implemented_error_response_body",
    "RidershipPassengersListRidershipPassengersResponseBody": ".ridership_passengers_list_ridership_passengers_response_body",
    "RidershipPassengersListRidershipPassengersServiceUnavailableErrorResponseBody": ".ridership_passengers_list_ridership_passengers_service_unavailable_error_response_body",
    "RidershipPassengersListRidershipPassengersTooManyRequestsErrorResponseBody": ".ridership_passengers_list_ridership_passengers_too_many_requests_error_response_body",
    "RidershipPassengersListRidershipPassengersUnauthorizedErrorResponseBody": ".ridership_passengers_list_ridership_passengers_unauthorized_error_response_body",
    "RidershipPassengersUpdateRidershipPassengerBadGatewayErrorResponseBody": ".ridership_passengers_update_ridership_passenger_bad_gateway_error_response_body",
    "RidershipPassengersUpdateRidershipPassengerGatewayTimeoutErrorResponseBody": ".ridership_passengers_update_ridership_passenger_gateway_timeout_error_response_body",
    "RidershipPassengersUpdateRidershipPassengerInternalServerErrorResponseBody": ".ridership_passengers_update_ridership_passenger_internal_server_error_response_body",
    "RidershipPassengersUpdateRidershipPassengerMethodNotAllowedErrorResponseBody": ".ridership_passengers_update_ridership_passenger_method_not_allowed_error_response_body",
    "RidershipPassengersUpdateRidershipPassengerNotFoundErrorResponseBody": ".ridership_passengers_update_ridership_passenger_not_found_error_response_body",
    "RidershipPassengersUpdateRidershipPassengerNotImplementedErrorResponseBody": ".ridership_passengers_update_ridership_passenger_not_implemented_error_response_body",
    "RidershipPassengersUpdateRidershipPassengerResponseBody": ".ridership_passengers_update_ridership_passenger_response_body",
    "RidershipPassengersUpdateRidershipPassengerServiceUnavailableErrorResponseBody": ".ridership_passengers_update_ridership_passenger_service_unavailable_error_response_body",
    "RidershipPassengersUpdateRidershipPassengerTooManyRequestsErrorResponseBody": ".ridership_passengers_update_ridership_passenger_too_many_requests_error_response_body",
    "RidershipPassengersUpdateRidershipPassengerUnauthorizedErrorResponseBody": ".ridership_passengers_update_ridership_passenger_unauthorized_error_response_body",
    "RidershipRouteSetupObjectResponseBody": ".ridership_route_setup_object_response_body",
    "RidershipRouteSetupPassengerInputRequestBody": ".ridership_route_setup_passenger_input_request_body",
    "RidershipRouteSetupPassengerObjectResponseBody": ".ridership_route_setup_passenger_object_response_body",
    "RidershipRouteSetupsCreateRidershipRouteSetupBadGatewayErrorResponseBody": ".ridership_route_setups_create_ridership_route_setup_bad_gateway_error_response_body",
    "RidershipRouteSetupsCreateRidershipRouteSetupGatewayTimeoutErrorResponseBody": ".ridership_route_setups_create_ridership_route_setup_gateway_timeout_error_response_body",
    "RidershipRouteSetupsCreateRidershipRouteSetupInternalServerErrorResponseBody": ".ridership_route_setups_create_ridership_route_setup_internal_server_error_response_body",
    "RidershipRouteSetupsCreateRidershipRouteSetupMethodNotAllowedErrorResponseBody": ".ridership_route_setups_create_ridership_route_setup_method_not_allowed_error_response_body",
    "RidershipRouteSetupsCreateRidershipRouteSetupNotFoundErrorResponseBody": ".ridership_route_setups_create_ridership_route_setup_not_found_error_response_body",
    "RidershipRouteSetupsCreateRidershipRouteSetupNotImplementedErrorResponseBody": ".ridership_route_setups_create_ridership_route_setup_not_implemented_error_response_body",
    "RidershipRouteSetupsCreateRidershipRouteSetupResponseBody": ".ridership_route_setups_create_ridership_route_setup_response_body",
    "RidershipRouteSetupsCreateRidershipRouteSetupServiceUnavailableErrorResponseBody": ".ridership_route_setups_create_ridership_route_setup_service_unavailable_error_response_body",
    "RidershipRouteSetupsCreateRidershipRouteSetupTooManyRequestsErrorResponseBody": ".ridership_route_setups_create_ridership_route_setup_too_many_requests_error_response_body",
    "RidershipRouteSetupsCreateRidershipRouteSetupUnauthorizedErrorResponseBody": ".ridership_route_setups_create_ridership_route_setup_unauthorized_error_response_body",
    "RidershipRouteSetupsDeleteRidershipRouteSetupBadGatewayErrorResponseBody": ".ridership_route_setups_delete_ridership_route_setup_bad_gateway_error_response_body",
    "RidershipRouteSetupsDeleteRidershipRouteSetupGatewayTimeoutErrorResponseBody": ".ridership_route_setups_delete_ridership_route_setup_gateway_timeout_error_response_body",
    "RidershipRouteSetupsDeleteRidershipRouteSetupInternalServerErrorResponseBody": ".ridership_route_setups_delete_ridership_route_setup_internal_server_error_response_body",
    "RidershipRouteSetupsDeleteRidershipRouteSetupMethodNotAllowedErrorResponseBody": ".ridership_route_setups_delete_ridership_route_setup_method_not_allowed_error_response_body",
    "RidershipRouteSetupsDeleteRidershipRouteSetupNotFoundErrorResponseBody": ".ridership_route_setups_delete_ridership_route_setup_not_found_error_response_body",
    "RidershipRouteSetupsDeleteRidershipRouteSetupNotImplementedErrorResponseBody": ".ridership_route_setups_delete_ridership_route_setup_not_implemented_error_response_body",
    "RidershipRouteSetupsDeleteRidershipRouteSetupServiceUnavailableErrorResponseBody": ".ridership_route_setups_delete_ridership_route_setup_service_unavailable_error_response_body",
    "RidershipRouteSetupsDeleteRidershipRouteSetupTooManyRequestsErrorResponseBody": ".ridership_route_setups_delete_ridership_route_setup_too_many_requests_error_response_body",
    "RidershipRouteSetupsDeleteRidershipRouteSetupUnauthorizedErrorResponseBody": ".ridership_route_setups_delete_ridership_route_setup_unauthorized_error_response_body",
    "RidershipRouteSetupsGetRidershipRouteSetupBadGatewayErrorResponseBody": ".ridership_route_setups_get_ridership_route_setup_bad_gateway_error_response_body",
    "RidershipRouteSetupsGetRidershipRouteSetupGatewayTimeoutErrorResponseBody": ".ridership_route_setups_get_ridership_route_setup_gateway_timeout_error_response_body",
    "RidershipRouteSetupsGetRidershipRouteSetupInternalServerErrorResponseBody": ".ridership_route_setups_get_ridership_route_setup_internal_server_error_response_body",
    "RidershipRouteSetupsGetRidershipRouteSetupMethodNotAllowedErrorResponseBody": ".ridership_route_setups_get_ridership_route_setup_method_not_allowed_error_response_body",
    "RidershipRouteSetupsGetRidershipRouteSetupNotFoundErrorResponseBody": ".ridership_route_setups_get_ridership_route_setup_not_found_error_response_body",
    "RidershipRouteSetupsGetRidershipRouteSetupNotImplementedErrorResponseBody": ".ridership_route_setups_get_ridership_route_setup_not_implemented_error_response_body",
    "RidershipRouteSetupsGetRidershipRouteSetupResponseBody": ".ridership_route_setups_get_ridership_route_setup_response_body",
    "RidershipRouteSetupsGetRidershipRouteSetupServiceUnavailableErrorResponseBody": ".ridership_route_setups_get_ridership_route_setup_service_unavailable_error_response_body",
    "RidershipRouteSetupsGetRidershipRouteSetupTooManyRequestsErrorResponseBody": ".ridership_route_setups_get_ridership_route_setup_too_many_requests_error_response_body",
    "RidershipRouteSetupsGetRidershipRouteSetupUnauthorizedErrorResponseBody": ".ridership_route_setups_get_ridership_route_setup_unauthorized_error_response_body",
    "RidershipRouteSetupsUpdateRidershipRouteSetupBadGatewayErrorResponseBody": ".ridership_route_setups_update_ridership_route_setup_bad_gateway_error_response_body",
    "RidershipRouteSetupsUpdateRidershipRouteSetupGatewayTimeoutErrorResponseBody": ".ridership_route_setups_update_ridership_route_setup_gateway_timeout_error_response_body",
    "RidershipRouteSetupsUpdateRidershipRouteSetupInternalServerErrorResponseBody": ".ridership_route_setups_update_ridership_route_setup_internal_server_error_response_body",
    "RidershipRouteSetupsUpdateRidershipRouteSetupMethodNotAllowedErrorResponseBody": ".ridership_route_setups_update_ridership_route_setup_method_not_allowed_error_response_body",
    "RidershipRouteSetupsUpdateRidershipRouteSetupNotFoundErrorResponseBody": ".ridership_route_setups_update_ridership_route_setup_not_found_error_response_body",
    "RidershipRouteSetupsUpdateRidershipRouteSetupNotImplementedErrorResponseBody": ".ridership_route_setups_update_ridership_route_setup_not_implemented_error_response_body",
    "RidershipRouteSetupsUpdateRidershipRouteSetupResponseBody": ".ridership_route_setups_update_ridership_route_setup_response_body",
    "RidershipRouteSetupsUpdateRidershipRouteSetupServiceUnavailableErrorResponseBody": ".ridership_route_setups_update_ridership_route_setup_service_unavailable_error_response_body",
    "RidershipRouteSetupsUpdateRidershipRouteSetupTooManyRequestsErrorResponseBody": ".ridership_route_setups_update_ridership_route_setup_too_many_requests_error_response_body",
    "RidershipRouteSetupsUpdateRidershipRouteSetupUnauthorizedErrorResponseBody": ".ridership_route_setups_update_ridership_route_setup_unauthorized_error_response_body",
    "RollingStopDetectionAlertSettingsObjectResponseBody": ".rolling_stop_detection_alert_settings_object_response_body",
    "RouteChangesResponseBody": ".route_changes_response_body",
    "RouteEventDetailsResponseBody": ".route_event_details_response_body",
    "RouteEventResponseResponseBody": ".route_event_response_response_body",
    "RouteEventResponseResponseBodyEventType": ".route_event_response_response_body_event_type",
    "RouteEventRouteResponseResponseBody": ".route_event_route_response_response_body",
    "RouteEventStopResponseResponseBody": ".route_event_stop_response_response_body",
    "RouteFeedObjectResponseBody": ".route_feed_object_response_body",
    "RouteFeedObjectResponseBodyOperation": ".route_feed_object_response_body_operation",
    "RouteFeedObjectResponseBodySource": ".route_feed_object_response_body_source",
    "RouteFeedObjectResponseBodyType": ".route_feed_object_response_body_type",
    "RouteObjectResponseBody": ".route_object_response_body",
    "RouteSettingsRequestBody": ".route_settings_request_body",
    "RouteSettingsRequestBodyRouteCompletionCondition": ".route_settings_request_body_route_completion_condition",
    "RouteSettingsRequestBodyRouteStartingCondition": ".route_settings_request_body_route_starting_condition",
    "RouteSettingsRequestBodySequencingMethod": ".route_settings_request_body_sequencing_method",
    "RouteSettingsResponseBody": ".route_settings_response_body",
    "RouteSettingsResponseBodyRouteCompletionCondition": ".route_settings_response_body_route_completion_condition",
    "RouteSettingsResponseBodyRouteStartingCondition": ".route_settings_response_body_route_starting_condition",
    "RouteSettingsResponseBodySequencingMethod": ".route_settings_response_body_sequencing_method",
    "RouteStopDetailsObjectResponseBody": ".route_stop_details_object_response_body",
    "RouteStopDetailsObjectResponseBodyOperation": ".route_stop_details_object_response_body_operation",
    "RouteStopDetailsObjectResponseBodyType": ".route_stop_details_object_response_body_type",
    "RouteStopEstimatedArrivalDetailsObjectRequestBody": ".route_stop_estimated_arrival_details_object_request_body",
    "RouteStopEstimatedArrivalDetailsObjectResponseBody": ".route_stop_estimated_arrival_details_object_response_body",
    "RouteStopEtaResponseBody": ".route_stop_eta_response_body",
    "RouteStopObjectResponseBody": ".route_stop_object_response_body",
    "RoutesCreateRouteBadGatewayErrorResponseBody": ".routes_create_route_bad_gateway_error_response_body",
    "RoutesCreateRouteGatewayTimeoutErrorResponseBody": ".routes_create_route_gateway_timeout_error_response_body",
    "RoutesCreateRouteInternalServerErrorResponseBody": ".routes_create_route_internal_server_error_response_body",
    "RoutesCreateRouteMethodNotAllowedErrorResponseBody": ".routes_create_route_method_not_allowed_error_response_body",
    "RoutesCreateRouteNotFoundErrorResponseBody": ".routes_create_route_not_found_error_response_body",
    "RoutesCreateRouteNotImplementedErrorResponseBody": ".routes_create_route_not_implemented_error_response_body",
    "RoutesCreateRouteResponseBody": ".routes_create_route_response_body",
    "RoutesCreateRouteServiceUnavailableErrorResponseBody": ".routes_create_route_service_unavailable_error_response_body",
    "RoutesCreateRouteTooManyRequestsErrorResponseBody": ".routes_create_route_too_many_requests_error_response_body",
    "RoutesCreateRouteUnauthorizedErrorResponseBody": ".routes_create_route_unauthorized_error_response_body",
    "RoutesDeleteRouteBadGatewayErrorResponseBody": ".routes_delete_route_bad_gateway_error_response_body",
    "RoutesDeleteRouteGatewayTimeoutErrorResponseBody": ".routes_delete_route_gateway_timeout_error_response_body",
    "RoutesDeleteRouteInternalServerErrorResponseBody": ".routes_delete_route_internal_server_error_response_body",
    "RoutesDeleteRouteMethodNotAllowedErrorResponseBody": ".routes_delete_route_method_not_allowed_error_response_body",
    "RoutesDeleteRouteNotFoundErrorResponseBody": ".routes_delete_route_not_found_error_response_body",
    "RoutesDeleteRouteNotImplementedErrorResponseBody": ".routes_delete_route_not_implemented_error_response_body",
    "RoutesDeleteRouteServiceUnavailableErrorResponseBody": ".routes_delete_route_service_unavailable_error_response_body",
    "RoutesDeleteRouteTooManyRequestsErrorResponseBody": ".routes_delete_route_too_many_requests_error_response_body",
    "RoutesDeleteRouteUnauthorizedErrorResponseBody": ".routes_delete_route_unauthorized_error_response_body",
    "RoutesFetchRouteBadGatewayErrorResponseBody": ".routes_fetch_route_bad_gateway_error_response_body",
    "RoutesFetchRouteGatewayTimeoutErrorResponseBody": ".routes_fetch_route_gateway_timeout_error_response_body",
    "RoutesFetchRouteInternalServerErrorResponseBody": ".routes_fetch_route_internal_server_error_response_body",
    "RoutesFetchRouteMethodNotAllowedErrorResponseBody": ".routes_fetch_route_method_not_allowed_error_response_body",
    "RoutesFetchRouteNotFoundErrorResponseBody": ".routes_fetch_route_not_found_error_response_body",
    "RoutesFetchRouteNotImplementedErrorResponseBody": ".routes_fetch_route_not_implemented_error_response_body",
    "RoutesFetchRouteResponseBody": ".routes_fetch_route_response_body",
    "RoutesFetchRouteServiceUnavailableErrorResponseBody": ".routes_fetch_route_service_unavailable_error_response_body",
    "RoutesFetchRouteTooManyRequestsErrorResponseBody": ".routes_fetch_route_too_many_requests_error_response_body",
    "RoutesFetchRouteUnauthorizedErrorResponseBody": ".routes_fetch_route_unauthorized_error_response_body",
    "RoutesFetchRoutesBadGatewayErrorResponseBody": ".routes_fetch_routes_bad_gateway_error_response_body",
    "RoutesFetchRoutesGatewayTimeoutErrorResponseBody": ".routes_fetch_routes_gateway_timeout_error_response_body",
    "RoutesFetchRoutesInternalServerErrorResponseBody": ".routes_fetch_routes_internal_server_error_response_body",
    "RoutesFetchRoutesMethodNotAllowedErrorResponseBody": ".routes_fetch_routes_method_not_allowed_error_response_body",
    "RoutesFetchRoutesNotFoundErrorResponseBody": ".routes_fetch_routes_not_found_error_response_body",
    "RoutesFetchRoutesNotImplementedErrorResponseBody": ".routes_fetch_routes_not_implemented_error_response_body",
    "RoutesFetchRoutesResponseBody": ".routes_fetch_routes_response_body",
    "RoutesFetchRoutesServiceUnavailableErrorResponseBody": ".routes_fetch_routes_service_unavailable_error_response_body",
    "RoutesFetchRoutesTooManyRequestsErrorResponseBody": ".routes_fetch_routes_too_many_requests_error_response_body",
    "RoutesFetchRoutesUnauthorizedErrorResponseBody": ".routes_fetch_routes_unauthorized_error_response_body",
    "RoutesGetRouteEventsStreamBadGatewayErrorResponseBody": ".routes_get_route_events_stream_bad_gateway_error_response_body",
    "RoutesGetRouteEventsStreamGatewayTimeoutErrorResponseBody": ".routes_get_route_events_stream_gateway_timeout_error_response_body",
    "RoutesGetRouteEventsStreamInternalServerErrorResponseBody": ".routes_get_route_events_stream_internal_server_error_response_body",
    "RoutesGetRouteEventsStreamMethodNotAllowedErrorResponseBody": ".routes_get_route_events_stream_method_not_allowed_error_response_body",
    "RoutesGetRouteEventsStreamNotFoundErrorResponseBody": ".routes_get_route_events_stream_not_found_error_response_body",
    "RoutesGetRouteEventsStreamNotImplementedErrorResponseBody": ".routes_get_route_events_stream_not_implemented_error_response_body",
    "RoutesGetRouteEventsStreamResponseBody": ".routes_get_route_events_stream_response_body",
    "RoutesGetRouteEventsStreamServiceUnavailableErrorResponseBody": ".routes_get_route_events_stream_service_unavailable_error_response_body",
    "RoutesGetRouteEventsStreamTooManyRequestsErrorResponseBody": ".routes_get_route_events_stream_too_many_requests_error_response_body",
    "RoutesGetRouteEventsStreamUnauthorizedErrorResponseBody": ".routes_get_route_events_stream_unauthorized_error_response_body",
    "RoutesGetRoutesFeedBadGatewayErrorResponseBody": ".routes_get_routes_feed_bad_gateway_error_response_body",
    "RoutesGetRoutesFeedGatewayTimeoutErrorResponseBody": ".routes_get_routes_feed_gateway_timeout_error_response_body",
    "RoutesGetRoutesFeedInternalServerErrorResponseBody": ".routes_get_routes_feed_internal_server_error_response_body",
    "RoutesGetRoutesFeedMethodNotAllowedErrorResponseBody": ".routes_get_routes_feed_method_not_allowed_error_response_body",
    "RoutesGetRoutesFeedNotFoundErrorResponseBody": ".routes_get_routes_feed_not_found_error_response_body",
    "RoutesGetRoutesFeedNotImplementedErrorResponseBody": ".routes_get_routes_feed_not_implemented_error_response_body",
    "RoutesGetRoutesFeedResponseBody": ".routes_get_routes_feed_response_body",
    "RoutesGetRoutesFeedServiceUnavailableErrorResponseBody": ".routes_get_routes_feed_service_unavailable_error_response_body",
    "RoutesGetRoutesFeedTooManyRequestsErrorResponseBody": ".routes_get_routes_feed_too_many_requests_error_response_body",
    "RoutesGetRoutesFeedUnauthorizedErrorResponseBody": ".routes_get_routes_feed_unauthorized_error_response_body",
    "RoutesPatchRouteBadGatewayErrorResponseBody": ".routes_patch_route_bad_gateway_error_response_body",
    "RoutesPatchRouteGatewayTimeoutErrorResponseBody": ".routes_patch_route_gateway_timeout_error_response_body",
    "RoutesPatchRouteInternalServerErrorResponseBody": ".routes_patch_route_internal_server_error_response_body",
    "RoutesPatchRouteMethodNotAllowedErrorResponseBody": ".routes_patch_route_method_not_allowed_error_response_body",
    "RoutesPatchRouteNotFoundErrorResponseBody": ".routes_patch_route_not_found_error_response_body",
    "RoutesPatchRouteNotImplementedErrorResponseBody": ".routes_patch_route_not_implemented_error_response_body",
    "RoutesPatchRouteResponseBody": ".routes_patch_route_response_body",
    "RoutesPatchRouteServiceUnavailableErrorResponseBody": ".routes_patch_route_service_unavailable_error_response_body",
    "RoutesPatchRouteTooManyRequestsErrorResponseBody": ".routes_patch_route_too_many_requests_error_response_body",
    "RoutesPatchRouteUnauthorizedErrorResponseBody": ".routes_patch_route_unauthorized_error_response_body",
    "RoutesSingleUseAddressObjectRequestBody": ".routes_single_use_address_object_request_body",
    "RoutesSingleUseAddressObjectResponseBody": ".routes_single_use_address_object_response_body",
    "RoutesStopResponseObjectResponseBody": ".routes_stop_response_object_response_body",
    "RoutesStopResponseObjectResponseBodyState": ".routes_stop_response_object_response_body_state",
    "SafetyBehaviorTriggerDetailsObjectRequestBody": ".safety_behavior_trigger_details_object_request_body",
    "SafetyBehaviorTriggerDetailsObjectRequestBodyBehaviorsItem": ".safety_behavior_trigger_details_object_request_body_behaviors_item",
    "SafetyBehaviorTriggerDetailsObjectRequestBodySeveritiesItem": ".safety_behavior_trigger_details_object_request_body_severities_item",
    "SafetyBehaviorTriggerDetailsObjectRequestBodyStatusesItem": ".safety_behavior_trigger_details_object_request_body_statuses_item",
    "SafetyBehaviorTriggerDetailsObjectResponseBody": ".safety_behavior_trigger_details_object_response_body",
    "SafetyBehaviorTriggerDetailsObjectResponseBodyBehaviorsItem": ".safety_behavior_trigger_details_object_response_body_behaviors_item",
    "SafetyBehaviorTriggerDetailsObjectResponseBodySeveritiesItem": ".safety_behavior_trigger_details_object_response_body_severities_item",
    "SafetyBehaviorTriggerDetailsObjectResponseBodyStatusesItem": ".safety_behavior_trigger_details_object_response_body_statuses_item",
    "SafetyEvent": ".safety_event",
    "SafetyEventActivityFeedItemResponseBody": ".safety_event_activity_feed_item_response_body",
    "SafetyEventActivityFeedItemResponseBodyType": ".safety_event_activity_feed_item_response_body_type",
    "SafetyEventBehaviorLabel": ".safety_event_behavior_label",
    "SafetyEventBehaviorLabelName": ".safety_event_behavior_label_name",
    "SafetyEventBehaviorLabelSource": ".safety_event_behavior_label_source",
    "SafetyEventBehaviorLabelType": ".safety_event_behavior_label_type",
    "SafetyEventBehaviorLabels": ".safety_event_behavior_labels",
    "SafetyEventBehaviorLabelsResponseBody": ".safety_event_behavior_labels_response_body",
    "SafetyEventBehaviorLabelsResponseBodyType": ".safety_event_behavior_labels_response_body_type",
    "SafetyEventCoachingState": ".safety_event_coaching_state",
    "SafetyEventDismissalReasonResponseBody": ".safety_event_dismissal_reason_response_body",
    "SafetyEventDismissalReasonResponseBodyCode": ".safety_event_dismissal_reason_response_body_code",
    "SafetyEventDownloadForwardVideoUrl": ".safety_event_download_forward_video_url",
    "SafetyEventDownloadInwardVideoUrl": ".safety_event_download_inward_video_url",
    "SafetyEventDownloadTrackedInwardVideoUrl": ".safety_event_download_tracked_inward_video_url",
    "SafetyEventDriverObjectResponseBody": ".safety_event_driver_object_response_body",
    "SafetyEventId": ".safety_event_id",
    "SafetyEventMaxAccelerationGForce": ".safety_event_max_acceleration_g_force",
    "SafetyEventObjectResponseBody": ".safety_event_object_response_body",
    "SafetyEventSpeedingMetadataResponseBody": ".safety_event_speeding_metadata_response_body",
    "SafetyEventTime": ".safety_event_time",
    "SafetyEventV2AssetObjectResponseBody": ".safety_event_v_2_asset_object_response_body",
    "SafetyEventV2AssetObjectResponseBodyType": ".safety_event_v_2_asset_object_response_body_type",
    "SafetyEventV2BehaviorLabelsResponseBody": ".safety_event_v_2_behavior_labels_response_body",
    "SafetyEventV2BehaviorLabelsResponseBodyLabel": ".safety_event_v_2_behavior_labels_response_body_label",
    "SafetyEventV2BehaviorLabelsResponseBodySource": ".safety_event_v_2_behavior_labels_response_body_source",
    "SafetyEventV2ContextLabelsResponseBody": ".safety_event_v_2_context_labels_response_body",
    "SafetyEventV2DriverObjectResponseBody": ".safety_event_v_2_driver_object_response_body",
    "SafetyEventV2MediaResponseBody": ".safety_event_v_2_media_response_body",
    "SafetyEventV2MediaResponseBodyCameraRole": ".safety_event_v_2_media_response_body_camera_role",
    "SafetyEventV2MediaResponseBodyInput": ".safety_event_v_2_media_response_body_input",
    "SafetyEventV2ObjectResponseBody": ".safety_event_v_2_object_response_body",
    "SafetyEventV2ObjectResponseBodyEventState": ".safety_event_v_2_object_response_body_event_state",
    "SafetyEventVehicleObjectResponseBody": ".safety_event_vehicle_object_response_body",
    "SafetyEventsGetSafetyActivityEventFeedBadGatewayErrorResponseBody": ".safety_events_get_safety_activity_event_feed_bad_gateway_error_response_body",
    "SafetyEventsGetSafetyActivityEventFeedGatewayTimeoutErrorResponseBody": ".safety_events_get_safety_activity_event_feed_gateway_timeout_error_response_body",
    "SafetyEventsGetSafetyActivityEventFeedInternalServerErrorResponseBody": ".safety_events_get_safety_activity_event_feed_internal_server_error_response_body",
    "SafetyEventsGetSafetyActivityEventFeedMethodNotAllowedErrorResponseBody": ".safety_events_get_safety_activity_event_feed_method_not_allowed_error_response_body",
    "SafetyEventsGetSafetyActivityEventFeedNotFoundErrorResponseBody": ".safety_events_get_safety_activity_event_feed_not_found_error_response_body",
    "SafetyEventsGetSafetyActivityEventFeedNotImplementedErrorResponseBody": ".safety_events_get_safety_activity_event_feed_not_implemented_error_response_body",
    "SafetyEventsGetSafetyActivityEventFeedResponseBody": ".safety_events_get_safety_activity_event_feed_response_body",
    "SafetyEventsGetSafetyActivityEventFeedServiceUnavailableErrorResponseBody": ".safety_events_get_safety_activity_event_feed_service_unavailable_error_response_body",
    "SafetyEventsGetSafetyActivityEventFeedTooManyRequestsErrorResponseBody": ".safety_events_get_safety_activity_event_feed_too_many_requests_error_response_body",
    "SafetyEventsGetSafetyActivityEventFeedUnauthorizedErrorResponseBody": ".safety_events_get_safety_activity_event_feed_unauthorized_error_response_body",
    "SafetyEventsListResponse": ".safety_events_list_response",
    "SafetyEventsV2GetSafetyEventsV2BadGatewayErrorResponseBody": ".safety_events_v_2_get_safety_events_v_2_bad_gateway_error_response_body",
    "SafetyEventsV2GetSafetyEventsV2GatewayTimeoutErrorResponseBody": ".safety_events_v_2_get_safety_events_v_2_gateway_timeout_error_response_body",
    "SafetyEventsV2GetSafetyEventsV2InternalServerErrorResponseBody": ".safety_events_v_2_get_safety_events_v_2_internal_server_error_response_body",
    "SafetyEventsV2GetSafetyEventsV2MethodNotAllowedErrorResponseBody": ".safety_events_v_2_get_safety_events_v_2_method_not_allowed_error_response_body",
    "SafetyEventsV2GetSafetyEventsV2NotFoundErrorResponseBody": ".safety_events_v_2_get_safety_events_v_2_not_found_error_response_body",
    "SafetyEventsV2GetSafetyEventsV2NotImplementedErrorResponseBody": ".safety_events_v_2_get_safety_events_v_2_not_implemented_error_response_body",
    "SafetyEventsV2GetSafetyEventsV2ResponseBody": ".safety_events_v_2_get_safety_events_v_2_response_body",
    "SafetyEventsV2GetSafetyEventsV2ServiceUnavailableErrorResponseBody": ".safety_events_v_2_get_safety_events_v_2_service_unavailable_error_response_body",
    "SafetyEventsV2GetSafetyEventsV2StreamBadGatewayErrorResponseBody": ".safety_events_v_2_get_safety_events_v_2_stream_bad_gateway_error_response_body",
    "SafetyEventsV2GetSafetyEventsV2StreamGatewayTimeoutErrorResponseBody": ".safety_events_v_2_get_safety_events_v_2_stream_gateway_timeout_error_response_body",
    "SafetyEventsV2GetSafetyEventsV2StreamInternalServerErrorResponseBody": ".safety_events_v_2_get_safety_events_v_2_stream_internal_server_error_response_body",
    "SafetyEventsV2GetSafetyEventsV2StreamMethodNotAllowedErrorResponseBody": ".safety_events_v_2_get_safety_events_v_2_stream_method_not_allowed_error_response_body",
    "SafetyEventsV2GetSafetyEventsV2StreamNotFoundErrorResponseBody": ".safety_events_v_2_get_safety_events_v_2_stream_not_found_error_response_body",
    "SafetyEventsV2GetSafetyEventsV2StreamNotImplementedErrorResponseBody": ".safety_events_v_2_get_safety_events_v_2_stream_not_implemented_error_response_body",
    "SafetyEventsV2GetSafetyEventsV2StreamResponseBody": ".safety_events_v_2_get_safety_events_v_2_stream_response_body",
    "SafetyEventsV2GetSafetyEventsV2StreamServiceUnavailableErrorResponseBody": ".safety_events_v_2_get_safety_events_v_2_stream_service_unavailable_error_response_body",
    "SafetyEventsV2GetSafetyEventsV2StreamTooManyRequestsErrorResponseBody": ".safety_events_v_2_get_safety_events_v_2_stream_too_many_requests_error_response_body",
    "SafetyEventsV2GetSafetyEventsV2StreamUnauthorizedErrorResponseBody": ".safety_events_v_2_get_safety_events_v_2_stream_unauthorized_error_response_body",
    "SafetyEventsV2GetSafetyEventsV2TooManyRequestsErrorResponseBody": ".safety_events_v_2_get_safety_events_v_2_too_many_requests_error_response_body",
    "SafetyEventsV2GetSafetyEventsV2UnauthorizedErrorResponseBody": ".safety_events_v_2_get_safety_events_v_2_unauthorized_error_response_body",
    "SafetyScoreBehaviorObjectResponseBody": ".safety_score_behavior_object_response_body",
    "SafetyScoreBehaviorObjectResponseBodyBehaviorType": ".safety_score_behavior_object_response_body_behavior_type",
    "SafetyScoreConfigurationSettingsObjectResponseBody": ".safety_score_configuration_settings_object_response_body",
    "SafetyScoreDetailsRequestBody": ".safety_score_details_request_body",
    "SafetyScoreDetailsRequestBodyComparison": ".safety_score_details_request_body_comparison",
    "SafetyScoreDetailsResponseBody": ".safety_score_details_response_body",
    "SafetyScoreDetailsResponseBodyComparison": ".safety_score_details_response_body_comparison",
    "SafetyScoreSpeedingObjectResponseBody": ".safety_score_speeding_object_response_body",
    "SafetyScoreSpeedingObjectResponseBodySpeedingType": ".safety_score_speeding_object_response_body_speeding_type",
    "SafetyScoresGetDriverSafetyScoreTripsBadGatewayErrorResponseBody": ".safety_scores_get_driver_safety_score_trips_bad_gateway_error_response_body",
    "SafetyScoresGetDriverSafetyScoreTripsGatewayTimeoutErrorResponseBody": ".safety_scores_get_driver_safety_score_trips_gateway_timeout_error_response_body",
    "SafetyScoresGetDriverSafetyScoreTripsInternalServerErrorResponseBody": ".safety_scores_get_driver_safety_score_trips_internal_server_error_response_body",
    "SafetyScoresGetDriverSafetyScoreTripsMethodNotAllowedErrorResponseBody": ".safety_scores_get_driver_safety_score_trips_method_not_allowed_error_response_body",
    "SafetyScoresGetDriverSafetyScoreTripsNotFoundErrorResponseBody": ".safety_scores_get_driver_safety_score_trips_not_found_error_response_body",
    "SafetyScoresGetDriverSafetyScoreTripsNotImplementedErrorResponseBody": ".safety_scores_get_driver_safety_score_trips_not_implemented_error_response_body",
    "SafetyScoresGetDriverSafetyScoreTripsResponseBody": ".safety_scores_get_driver_safety_score_trips_response_body",
    "SafetyScoresGetDriverSafetyScoreTripsServiceUnavailableErrorResponseBody": ".safety_scores_get_driver_safety_score_trips_service_unavailable_error_response_body",
    "SafetyScoresGetDriverSafetyScoreTripsTooManyRequestsErrorResponseBody": ".safety_scores_get_driver_safety_score_trips_too_many_requests_error_response_body",
    "SafetyScoresGetDriverSafetyScoreTripsUnauthorizedErrorResponseBody": ".safety_scores_get_driver_safety_score_trips_unauthorized_error_response_body",
    "SafetyScoresGetDriverSafetyScoresBadGatewayErrorResponseBody": ".safety_scores_get_driver_safety_scores_bad_gateway_error_response_body",
    "SafetyScoresGetDriverSafetyScoresGatewayTimeoutErrorResponseBody": ".safety_scores_get_driver_safety_scores_gateway_timeout_error_response_body",
    "SafetyScoresGetDriverSafetyScoresInternalServerErrorResponseBody": ".safety_scores_get_driver_safety_scores_internal_server_error_response_body",
    "SafetyScoresGetDriverSafetyScoresMethodNotAllowedErrorResponseBody": ".safety_scores_get_driver_safety_scores_method_not_allowed_error_response_body",
    "SafetyScoresGetDriverSafetyScoresNotFoundErrorResponseBody": ".safety_scores_get_driver_safety_scores_not_found_error_response_body",
    "SafetyScoresGetDriverSafetyScoresNotImplementedErrorResponseBody": ".safety_scores_get_driver_safety_scores_not_implemented_error_response_body",
    "SafetyScoresGetDriverSafetyScoresResponseBody": ".safety_scores_get_driver_safety_scores_response_body",
    "SafetyScoresGetDriverSafetyScoresServiceUnavailableErrorResponseBody": ".safety_scores_get_driver_safety_scores_service_unavailable_error_response_body",
    "SafetyScoresGetDriverSafetyScoresTooManyRequestsErrorResponseBody": ".safety_scores_get_driver_safety_scores_too_many_requests_error_response_body",
    "SafetyScoresGetDriverSafetyScoresUnauthorizedErrorResponseBody": ".safety_scores_get_driver_safety_scores_unauthorized_error_response_body",
    "SafetyScoresGetTagGroupSafetyScoresBadGatewayErrorResponseBody": ".safety_scores_get_tag_group_safety_scores_bad_gateway_error_response_body",
    "SafetyScoresGetTagGroupSafetyScoresGatewayTimeoutErrorResponseBody": ".safety_scores_get_tag_group_safety_scores_gateway_timeout_error_response_body",
    "SafetyScoresGetTagGroupSafetyScoresInternalServerErrorResponseBody": ".safety_scores_get_tag_group_safety_scores_internal_server_error_response_body",
    "SafetyScoresGetTagGroupSafetyScoresMethodNotAllowedErrorResponseBody": ".safety_scores_get_tag_group_safety_scores_method_not_allowed_error_response_body",
    "SafetyScoresGetTagGroupSafetyScoresNotFoundErrorResponseBody": ".safety_scores_get_tag_group_safety_scores_not_found_error_response_body",
    "SafetyScoresGetTagGroupSafetyScoresNotImplementedErrorResponseBody": ".safety_scores_get_tag_group_safety_scores_not_implemented_error_response_body",
    "SafetyScoresGetTagGroupSafetyScoresResponseBody": ".safety_scores_get_tag_group_safety_scores_response_body",
    "SafetyScoresGetTagGroupSafetyScoresServiceUnavailableErrorResponseBody": ".safety_scores_get_tag_group_safety_scores_service_unavailable_error_response_body",
    "SafetyScoresGetTagGroupSafetyScoresTooManyRequestsErrorResponseBody": ".safety_scores_get_tag_group_safety_scores_too_many_requests_error_response_body",
    "SafetyScoresGetTagGroupSafetyScoresUnauthorizedErrorResponseBody": ".safety_scores_get_tag_group_safety_scores_unauthorized_error_response_body",
    "SafetyScoresGetTagSafetyScoresBadGatewayErrorResponseBody": ".safety_scores_get_tag_safety_scores_bad_gateway_error_response_body",
    "SafetyScoresGetTagSafetyScoresGatewayTimeoutErrorResponseBody": ".safety_scores_get_tag_safety_scores_gateway_timeout_error_response_body",
    "SafetyScoresGetTagSafetyScoresInternalServerErrorResponseBody": ".safety_scores_get_tag_safety_scores_internal_server_error_response_body",
    "SafetyScoresGetTagSafetyScoresMethodNotAllowedErrorResponseBody": ".safety_scores_get_tag_safety_scores_method_not_allowed_error_response_body",
    "SafetyScoresGetTagSafetyScoresNotFoundErrorResponseBody": ".safety_scores_get_tag_safety_scores_not_found_error_response_body",
    "SafetyScoresGetTagSafetyScoresNotImplementedErrorResponseBody": ".safety_scores_get_tag_safety_scores_not_implemented_error_response_body",
    "SafetyScoresGetTagSafetyScoresResponseBody": ".safety_scores_get_tag_safety_scores_response_body",
    "SafetyScoresGetTagSafetyScoresServiceUnavailableErrorResponseBody": ".safety_scores_get_tag_safety_scores_service_unavailable_error_response_body",
    "SafetyScoresGetTagSafetyScoresTooManyRequestsErrorResponseBody": ".safety_scores_get_tag_safety_scores_too_many_requests_error_response_body",
    "SafetyScoresGetTagSafetyScoresUnauthorizedErrorResponseBody": ".safety_scores_get_tag_safety_scores_unauthorized_error_response_body",
    "SafetyScoresGetVehicleSafetyScoreTripsBadGatewayErrorResponseBody": ".safety_scores_get_vehicle_safety_score_trips_bad_gateway_error_response_body",
    "SafetyScoresGetVehicleSafetyScoreTripsGatewayTimeoutErrorResponseBody": ".safety_scores_get_vehicle_safety_score_trips_gateway_timeout_error_response_body",
    "SafetyScoresGetVehicleSafetyScoreTripsInternalServerErrorResponseBody": ".safety_scores_get_vehicle_safety_score_trips_internal_server_error_response_body",
    "SafetyScoresGetVehicleSafetyScoreTripsMethodNotAllowedErrorResponseBody": ".safety_scores_get_vehicle_safety_score_trips_method_not_allowed_error_response_body",
    "SafetyScoresGetVehicleSafetyScoreTripsNotFoundErrorResponseBody": ".safety_scores_get_vehicle_safety_score_trips_not_found_error_response_body",
    "SafetyScoresGetVehicleSafetyScoreTripsNotImplementedErrorResponseBody": ".safety_scores_get_vehicle_safety_score_trips_not_implemented_error_response_body",
    "SafetyScoresGetVehicleSafetyScoreTripsResponseBody": ".safety_scores_get_vehicle_safety_score_trips_response_body",
    "SafetyScoresGetVehicleSafetyScoreTripsServiceUnavailableErrorResponseBody": ".safety_scores_get_vehicle_safety_score_trips_service_unavailable_error_response_body",
    "SafetyScoresGetVehicleSafetyScoreTripsTooManyRequestsErrorResponseBody": ".safety_scores_get_vehicle_safety_score_trips_too_many_requests_error_response_body",
    "SafetyScoresGetVehicleSafetyScoreTripsUnauthorizedErrorResponseBody": ".safety_scores_get_vehicle_safety_score_trips_unauthorized_error_response_body",
    "SafetyScoresGetVehicleSafetyScoresBadGatewayErrorResponseBody": ".safety_scores_get_vehicle_safety_scores_bad_gateway_error_response_body",
    "SafetyScoresGetVehicleSafetyScoresGatewayTimeoutErrorResponseBody": ".safety_scores_get_vehicle_safety_scores_gateway_timeout_error_response_body",
    "SafetyScoresGetVehicleSafetyScoresInternalServerErrorResponseBody": ".safety_scores_get_vehicle_safety_scores_internal_server_error_response_body",
    "SafetyScoresGetVehicleSafetyScoresMethodNotAllowedErrorResponseBody": ".safety_scores_get_vehicle_safety_scores_method_not_allowed_error_response_body",
    "SafetyScoresGetVehicleSafetyScoresNotFoundErrorResponseBody": ".safety_scores_get_vehicle_safety_scores_not_found_error_response_body",
    "SafetyScoresGetVehicleSafetyScoresNotImplementedErrorResponseBody": ".safety_scores_get_vehicle_safety_scores_not_implemented_error_response_body",
    "SafetyScoresGetVehicleSafetyScoresResponseBody": ".safety_scores_get_vehicle_safety_scores_response_body",
    "SafetyScoresGetVehicleSafetyScoresServiceUnavailableErrorResponseBody": ".safety_scores_get_vehicle_safety_scores_service_unavailable_error_response_body",
    "SafetyScoresGetVehicleSafetyScoresTooManyRequestsErrorResponseBody": ".safety_scores_get_vehicle_safety_scores_too_many_requests_error_response_body",
    "SafetyScoresGetVehicleSafetyScoresUnauthorizedErrorResponseBody": ".safety_scores_get_vehicle_safety_scores_unauthorized_error_response_body",
    "SafetySettingsGetSafetySettingsBadGatewayErrorResponseBody": ".safety_settings_get_safety_settings_bad_gateway_error_response_body",
    "SafetySettingsGetSafetySettingsGatewayTimeoutErrorResponseBody": ".safety_settings_get_safety_settings_gateway_timeout_error_response_body",
    "SafetySettingsGetSafetySettingsInternalServerErrorResponseBody": ".safety_settings_get_safety_settings_internal_server_error_response_body",
    "SafetySettingsGetSafetySettingsMethodNotAllowedErrorResponseBody": ".safety_settings_get_safety_settings_method_not_allowed_error_response_body",
    "SafetySettingsGetSafetySettingsNotFoundErrorResponseBody": ".safety_settings_get_safety_settings_not_found_error_response_body",
    "SafetySettingsGetSafetySettingsNotImplementedErrorResponseBody": ".safety_settings_get_safety_settings_not_implemented_error_response_body",
    "SafetySettingsGetSafetySettingsResponseBody": ".safety_settings_get_safety_settings_response_body",
    "SafetySettingsGetSafetySettingsServiceUnavailableErrorResponseBody": ".safety_settings_get_safety_settings_service_unavailable_error_response_body",
    "SafetySettingsGetSafetySettingsTooManyRequestsErrorResponseBody": ".safety_settings_get_safety_settings_too_many_requests_error_response_body",
    "SafetySettingsGetSafetySettingsUnauthorizedErrorResponseBody": ".safety_settings_get_safety_settings_unauthorized_error_response_body",
    "SafetySettingsObjectResponseBody": ".safety_settings_object_response_body",
    "SafetySettingsObjectResponseBodyDefaultVehicleType": ".safety_settings_object_response_body_default_vehicle_type",
    "ScannedDocumentValueObjectRequestBody": ".scanned_document_value_object_request_body",
    "ScannedDocumentValueObjectResponseBody": ".scanned_document_value_object_response_body",
    "ScheduledMaintenanceByEngineHoursDetailsObjectRequestBody": ".scheduled_maintenance_by_engine_hours_details_object_request_body",
    "ScheduledMaintenanceByEngineHoursDetailsObjectResponseBody": ".scheduled_maintenance_by_engine_hours_details_object_response_body",
    "ScheduledMaintenanceByEngineHoursResponseBody": ".scheduled_maintenance_by_engine_hours_response_body",
    "ScheduledMaintenanceDataResponseBody": ".scheduled_maintenance_data_response_body",
    "ScheduledMaintenanceOdometerDataResponseBody": ".scheduled_maintenance_odometer_data_response_body",
    "ScheduledMaintenanceOdometerTriggerDetailsObjectRequestBody": ".scheduled_maintenance_odometer_trigger_details_object_request_body",
    "ScheduledMaintenanceOdometerTriggerDetailsObjectResponseBody": ".scheduled_maintenance_odometer_trigger_details_object_response_body",
    "ScheduledMaintenanceTriggerDetailsObjectRequestBody": ".scheduled_maintenance_trigger_details_object_request_body",
    "ScheduledMaintenanceTriggerDetailsObjectResponseBody": ".scheduled_maintenance_trigger_details_object_response_body",
    "ScopeObjectRequestBody": ".scope_object_request_body",
    "ScopeObjectResponseBody": ".scope_object_response_body",
    "Sensor": ".sensor",
    "SensorResponseBody": ".sensor_response_body",
    "Serial": ".serial",
    "ServiceTaskDefinitionObjectResponseBody": ".service_task_definition_object_response_body",
    "ServiceTaskInstanceInputObjectRequestBody": ".service_task_instance_input_object_request_body",
    "ServiceTaskInstanceInputObjectRequestBodyStatus": ".service_task_instance_input_object_request_body_status",
    "ServiceTaskInstanceObjectResponseBody": ".service_task_instance_object_response_body",
    "ServiceTaskInstanceObjectResponseBodyStatus": ".service_task_instance_object_response_body_status",
    "ServiceWindowObjectResponseBody": ".service_window_object_response_body",
    "SettingsComplianceResponseObjectResponseBody": ".settings_compliance_response_object_response_body",
    "SettingsGetComplianceSettingsBadGatewayErrorResponseBody": ".settings_get_compliance_settings_bad_gateway_error_response_body",
    "SettingsGetComplianceSettingsGatewayTimeoutErrorResponseBody": ".settings_get_compliance_settings_gateway_timeout_error_response_body",
    "SettingsGetComplianceSettingsInternalServerErrorResponseBody": ".settings_get_compliance_settings_internal_server_error_response_body",
    "SettingsGetComplianceSettingsMethodNotAllowedErrorResponseBody": ".settings_get_compliance_settings_method_not_allowed_error_response_body",
    "SettingsGetComplianceSettingsNotFoundErrorResponseBody": ".settings_get_compliance_settings_not_found_error_response_body",
    "SettingsGetComplianceSettingsNotImplementedErrorResponseBody": ".settings_get_compliance_settings_not_implemented_error_response_body",
    "SettingsGetComplianceSettingsResponseBody": ".settings_get_compliance_settings_response_body",
    "SettingsGetComplianceSettingsServiceUnavailableErrorResponseBody": ".settings_get_compliance_settings_service_unavailable_error_response_body",
    "SettingsGetComplianceSettingsTooManyRequestsErrorResponseBody": ".settings_get_compliance_settings_too_many_requests_error_response_body",
    "SettingsGetComplianceSettingsUnauthorizedErrorResponseBody": ".settings_get_compliance_settings_unauthorized_error_response_body",
    "SettingsGetDriverAppSettingsBadGatewayErrorResponseBody": ".settings_get_driver_app_settings_bad_gateway_error_response_body",
    "SettingsGetDriverAppSettingsGatewayTimeoutErrorResponseBody": ".settings_get_driver_app_settings_gateway_timeout_error_response_body",
    "SettingsGetDriverAppSettingsInternalServerErrorResponseBody": ".settings_get_driver_app_settings_internal_server_error_response_body",
    "SettingsGetDriverAppSettingsMethodNotAllowedErrorResponseBody": ".settings_get_driver_app_settings_method_not_allowed_error_response_body",
    "SettingsGetDriverAppSettingsNotFoundErrorResponseBody": ".settings_get_driver_app_settings_not_found_error_response_body",
    "SettingsGetDriverAppSettingsNotImplementedErrorResponseBody": ".settings_get_driver_app_settings_not_implemented_error_response_body",
    "SettingsGetDriverAppSettingsResponseBody": ".settings_get_driver_app_settings_response_body",
    "SettingsGetDriverAppSettingsServiceUnavailableErrorResponseBody": ".settings_get_driver_app_settings_service_unavailable_error_response_body",
    "SettingsGetDriverAppSettingsTooManyRequestsErrorResponseBody": ".settings_get_driver_app_settings_too_many_requests_error_response_body",
    "SettingsGetDriverAppSettingsUnauthorizedErrorResponseBody": ".settings_get_driver_app_settings_unauthorized_error_response_body",
    "SettingsPatchComplianceSettingsBadGatewayErrorResponseBody": ".settings_patch_compliance_settings_bad_gateway_error_response_body",
    "SettingsPatchComplianceSettingsGatewayTimeoutErrorResponseBody": ".settings_patch_compliance_settings_gateway_timeout_error_response_body",
    "SettingsPatchComplianceSettingsInternalServerErrorResponseBody": ".settings_patch_compliance_settings_internal_server_error_response_body",
    "SettingsPatchComplianceSettingsMethodNotAllowedErrorResponseBody": ".settings_patch_compliance_settings_method_not_allowed_error_response_body",
    "SettingsPatchComplianceSettingsNotFoundErrorResponseBody": ".settings_patch_compliance_settings_not_found_error_response_body",
    "SettingsPatchComplianceSettingsNotImplementedErrorResponseBody": ".settings_patch_compliance_settings_not_implemented_error_response_body",
    "SettingsPatchComplianceSettingsResponseBody": ".settings_patch_compliance_settings_response_body",
    "SettingsPatchComplianceSettingsServiceUnavailableErrorResponseBody": ".settings_patch_compliance_settings_service_unavailable_error_response_body",
    "SettingsPatchComplianceSettingsTooManyRequestsErrorResponseBody": ".settings_patch_compliance_settings_too_many_requests_error_response_body",
    "SettingsPatchComplianceSettingsUnauthorizedErrorResponseBody": ".settings_patch_compliance_settings_unauthorized_error_response_body",
    "SettingsPatchDriverAppSettingsBadGatewayErrorResponseBody": ".settings_patch_driver_app_settings_bad_gateway_error_response_body",
    "SettingsPatchDriverAppSettingsGatewayTimeoutErrorResponseBody": ".settings_patch_driver_app_settings_gateway_timeout_error_response_body",
    "SettingsPatchDriverAppSettingsInternalServerErrorResponseBody": ".settings_patch_driver_app_settings_internal_server_error_response_body",
    "SettingsPatchDriverAppSettingsMethodNotAllowedErrorResponseBody": ".settings_patch_driver_app_settings_method_not_allowed_error_response_body",
    "SettingsPatchDriverAppSettingsNotFoundErrorResponseBody": ".settings_patch_driver_app_settings_not_found_error_response_body",
    "SettingsPatchDriverAppSettingsNotImplementedErrorResponseBody": ".settings_patch_driver_app_settings_not_implemented_error_response_body",
    "SettingsPatchDriverAppSettingsResponseBody": ".settings_patch_driver_app_settings_response_body",
    "SettingsPatchDriverAppSettingsServiceUnavailableErrorResponseBody": ".settings_patch_driver_app_settings_service_unavailable_error_response_body",
    "SettingsPatchDriverAppSettingsTooManyRequestsErrorResponseBody": ".settings_patch_driver_app_settings_too_many_requests_error_response_body",
    "SettingsPatchDriverAppSettingsUnauthorizedErrorResponseBody": ".settings_patch_driver_app_settings_unauthorized_error_response_body",
    "SettingsResponseBody": ".settings_response_body",
    "SevereSpeedingStartedObjectResponseBody": ".severe_speeding_started_object_response_body",
    "SevereSpeedingStartedResponseObjectResponseBody": ".severe_speeding_started_response_object_response_body",
    "SignatoryUserObjectResponseBody": ".signatory_user_object_response_body",
    "SignatureFieldTypeMetaDataObjectResponseBody": ".signature_field_type_meta_data_object_response_body",
    "SignatureValueObjectRequestBody": ".signature_value_object_request_body",
    "SignatureValueObjectResponseBody": ".signature_value_object_response_body",
    "SingleApprovalRequirementsObjectResponseBody": ".single_approval_requirements_object_response_body",
    "SingleDriverEfficiencyByDriverDataObjectResponseBody": ".single_driver_efficiency_by_driver_data_object_response_body",
    "SingleDriverEfficiencyByVehicleDataObjectResponseBody": ".single_driver_efficiency_by_vehicle_data_object_response_body",
    "SingleUseLocationObjectResponseBody": ".single_use_location_object_response_body",
    "SiteGatewayDisconnectedResponseBody": ".site_gateway_disconnected_response_body",
    "SkillObjectResponseBody": ".skill_object_response_body",
    "SpecificVehicleFaultCodeObjectRequestBody": ".specific_vehicle_fault_code_object_request_body",
    "SpecificVehicleFaultCodeObjectRequestBodyType": ".specific_vehicle_fault_code_object_request_body_type",
    "SpecificVehicleFaultCodeObjectResponseBody": ".specific_vehicle_fault_code_object_response_body",
    "SpecificVehicleFaultCodeObjectResponseBodyType": ".specific_vehicle_fault_code_object_response_body_type",
    "SpeedDataResponseBody": ".speed_data_response_body",
    "SpeedDataResponseBodyOperation": ".speed_data_response_body_operation",
    "SpeedResponseResponseBody": ".speed_response_response_body",
    "SpeedTriggerDetailsObjectRequestBody": ".speed_trigger_details_object_request_body",
    "SpeedTriggerDetailsObjectRequestBodyOperation": ".speed_trigger_details_object_request_body_operation",
    "SpeedTriggerDetailsObjectResponseBody": ".speed_trigger_details_object_response_body",
    "SpeedTriggerDetailsObjectResponseBodyOperation": ".speed_trigger_details_object_response_body_operation",
    "SpeedingIntervalLocationResponseResponseBody": ".speeding_interval_location_response_response_body",
    "SpeedingIntervalResponseBody": ".speeding_interval_response_body",
    "SpeedingIntervalResponseBodySeverityLevel": ".speeding_interval_response_body_severity_level",
    "SpeedingIntervalsGetSpeedingIntervalsBadGatewayErrorResponseBody": ".speeding_intervals_get_speeding_intervals_bad_gateway_error_response_body",
    "SpeedingIntervalsGetSpeedingIntervalsGatewayTimeoutErrorResponseBody": ".speeding_intervals_get_speeding_intervals_gateway_timeout_error_response_body",
    "SpeedingIntervalsGetSpeedingIntervalsInternalServerErrorResponseBody": ".speeding_intervals_get_speeding_intervals_internal_server_error_response_body",
    "SpeedingIntervalsGetSpeedingIntervalsMethodNotAllowedErrorResponseBody": ".speeding_intervals_get_speeding_intervals_method_not_allowed_error_response_body",
    "SpeedingIntervalsGetSpeedingIntervalsNotFoundErrorResponseBody": ".speeding_intervals_get_speeding_intervals_not_found_error_response_body",
    "SpeedingIntervalsGetSpeedingIntervalsNotImplementedErrorResponseBody": ".speeding_intervals_get_speeding_intervals_not_implemented_error_response_body",
    "SpeedingIntervalsGetSpeedingIntervalsResponseBody": ".speeding_intervals_get_speeding_intervals_response_body",
    "SpeedingIntervalsGetSpeedingIntervalsServiceUnavailableErrorResponseBody": ".speeding_intervals_get_speeding_intervals_service_unavailable_error_response_body",
    "SpeedingIntervalsGetSpeedingIntervalsTooManyRequestsErrorResponseBody": ".speeding_intervals_get_speeding_intervals_too_many_requests_error_response_body",
    "SpeedingIntervalsGetSpeedingIntervalsUnauthorizedErrorResponseBody": ".speeding_intervals_get_speeding_intervals_unauthorized_error_response_body",
    "SpeedingSettingsObjectResponseBody": ".speeding_settings_object_response_body",
    "SpeedingSettingsObjectResponseBodyUnit": ".speeding_settings_object_response_body_unit",
    "SpeedingSeverityLevelResponseBody": ".speeding_severity_level_response_body",
    "SpeedingSeverityLevelResponseBodySeverityLevel": ".speeding_severity_level_response_body_severity_level",
    "StartFunctionRunResponseBodyResponseBody": ".start_function_run_response_body_response_body",
    "StopEtaUpdatedEventDetailsResponseBody": ".stop_eta_updated_event_details_response_body",
    "StopTaskCompletedEventDetailsResponseBody": ".stop_task_completed_event_details_response_body",
    "StopTaskCompletedEventDetailsResponseBodyTaskType": ".stop_task_completed_event_details_response_body_task_type",
    "StopTaskSkippedEventDetailsResponseBody": ".stop_task_skipped_event_details_response_body",
    "StopTaskSkippedEventDetailsResponseBodyTaskType": ".stop_task_skipped_event_details_response_body_task_type",
    "StringDataPoint": ".string_data_point",
    "SuddenFuelLevelDropResponseBody": ".sudden_fuel_level_drop_response_body",
    "SuddenFuelLevelDropTriggerDetailsObjectRequestBody": ".sudden_fuel_level_drop_trigger_details_object_request_body",
    "SuddenFuelLevelDropTriggerDetailsObjectResponseBody": ".sudden_fuel_level_drop_trigger_details_object_response_body",
    "SuddenFuelLevelRiseResponseBody": ".sudden_fuel_level_rise_response_body",
    "SuddenFuelLevelRiseTriggerDetailsObjectRequestBody": ".sudden_fuel_level_rise_trigger_details_object_request_body",
    "SuddenFuelLevelRiseTriggerDetailsObjectResponseBody": ".sudden_fuel_level_rise_trigger_details_object_response_body",
    "TachographActivity": ".tachograph_activity",
    "TachographActivityList": ".tachograph_activity_list",
    "TachographActivityListWrapper": ".tachograph_activity_list_wrapper",
    "TachographActivityState": ".tachograph_activity_state",
    "TachographDriverFile": ".tachograph_driver_file",
    "TachographDriverFileData": ".tachograph_driver_file_data",
    "TachographDriverFileList": ".tachograph_driver_file_list",
    "TachographDriverFileListWrapper": ".tachograph_driver_file_list_wrapper",
    "TachographDriverFilesResponse": ".tachograph_driver_files_response",
    "TachographVehicleFile": ".tachograph_vehicle_file",
    "TachographVehicleFileData": ".tachograph_vehicle_file_data",
    "TachographVehicleFileList": ".tachograph_vehicle_file_list",
    "TachographVehicleFileListWrapper": ".tachograph_vehicle_file_list_wrapper",
    "TachographVehicleFilesResponse": ".tachograph_vehicle_files_response",
    "Tag": ".tag",
    "TagAllOf": ".tag_all_of",
    "TagAllOfExternalIds": ".tag_all_of_external_ids",
    "TagGroupSafetyScoreResponseBody": ".tag_group_safety_score_response_body",
    "TagId": ".tag_id",
    "TagIds": ".tag_ids",
    "TagName": ".tag_name",
    "TagResponse": ".tag_response",
    "TagSafetyScoreResponseBody": ".tag_safety_score_response_body",
    "TagTinyResponse": ".tag_tiny_response",
    "TaggedObject": ".tagged_object",
    "TaggedObjectId": ".tagged_object_id",
    "TaggedObjectName": ".tagged_object_name",
    "TamperingDetectedResponseBody": ".tampering_detected_response_body",
    "Time": ".time",
    "TimeRangeObjectRequestBody": ".time_range_object_request_body",
    "TimeRangeObjectRequestBodyDaysOfWeekItem": ".time_range_object_request_body_days_of_week_item",
    "TimeRangeObjectResponseBody": ".time_range_object_response_body",
    "TimeRangeObjectResponseBodyDaysOfWeekItem": ".time_range_object_response_body_days_of_week_item",
    "TinyAssetObjectRequestBody": ".tiny_asset_object_request_body",
    "TinyAssetObjectRequestBodyAssetType": ".tiny_asset_object_request_body_asset_type",
    "TinyAssetObjectResponseBody": ".tiny_asset_object_response_body",
    "TinyAssetObjectResponseBodyAssetType": ".tiny_asset_object_response_body_asset_type",
    "TinyDriverObjectRequestBody": ".tiny_driver_object_request_body",
    "TinyDriverObjectResponseBody": ".tiny_driver_object_response_body",
    "TinyTag": ".tiny_tag",
    "TinyWidgetObjectRequestBody": ".tiny_widget_object_request_body",
    "TinyWidgetObjectResponseBody": ".tiny_widget_object_response_body",
    "TireFaultCodeDetailsObjectRequestBody": ".tire_fault_code_details_object_request_body",
    "TireFaultCodeDetailsObjectRequestBodyManufacturer": ".tire_fault_code_details_object_request_body_manufacturer",
    "TireFaultCodeDetailsObjectRequestBodySpecificTireFaultCodesItem": ".tire_fault_code_details_object_request_body_specific_tire_fault_codes_item",
    "TireFaultCodeDetailsObjectResponseBody": ".tire_fault_code_details_object_response_body",
    "TireFaultCodeDetailsObjectResponseBodyManufacturer": ".tire_fault_code_details_object_response_body_manufacturer",
    "TireFaultCodeDetailsObjectResponseBodySpecificTireFaultCodesItem": ".tire_fault_code_details_object_response_body_specific_tire_fault_codes_item",
    "TireFaultsResponseBody": ".tire_faults_response_body",
    "TotalBrakeEventCount": ".total_brake_event_count",
    "TrailerAssignmentsCreateDriverTrailerAssignmentBadGatewayErrorResponseBody": ".trailer_assignments_create_driver_trailer_assignment_bad_gateway_error_response_body",
    "TrailerAssignmentsCreateDriverTrailerAssignmentGatewayTimeoutErrorResponseBody": ".trailer_assignments_create_driver_trailer_assignment_gateway_timeout_error_response_body",
    "TrailerAssignmentsCreateDriverTrailerAssignmentInternalServerErrorResponseBody": ".trailer_assignments_create_driver_trailer_assignment_internal_server_error_response_body",
    "TrailerAssignmentsCreateDriverTrailerAssignmentMethodNotAllowedErrorResponseBody": ".trailer_assignments_create_driver_trailer_assignment_method_not_allowed_error_response_body",
    "TrailerAssignmentsCreateDriverTrailerAssignmentNotFoundErrorResponseBody": ".trailer_assignments_create_driver_trailer_assignment_not_found_error_response_body",
    "TrailerAssignmentsCreateDriverTrailerAssignmentNotImplementedErrorResponseBody": ".trailer_assignments_create_driver_trailer_assignment_not_implemented_error_response_body",
    "TrailerAssignmentsCreateDriverTrailerAssignmentResponseBody": ".trailer_assignments_create_driver_trailer_assignment_response_body",
    "TrailerAssignmentsCreateDriverTrailerAssignmentServiceUnavailableErrorResponseBody": ".trailer_assignments_create_driver_trailer_assignment_service_unavailable_error_response_body",
    "TrailerAssignmentsCreateDriverTrailerAssignmentTooManyRequestsErrorResponseBody": ".trailer_assignments_create_driver_trailer_assignment_too_many_requests_error_response_body",
    "TrailerAssignmentsCreateDriverTrailerAssignmentUnauthorizedErrorResponseBody": ".trailer_assignments_create_driver_trailer_assignment_unauthorized_error_response_body",
    "TrailerAssignmentsGetDriverTrailerAssignmentsBadGatewayErrorResponseBody": ".trailer_assignments_get_driver_trailer_assignments_bad_gateway_error_response_body",
    "TrailerAssignmentsGetDriverTrailerAssignmentsGatewayTimeoutErrorResponseBody": ".trailer_assignments_get_driver_trailer_assignments_gateway_timeout_error_response_body",
    "TrailerAssignmentsGetDriverTrailerAssignmentsInternalServerErrorResponseBody": ".trailer_assignments_get_driver_trailer_assignments_internal_server_error_response_body",
    "TrailerAssignmentsGetDriverTrailerAssignmentsMethodNotAllowedErrorResponseBody": ".trailer_assignments_get_driver_trailer_assignments_method_not_allowed_error_response_body",
    "TrailerAssignmentsGetDriverTrailerAssignmentsNotFoundErrorResponseBody": ".trailer_assignments_get_driver_trailer_assignments_not_found_error_response_body",
    "TrailerAssignmentsGetDriverTrailerAssignmentsNotImplementedErrorResponseBody": ".trailer_assignments_get_driver_trailer_assignments_not_implemented_error_response_body",
    "TrailerAssignmentsGetDriverTrailerAssignmentsResponseBody": ".trailer_assignments_get_driver_trailer_assignments_response_body",
    "TrailerAssignmentsGetDriverTrailerAssignmentsServiceUnavailableErrorResponseBody": ".trailer_assignments_get_driver_trailer_assignments_service_unavailable_error_response_body",
    "TrailerAssignmentsGetDriverTrailerAssignmentsTooManyRequestsErrorResponseBody": ".trailer_assignments_get_driver_trailer_assignments_too_many_requests_error_response_body",
    "TrailerAssignmentsGetDriverTrailerAssignmentsUnauthorizedErrorResponseBody": ".trailer_assignments_get_driver_trailer_assignments_unauthorized_error_response_body",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentBadGatewayErrorResponseBody": ".trailer_assignments_update_driver_trailer_assignment_bad_gateway_error_response_body",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentGatewayTimeoutErrorResponseBody": ".trailer_assignments_update_driver_trailer_assignment_gateway_timeout_error_response_body",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentInternalServerErrorResponseBody": ".trailer_assignments_update_driver_trailer_assignment_internal_server_error_response_body",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentMethodNotAllowedErrorResponseBody": ".trailer_assignments_update_driver_trailer_assignment_method_not_allowed_error_response_body",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentNotFoundErrorResponseBody": ".trailer_assignments_update_driver_trailer_assignment_not_found_error_response_body",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentNotImplementedErrorResponseBody": ".trailer_assignments_update_driver_trailer_assignment_not_implemented_error_response_body",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentResponseBody": ".trailer_assignments_update_driver_trailer_assignment_response_body",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentServiceUnavailableErrorResponseBody": ".trailer_assignments_update_driver_trailer_assignment_service_unavailable_error_response_body",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentTooManyRequestsErrorResponseBody": ".trailer_assignments_update_driver_trailer_assignment_too_many_requests_error_response_body",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentUnauthorizedErrorResponseBody": ".trailer_assignments_update_driver_trailer_assignment_unauthorized_error_response_body",
    "TrailerDvirObjectResponseBody": ".trailer_dvir_object_response_body",
    "TrailerGoaGatewayTinyResponseResponseBody": ".trailer_goa_gateway_tiny_response_response_body",
    "TrailerGoaGatewayTinyResponseResponseBodyModel": ".trailer_goa_gateway_tiny_response_response_body_model",
    "TrailerObjectResponseBody": ".trailer_object_response_body",
    "TrailerResponseObjectResponseBody": ".trailer_response_object_response_body",
    "TrailerStatDecorationResponseBody": ".trailer_stat_decoration_response_body",
    "TrailerStatGpsOdometerMetersTypeResponseBody": ".trailer_stat_gps_odometer_meters_type_response_body",
    "TrailerStatGpsOdometerMetersWithDecorationsTypeResponseBody": ".trailer_stat_gps_odometer_meters_with_decorations_type_response_body",
    "TrailerStatGpsTypeResponseBody": ".trailer_stat_gps_type_response_body",
    "TrailerStatGpsWithDecorationsTypeResponseBody": ".trailer_stat_gps_with_decorations_type_response_body",
    "TrailerStatReeferAlarmResponseBody": ".trailer_stat_reefer_alarm_response_body",
    "TrailerStatReeferAlarmTypeResponseBody": ".trailer_stat_reefer_alarm_type_response_body",
    "TrailerStatReeferAlarmWithDecorationsTypeResponseBody": ".trailer_stat_reefer_alarm_with_decorations_type_response_body",
    "TrailerStatReeferAmbientAirTemperatureMilliCTypeResponseBody": ".trailer_stat_reefer_ambient_air_temperature_milli_c_type_response_body",
    "TrailerStatReeferAmbientAirTemperatureWithDecorationsTypeResponseBody": ".trailer_stat_reefer_ambient_air_temperature_with_decorations_type_response_body",
    "TrailerStatReeferDoorStateZone1TypeResponseBody": ".trailer_stat_reefer_door_state_zone_1_type_response_body",
    "TrailerStatReeferDoorStateZone1TypeResponseBodyValue": ".trailer_stat_reefer_door_state_zone_1_type_response_body_value",
    "TrailerStatReeferDoorStateZone1WithDecorationsTypeResponseBody": ".trailer_stat_reefer_door_state_zone_1_with_decorations_type_response_body",
    "TrailerStatReeferDoorStateZone1WithDecorationsTypeResponseBodyValue": ".trailer_stat_reefer_door_state_zone_1_with_decorations_type_response_body_value",
    "TrailerStatReeferDoorStateZone2TypeResponseBody": ".trailer_stat_reefer_door_state_zone_2_type_response_body",
    "TrailerStatReeferDoorStateZone2TypeResponseBodyValue": ".trailer_stat_reefer_door_state_zone_2_type_response_body_value",
    "TrailerStatReeferDoorStateZone2WithDecorationsTypeResponseBody": ".trailer_stat_reefer_door_state_zone_2_with_decorations_type_response_body",
    "TrailerStatReeferDoorStateZone2WithDecorationsTypeResponseBodyValue": ".trailer_stat_reefer_door_state_zone_2_with_decorations_type_response_body_value",
    "TrailerStatReeferDoorStateZone3TypeResponseBody": ".trailer_stat_reefer_door_state_zone_3_type_response_body",
    "TrailerStatReeferDoorStateZone3TypeResponseBodyValue": ".trailer_stat_reefer_door_state_zone_3_type_response_body_value",
    "TrailerStatReeferDoorStateZone3WithDecorationsTypeResponseBody": ".trailer_stat_reefer_door_state_zone_3_with_decorations_type_response_body",
    "TrailerStatReeferDoorStateZone3WithDecorationsTypeResponseBodyValue": ".trailer_stat_reefer_door_state_zone_3_with_decorations_type_response_body_value",
    "TrailerStatReeferFuelPercentTypeResponseBody": ".trailer_stat_reefer_fuel_percent_type_response_body",
    "TrailerStatReeferFuelPercentWithDecorationsTypeResponseBody": ".trailer_stat_reefer_fuel_percent_with_decorations_type_response_body",
    "TrailerStatReeferObdEngineSecondsTypeResponseBody": ".trailer_stat_reefer_obd_engine_seconds_type_response_body",
    "TrailerStatReeferObdEngineSecondsWithDecorationsTypeResponseBody": ".trailer_stat_reefer_obd_engine_seconds_with_decorations_type_response_body",
    "TrailerStatReeferReturnAirTemperatureMilliCZone1TypeResponseBody": ".trailer_stat_reefer_return_air_temperature_milli_c_zone_1_type_response_body",
    "TrailerStatReeferReturnAirTemperatureMilliCZone1WithDecorationsTypeResponseBody": ".trailer_stat_reefer_return_air_temperature_milli_c_zone_1_with_decorations_type_response_body",
    "TrailerStatReeferReturnAirTemperatureMilliCZone2TypeResponseBody": ".trailer_stat_reefer_return_air_temperature_milli_c_zone_2_type_response_body",
    "TrailerStatReeferReturnAirTemperatureMilliCZone2WithDecorationsTypeResponseBody": ".trailer_stat_reefer_return_air_temperature_milli_c_zone_2_with_decorations_type_response_body",
    "TrailerStatReeferReturnAirTemperatureMilliCZone3TypeResponseBody": ".trailer_stat_reefer_return_air_temperature_milli_c_zone_3_type_response_body",
    "TrailerStatReeferReturnAirTemperatureMilliCZone3WithDecorationsTypeResponseBody": ".trailer_stat_reefer_return_air_temperature_milli_c_zone_3_with_decorations_type_response_body",
    "TrailerStatReeferRunModeTypeResponseBody": ".trailer_stat_reefer_run_mode_type_response_body",
    "TrailerStatReeferRunModeWithDecorationsTypeResponseBody": ".trailer_stat_reefer_run_mode_with_decorations_type_response_body",
    "TrailerStatReeferSetPointTemperatureMilliCZone1TypeResponseBody": ".trailer_stat_reefer_set_point_temperature_milli_c_zone_1_type_response_body",
    "TrailerStatReeferSetPointTemperatureMilliCZone1WithDecorationsTypeResponseBody": ".trailer_stat_reefer_set_point_temperature_milli_c_zone_1_with_decorations_type_response_body",
    "TrailerStatReeferSetPointTemperatureMilliCZone2TypeResponseBody": ".trailer_stat_reefer_set_point_temperature_milli_c_zone_2_type_response_body",
    "TrailerStatReeferSetPointTemperatureMilliCZone2WithDecorationsTypeResponseBody": ".trailer_stat_reefer_set_point_temperature_milli_c_zone_2_with_decorations_type_response_body",
    "TrailerStatReeferSetPointTemperatureMilliCZone3TypeResponseBody": ".trailer_stat_reefer_set_point_temperature_milli_c_zone_3_type_response_body",
    "TrailerStatReeferSetPointTemperatureMilliCZone3WithDecorationsTypeResponseBody": ".trailer_stat_reefer_set_point_temperature_milli_c_zone_3_with_decorations_type_response_body",
    "TrailerStatReeferStateTypeResponseBody": ".trailer_stat_reefer_state_type_response_body",
    "TrailerStatReeferStateWithDecorationsTypeResponseBody": ".trailer_stat_reefer_state_with_decorations_type_response_body",
    "TrailerStatReeferStateZone1TypeResponseBody": ".trailer_stat_reefer_state_zone_1_type_response_body",
    "TrailerStatReeferStateZone1WithDecorationsTypeResponseBody": ".trailer_stat_reefer_state_zone_1_with_decorations_type_response_body",
    "TrailerStatReeferStateZone2TypeResponseBody": ".trailer_stat_reefer_state_zone_2_type_response_body",
    "TrailerStatReeferStateZone2WithDecorationsTypeResponseBody": ".trailer_stat_reefer_state_zone_2_with_decorations_type_response_body",
    "TrailerStatReeferStateZone3TypeResponseBody": ".trailer_stat_reefer_state_zone_3_type_response_body",
    "TrailerStatReeferStateZone3WithDecorationsTypeResponseBody": ".trailer_stat_reefer_state_zone_3_with_decorations_type_response_body",
    "TrailerStatReeferSupplyAirTemperatureMilliCZone1TypeResponseBody": ".trailer_stat_reefer_supply_air_temperature_milli_c_zone_1_type_response_body",
    "TrailerStatReeferSupplyAirTemperatureMilliCZone1WithDecorationsTypeResponseBody": ".trailer_stat_reefer_supply_air_temperature_milli_c_zone_1_with_decorations_type_response_body",
    "TrailerStatReeferSupplyAirTemperatureMilliCZone2TypeResponseBody": ".trailer_stat_reefer_supply_air_temperature_milli_c_zone_2_type_response_body",
    "TrailerStatReeferSupplyAirTemperatureMilliCZone2WithDecorationsTypeResponseBody": ".trailer_stat_reefer_supply_air_temperature_milli_c_zone_2_with_decorations_type_response_body",
    "TrailerStatReeferSupplyAirTemperatureMilliCZone3TypeResponseBody": ".trailer_stat_reefer_supply_air_temperature_milli_c_zone_3_type_response_body",
    "TrailerStatReeferSupplyAirTemperatureMilliCZone3WithDecorationsTypeResponseBody": ".trailer_stat_reefer_supply_air_temperature_milli_c_zone_3_with_decorations_type_response_body",
    "TrailerStatsGetTrailerStatsFeedBadGatewayErrorResponseBody": ".trailer_stats_get_trailer_stats_feed_bad_gateway_error_response_body",
    "TrailerStatsGetTrailerStatsFeedGatewayTimeoutErrorResponseBody": ".trailer_stats_get_trailer_stats_feed_gateway_timeout_error_response_body",
    "TrailerStatsGetTrailerStatsFeedInternalServerErrorResponseBody": ".trailer_stats_get_trailer_stats_feed_internal_server_error_response_body",
    "TrailerStatsGetTrailerStatsFeedMethodNotAllowedErrorResponseBody": ".trailer_stats_get_trailer_stats_feed_method_not_allowed_error_response_body",
    "TrailerStatsGetTrailerStatsFeedNotFoundErrorResponseBody": ".trailer_stats_get_trailer_stats_feed_not_found_error_response_body",
    "TrailerStatsGetTrailerStatsFeedNotImplementedErrorResponseBody": ".trailer_stats_get_trailer_stats_feed_not_implemented_error_response_body",
    "TrailerStatsGetTrailerStatsFeedResponseBody": ".trailer_stats_get_trailer_stats_feed_response_body",
    "TrailerStatsGetTrailerStatsFeedServiceUnavailableErrorResponseBody": ".trailer_stats_get_trailer_stats_feed_service_unavailable_error_response_body",
    "TrailerStatsGetTrailerStatsFeedTooManyRequestsErrorResponseBody": ".trailer_stats_get_trailer_stats_feed_too_many_requests_error_response_body",
    "TrailerStatsGetTrailerStatsFeedUnauthorizedErrorResponseBody": ".trailer_stats_get_trailer_stats_feed_unauthorized_error_response_body",
    "TrailerStatsGetTrailerStatsHistoryBadGatewayErrorResponseBody": ".trailer_stats_get_trailer_stats_history_bad_gateway_error_response_body",
    "TrailerStatsGetTrailerStatsHistoryGatewayTimeoutErrorResponseBody": ".trailer_stats_get_trailer_stats_history_gateway_timeout_error_response_body",
    "TrailerStatsGetTrailerStatsHistoryInternalServerErrorResponseBody": ".trailer_stats_get_trailer_stats_history_internal_server_error_response_body",
    "TrailerStatsGetTrailerStatsHistoryMethodNotAllowedErrorResponseBody": ".trailer_stats_get_trailer_stats_history_method_not_allowed_error_response_body",
    "TrailerStatsGetTrailerStatsHistoryNotFoundErrorResponseBody": ".trailer_stats_get_trailer_stats_history_not_found_error_response_body",
    "TrailerStatsGetTrailerStatsHistoryNotImplementedErrorResponseBody": ".trailer_stats_get_trailer_stats_history_not_implemented_error_response_body",
    "TrailerStatsGetTrailerStatsHistoryResponseBody": ".trailer_stats_get_trailer_stats_history_response_body",
    "TrailerStatsGetTrailerStatsHistoryServiceUnavailableErrorResponseBody": ".trailer_stats_get_trailer_stats_history_service_unavailable_error_response_body",
    "TrailerStatsGetTrailerStatsHistoryTooManyRequestsErrorResponseBody": ".trailer_stats_get_trailer_stats_history_too_many_requests_error_response_body",
    "TrailerStatsGetTrailerStatsHistoryUnauthorizedErrorResponseBody": ".trailer_stats_get_trailer_stats_history_unauthorized_error_response_body",
    "TrailerStatsGetTrailerStatsSnapshotBadGatewayErrorResponseBody": ".trailer_stats_get_trailer_stats_snapshot_bad_gateway_error_response_body",
    "TrailerStatsGetTrailerStatsSnapshotGatewayTimeoutErrorResponseBody": ".trailer_stats_get_trailer_stats_snapshot_gateway_timeout_error_response_body",
    "TrailerStatsGetTrailerStatsSnapshotInternalServerErrorResponseBody": ".trailer_stats_get_trailer_stats_snapshot_internal_server_error_response_body",
    "TrailerStatsGetTrailerStatsSnapshotMethodNotAllowedErrorResponseBody": ".trailer_stats_get_trailer_stats_snapshot_method_not_allowed_error_response_body",
    "TrailerStatsGetTrailerStatsSnapshotNotFoundErrorResponseBody": ".trailer_stats_get_trailer_stats_snapshot_not_found_error_response_body",
    "TrailerStatsGetTrailerStatsSnapshotNotImplementedErrorResponseBody": ".trailer_stats_get_trailer_stats_snapshot_not_implemented_error_response_body",
    "TrailerStatsGetTrailerStatsSnapshotResponseBody": ".trailer_stats_get_trailer_stats_snapshot_response_body",
    "TrailerStatsGetTrailerStatsSnapshotServiceUnavailableErrorResponseBody": ".trailer_stats_get_trailer_stats_snapshot_service_unavailable_error_response_body",
    "TrailerStatsGetTrailerStatsSnapshotTooManyRequestsErrorResponseBody": ".trailer_stats_get_trailer_stats_snapshot_too_many_requests_error_response_body",
    "TrailerStatsGetTrailerStatsSnapshotUnauthorizedErrorResponseBody": ".trailer_stats_get_trailer_stats_snapshot_unauthorized_error_response_body",
    "TrailerStatsObjectResponseBody": ".trailer_stats_object_response_body",
    "TrailerStatsSnapshotObjectResponseBody": ".trailer_stats_snapshot_object_response_body",
    "TrailerTinyResponse": ".trailer_tiny_response",
    "TrailerWithAttributesResponseObjectResponseBody": ".trailer_with_attributes_response_object_response_body",
    "TrailersCreateTrailerBadGatewayErrorResponseBody": ".trailers_create_trailer_bad_gateway_error_response_body",
    "TrailersCreateTrailerGatewayTimeoutErrorResponseBody": ".trailers_create_trailer_gateway_timeout_error_response_body",
    "TrailersCreateTrailerInternalServerErrorResponseBody": ".trailers_create_trailer_internal_server_error_response_body",
    "TrailersCreateTrailerMethodNotAllowedErrorResponseBody": ".trailers_create_trailer_method_not_allowed_error_response_body",
    "TrailersCreateTrailerNotFoundErrorResponseBody": ".trailers_create_trailer_not_found_error_response_body",
    "TrailersCreateTrailerNotImplementedErrorResponseBody": ".trailers_create_trailer_not_implemented_error_response_body",
    "TrailersCreateTrailerResponseBody": ".trailers_create_trailer_response_body",
    "TrailersCreateTrailerServiceUnavailableErrorResponseBody": ".trailers_create_trailer_service_unavailable_error_response_body",
    "TrailersCreateTrailerTooManyRequestsErrorResponseBody": ".trailers_create_trailer_too_many_requests_error_response_body",
    "TrailersCreateTrailerUnauthorizedErrorResponseBody": ".trailers_create_trailer_unauthorized_error_response_body",
    "TrailersDeleteTrailerBadGatewayErrorResponseBody": ".trailers_delete_trailer_bad_gateway_error_response_body",
    "TrailersDeleteTrailerGatewayTimeoutErrorResponseBody": ".trailers_delete_trailer_gateway_timeout_error_response_body",
    "TrailersDeleteTrailerInternalServerErrorResponseBody": ".trailers_delete_trailer_internal_server_error_response_body",
    "TrailersDeleteTrailerMethodNotAllowedErrorResponseBody": ".trailers_delete_trailer_method_not_allowed_error_response_body",
    "TrailersDeleteTrailerNotFoundErrorResponseBody": ".trailers_delete_trailer_not_found_error_response_body",
    "TrailersDeleteTrailerNotImplementedErrorResponseBody": ".trailers_delete_trailer_not_implemented_error_response_body",
    "TrailersDeleteTrailerServiceUnavailableErrorResponseBody": ".trailers_delete_trailer_service_unavailable_error_response_body",
    "TrailersDeleteTrailerTooManyRequestsErrorResponseBody": ".trailers_delete_trailer_too_many_requests_error_response_body",
    "TrailersDeleteTrailerUnauthorizedErrorResponseBody": ".trailers_delete_trailer_unauthorized_error_response_body",
    "TrailersGetTrailerBadGatewayErrorResponseBody": ".trailers_get_trailer_bad_gateway_error_response_body",
    "TrailersGetTrailerGatewayTimeoutErrorResponseBody": ".trailers_get_trailer_gateway_timeout_error_response_body",
    "TrailersGetTrailerInternalServerErrorResponseBody": ".trailers_get_trailer_internal_server_error_response_body",
    "TrailersGetTrailerMethodNotAllowedErrorResponseBody": ".trailers_get_trailer_method_not_allowed_error_response_body",
    "TrailersGetTrailerNotFoundErrorResponseBody": ".trailers_get_trailer_not_found_error_response_body",
    "TrailersGetTrailerNotImplementedErrorResponseBody": ".trailers_get_trailer_not_implemented_error_response_body",
    "TrailersGetTrailerResponseBody": ".trailers_get_trailer_response_body",
    "TrailersGetTrailerServiceUnavailableErrorResponseBody": ".trailers_get_trailer_service_unavailable_error_response_body",
    "TrailersGetTrailerTooManyRequestsErrorResponseBody": ".trailers_get_trailer_too_many_requests_error_response_body",
    "TrailersGetTrailerUnauthorizedErrorResponseBody": ".trailers_get_trailer_unauthorized_error_response_body",
    "TrailersListTrailersBadGatewayErrorResponseBody": ".trailers_list_trailers_bad_gateway_error_response_body",
    "TrailersListTrailersGatewayTimeoutErrorResponseBody": ".trailers_list_trailers_gateway_timeout_error_response_body",
    "TrailersListTrailersInternalServerErrorResponseBody": ".trailers_list_trailers_internal_server_error_response_body",
    "TrailersListTrailersMethodNotAllowedErrorResponseBody": ".trailers_list_trailers_method_not_allowed_error_response_body",
    "TrailersListTrailersNotFoundErrorResponseBody": ".trailers_list_trailers_not_found_error_response_body",
    "TrailersListTrailersNotImplementedErrorResponseBody": ".trailers_list_trailers_not_implemented_error_response_body",
    "TrailersListTrailersResponseBody": ".trailers_list_trailers_response_body",
    "TrailersListTrailersServiceUnavailableErrorResponseBody": ".trailers_list_trailers_service_unavailable_error_response_body",
    "TrailersListTrailersTooManyRequestsErrorResponseBody": ".trailers_list_trailers_too_many_requests_error_response_body",
    "TrailersListTrailersUnauthorizedErrorResponseBody": ".trailers_list_trailers_unauthorized_error_response_body",
    "TrailersUpdateTrailerBadGatewayErrorResponseBody": ".trailers_update_trailer_bad_gateway_error_response_body",
    "TrailersUpdateTrailerGatewayTimeoutErrorResponseBody": ".trailers_update_trailer_gateway_timeout_error_response_body",
    "TrailersUpdateTrailerInternalServerErrorResponseBody": ".trailers_update_trailer_internal_server_error_response_body",
    "TrailersUpdateTrailerMethodNotAllowedErrorResponseBody": ".trailers_update_trailer_method_not_allowed_error_response_body",
    "TrailersUpdateTrailerNotFoundErrorResponseBody": ".trailers_update_trailer_not_found_error_response_body",
    "TrailersUpdateTrailerNotImplementedErrorResponseBody": ".trailers_update_trailer_not_implemented_error_response_body",
    "TrailersUpdateTrailerResponseBody": ".trailers_update_trailer_response_body",
    "TrailersUpdateTrailerServiceUnavailableErrorResponseBody": ".trailers_update_trailer_service_unavailable_error_response_body",
    "TrailersUpdateTrailerTooManyRequestsErrorResponseBody": ".trailers_update_trailer_too_many_requests_error_response_body",
    "TrailersUpdateTrailerUnauthorizedErrorResponseBody": ".trailers_update_trailer_unauthorized_error_response_body",
    "TrainingAssignmentNearDueDateTriggerAssignmentGroupObjectRequestBody": ".training_assignment_near_due_date_trigger_assignment_group_object_request_body",
    "TrainingAssignmentNearDueDateTriggerAssignmentGroupObjectRequestBodyAssignmentGroupType": ".training_assignment_near_due_date_trigger_assignment_group_object_request_body_assignment_group_type",
    "TrainingAssignmentNearDueDateTriggerAssignmentGroupObjectResponseBody": ".training_assignment_near_due_date_trigger_assignment_group_object_response_body",
    "TrainingAssignmentNearDueDateTriggerAssignmentGroupObjectResponseBodyAssignmentGroupType": ".training_assignment_near_due_date_trigger_assignment_group_object_response_body_assignment_group_type",
    "TrainingAssignmentNearDueDateTriggerDetailsObjectRequestBody": ".training_assignment_near_due_date_trigger_details_object_request_body",
    "TrainingAssignmentNearDueDateTriggerDetailsObjectRequestBodyConditionUnits": ".training_assignment_near_due_date_trigger_details_object_request_body_condition_units",
    "TrainingAssignmentNearDueDateTriggerDetailsObjectResponseBody": ".training_assignment_near_due_date_trigger_details_object_response_body",
    "TrainingAssignmentNearDueDateTriggerDetailsObjectResponseBodyConditionUnits": ".training_assignment_near_due_date_trigger_details_object_response_body_condition_units",
    "TrainingAssignmentPostResponseObjectResponseBody": ".training_assignment_post_response_object_response_body",
    "TrainingAssignmentResponseObjectResponseBody": ".training_assignment_response_object_response_body",
    "TrainingAssignmentResponseObjectResponseBodyStatus": ".training_assignment_response_object_response_body_status",
    "TrainingAssignmentsDeleteTrainingAssignmentsBadGatewayErrorResponseBody": ".training_assignments_delete_training_assignments_bad_gateway_error_response_body",
    "TrainingAssignmentsDeleteTrainingAssignmentsGatewayTimeoutErrorResponseBody": ".training_assignments_delete_training_assignments_gateway_timeout_error_response_body",
    "TrainingAssignmentsDeleteTrainingAssignmentsInternalServerErrorResponseBody": ".training_assignments_delete_training_assignments_internal_server_error_response_body",
    "TrainingAssignmentsDeleteTrainingAssignmentsMethodNotAllowedErrorResponseBody": ".training_assignments_delete_training_assignments_method_not_allowed_error_response_body",
    "TrainingAssignmentsDeleteTrainingAssignmentsNotFoundErrorResponseBody": ".training_assignments_delete_training_assignments_not_found_error_response_body",
    "TrainingAssignmentsDeleteTrainingAssignmentsNotImplementedErrorResponseBody": ".training_assignments_delete_training_assignments_not_implemented_error_response_body",
    "TrainingAssignmentsDeleteTrainingAssignmentsServiceUnavailableErrorResponseBody": ".training_assignments_delete_training_assignments_service_unavailable_error_response_body",
    "TrainingAssignmentsDeleteTrainingAssignmentsTooManyRequestsErrorResponseBody": ".training_assignments_delete_training_assignments_too_many_requests_error_response_body",
    "TrainingAssignmentsDeleteTrainingAssignmentsUnauthorizedErrorResponseBody": ".training_assignments_delete_training_assignments_unauthorized_error_response_body",
    "TrainingAssignmentsGetTrainingAssignmentsStreamBadGatewayErrorResponseBody": ".training_assignments_get_training_assignments_stream_bad_gateway_error_response_body",
    "TrainingAssignmentsGetTrainingAssignmentsStreamGatewayTimeoutErrorResponseBody": ".training_assignments_get_training_assignments_stream_gateway_timeout_error_response_body",
    "TrainingAssignmentsGetTrainingAssignmentsStreamInternalServerErrorResponseBody": ".training_assignments_get_training_assignments_stream_internal_server_error_response_body",
    "TrainingAssignmentsGetTrainingAssignmentsStreamMethodNotAllowedErrorResponseBody": ".training_assignments_get_training_assignments_stream_method_not_allowed_error_response_body",
    "TrainingAssignmentsGetTrainingAssignmentsStreamNotFoundErrorResponseBody": ".training_assignments_get_training_assignments_stream_not_found_error_response_body",
    "TrainingAssignmentsGetTrainingAssignmentsStreamNotImplementedErrorResponseBody": ".training_assignments_get_training_assignments_stream_not_implemented_error_response_body",
    "TrainingAssignmentsGetTrainingAssignmentsStreamResponseBody": ".training_assignments_get_training_assignments_stream_response_body",
    "TrainingAssignmentsGetTrainingAssignmentsStreamServiceUnavailableErrorResponseBody": ".training_assignments_get_training_assignments_stream_service_unavailable_error_response_body",
    "TrainingAssignmentsGetTrainingAssignmentsStreamTooManyRequestsErrorResponseBody": ".training_assignments_get_training_assignments_stream_too_many_requests_error_response_body",
    "TrainingAssignmentsGetTrainingAssignmentsStreamUnauthorizedErrorResponseBody": ".training_assignments_get_training_assignments_stream_unauthorized_error_response_body",
    "TrainingAssignmentsPatchTrainingAssignmentsBadGatewayErrorResponseBody": ".training_assignments_patch_training_assignments_bad_gateway_error_response_body",
    "TrainingAssignmentsPatchTrainingAssignmentsGatewayTimeoutErrorResponseBody": ".training_assignments_patch_training_assignments_gateway_timeout_error_response_body",
    "TrainingAssignmentsPatchTrainingAssignmentsInternalServerErrorResponseBody": ".training_assignments_patch_training_assignments_internal_server_error_response_body",
    "TrainingAssignmentsPatchTrainingAssignmentsMethodNotAllowedErrorResponseBody": ".training_assignments_patch_training_assignments_method_not_allowed_error_response_body",
    "TrainingAssignmentsPatchTrainingAssignmentsNotFoundErrorResponseBody": ".training_assignments_patch_training_assignments_not_found_error_response_body",
    "TrainingAssignmentsPatchTrainingAssignmentsNotImplementedErrorResponseBody": ".training_assignments_patch_training_assignments_not_implemented_error_response_body",
    "TrainingAssignmentsPatchTrainingAssignmentsResponseBody": ".training_assignments_patch_training_assignments_response_body",
    "TrainingAssignmentsPatchTrainingAssignmentsServiceUnavailableErrorResponseBody": ".training_assignments_patch_training_assignments_service_unavailable_error_response_body",
    "TrainingAssignmentsPatchTrainingAssignmentsTooManyRequestsErrorResponseBody": ".training_assignments_patch_training_assignments_too_many_requests_error_response_body",
    "TrainingAssignmentsPatchTrainingAssignmentsUnauthorizedErrorResponseBody": ".training_assignments_patch_training_assignments_unauthorized_error_response_body",
    "TrainingAssignmentsPostTrainingAssignmentsBadGatewayErrorResponseBody": ".training_assignments_post_training_assignments_bad_gateway_error_response_body",
    "TrainingAssignmentsPostTrainingAssignmentsGatewayTimeoutErrorResponseBody": ".training_assignments_post_training_assignments_gateway_timeout_error_response_body",
    "TrainingAssignmentsPostTrainingAssignmentsInternalServerErrorResponseBody": ".training_assignments_post_training_assignments_internal_server_error_response_body",
    "TrainingAssignmentsPostTrainingAssignmentsMethodNotAllowedErrorResponseBody": ".training_assignments_post_training_assignments_method_not_allowed_error_response_body",
    "TrainingAssignmentsPostTrainingAssignmentsNotFoundErrorResponseBody": ".training_assignments_post_training_assignments_not_found_error_response_body",
    "TrainingAssignmentsPostTrainingAssignmentsNotImplementedErrorResponseBody": ".training_assignments_post_training_assignments_not_implemented_error_response_body",
    "TrainingAssignmentsPostTrainingAssignmentsResponseBody": ".training_assignments_post_training_assignments_response_body",
    "TrainingAssignmentsPostTrainingAssignmentsServiceUnavailableErrorResponseBody": ".training_assignments_post_training_assignments_service_unavailable_error_response_body",
    "TrainingAssignmentsPostTrainingAssignmentsTooManyRequestsErrorResponseBody": ".training_assignments_post_training_assignments_too_many_requests_error_response_body",
    "TrainingAssignmentsPostTrainingAssignmentsUnauthorizedErrorResponseBody": ".training_assignments_post_training_assignments_unauthorized_error_response_body",
    "TrainingCategoryObjectResponseBody": ".training_category_object_response_body",
    "TrainingCourseLabelObjectResponseBody": ".training_course_label_object_response_body",
    "TrainingCourseObjectResponseBody": ".training_course_object_response_body",
    "TrainingCourseResponseObjectResponseBody": ".training_course_response_object_response_body",
    "TrainingCourseResponseObjectResponseBodyStatus": ".training_course_response_object_response_body_status",
    "TrainingCoursesGetTrainingCoursesBadGatewayErrorResponseBody": ".training_courses_get_training_courses_bad_gateway_error_response_body",
    "TrainingCoursesGetTrainingCoursesGatewayTimeoutErrorResponseBody": ".training_courses_get_training_courses_gateway_timeout_error_response_body",
    "TrainingCoursesGetTrainingCoursesInternalServerErrorResponseBody": ".training_courses_get_training_courses_internal_server_error_response_body",
    "TrainingCoursesGetTrainingCoursesMethodNotAllowedErrorResponseBody": ".training_courses_get_training_courses_method_not_allowed_error_response_body",
    "TrainingCoursesGetTrainingCoursesNotFoundErrorResponseBody": ".training_courses_get_training_courses_not_found_error_response_body",
    "TrainingCoursesGetTrainingCoursesNotImplementedErrorResponseBody": ".training_courses_get_training_courses_not_implemented_error_response_body",
    "TrainingCoursesGetTrainingCoursesResponseBody": ".training_courses_get_training_courses_response_body",
    "TrainingCoursesGetTrainingCoursesServiceUnavailableErrorResponseBody": ".training_courses_get_training_courses_service_unavailable_error_response_body",
    "TrainingCoursesGetTrainingCoursesTooManyRequestsErrorResponseBody": ".training_courses_get_training_courses_too_many_requests_error_response_body",
    "TrainingCoursesGetTrainingCoursesUnauthorizedErrorResponseBody": ".training_courses_get_training_courses_unauthorized_error_response_body",
    "TrainingLearnerObjectResponseBody": ".training_learner_object_response_body",
    "TrainingLearnerObjectResponseBodyType": ".training_learner_object_response_body_type",
    "TriggerParamsObjectRequestBody": ".trigger_params_object_request_body",
    "TriggerParamsObjectResponseBody": ".trigger_params_object_response_body",
    "TripAssetResponseBody": ".trip_asset_response_body",
    "TripAssetResponseBodyType": ".trip_asset_response_body_type",
    "TripResponseBody": ".trip_response_body",
    "TripResponseBodyCompletionStatus": ".trip_response_body_completion_status",
    "TripSpeedingIntervalsResponseBody": ".trip_speeding_intervals_response_body",
    "TripsBreakdownResponseBody": ".trips_breakdown_response_body",
    "TripsGetTripsBadGatewayErrorResponseBody": ".trips_get_trips_bad_gateway_error_response_body",
    "TripsGetTripsGatewayTimeoutErrorResponseBody": ".trips_get_trips_gateway_timeout_error_response_body",
    "TripsGetTripsInternalServerErrorResponseBody": ".trips_get_trips_internal_server_error_response_body",
    "TripsGetTripsMethodNotAllowedErrorResponseBody": ".trips_get_trips_method_not_allowed_error_response_body",
    "TripsGetTripsNotFoundErrorResponseBody": ".trips_get_trips_not_found_error_response_body",
    "TripsGetTripsNotImplementedErrorResponseBody": ".trips_get_trips_not_implemented_error_response_body",
    "TripsGetTripsResponseBody": ".trips_get_trips_response_body",
    "TripsGetTripsServiceUnavailableErrorResponseBody": ".trips_get_trips_service_unavailable_error_response_body",
    "TripsGetTripsTooManyRequestsErrorResponseBody": ".trips_get_trips_too_many_requests_error_response_body",
    "TripsGetTripsUnauthorizedErrorResponseBody": ".trips_get_trips_unauthorized_error_response_body",
    "UnassignedDrivingDataResponseBody": ".unassigned_driving_data_response_body",
    "UnassignedDrivingTriggerDetailsObjectRequestBody": ".unassigned_driving_trigger_details_object_request_body",
    "UnassignedDrivingTriggerDetailsObjectResponseBody": ".unassigned_driving_trigger_details_object_response_body",
    "UpdateAddressRequestGeofence": ".update_address_request_geofence",
    "UpdateDriverRequestAttributes": ".update_driver_request_attributes",
    "UpdateDriverRequestHosSetting": ".update_driver_request_hos_setting",
    "UpdateEngineImmobilizerRelayStateRequestBodyRequestBody": ".update_engine_immobilizer_relay_state_request_body_request_body",
    "UpdateEngineImmobilizerRelayStateRequestBodyRequestBodyId": ".update_engine_immobilizer_relay_state_request_body_request_body_id",
    "UpdateHubLocationRequestBodyRequestBody": ".update_hub_location_request_body_request_body",
    "UpdateRoutesStopRequestObjectRequestBody": ".update_routes_stop_request_object_request_body",
    "UploadedMediaObjectResponseBody": ".uploaded_media_object_response_body",
    "UploadedMediaObjectResponseBodyCameraRole": ".uploaded_media_object_response_body_camera_role",
    "UploadedMediaObjectResponseBodyInput": ".uploaded_media_object_response_body_input",
    "UploadedMediaObjectResponseBodyMediaType": ".uploaded_media_object_response_body_media_type",
    "UploadedMediaObjectResponseBodyTriggerReason": ".uploaded_media_object_response_body_trigger_reason",
    "UrlInfoObjectResponseBody": ".url_info_object_response_body",
    "UsDriverRulesetOverride": ".us_driver_ruleset_override",
    "UsDriverRulesetOverrideCycle": ".us_driver_ruleset_override_cycle",
    "UsDriverRulesetOverrideRestart": ".us_driver_ruleset_override_restart",
    "UsDriverRulesetOverrideRestbreak": ".us_driver_ruleset_override_restbreak",
    "UsDriverRulesetOverrideUsStateToOverride": ".us_driver_ruleset_override_us_state_to_override",
    "User": ".user",
    "UserAuthType": ".user_auth_type",
    "UserEmail": ".user_email",
    "UserExpireAt": ".user_expire_at",
    "UserId": ".user_id",
    "UserIdentifierSerial": ".user_identifier_serial",
    "UserName": ".user_name",
    "UserResponse": ".user_response",
    "UserRole": ".user_role",
    "UserRoleAssignment": ".user_role_assignment",
    "UserRoles": ".user_roles",
    "UserTinyResponse": ".user_tiny_response",
    "V1Asset": ".v_1_asset",
    "V1AssetCable": ".v_1_asset_cable",
    "V1AssetCurrentLocation": ".v_1_asset_current_location",
    "V1AssetCurrentLocationsResponse": ".v_1_asset_current_locations_response",
    "V1AssetLocationResponse": ".v_1_asset_location_response",
    "V1AssetLocationResponseItem": ".v_1_asset_location_response_item",
    "V1AssetReeferResponse": ".v_1_asset_reefer_response",
    "V1AssetReeferResponseReeferStats": ".v_1_asset_reefer_response_reefer_stats",
    "V1AssetReeferResponseReeferStatsAlarms": ".v_1_asset_reefer_response_reefer_stats_alarms",
    "V1AssetReeferResponseReeferStatsAlarms1": ".v_1_asset_reefer_response_reefer_stats_alarms_1",
    "V1AssetReeferResponseReeferStatsEngineHours": ".v_1_asset_reefer_response_reefer_stats_engine_hours",
    "V1AssetReeferResponseReeferStatsFuelPercentage": ".v_1_asset_reefer_response_reefer_stats_fuel_percentage",
    "V1AssetReeferResponseReeferStatsPowerStatus": ".v_1_asset_reefer_response_reefer_stats_power_status",
    "V1AssetReeferResponseReeferStatsReturnAirTemp": ".v_1_asset_reefer_response_reefer_stats_return_air_temp",
    "V1AssetReeferResponseReeferStatsSetPoint": ".v_1_asset_reefer_response_reefer_stats_set_point",
    "V1AssetsReefer": ".v_1_assets_reefer",
    "V1AssetsReeferReeferStats": ".v_1_assets_reefer_reefer_stats",
    "V1AssetsReeferReeferStatsAmbientAirTemperature": ".v_1_assets_reefer_reefer_stats_ambient_air_temperature",
    "V1AssetsReeferReeferStatsDischargeAirTemperature": ".v_1_assets_reefer_reefer_stats_discharge_air_temperature",
    "V1AssetsReeferReeferStatsPowerStatus": ".v_1_assets_reefer_reefer_stats_power_status",
    "V1AssetsReeferReeferStatsPowerStatusStatus": ".v_1_assets_reefer_reefer_stats_power_status_status",
    "V1CargoResponse": ".v_1_cargo_response",
    "V1CargoResponseSensors": ".v_1_cargo_response_sensors",
    "V1DoorResponse": ".v_1_door_response",
    "V1DoorResponseSensors": ".v_1_door_response_sensors",
    "V1DriverSafetyScoreResponse": ".v_1_driver_safety_score_response",
    "V1HosAuthenticationLogsResponse": ".v_1_hos_authentication_logs_response",
    "V1HosAuthenticationLogsResponseAuthenticationLogs": ".v_1_hos_authentication_logs_response_authentication_logs",
    "V1HumidityResponse": ".v_1_humidity_response",
    "V1HumidityResponseSensors": ".v_1_humidity_response_sensors",
    "V1Machine": ".v_1_machine",
    "V1MachineHistoryResponse": ".v_1_machine_history_response",
    "V1MachineHistoryResponseMachines": ".v_1_machine_history_response_machines",
    "V1MachineHistoryResponseVibrations": ".v_1_machine_history_response_vibrations",
    "V1Message": ".v_1_message",
    "V1MessageResponse": ".v_1_message_response",
    "V1MessageSender": ".v_1_message_sender",
    "V1Messages": ".v_1_messages",
    "V1MessagesResponse": ".v_1_messages_response",
    "V1Pagination": ".v_1_pagination",
    "V1ProgramsForTheCameraResponse": ".v_1_programs_for_the_camera_response",
    "V1ProgramsForTheCameraResponseItem": ".v_1_programs_for_the_camera_response_item",
    "V1SafetyReportHarshEvent": ".v_1_safety_report_harsh_event",
    "V1Sensor": ".v_1_sensor",
    "V1SensorHistoryResponse": ".v_1_sensor_history_response",
    "V1SensorHistoryResponseResults": ".v_1_sensor_history_response_results",
    "V1SensorsHistorySeries": ".v_1_sensors_history_series",
    "V1SensorsHistorySeriesField": ".v_1_sensors_history_series_field",
    "V1TemperatureResponse": ".v_1_temperature_response",
    "V1TemperatureResponseSensors": ".v_1_temperature_response_sensors",
    "V1TrailerAssignmentResponse": ".v_1_trailer_assignment_response",
    "V1TrailerAssignmentsResponse": ".v_1_trailer_assignments_response",
    "V1TrailerAssignmentsResponseAllOf": ".v_1_trailer_assignments_response_all_of",
    "V1TrailerBase": ".v_1_trailer_base",
    "V1TripResponse": ".v_1_trip_response",
    "V1TripResponseEndAddress": ".v_1_trip_response_end_address",
    "V1TripResponseEndCoordinates": ".v_1_trip_response_end_coordinates",
    "V1TripResponseStartAddress": ".v_1_trip_response_start_address",
    "V1TripResponseStartCoordinates": ".v_1_trip_response_start_coordinates",
    "V1TripResponseTrips": ".v_1_trip_response_trips",
    "V1VehicleHarshEventResponse": ".v_1_vehicle_harsh_event_response",
    "V1VehicleHarshEventResponseLocation": ".v_1_vehicle_harsh_event_response_location",
    "V1VehicleMaintenance": ".v_1_vehicle_maintenance",
    "V1VehicleMaintenanceJ1939": ".v_1_vehicle_maintenance_j_1939",
    "V1VehicleMaintenanceJ1939CheckEngineLight": ".v_1_vehicle_maintenance_j_1939_check_engine_light",
    "V1VehicleMaintenanceJ1939DiagnosticTroubleCodes": ".v_1_vehicle_maintenance_j_1939_diagnostic_trouble_codes",
    "V1VehicleMaintenancePassenger": ".v_1_vehicle_maintenance_passenger",
    "V1VehicleMaintenancePassengerCheckEngineLight": ".v_1_vehicle_maintenance_passenger_check_engine_light",
    "V1VehicleMaintenancePassengerDiagnosticTroubleCodes": ".v_1_vehicle_maintenance_passenger_diagnostic_trouble_codes",
    "V1VehicleSafetyScoreResponse": ".v_1_vehicle_safety_score_response",
    "V1VisionCamerasResponse": ".v_1_vision_cameras_response",
    "V1VisionCamerasResponseItem": ".v_1_vision_cameras_response_item",
    "V1VisionRunByCameraResponse": ".v_1_vision_run_by_camera_response",
    "V1VisionRunByCameraResponseInspectionResults": ".v_1_vision_run_by_camera_response_inspection_results",
    "V1VisionRunByCameraResponseProgram": ".v_1_vision_run_by_camera_response_program",
    "V1VisionRunByCameraResponseRunSummary": ".v_1_vision_run_by_camera_response_run_summary",
    "V1VisionRunsByCameraAndProgramResponse": ".v_1_vision_runs_by_camera_and_program_response",
    "V1VisionRunsByCameraResponse": ".v_1_vision_runs_by_camera_response",
    "V1VisionRunsByCameraResponseItem": ".v_1_vision_runs_by_camera_response_item",
    "V1VisionRunsByCameraResponseItemProgram": ".v_1_vision_runs_by_camera_response_item_program",
    "V1VisionRunsByCameraResponseItemReportMetadata": ".v_1_vision_runs_by_camera_response_item_report_metadata",
    "V1VisionRunsResponse": ".v_1_vision_runs_response",
    "V1VisionRunsResponseReportMetadata": ".v_1_vision_runs_response_report_metadata",
    "V1VisionRunsResponseVisionRuns": ".v_1_vision_runs_response_vision_runs",
    "V1VisionStepResults": ".v_1_vision_step_results",
    "V1VisionStepResultsItem": ".v_1_vision_step_results_item",
    "V1VisionStepResultsItemAngleCheck": ".v_1_vision_step_results_item_angle_check",
    "V1VisionStepResultsItemAngleCheckAngleConfigured": ".v_1_vision_step_results_item_angle_check_angle_configured",
    "V1VisionStepResultsItemBarcodeItem": ".v_1_vision_step_results_item_barcode_item",
    "V1VisionStepResultsItemBooleanLogic": ".v_1_vision_step_results_item_boolean_logic",
    "V1VisionStepResultsItemBooleanLogicStepsItem": ".v_1_vision_step_results_item_boolean_logic_steps_item",
    "V1VisionStepResultsItemCaliper": ".v_1_vision_step_results_item_caliper",
    "V1VisionStepResultsItemCaliperAngleRange": ".v_1_vision_step_results_item_caliper_angle_range",
    "V1VisionStepResultsItemCaliperContrastRange": ".v_1_vision_step_results_item_caliper_contrast_range",
    "V1VisionStepResultsItemCaliperFilterPolarity": ".v_1_vision_step_results_item_caliper_filter_polarity",
    "V1VisionStepResultsItemCaliperSharpnessRange": ".v_1_vision_step_results_item_caliper_sharpness_range",
    "V1VisionStepResultsItemCaliperStraightnessRange": ".v_1_vision_step_results_item_caliper_straightness_range",
    "V1VisionStepResultsItemContour": ".v_1_vision_step_results_item_contour",
    "V1VisionStepResultsItemDistance": ".v_1_vision_step_results_item_distance",
    "V1VisionStepResultsItemExpirationDate": ".v_1_vision_step_results_item_expiration_date",
    "V1VisionStepResultsItemFindCopies": ".v_1_vision_step_results_item_find_copies",
    "V1VisionStepResultsItemFindEdge": ".v_1_vision_step_results_item_find_edge",
    "V1VisionStepResultsItemFindEdgeAngleRange": ".v_1_vision_step_results_item_find_edge_angle_range",
    "V1VisionStepResultsItemFindEdgeContrastRange": ".v_1_vision_step_results_item_find_edge_contrast_range",
    "V1VisionStepResultsItemFindEdgeSharpnessRange": ".v_1_vision_step_results_item_find_edge_sharpness_range",
    "V1VisionStepResultsItemFindEdgeStraightnessRange": ".v_1_vision_step_results_item_find_edge_straightness_range",
    "V1VisionStepResultsItemFindShapes": ".v_1_vision_step_results_item_find_shapes",
    "V1VisionStepResultsItemFixture": ".v_1_vision_step_results_item_fixture",
    "V1VisionStepResultsItemFixtureCoordinates": ".v_1_vision_step_results_item_fixture_coordinates",
    "V1VisionStepResultsItemLabelMatch": ".v_1_vision_step_results_item_label_match",
    "V1VisionStepResultsItemPresenceAbsence": ".v_1_vision_step_results_item_presence_absence",
    "V1VisionStepResultsItemPresenceAbsenceBlueRange": ".v_1_vision_step_results_item_presence_absence_blue_range",
    "V1VisionStepResultsItemPresenceAbsenceGrayscaleRange": ".v_1_vision_step_results_item_presence_absence_grayscale_range",
    "V1VisionStepResultsItemPresenceAbsenceGreenRange": ".v_1_vision_step_results_item_presence_absence_green_range",
    "V1VisionStepResultsItemPresenceAbsenceHueRange": ".v_1_vision_step_results_item_presence_absence_hue_range",
    "V1VisionStepResultsItemPresenceAbsenceRedRange": ".v_1_vision_step_results_item_presence_absence_red_range",
    "V1VisionStepResultsItemPresenceAbsenceSaturationRange": ".v_1_vision_step_results_item_presence_absence_saturation_range",
    "V1VisionStepResultsItemPresenceAbsenceValueRange": ".v_1_vision_step_results_item_presence_absence_value_range",
    "V1VisionStepResultsItemTextMatch": ".v_1_vision_step_results_item_text_match",
    "Vehicle": ".vehicle",
    "VehicleAssignmentObjectResponseBody": ".vehicle_assignment_object_response_body",
    "VehicleAssignmentObjectResponseBodyAssignmentType": ".vehicle_assignment_object_response_body_assignment_type",
    "VehicleAuxInputName": ".vehicle_aux_input_name",
    "VehicleAuxInputType": ".vehicle_aux_input_type",
    "VehicleBatterVoltageDetailsObjectRequestBody": ".vehicle_batter_voltage_details_object_request_body",
    "VehicleBatterVoltageDetailsObjectRequestBodyOperation": ".vehicle_batter_voltage_details_object_request_body_operation",
    "VehicleBatterVoltageDetailsObjectResponseBody": ".vehicle_batter_voltage_details_object_response_body",
    "VehicleBatterVoltageDetailsObjectResponseBodyOperation": ".vehicle_batter_voltage_details_object_response_body_operation",
    "VehicleBatteryVoltageResponseBody": ".vehicle_battery_voltage_response_body",
    "VehicleDefLevelPercentageResponseBody": ".vehicle_def_level_percentage_response_body",
    "VehicleDetectedResponseBody": ".vehicle_detected_response_body",
    "VehicleDvirObjectResponseBody": ".vehicle_dvir_object_response_body",
    "VehicleEsn": ".vehicle_esn",
    "VehicleExternalIds": ".vehicle_external_ids",
    "VehicleFaultCodeDetailsObjectRequestBody": ".vehicle_fault_code_details_object_request_body",
    "VehicleFaultCodeDetailsObjectResponseBody": ".vehicle_fault_code_details_object_response_body",
    "VehicleFaultsResponseBody": ".vehicle_faults_response_body",
    "VehicleHarshAccelerationSettingType": ".vehicle_harsh_acceleration_setting_type",
    "VehicleId": ".vehicle_id",
    "VehicleLicensePlate": ".vehicle_license_plate",
    "VehicleLocation": ".vehicle_location",
    "VehicleLocationAddress": ".vehicle_location_address",
    "VehicleLocationHeading": ".vehicle_location_heading",
    "VehicleLocationIsEcuSpeed": ".vehicle_location_is_ecu_speed",
    "VehicleLocationLatitude": ".vehicle_location_latitude",
    "VehicleLocationLongitude": ".vehicle_location_longitude",
    "VehicleLocationSpeed": ".vehicle_location_speed",
    "VehicleLocationsListResponse": ".vehicle_locations_list_response",
    "VehicleLocationsListResponseData": ".vehicle_locations_list_response_data",
    "VehicleLocationsResponse": ".vehicle_locations_response",
    "VehicleLocationsResponseData": ".vehicle_locations_response_data",
    "VehicleMake": ".vehicle_make",
    "VehicleModel": ".vehicle_model",
    "VehicleName": ".vehicle_name",
    "VehicleNotes": ".vehicle_notes",
    "VehicleRegulationMode": ".vehicle_regulation_mode",
    "VehicleResponse": ".vehicle_response",
    "VehicleResponseObjectResponseBody": ".vehicle_response_object_response_body",
    "VehicleResponseObjectResponseBodyVehicleRegulationMode": ".vehicle_response_object_response_body_vehicle_regulation_mode",
    "VehicleResponseObjectResponseBodyVehicleType": ".vehicle_response_object_response_body_vehicle_type",
    "VehicleResponseResponseBody": ".vehicle_response_response_body",
    "VehicleResponseResponseBodyAssetType": ".vehicle_response_response_body_asset_type",
    "VehicleSafetyScoreResponseBody": ".vehicle_safety_score_response_body",
    "VehicleSensorConfiguration": ".vehicle_sensor_configuration",
    "VehicleSensorConfigurationArea": ".vehicle_sensor_configuration_area",
    "VehicleSensorConfigurationAreaPosition": ".vehicle_sensor_configuration_area_position",
    "VehicleSensorConfigurationAreaResponseBody": ".vehicle_sensor_configuration_area_response_body",
    "VehicleSensorConfigurationAreaResponseBodyPosition": ".vehicle_sensor_configuration_area_response_body_position",
    "VehicleSensorConfigurationDoor": ".vehicle_sensor_configuration_door",
    "VehicleSensorConfigurationDoorPosition": ".vehicle_sensor_configuration_door_position",
    "VehicleSensorConfigurationDoorResponseBody": ".vehicle_sensor_configuration_door_response_body",
    "VehicleSensorConfigurationDoorResponseBodyPosition": ".vehicle_sensor_configuration_door_response_body_position",
    "VehicleSensorConfigurationResponseBody": ".vehicle_sensor_configuration_response_body",
    "VehicleStatsAmbientAirTempMilliC": ".vehicle_stats_ambient_air_temp_milli_c",
    "VehicleStatsAmbientAirTempMilliCValue": ".vehicle_stats_ambient_air_temp_milli_c_value",
    "VehicleStatsAmbientAirTempMilliCWithDecoration": ".vehicle_stats_ambient_air_temp_milli_c_with_decoration",
    "VehicleStatsAuxInput": ".vehicle_stats_aux_input",
    "VehicleStatsAuxInputDecoration": ".vehicle_stats_aux_input_decoration",
    "VehicleStatsAuxInputTime": ".vehicle_stats_aux_input_time",
    "VehicleStatsAuxInputValue": ".vehicle_stats_aux_input_value",
    "VehicleStatsAuxInputWithDecoration": ".vehicle_stats_aux_input_with_decoration",
    "VehicleStatsBarometricPressurePa": ".vehicle_stats_barometric_pressure_pa",
    "VehicleStatsBarometricPressurePaValue": ".vehicle_stats_barometric_pressure_pa_value",
    "VehicleStatsBarometricPressurePaWithDecoration": ".vehicle_stats_barometric_pressure_pa_with_decoration",
    "VehicleStatsBatteryMilliVoltsValue": ".vehicle_stats_battery_milli_volts_value",
    "VehicleStatsBatteryVoltage": ".vehicle_stats_battery_voltage",
    "VehicleStatsBatteryVoltageWithDecoration": ".vehicle_stats_battery_voltage_with_decoration",
    "VehicleStatsDecorations": ".vehicle_stats_decorations",
    "VehicleStatsDecorationsAmbientAirTemperatureMilliC": ".vehicle_stats_decorations_ambient_air_temperature_milli_c",
    "VehicleStatsDecorationsBarometricPressurePa": ".vehicle_stats_decorations_barometric_pressure_pa",
    "VehicleStatsDecorationsBatteryMilliVolts": ".vehicle_stats_decorations_battery_milli_volts",
    "VehicleStatsDecorationsDefLevelMilliPercent": ".vehicle_stats_decorations_def_level_milli_percent",
    "VehicleStatsDecorationsEcuSpeedMph": ".vehicle_stats_decorations_ecu_speed_mph",
    "VehicleStatsDecorationsEngineCoolantTemperatureMilliC": ".vehicle_stats_decorations_engine_coolant_temperature_milli_c",
    "VehicleStatsDecorationsEngineLoadPercent": ".vehicle_stats_decorations_engine_load_percent",
    "VehicleStatsDecorationsEngineOilPressureKPa": ".vehicle_stats_decorations_engine_oil_pressure_k_pa",
    "VehicleStatsDecorationsEngineRpm": ".vehicle_stats_decorations_engine_rpm",
    "VehicleStatsDecorationsEngineStates": ".vehicle_stats_decorations_engine_states",
    "VehicleStatsDecorationsEngineStatesValue": ".vehicle_stats_decorations_engine_states_value",
    "VehicleStatsDecorationsFuelConsumedMilliliters": ".vehicle_stats_decorations_fuel_consumed_milliliters",
    "VehicleStatsDecorationsFuelPercents": ".vehicle_stats_decorations_fuel_percents",
    "VehicleStatsDecorationsGps": ".vehicle_stats_decorations_gps",
    "VehicleStatsDecorationsGpsDistanceMeters": ".vehicle_stats_decorations_gps_distance_meters",
    "VehicleStatsDecorationsGpsOdometerMeters": ".vehicle_stats_decorations_gps_odometer_meters",
    "VehicleStatsDecorationsIdlingDurationMilliseconds": ".vehicle_stats_decorations_idling_duration_milliseconds",
    "VehicleStatsDecorationsIntakeManifoldTemperatureMilliC": ".vehicle_stats_decorations_intake_manifold_temperature_milli_c",
    "VehicleStatsDecorationsObdEngineSeconds": ".vehicle_stats_decorations_obd_engine_seconds",
    "VehicleStatsDecorationsObdOdometerMeters": ".vehicle_stats_decorations_obd_odometer_meters",
    "VehicleStatsDefLevelMilliPercent": ".vehicle_stats_def_level_milli_percent",
    "VehicleStatsDefLevelMilliPercentValue": ".vehicle_stats_def_level_milli_percent_value",
    "VehicleStatsDefLevelMilliPercentWithDecoration": ".vehicle_stats_def_level_milli_percent_with_decoration",
    "VehicleStatsEcuDoorStatus": ".vehicle_stats_ecu_door_status",
    "VehicleStatsEcuDoorStatusValue": ".vehicle_stats_ecu_door_status_value",
    "VehicleStatsEcuSpeedMph": ".vehicle_stats_ecu_speed_mph",
    "VehicleStatsEcuSpeedMphValue": ".vehicle_stats_ecu_speed_mph_value",
    "VehicleStatsEcuSpeedMphWithDecoration": ".vehicle_stats_ecu_speed_mph_with_decoration",
    "VehicleStatsEngineCoolantTempMilliC": ".vehicle_stats_engine_coolant_temp_milli_c",
    "VehicleStatsEngineCoolantTempMilliCValue": ".vehicle_stats_engine_coolant_temp_milli_c_value",
    "VehicleStatsEngineCoolantTempMilliCWithDecoration": ".vehicle_stats_engine_coolant_temp_milli_c_with_decoration",
    "VehicleStatsEngineImmobilizer": ".vehicle_stats_engine_immobilizer",
    "VehicleStatsEngineImmobilizerState": ".vehicle_stats_engine_immobilizer_state",
    "VehicleStatsEngineImmobilizerWithDecoration": ".vehicle_stats_engine_immobilizer_with_decoration",
    "VehicleStatsEngineImmobilizerWithDecorationState": ".vehicle_stats_engine_immobilizer_with_decoration_state",
    "VehicleStatsEngineLoadPercent": ".vehicle_stats_engine_load_percent",
    "VehicleStatsEngineLoadPercentValue": ".vehicle_stats_engine_load_percent_value",
    "VehicleStatsEngineLoadPercentWithDecoration": ".vehicle_stats_engine_load_percent_with_decoration",
    "VehicleStatsEngineOilPressureKPa": ".vehicle_stats_engine_oil_pressure_k_pa",
    "VehicleStatsEngineOilPressureKPaValue": ".vehicle_stats_engine_oil_pressure_k_pa_value",
    "VehicleStatsEngineOilPressureKPaWithDecoration": ".vehicle_stats_engine_oil_pressure_k_pa_with_decoration",
    "VehicleStatsEngineRpm": ".vehicle_stats_engine_rpm",
    "VehicleStatsEngineRpmValue": ".vehicle_stats_engine_rpm_value",
    "VehicleStatsEngineRpmWithDecoration": ".vehicle_stats_engine_rpm_with_decoration",
    "VehicleStatsEngineState": ".vehicle_stats_engine_state",
    "VehicleStatsEngineStateSetting": ".vehicle_stats_engine_state_setting",
    "VehicleStatsEngineStateWithDecoration": ".vehicle_stats_engine_state_with_decoration",
    "VehicleStatsEvAverageBatteryTemperatureMilliCelsius": ".vehicle_stats_ev_average_battery_temperature_milli_celsius",
    "VehicleStatsEvBatteryCurrentMilliAmp": ".vehicle_stats_ev_battery_current_milli_amp",
    "VehicleStatsEvBatteryStateOfHealthMilliPercent": ".vehicle_stats_ev_battery_state_of_health_milli_percent",
    "VehicleStatsEvBatteryVoltageMilliVolt": ".vehicle_stats_ev_battery_voltage_milli_volt",
    "VehicleStatsEvChargingCurrentMilliAmp": ".vehicle_stats_ev_charging_current_milli_amp",
    "VehicleStatsEvChargingEnergyMicroWh": ".vehicle_stats_ev_charging_energy_micro_wh",
    "VehicleStatsEvChargingStatus": ".vehicle_stats_ev_charging_status",
    "VehicleStatsEvChargingVoltageMilliVolt": ".vehicle_stats_ev_charging_voltage_milli_volt",
    "VehicleStatsEvConsumedEnergyMicroWh": ".vehicle_stats_ev_consumed_energy_micro_wh",
    "VehicleStatsEvDistanceDrivenMeters": ".vehicle_stats_ev_distance_driven_meters",
    "VehicleStatsEvRegeneratedEnergyMicroWh": ".vehicle_stats_ev_regenerated_energy_micro_wh",
    "VehicleStatsEvStateOfChargeMilliPercent": ".vehicle_stats_ev_state_of_charge_milli_percent",
    "VehicleStatsFaultCodes": ".vehicle_stats_fault_codes",
    "VehicleStatsFaultCodesCanBusType": ".vehicle_stats_fault_codes_can_bus_type",
    "VehicleStatsFaultCodesIgnitionType": ".vehicle_stats_fault_codes_ignition_type",
    "VehicleStatsFaultCodesJ1939": ".vehicle_stats_fault_codes_j_1939",
    "VehicleStatsFaultCodesJ1939Lights": ".vehicle_stats_fault_codes_j_1939_lights",
    "VehicleStatsFaultCodesJ1939TroubleCode": ".vehicle_stats_fault_codes_j_1939_trouble_code",
    "VehicleStatsFaultCodesJ1939TroubleCodes": ".vehicle_stats_fault_codes_j_1939_trouble_codes",
    "VehicleStatsFaultCodesObdii": ".vehicle_stats_fault_codes_obdii",
    "VehicleStatsFaultCodesObdiiTroubleCode": ".vehicle_stats_fault_codes_obdii_trouble_code",
    "VehicleStatsFaultCodesOem": ".vehicle_stats_fault_codes_oem",
    "VehicleStatsFaultCodesOemTroubleCode": ".vehicle_stats_fault_codes_oem_trouble_code",
    "VehicleStatsFaultCodesOemTroubleCodes": ".vehicle_stats_fault_codes_oem_trouble_codes",
    "VehicleStatsFaultCodesPassengerDtc": ".vehicle_stats_fault_codes_passenger_dtc",
    "VehicleStatsFaultCodesPassengerMonitorStatus": ".vehicle_stats_fault_codes_passenger_monitor_status",
    "VehicleStatsFaultCodesPassengerMonitorStatusValue": ".vehicle_stats_fault_codes_passenger_monitor_status_value",
    "VehicleStatsFaultCodesTxId": ".vehicle_stats_fault_codes_tx_id",
    "VehicleStatsFaultCodesValue": ".vehicle_stats_fault_codes_value",
    "VehicleStatsFaultCodesValueJ1939": ".vehicle_stats_fault_codes_value_j_1939",
    "VehicleStatsFaultCodesValueJ1939CheckEngineLights": ".vehicle_stats_fault_codes_value_j_1939_check_engine_lights",
    "VehicleStatsFaultCodesValueJ1939DiagnosticTroubleCodes": ".vehicle_stats_fault_codes_value_j_1939_diagnostic_trouble_codes",
    "VehicleStatsFaultCodesValueJ1939VendorSpecificFields": ".vehicle_stats_fault_codes_value_j_1939_vendor_specific_fields",
    "VehicleStatsFaultCodesValueObdii": ".vehicle_stats_fault_codes_value_obdii",
    "VehicleStatsFaultCodesValueObdiiConfirmedDtcs": ".vehicle_stats_fault_codes_value_obdii_confirmed_dtcs",
    "VehicleStatsFaultCodesValueObdiiDiagnosticTroubleCodes": ".vehicle_stats_fault_codes_value_obdii_diagnostic_trouble_codes",
    "VehicleStatsFaultCodesValueObdiiDiagnosticTroubleCodesIgnitionType": ".vehicle_stats_fault_codes_value_obdii_diagnostic_trouble_codes_ignition_type",
    "VehicleStatsFaultCodesValueObdiiMonitorStatus": ".vehicle_stats_fault_codes_value_obdii_monitor_status",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusCatalyst": ".vehicle_stats_fault_codes_value_obdii_monitor_status_catalyst",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusComprehensive": ".vehicle_stats_fault_codes_value_obdii_monitor_status_comprehensive",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusEgr": ".vehicle_stats_fault_codes_value_obdii_monitor_status_egr",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusEvapSystem": ".vehicle_stats_fault_codes_value_obdii_monitor_status_evap_system",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusFuel": ".vehicle_stats_fault_codes_value_obdii_monitor_status_fuel",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusHeatedCatalyst": ".vehicle_stats_fault_codes_value_obdii_monitor_status_heated_catalyst",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusHeatedO2Sensor": ".vehicle_stats_fault_codes_value_obdii_monitor_status_heated_o_2_sensor",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusIsoSaeReserved": ".vehicle_stats_fault_codes_value_obdii_monitor_status_iso_sae_reserved",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusMisfire": ".vehicle_stats_fault_codes_value_obdii_monitor_status_misfire",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusO2Sensor": ".vehicle_stats_fault_codes_value_obdii_monitor_status_o_2_sensor",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusSecondaryAir": ".vehicle_stats_fault_codes_value_obdii_monitor_status_secondary_air",
    "VehicleStatsFaultCodesValueOem": ".vehicle_stats_fault_codes_value_oem",
    "VehicleStatsFaultCodesValueOemDiagnosticTroubleCodes": ".vehicle_stats_fault_codes_value_oem_diagnostic_trouble_codes",
    "VehicleStatsFaultCodesVendorSpecificFields": ".vehicle_stats_fault_codes_vendor_specific_fields",
    "VehicleStatsFaultCodesWithDecoration": ".vehicle_stats_fault_codes_with_decoration",
    "VehicleStatsFuelConsumedMilliliters": ".vehicle_stats_fuel_consumed_milliliters",
    "VehicleStatsFuelConsumedMillilitersValue": ".vehicle_stats_fuel_consumed_milliliters_value",
    "VehicleStatsFuelConsumedMillilitersWithDecoration": ".vehicle_stats_fuel_consumed_milliliters_with_decoration",
    "VehicleStatsFuelPercent": ".vehicle_stats_fuel_percent",
    "VehicleStatsFuelPercentValue": ".vehicle_stats_fuel_percent_value",
    "VehicleStatsFuelPercentWithDecoration": ".vehicle_stats_fuel_percent_with_decoration",
    "VehicleStatsGps": ".vehicle_stats_gps",
    "VehicleStatsGpsDistanceMeters": ".vehicle_stats_gps_distance_meters",
    "VehicleStatsGpsDistanceMetersValue": ".vehicle_stats_gps_distance_meters_value",
    "VehicleStatsGpsDistanceMetersWithDecoration": ".vehicle_stats_gps_distance_meters_with_decoration",
    "VehicleStatsGpsOdometerMeters": ".vehicle_stats_gps_odometer_meters",
    "VehicleStatsGpsOdometerMetersValue": ".vehicle_stats_gps_odometer_meters_value",
    "VehicleStatsGpsOdometerMetersWithDecoration": ".vehicle_stats_gps_odometer_meters_with_decoration",
    "VehicleStatsIdlingDurationMilliseconds": ".vehicle_stats_idling_duration_milliseconds",
    "VehicleStatsIdlingDurationMillisecondsValue": ".vehicle_stats_idling_duration_milliseconds_value",
    "VehicleStatsIdlingDurationMillisecondsWithDecoration": ".vehicle_stats_idling_duration_milliseconds_with_decoration",
    "VehicleStatsIntakeManifoldTempMilliC": ".vehicle_stats_intake_manifold_temp_milli_c",
    "VehicleStatsIntakeManifoldTempMilliCValue": ".vehicle_stats_intake_manifold_temp_milli_c_value",
    "VehicleStatsIntakeManifoldTempMilliCWithDecoration": ".vehicle_stats_intake_manifold_temp_milli_c_with_decoration",
    "VehicleStatsListGps": ".vehicle_stats_list_gps",
    "VehicleStatsListResponse": ".vehicle_stats_list_response",
    "VehicleStatsListResponseData": ".vehicle_stats_list_response_data",
    "VehicleStatsListSyntheticEngineSeconds": ".vehicle_stats_list_synthetic_engine_seconds",
    "VehicleStatsNfcCardScan": ".vehicle_stats_nfc_card_scan",
    "VehicleStatsNfcCardScanCard": ".vehicle_stats_nfc_card_scan_card",
    "VehicleStatsNfcCardScanWithDecoration": ".vehicle_stats_nfc_card_scan_with_decoration",
    "VehicleStatsObdEngineSeconds": ".vehicle_stats_obd_engine_seconds",
    "VehicleStatsObdEngineSecondsValue": ".vehicle_stats_obd_engine_seconds_value",
    "VehicleStatsObdEngineSecondsWithDecoration": ".vehicle_stats_obd_engine_seconds_with_decoration",
    "VehicleStatsObdOdometerMeters": ".vehicle_stats_obd_odometer_meters",
    "VehicleStatsObdOdometerMetersValue": ".vehicle_stats_obd_odometer_meters_value",
    "VehicleStatsObdOdometerMetersWithDecoration": ".vehicle_stats_obd_odometer_meters_with_decoration",
    "VehicleStatsResponse": ".vehicle_stats_response",
    "VehicleStatsResponseData": ".vehicle_stats_response_data",
    "VehicleStatsResponseEcuDoorStatus": ".vehicle_stats_response_ecu_door_status",
    "VehicleStatsResponseEcuDoorStatusValue": ".vehicle_stats_response_ecu_door_status_value",
    "VehicleStatsResponseEvAverageBatteryTemperatureMilliCelsius": ".vehicle_stats_response_ev_average_battery_temperature_milli_celsius",
    "VehicleStatsResponseEvBatteryCurrentMilliAmp": ".vehicle_stats_response_ev_battery_current_milli_amp",
    "VehicleStatsResponseEvBatteryStateOfHealthMilliPercent": ".vehicle_stats_response_ev_battery_state_of_health_milli_percent",
    "VehicleStatsResponseEvBatteryVoltageMilliVolt": ".vehicle_stats_response_ev_battery_voltage_milli_volt",
    "VehicleStatsResponseEvChargingCurrentMilliAmp": ".vehicle_stats_response_ev_charging_current_milli_amp",
    "VehicleStatsResponseEvChargingEnergyMicroWh": ".vehicle_stats_response_ev_charging_energy_micro_wh",
    "VehicleStatsResponseEvChargingStatus": ".vehicle_stats_response_ev_charging_status",
    "VehicleStatsResponseEvChargingVoltageMilliVolt": ".vehicle_stats_response_ev_charging_voltage_milli_volt",
    "VehicleStatsResponseEvConsumedEnergyMicroWh": ".vehicle_stats_response_ev_consumed_energy_micro_wh",
    "VehicleStatsResponseEvDistanceDrivenMeters": ".vehicle_stats_response_ev_distance_driven_meters",
    "VehicleStatsResponseEvRegeneratedEnergyMicroWh": ".vehicle_stats_response_ev_regenerated_energy_micro_wh",
    "VehicleStatsResponseEvStateOfChargeMilliPercent": ".vehicle_stats_response_ev_state_of_charge_milli_percent",
    "VehicleStatsResponseSeatbeltDriver": ".vehicle_stats_response_seatbelt_driver",
    "VehicleStatsResponseSeatbeltDriverValue": ".vehicle_stats_response_seatbelt_driver_value",
    "VehicleStatsResponseSpreaderActive": ".vehicle_stats_response_spreader_active",
    "VehicleStatsResponseSpreaderActiveValue": ".vehicle_stats_response_spreader_active_value",
    "VehicleStatsResponseSpreaderAirTemp": ".vehicle_stats_response_spreader_air_temp",
    "VehicleStatsResponseSpreaderBlastState": ".vehicle_stats_response_spreader_blast_state",
    "VehicleStatsResponseSpreaderBlastStateValue": ".vehicle_stats_response_spreader_blast_state_value",
    "VehicleStatsResponseSpreaderGranularName": ".vehicle_stats_response_spreader_granular_name",
    "VehicleStatsResponseSpreaderGranularRate": ".vehicle_stats_response_spreader_granular_rate",
    "VehicleStatsResponseSpreaderLiquidName": ".vehicle_stats_response_spreader_liquid_name",
    "VehicleStatsResponseSpreaderLiquidRate": ".vehicle_stats_response_spreader_liquid_rate",
    "VehicleStatsResponseSpreaderOnState": ".vehicle_stats_response_spreader_on_state",
    "VehicleStatsResponseSpreaderOnStateValue": ".vehicle_stats_response_spreader_on_state_value",
    "VehicleStatsResponseSpreaderPlowStatus": ".vehicle_stats_response_spreader_plow_status",
    "VehicleStatsResponseSpreaderPlowStatusValue": ".vehicle_stats_response_spreader_plow_status_value",
    "VehicleStatsResponseSpreaderPrewetName": ".vehicle_stats_response_spreader_prewet_name",
    "VehicleStatsResponseSpreaderPrewetRate": ".vehicle_stats_response_spreader_prewet_rate",
    "VehicleStatsResponseSpreaderRoadTemp": ".vehicle_stats_response_spreader_road_temp",
    "VehicleStatsSeatbeltDriver": ".vehicle_stats_seatbelt_driver",
    "VehicleStatsSeatbeltDriverValue": ".vehicle_stats_seatbelt_driver_value",
    "VehicleStatsSpreaderActive": ".vehicle_stats_spreader_active",
    "VehicleStatsSpreaderActiveValue": ".vehicle_stats_spreader_active_value",
    "VehicleStatsSpreaderAirTemp": ".vehicle_stats_spreader_air_temp",
    "VehicleStatsSpreaderBlastState": ".vehicle_stats_spreader_blast_state",
    "VehicleStatsSpreaderBlastStateValue": ".vehicle_stats_spreader_blast_state_value",
    "VehicleStatsSpreaderGranularName": ".vehicle_stats_spreader_granular_name",
    "VehicleStatsSpreaderGranularRate": ".vehicle_stats_spreader_granular_rate",
    "VehicleStatsSpreaderLiquidName": ".vehicle_stats_spreader_liquid_name",
    "VehicleStatsSpreaderLiquidRate": ".vehicle_stats_spreader_liquid_rate",
    "VehicleStatsSpreaderOnState": ".vehicle_stats_spreader_on_state",
    "VehicleStatsSpreaderOnStateValue": ".vehicle_stats_spreader_on_state_value",
    "VehicleStatsSpreaderPlowStatus": ".vehicle_stats_spreader_plow_status",
    "VehicleStatsSpreaderPlowStatusValue": ".vehicle_stats_spreader_plow_status_value",
    "VehicleStatsSpreaderPrewetName": ".vehicle_stats_spreader_prewet_name",
    "VehicleStatsSpreaderPrewetRate": ".vehicle_stats_spreader_prewet_rate",
    "VehicleStatsSpreaderRoadTemp": ".vehicle_stats_spreader_road_temp",
    "VehicleStatsSyntheticEngineSeconds": ".vehicle_stats_synthetic_engine_seconds",
    "VehicleStatsSyntheticEngineSecondsValue": ".vehicle_stats_synthetic_engine_seconds_value",
    "VehicleStatsTirePressures": ".vehicle_stats_tire_pressures",
    "VehicleSummary": ".vehicle_summary",
    "VehicleTags": ".vehicle_tags",
    "VehicleTinyResponse": ".vehicle_tiny_response",
    "VehicleType": ".vehicle_type",
    "VehicleVin": ".vehicle_vin",
    "VehicleWithGatewayTinyResponseResponseBody": ".vehicle_with_gateway_tiny_response_response_body",
    "VehicleWithGatewayTinyResponseResponseBodyAssetType": ".vehicle_with_gateway_tiny_response_response_body_asset_type",
    "VehicleYear": ".vehicle_year",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsBadGatewayErrorResponseBody": ".vehicles_driver_assignments_get_vehicles_driver_assignments_bad_gateway_error_response_body",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsGatewayTimeoutErrorResponseBody": ".vehicles_driver_assignments_get_vehicles_driver_assignments_gateway_timeout_error_response_body",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsInternalServerErrorResponseBody": ".vehicles_driver_assignments_get_vehicles_driver_assignments_internal_server_error_response_body",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsMethodNotAllowedErrorResponseBody": ".vehicles_driver_assignments_get_vehicles_driver_assignments_method_not_allowed_error_response_body",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsNotFoundErrorResponseBody": ".vehicles_driver_assignments_get_vehicles_driver_assignments_not_found_error_response_body",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsNotImplementedErrorResponseBody": ".vehicles_driver_assignments_get_vehicles_driver_assignments_not_implemented_error_response_body",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsResponseBody": ".vehicles_driver_assignments_get_vehicles_driver_assignments_response_body",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsServiceUnavailableErrorResponseBody": ".vehicles_driver_assignments_get_vehicles_driver_assignments_service_unavailable_error_response_body",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsTooManyRequestsErrorResponseBody": ".vehicles_driver_assignments_get_vehicles_driver_assignments_too_many_requests_error_response_body",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsUnauthorizedErrorResponseBody": ".vehicles_driver_assignments_get_vehicles_driver_assignments_unauthorized_error_response_body",
    "VehiclesDriverAssignmentsObjectResponseBody": ".vehicles_driver_assignments_object_response_body",
    "VehiclesListVehiclesBadGatewayErrorResponseBody": ".vehicles_list_vehicles_bad_gateway_error_response_body",
    "VehiclesListVehiclesGatewayTimeoutErrorResponseBody": ".vehicles_list_vehicles_gateway_timeout_error_response_body",
    "VehiclesListVehiclesInternalServerErrorResponseBody": ".vehicles_list_vehicles_internal_server_error_response_body",
    "VehiclesListVehiclesMethodNotAllowedErrorResponseBody": ".vehicles_list_vehicles_method_not_allowed_error_response_body",
    "VehiclesListVehiclesNotFoundErrorResponseBody": ".vehicles_list_vehicles_not_found_error_response_body",
    "VehiclesListVehiclesNotImplementedErrorResponseBody": ".vehicles_list_vehicles_not_implemented_error_response_body",
    "VehiclesListVehiclesResponseBody": ".vehicles_list_vehicles_response_body",
    "VehiclesListVehiclesServiceUnavailableErrorResponseBody": ".vehicles_list_vehicles_service_unavailable_error_response_body",
    "VehiclesListVehiclesTooManyRequestsErrorResponseBody": ".vehicles_list_vehicles_too_many_requests_error_response_body",
    "VehiclesListVehiclesUnauthorizedErrorResponseBody": ".vehicles_list_vehicles_unauthorized_error_response_body",
    "VehiclesLockLockVehicleBadGatewayErrorResponseBody": ".vehicles_lock_lock_vehicle_bad_gateway_error_response_body",
    "VehiclesLockLockVehicleGatewayTimeoutErrorResponseBody": ".vehicles_lock_lock_vehicle_gateway_timeout_error_response_body",
    "VehiclesLockLockVehicleInternalServerErrorResponseBody": ".vehicles_lock_lock_vehicle_internal_server_error_response_body",
    "VehiclesLockLockVehicleMethodNotAllowedErrorResponseBody": ".vehicles_lock_lock_vehicle_method_not_allowed_error_response_body",
    "VehiclesLockLockVehicleNotFoundErrorResponseBody": ".vehicles_lock_lock_vehicle_not_found_error_response_body",
    "VehiclesLockLockVehicleNotImplementedErrorResponseBody": ".vehicles_lock_lock_vehicle_not_implemented_error_response_body",
    "VehiclesLockLockVehicleServiceUnavailableErrorResponseBody": ".vehicles_lock_lock_vehicle_service_unavailable_error_response_body",
    "VehiclesLockLockVehicleTooManyRequestsErrorResponseBody": ".vehicles_lock_lock_vehicle_too_many_requests_error_response_body",
    "VehiclesLockLockVehicleUnauthorizedErrorResponseBody": ".vehicles_lock_lock_vehicle_unauthorized_error_response_body",
    "VehiclesLockUnlockVehicleBadGatewayErrorResponseBody": ".vehicles_lock_unlock_vehicle_bad_gateway_error_response_body",
    "VehiclesLockUnlockVehicleGatewayTimeoutErrorResponseBody": ".vehicles_lock_unlock_vehicle_gateway_timeout_error_response_body",
    "VehiclesLockUnlockVehicleInternalServerErrorResponseBody": ".vehicles_lock_unlock_vehicle_internal_server_error_response_body",
    "VehiclesLockUnlockVehicleMethodNotAllowedErrorResponseBody": ".vehicles_lock_unlock_vehicle_method_not_allowed_error_response_body",
    "VehiclesLockUnlockVehicleNotFoundErrorResponseBody": ".vehicles_lock_unlock_vehicle_not_found_error_response_body",
    "VehiclesLockUnlockVehicleNotImplementedErrorResponseBody": ".vehicles_lock_unlock_vehicle_not_implemented_error_response_body",
    "VehiclesLockUnlockVehicleServiceUnavailableErrorResponseBody": ".vehicles_lock_unlock_vehicle_service_unavailable_error_response_body",
    "VehiclesLockUnlockVehicleTooManyRequestsErrorResponseBody": ".vehicles_lock_unlock_vehicle_too_many_requests_error_response_body",
    "VehiclesLockUnlockVehicleUnauthorizedErrorResponseBody": ".vehicles_lock_unlock_vehicle_unauthorized_error_response_body",
    "VertexRequestBody": ".vertex_request_body",
    "VertexResponseBody": ".vertex_response_body",
    "VoiceCoachingSettingsObjectResponseBody": ".voice_coaching_settings_object_response_body",
    "VoiceCoachingSettingsObjectResponseBodyEventsToCoachItem": ".voice_coaching_settings_object_response_body_events_to_coach_item",
    "VoiceCoachingSettingsObjectResponseBodyLanguage": ".voice_coaching_settings_object_response_body_language",
    "WalkaroundPhotoObjectResponseBody": ".walkaround_photo_object_response_body",
    "WebhookParamsObjectRequestBody": ".webhook_params_object_request_body",
    "WebhookParamsObjectRequestBodyPayloadType": ".webhook_params_object_request_body_payload_type",
    "WebhookParamsObjectResponseBody": ".webhook_params_object_response_body",
    "WebhookParamsObjectResponseBodyPayloadType": ".webhook_params_object_response_body_payload_type",
    "WebhookResponseResponseBody": ".webhook_response_response_body",
    "WebhookResponseResponseBodyEventTypesItem": ".webhook_response_response_body_event_types_item",
    "WebhookResponseResponseBodyVersion": ".webhook_response_response_body_version",
    "WebhookRouteResponseObjectResponseBody": ".webhook_route_response_object_response_body",
    "WebhooksDeleteWebhookBadGatewayErrorResponseBody": ".webhooks_delete_webhook_bad_gateway_error_response_body",
    "WebhooksDeleteWebhookGatewayTimeoutErrorResponseBody": ".webhooks_delete_webhook_gateway_timeout_error_response_body",
    "WebhooksDeleteWebhookInternalServerErrorResponseBody": ".webhooks_delete_webhook_internal_server_error_response_body",
    "WebhooksDeleteWebhookMethodNotAllowedErrorResponseBody": ".webhooks_delete_webhook_method_not_allowed_error_response_body",
    "WebhooksDeleteWebhookNotFoundErrorResponseBody": ".webhooks_delete_webhook_not_found_error_response_body",
    "WebhooksDeleteWebhookNotImplementedErrorResponseBody": ".webhooks_delete_webhook_not_implemented_error_response_body",
    "WebhooksDeleteWebhookServiceUnavailableErrorResponseBody": ".webhooks_delete_webhook_service_unavailable_error_response_body",
    "WebhooksDeleteWebhookTooManyRequestsErrorResponseBody": ".webhooks_delete_webhook_too_many_requests_error_response_body",
    "WebhooksDeleteWebhookUnauthorizedErrorResponseBody": ".webhooks_delete_webhook_unauthorized_error_response_body",
    "WebhooksGetWebhookBadGatewayErrorResponseBody": ".webhooks_get_webhook_bad_gateway_error_response_body",
    "WebhooksGetWebhookGatewayTimeoutErrorResponseBody": ".webhooks_get_webhook_gateway_timeout_error_response_body",
    "WebhooksGetWebhookInternalServerErrorResponseBody": ".webhooks_get_webhook_internal_server_error_response_body",
    "WebhooksGetWebhookMethodNotAllowedErrorResponseBody": ".webhooks_get_webhook_method_not_allowed_error_response_body",
    "WebhooksGetWebhookNotFoundErrorResponseBody": ".webhooks_get_webhook_not_found_error_response_body",
    "WebhooksGetWebhookNotImplementedErrorResponseBody": ".webhooks_get_webhook_not_implemented_error_response_body",
    "WebhooksGetWebhookResponseBody": ".webhooks_get_webhook_response_body",
    "WebhooksGetWebhookResponseBodyEventTypesItem": ".webhooks_get_webhook_response_body_event_types_item",
    "WebhooksGetWebhookResponseBodyVersion": ".webhooks_get_webhook_response_body_version",
    "WebhooksGetWebhookServiceUnavailableErrorResponseBody": ".webhooks_get_webhook_service_unavailable_error_response_body",
    "WebhooksGetWebhookTooManyRequestsErrorResponseBody": ".webhooks_get_webhook_too_many_requests_error_response_body",
    "WebhooksGetWebhookUnauthorizedErrorResponseBody": ".webhooks_get_webhook_unauthorized_error_response_body",
    "WebhooksListWebhooksBadGatewayErrorResponseBody": ".webhooks_list_webhooks_bad_gateway_error_response_body",
    "WebhooksListWebhooksGatewayTimeoutErrorResponseBody": ".webhooks_list_webhooks_gateway_timeout_error_response_body",
    "WebhooksListWebhooksInternalServerErrorResponseBody": ".webhooks_list_webhooks_internal_server_error_response_body",
    "WebhooksListWebhooksMethodNotAllowedErrorResponseBody": ".webhooks_list_webhooks_method_not_allowed_error_response_body",
    "WebhooksListWebhooksNotFoundErrorResponseBody": ".webhooks_list_webhooks_not_found_error_response_body",
    "WebhooksListWebhooksNotImplementedErrorResponseBody": ".webhooks_list_webhooks_not_implemented_error_response_body",
    "WebhooksListWebhooksResponseBody": ".webhooks_list_webhooks_response_body",
    "WebhooksListWebhooksServiceUnavailableErrorResponseBody": ".webhooks_list_webhooks_service_unavailable_error_response_body",
    "WebhooksListWebhooksTooManyRequestsErrorResponseBody": ".webhooks_list_webhooks_too_many_requests_error_response_body",
    "WebhooksListWebhooksUnauthorizedErrorResponseBody": ".webhooks_list_webhooks_unauthorized_error_response_body",
    "WebhooksPatchWebhookBadGatewayErrorResponseBody": ".webhooks_patch_webhook_bad_gateway_error_response_body",
    "WebhooksPatchWebhookGatewayTimeoutErrorResponseBody": ".webhooks_patch_webhook_gateway_timeout_error_response_body",
    "WebhooksPatchWebhookInternalServerErrorResponseBody": ".webhooks_patch_webhook_internal_server_error_response_body",
    "WebhooksPatchWebhookMethodNotAllowedErrorResponseBody": ".webhooks_patch_webhook_method_not_allowed_error_response_body",
    "WebhooksPatchWebhookNotFoundErrorResponseBody": ".webhooks_patch_webhook_not_found_error_response_body",
    "WebhooksPatchWebhookNotImplementedErrorResponseBody": ".webhooks_patch_webhook_not_implemented_error_response_body",
    "WebhooksPatchWebhookResponseBody": ".webhooks_patch_webhook_response_body",
    "WebhooksPatchWebhookResponseBodyEventTypesItem": ".webhooks_patch_webhook_response_body_event_types_item",
    "WebhooksPatchWebhookResponseBodyVersion": ".webhooks_patch_webhook_response_body_version",
    "WebhooksPatchWebhookServiceUnavailableErrorResponseBody": ".webhooks_patch_webhook_service_unavailable_error_response_body",
    "WebhooksPatchWebhookTooManyRequestsErrorResponseBody": ".webhooks_patch_webhook_too_many_requests_error_response_body",
    "WebhooksPatchWebhookUnauthorizedErrorResponseBody": ".webhooks_patch_webhook_unauthorized_error_response_body",
    "WebhooksPostWebhooksBadGatewayErrorResponseBody": ".webhooks_post_webhooks_bad_gateway_error_response_body",
    "WebhooksPostWebhooksGatewayTimeoutErrorResponseBody": ".webhooks_post_webhooks_gateway_timeout_error_response_body",
    "WebhooksPostWebhooksInternalServerErrorResponseBody": ".webhooks_post_webhooks_internal_server_error_response_body",
    "WebhooksPostWebhooksMethodNotAllowedErrorResponseBody": ".webhooks_post_webhooks_method_not_allowed_error_response_body",
    "WebhooksPostWebhooksNotFoundErrorResponseBody": ".webhooks_post_webhooks_not_found_error_response_body",
    "WebhooksPostWebhooksNotImplementedErrorResponseBody": ".webhooks_post_webhooks_not_implemented_error_response_body",
    "WebhooksPostWebhooksResponseBody": ".webhooks_post_webhooks_response_body",
    "WebhooksPostWebhooksResponseBodyEventTypesItem": ".webhooks_post_webhooks_response_body_event_types_item",
    "WebhooksPostWebhooksResponseBodyVersion": ".webhooks_post_webhooks_response_body_version",
    "WebhooksPostWebhooksServiceUnavailableErrorResponseBody": ".webhooks_post_webhooks_service_unavailable_error_response_body",
    "WebhooksPostWebhooksTooManyRequestsErrorResponseBody": ".webhooks_post_webhooks_too_many_requests_error_response_body",
    "WebhooksPostWebhooksUnauthorizedErrorResponseBody": ".webhooks_post_webhooks_unauthorized_error_response_body",
    "WorkOrderAttachmentObjectResponseBody": ".work_order_attachment_object_response_body",
    "WorkOrderAttachmentObjectResponseBodyProcessingStatus": ".work_order_attachment_object_response_body_processing_status",
    "WorkOrderDiscountObjectRequestBody": ".work_order_discount_object_request_body",
    "WorkOrderDiscountObjectResponseBody": ".work_order_discount_object_response_body",
    "WorkOrderItemObjectRequestBody": ".work_order_item_object_request_body",
    "WorkOrderItemObjectRequestBodyType": ".work_order_item_object_request_body_type",
    "WorkOrderItemObjectResponseBody": ".work_order_item_object_response_body",
    "WorkOrderItemObjectResponseBodyType": ".work_order_item_object_response_body_type",
    "WorkOrderMoneyObjectRequestBody": ".work_order_money_object_request_body",
    "WorkOrderMoneyObjectRequestBodyCurrency": ".work_order_money_object_request_body_currency",
    "WorkOrderMoneyObjectResponseBody": ".work_order_money_object_response_body",
    "WorkOrderMoneyObjectResponseBodyCurrency": ".work_order_money_object_response_body_currency",
    "WorkOrderObjectResponseBody": ".work_order_object_response_body",
    "WorkOrderObjectResponseBodyPriority": ".work_order_object_response_body_priority",
    "WorkOrderObjectResponseBodyStatus": ".work_order_object_response_body_status",
    "WorkOrderTaxCreateObjectRequestBody": ".work_order_tax_create_object_request_body",
    "WorkOrderTaxObjectRequestBody": ".work_order_tax_object_request_body",
    "WorkOrderTaxObjectResponseBody": ".work_order_tax_object_response_body",
    "WorkOrderUnallocatedLaborObjectResponseBody": ".work_order_unallocated_labor_object_response_body",
    "WorkOrdersDeleteWorkOrdersBadGatewayErrorResponseBody": ".work_orders_delete_work_orders_bad_gateway_error_response_body",
    "WorkOrdersDeleteWorkOrdersGatewayTimeoutErrorResponseBody": ".work_orders_delete_work_orders_gateway_timeout_error_response_body",
    "WorkOrdersDeleteWorkOrdersInternalServerErrorResponseBody": ".work_orders_delete_work_orders_internal_server_error_response_body",
    "WorkOrdersDeleteWorkOrdersMethodNotAllowedErrorResponseBody": ".work_orders_delete_work_orders_method_not_allowed_error_response_body",
    "WorkOrdersDeleteWorkOrdersNotFoundErrorResponseBody": ".work_orders_delete_work_orders_not_found_error_response_body",
    "WorkOrdersDeleteWorkOrdersNotImplementedErrorResponseBody": ".work_orders_delete_work_orders_not_implemented_error_response_body",
    "WorkOrdersDeleteWorkOrdersServiceUnavailableErrorResponseBody": ".work_orders_delete_work_orders_service_unavailable_error_response_body",
    "WorkOrdersDeleteWorkOrdersTooManyRequestsErrorResponseBody": ".work_orders_delete_work_orders_too_many_requests_error_response_body",
    "WorkOrdersDeleteWorkOrdersUnauthorizedErrorResponseBody": ".work_orders_delete_work_orders_unauthorized_error_response_body",
    "WorkOrdersGetServiceTasksBadGatewayErrorResponseBody": ".work_orders_get_service_tasks_bad_gateway_error_response_body",
    "WorkOrdersGetServiceTasksGatewayTimeoutErrorResponseBody": ".work_orders_get_service_tasks_gateway_timeout_error_response_body",
    "WorkOrdersGetServiceTasksInternalServerErrorResponseBody": ".work_orders_get_service_tasks_internal_server_error_response_body",
    "WorkOrdersGetServiceTasksMethodNotAllowedErrorResponseBody": ".work_orders_get_service_tasks_method_not_allowed_error_response_body",
    "WorkOrdersGetServiceTasksNotFoundErrorResponseBody": ".work_orders_get_service_tasks_not_found_error_response_body",
    "WorkOrdersGetServiceTasksNotImplementedErrorResponseBody": ".work_orders_get_service_tasks_not_implemented_error_response_body",
    "WorkOrdersGetServiceTasksResponseBody": ".work_orders_get_service_tasks_response_body",
    "WorkOrdersGetServiceTasksServiceUnavailableErrorResponseBody": ".work_orders_get_service_tasks_service_unavailable_error_response_body",
    "WorkOrdersGetServiceTasksTooManyRequestsErrorResponseBody": ".work_orders_get_service_tasks_too_many_requests_error_response_body",
    "WorkOrdersGetServiceTasksUnauthorizedErrorResponseBody": ".work_orders_get_service_tasks_unauthorized_error_response_body",
    "WorkOrdersGetWorkOrdersBadGatewayErrorResponseBody": ".work_orders_get_work_orders_bad_gateway_error_response_body",
    "WorkOrdersGetWorkOrdersGatewayTimeoutErrorResponseBody": ".work_orders_get_work_orders_gateway_timeout_error_response_body",
    "WorkOrdersGetWorkOrdersInternalServerErrorResponseBody": ".work_orders_get_work_orders_internal_server_error_response_body",
    "WorkOrdersGetWorkOrdersMethodNotAllowedErrorResponseBody": ".work_orders_get_work_orders_method_not_allowed_error_response_body",
    "WorkOrdersGetWorkOrdersNotFoundErrorResponseBody": ".work_orders_get_work_orders_not_found_error_response_body",
    "WorkOrdersGetWorkOrdersNotImplementedErrorResponseBody": ".work_orders_get_work_orders_not_implemented_error_response_body",
    "WorkOrdersGetWorkOrdersResponseBody": ".work_orders_get_work_orders_response_body",
    "WorkOrdersGetWorkOrdersServiceUnavailableErrorResponseBody": ".work_orders_get_work_orders_service_unavailable_error_response_body",
    "WorkOrdersGetWorkOrdersTooManyRequestsErrorResponseBody": ".work_orders_get_work_orders_too_many_requests_error_response_body",
    "WorkOrdersGetWorkOrdersUnauthorizedErrorResponseBody": ".work_orders_get_work_orders_unauthorized_error_response_body",
    "WorkOrdersPatchWorkOrdersBadGatewayErrorResponseBody": ".work_orders_patch_work_orders_bad_gateway_error_response_body",
    "WorkOrdersPatchWorkOrdersGatewayTimeoutErrorResponseBody": ".work_orders_patch_work_orders_gateway_timeout_error_response_body",
    "WorkOrdersPatchWorkOrdersInternalServerErrorResponseBody": ".work_orders_patch_work_orders_internal_server_error_response_body",
    "WorkOrdersPatchWorkOrdersMethodNotAllowedErrorResponseBody": ".work_orders_patch_work_orders_method_not_allowed_error_response_body",
    "WorkOrdersPatchWorkOrdersNotFoundErrorResponseBody": ".work_orders_patch_work_orders_not_found_error_response_body",
    "WorkOrdersPatchWorkOrdersNotImplementedErrorResponseBody": ".work_orders_patch_work_orders_not_implemented_error_response_body",
    "WorkOrdersPatchWorkOrdersResponseBody": ".work_orders_patch_work_orders_response_body",
    "WorkOrdersPatchWorkOrdersServiceUnavailableErrorResponseBody": ".work_orders_patch_work_orders_service_unavailable_error_response_body",
    "WorkOrdersPatchWorkOrdersTooManyRequestsErrorResponseBody": ".work_orders_patch_work_orders_too_many_requests_error_response_body",
    "WorkOrdersPatchWorkOrdersUnauthorizedErrorResponseBody": ".work_orders_patch_work_orders_unauthorized_error_response_body",
    "WorkOrdersPostInvoiceScanBadGatewayErrorResponseBody": ".work_orders_post_invoice_scan_bad_gateway_error_response_body",
    "WorkOrdersPostInvoiceScanGatewayTimeoutErrorResponseBody": ".work_orders_post_invoice_scan_gateway_timeout_error_response_body",
    "WorkOrdersPostInvoiceScanInternalServerErrorResponseBody": ".work_orders_post_invoice_scan_internal_server_error_response_body",
    "WorkOrdersPostInvoiceScanMethodNotAllowedErrorResponseBody": ".work_orders_post_invoice_scan_method_not_allowed_error_response_body",
    "WorkOrdersPostInvoiceScanNotFoundErrorResponseBody": ".work_orders_post_invoice_scan_not_found_error_response_body",
    "WorkOrdersPostInvoiceScanNotImplementedErrorResponseBody": ".work_orders_post_invoice_scan_not_implemented_error_response_body",
    "WorkOrdersPostInvoiceScanResponseBody": ".work_orders_post_invoice_scan_response_body",
    "WorkOrdersPostInvoiceScanServiceUnavailableErrorResponseBody": ".work_orders_post_invoice_scan_service_unavailable_error_response_body",
    "WorkOrdersPostInvoiceScanTooManyRequestsErrorResponseBody": ".work_orders_post_invoice_scan_too_many_requests_error_response_body",
    "WorkOrdersPostInvoiceScanUnauthorizedErrorResponseBody": ".work_orders_post_invoice_scan_unauthorized_error_response_body",
    "WorkOrdersPostWorkOrdersBadGatewayErrorResponseBody": ".work_orders_post_work_orders_bad_gateway_error_response_body",
    "WorkOrdersPostWorkOrdersGatewayTimeoutErrorResponseBody": ".work_orders_post_work_orders_gateway_timeout_error_response_body",
    "WorkOrdersPostWorkOrdersInternalServerErrorResponseBody": ".work_orders_post_work_orders_internal_server_error_response_body",
    "WorkOrdersPostWorkOrdersMethodNotAllowedErrorResponseBody": ".work_orders_post_work_orders_method_not_allowed_error_response_body",
    "WorkOrdersPostWorkOrdersNotFoundErrorResponseBody": ".work_orders_post_work_orders_not_found_error_response_body",
    "WorkOrdersPostWorkOrdersNotImplementedErrorResponseBody": ".work_orders_post_work_orders_not_implemented_error_response_body",
    "WorkOrdersPostWorkOrdersResponseBody": ".work_orders_post_work_orders_response_body",
    "WorkOrdersPostWorkOrdersServiceUnavailableErrorResponseBody": ".work_orders_post_work_orders_service_unavailable_error_response_body",
    "WorkOrdersPostWorkOrdersTooManyRequestsErrorResponseBody": ".work_orders_post_work_orders_too_many_requests_error_response_body",
    "WorkOrdersPostWorkOrdersUnauthorizedErrorResponseBody": ".work_orders_post_work_orders_unauthorized_error_response_body",
    "WorkOrdersStreamWorkOrdersBadGatewayErrorResponseBody": ".work_orders_stream_work_orders_bad_gateway_error_response_body",
    "WorkOrdersStreamWorkOrdersGatewayTimeoutErrorResponseBody": ".work_orders_stream_work_orders_gateway_timeout_error_response_body",
    "WorkOrdersStreamWorkOrdersInternalServerErrorResponseBody": ".work_orders_stream_work_orders_internal_server_error_response_body",
    "WorkOrdersStreamWorkOrdersMethodNotAllowedErrorResponseBody": ".work_orders_stream_work_orders_method_not_allowed_error_response_body",
    "WorkOrdersStreamWorkOrdersNotFoundErrorResponseBody": ".work_orders_stream_work_orders_not_found_error_response_body",
    "WorkOrdersStreamWorkOrdersNotImplementedErrorResponseBody": ".work_orders_stream_work_orders_not_implemented_error_response_body",
    "WorkOrdersStreamWorkOrdersResponseBody": ".work_orders_stream_work_orders_response_body",
    "WorkOrdersStreamWorkOrdersServiceUnavailableErrorResponseBody": ".work_orders_stream_work_orders_service_unavailable_error_response_body",
    "WorkOrdersStreamWorkOrdersTooManyRequestsErrorResponseBody": ".work_orders_stream_work_orders_too_many_requests_error_response_body",
    "WorkOrdersStreamWorkOrdersUnauthorizedErrorResponseBody": ".work_orders_stream_work_orders_unauthorized_error_response_body",
    "WorkerSafetySosDataResponseBody": ".worker_safety_sos_data_response_body",
    "WorkerSafetySosDataResponseBodySourceType": ".worker_safety_sos_data_response_body_source_type",
    "WorkflowAddressEventWithGeofenceObjectResponseBody": ".workflow_address_event_with_geofence_object_response_body",
    "WorkflowAuthorSignatureObjectResponseBody": ".workflow_author_signature_object_response_body",
    "WorkflowAuthorSignatureObjectResponseBodyType": ".workflow_author_signature_object_response_body_type",
    "WorkflowCircleResponseBody": ".workflow_circle_response_body",
    "WorkflowDvirObjectResponseBody": ".workflow_dvir_object_response_body",
    "WorkflowDvirObjectResponseBodySafetyStatus": ".workflow_dvir_object_response_body_safety_status",
    "WorkflowDvirObjectResponseBodyType": ".workflow_dvir_object_response_body_type",
    "WorkflowDvirSubmittedResponseObjectResponseBody": ".workflow_dvir_submitted_response_object_response_body",
    "WorkflowGeofenceEventResponseObjectResponseBody": ".workflow_geofence_event_response_object_response_body",
    "WorkflowGeofenceResponseBody": ".workflow_geofence_response_body",
    "WorkflowIncidentConditionObjectResponseBody": ".workflow_incident_condition_object_response_body",
    "WorkflowIncidentDetailsObjectResponseBody": ".workflow_incident_details_object_response_body",
    "WorkflowPolygonResponseBody": ".workflow_polygon_response_body",
    "WorkflowSignatoryUserObjectResponseBody": ".workflow_signatory_user_object_response_body",
    "WorkflowTriggerObjectRequestBody": ".workflow_trigger_object_request_body",
    "WorkflowTriggerObjectResponseBody": ".workflow_trigger_object_response_body",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AccessoryResponseObjectResponseBody",
    "ActionObjectRequestBody",
    "ActionObjectResponseBody",
    "ActionParamsObjectRequestBody",
    "ActionParamsObjectResponseBody",
    "Address",
    "AddressAddressTypesItem",
    "AddressExternalIds",
    "AddressGeofence",
    "AddressGeofenceCircle",
    "AddressGeofencePolygon",
    "AddressGeofencePolygonVertices",
    "AddressGeofenceSettings",
    "AddressResponse",
    "AddressResponseResponseBody",
    "AddressTinyResponse",
    "AdvancedIdlingGetIdlingEventsBadGatewayErrorResponseBody",
    "AdvancedIdlingGetIdlingEventsGatewayTimeoutErrorResponseBody",
    "AdvancedIdlingGetIdlingEventsInternalServerErrorResponseBody",
    "AdvancedIdlingGetIdlingEventsMethodNotAllowedErrorResponseBody",
    "AdvancedIdlingGetIdlingEventsNotFoundErrorResponseBody",
    "AdvancedIdlingGetIdlingEventsNotImplementedErrorResponseBody",
    "AdvancedIdlingGetIdlingEventsResponseBody",
    "AdvancedIdlingGetIdlingEventsServiceUnavailableErrorResponseBody",
    "AdvancedIdlingGetIdlingEventsTooManyRequestsErrorResponseBody",
    "AdvancedIdlingGetIdlingEventsUnauthorizedErrorResponseBody",
    "AempEquipmentGetAempEquipmentListBadGatewayErrorResponseBody",
    "AempEquipmentGetAempEquipmentListGatewayTimeoutErrorResponseBody",
    "AempEquipmentGetAempEquipmentListInternalServerErrorResponseBody",
    "AempEquipmentGetAempEquipmentListMethodNotAllowedErrorResponseBody",
    "AempEquipmentGetAempEquipmentListNotFoundErrorResponseBody",
    "AempEquipmentGetAempEquipmentListNotImplementedErrorResponseBody",
    "AempEquipmentGetAempEquipmentListResponseBody",
    "AempEquipmentGetAempEquipmentListServiceUnavailableErrorResponseBody",
    "AempEquipmentGetAempEquipmentListTooManyRequestsErrorResponseBody",
    "AempEquipmentGetAempEquipmentListUnauthorizedErrorResponseBody",
    "AempEquipmentWithAdditionalFieldsResponseBody",
    "AempFleetListResponseBody",
    "AempLinkResponseBody",
    "AlertObjectAssetResponseBody",
    "AlertObjectAssetResponseBodyType",
    "AlertObjectDriverResponseBody",
    "AlertObjectMachineInputResponseBody",
    "AlertObjectOnvifCameraStreamResponseBody",
    "AlertObjectProductResponseBody",
    "AlertObjectSensorResponseBody",
    "AlertObjectSitesResponseBody",
    "AlertObjectTrailerResponseBody",
    "AlertObjectVehicleResponseBody",
    "AlertObjectWorkforceCameraDeviceResponseBody",
    "AlertsDeleteConfigurationsBadGatewayErrorResponseBody",
    "AlertsDeleteConfigurationsGatewayTimeoutErrorResponseBody",
    "AlertsDeleteConfigurationsInternalServerErrorResponseBody",
    "AlertsDeleteConfigurationsMethodNotAllowedErrorResponseBody",
    "AlertsDeleteConfigurationsNotFoundErrorResponseBody",
    "AlertsDeleteConfigurationsNotImplementedErrorResponseBody",
    "AlertsDeleteConfigurationsServiceUnavailableErrorResponseBody",
    "AlertsDeleteConfigurationsTooManyRequestsErrorResponseBody",
    "AlertsDeleteConfigurationsUnauthorizedErrorResponseBody",
    "AlertsGetConfigurationsBadGatewayErrorResponseBody",
    "AlertsGetConfigurationsGatewayTimeoutErrorResponseBody",
    "AlertsGetConfigurationsInternalServerErrorResponseBody",
    "AlertsGetConfigurationsMethodNotAllowedErrorResponseBody",
    "AlertsGetConfigurationsNotFoundErrorResponseBody",
    "AlertsGetConfigurationsNotImplementedErrorResponseBody",
    "AlertsGetConfigurationsResponseBody",
    "AlertsGetConfigurationsServiceUnavailableErrorResponseBody",
    "AlertsGetConfigurationsTooManyRequestsErrorResponseBody",
    "AlertsGetConfigurationsUnauthorizedErrorResponseBody",
    "AlertsGetIncidentsBadGatewayErrorResponseBody",
    "AlertsGetIncidentsGatewayTimeoutErrorResponseBody",
    "AlertsGetIncidentsInternalServerErrorResponseBody",
    "AlertsGetIncidentsMethodNotAllowedErrorResponseBody",
    "AlertsGetIncidentsNotFoundErrorResponseBody",
    "AlertsGetIncidentsNotImplementedErrorResponseBody",
    "AlertsGetIncidentsResponseBody",
    "AlertsGetIncidentsServiceUnavailableErrorResponseBody",
    "AlertsGetIncidentsTooManyRequestsErrorResponseBody",
    "AlertsGetIncidentsUnauthorizedErrorResponseBody",
    "AlertsPatchConfigurationsBadGatewayErrorResponseBody",
    "AlertsPatchConfigurationsGatewayTimeoutErrorResponseBody",
    "AlertsPatchConfigurationsInternalServerErrorResponseBody",
    "AlertsPatchConfigurationsMethodNotAllowedErrorResponseBody",
    "AlertsPatchConfigurationsNotFoundErrorResponseBody",
    "AlertsPatchConfigurationsNotImplementedErrorResponseBody",
    "AlertsPatchConfigurationsResponseBody",
    "AlertsPatchConfigurationsServiceUnavailableErrorResponseBody",
    "AlertsPatchConfigurationsTooManyRequestsErrorResponseBody",
    "AlertsPatchConfigurationsUnauthorizedErrorResponseBody",
    "AlertsPostConfigurationsBadGatewayErrorResponseBody",
    "AlertsPostConfigurationsGatewayTimeoutErrorResponseBody",
    "AlertsPostConfigurationsInternalServerErrorResponseBody",
    "AlertsPostConfigurationsMethodNotAllowedErrorResponseBody",
    "AlertsPostConfigurationsNotFoundErrorResponseBody",
    "AlertsPostConfigurationsNotImplementedErrorResponseBody",
    "AlertsPostConfigurationsResponseBody",
    "AlertsPostConfigurationsServiceUnavailableErrorResponseBody",
    "AlertsPostConfigurationsTooManyRequestsErrorResponseBody",
    "AlertsPostConfigurationsUnauthorizedErrorResponseBody",
    "AmbientTemperatureDetailsObjectRequestBody",
    "AmbientTemperatureDetailsObjectRequestBodyOperation",
    "AmbientTemperatureDetailsObjectResponseBody",
    "AmbientTemperatureDetailsObjectResponseBodyOperation",
    "AmbientTemperatureResponseBody",
    "AnticipationBrakeEventCount",
    "AppointmentWindowRequestBody",
    "AppointmentWindowResponseBody",
    "AssetDataInput",
    "AssetDataInputLastPoint",
    "AssetDataOutput",
    "AssetDataOutputsPatchAssetDataOutputsBadGatewayErrorResponseBody",
    "AssetDataOutputsPatchAssetDataOutputsGatewayTimeoutErrorResponseBody",
    "AssetDataOutputsPatchAssetDataOutputsInternalServerErrorResponseBody",
    "AssetDataOutputsPatchAssetDataOutputsMethodNotAllowedErrorResponseBody",
    "AssetDataOutputsPatchAssetDataOutputsNotFoundErrorResponseBody",
    "AssetDataOutputsPatchAssetDataOutputsNotImplementedErrorResponseBody",
    "AssetDataOutputsPatchAssetDataOutputsResponseBody",
    "AssetDataOutputsPatchAssetDataOutputsServiceUnavailableErrorResponseBody",
    "AssetDataOutputsPatchAssetDataOutputsTooManyRequestsErrorResponseBody",
    "AssetDataOutputsPatchAssetDataOutputsUnauthorizedErrorResponseBody",
    "AssetLocation",
    "AssetLocationHeading",
    "AssetLocationSpeed",
    "AssetName",
    "AssetResponse",
    "AssetResponseBody",
    "AssetResponseBodyRegulationMode",
    "AssetResponseBodyType",
    "AssetResponseLocationDataInput",
    "AssetResponseParentAsset",
    "AssetResponseResponseBody",
    "AssetResponseRunningStatusDataInput",
    "AssetsCreateAssetBadGatewayErrorResponseBody",
    "AssetsCreateAssetGatewayTimeoutErrorResponseBody",
    "AssetsCreateAssetInternalServerErrorResponseBody",
    "AssetsCreateAssetMethodNotAllowedErrorResponseBody",
    "AssetsCreateAssetNotFoundErrorResponseBody",
    "AssetsCreateAssetNotImplementedErrorResponseBody",
    "AssetsCreateAssetResponseBody",
    "AssetsCreateAssetServiceUnavailableErrorResponseBody",
    "AssetsCreateAssetTooManyRequestsErrorResponseBody",
    "AssetsCreateAssetUnauthorizedErrorResponseBody",
    "AssetsDeleteAssetBadGatewayErrorResponseBody",
    "AssetsDeleteAssetGatewayTimeoutErrorResponseBody",
    "AssetsDeleteAssetInternalServerErrorResponseBody",
    "AssetsDeleteAssetMethodNotAllowedErrorResponseBody",
    "AssetsDeleteAssetNotFoundErrorResponseBody",
    "AssetsDeleteAssetNotImplementedErrorResponseBody",
    "AssetsDeleteAssetServiceUnavailableErrorResponseBody",
    "AssetsDeleteAssetTooManyRequestsErrorResponseBody",
    "AssetsDeleteAssetUnauthorizedErrorResponseBody",
    "AssetsInputsAssetResponseResponseBody",
    "AssetsInputsAuxInputResponseBody",
    "AssetsInputsGetAssetsInputsBadGatewayErrorResponseBody",
    "AssetsInputsGetAssetsInputsGatewayTimeoutErrorResponseBody",
    "AssetsInputsGetAssetsInputsInternalServerErrorResponseBody",
    "AssetsInputsGetAssetsInputsMethodNotAllowedErrorResponseBody",
    "AssetsInputsGetAssetsInputsNotFoundErrorResponseBody",
    "AssetsInputsGetAssetsInputsNotImplementedErrorResponseBody",
    "AssetsInputsGetAssetsInputsResponseBody",
    "AssetsInputsGetAssetsInputsServiceUnavailableErrorResponseBody",
    "AssetsInputsGetAssetsInputsTooManyRequestsErrorResponseBody",
    "AssetsInputsGetAssetsInputsUnauthorizedErrorResponseBody",
    "AssetsInputsResponseResponseBody",
    "AssetsInputsResponseResponseBodyUnits",
    "AssetsListAssetsBadGatewayErrorResponseBody",
    "AssetsListAssetsGatewayTimeoutErrorResponseBody",
    "AssetsListAssetsInternalServerErrorResponseBody",
    "AssetsListAssetsMethodNotAllowedErrorResponseBody",
    "AssetsListAssetsNotFoundErrorResponseBody",
    "AssetsListAssetsNotImplementedErrorResponseBody",
    "AssetsListAssetsResponseBody",
    "AssetsListAssetsServiceUnavailableErrorResponseBody",
    "AssetsListAssetsTooManyRequestsErrorResponseBody",
    "AssetsListAssetsUnauthorizedErrorResponseBody",
    "AssetsLocationLinkConfigAddressDetailsObject",
    "AssetsLocationLinkConfigAddressDetailsObjectResponseBody",
    "AssetsLocationLinkRequestConfigObject",
    "AssetsLocationLinkResponseConfigObjectResponseBody",
    "AssetsNearLocationLinkConfigObject",
    "AssetsNearLocationLinkConfigObjectResponseBody",
    "AssetsOnRouteLinkConfigObject",
    "AssetsOnRouteLinkConfigObjectResponseBody",
    "AssetsUpdateAssetBadGatewayErrorResponseBody",
    "AssetsUpdateAssetGatewayTimeoutErrorResponseBody",
    "AssetsUpdateAssetInternalServerErrorResponseBody",
    "AssetsUpdateAssetMethodNotAllowedErrorResponseBody",
    "AssetsUpdateAssetNotFoundErrorResponseBody",
    "AssetsUpdateAssetNotImplementedErrorResponseBody",
    "AssetsUpdateAssetResponseBody",
    "AssetsUpdateAssetServiceUnavailableErrorResponseBody",
    "AssetsUpdateAssetTooManyRequestsErrorResponseBody",
    "AssetsUpdateAssetUnauthorizedErrorResponseBody",
    "Attribute",
    "AttributeAttributeType",
    "AttributeEntity",
    "AttributeEntityExternalIds",
    "AttributeEntityType",
    "AttributeExpanded",
    "AttributeExpandedAllOf",
    "AttributeExpandedResponse",
    "AttributeTiny",
    "AttributeUnit",
    "AttributeValueTiny",
    "AuthTokenAuthTokenBadGatewayErrorResponseBody",
    "AuthTokenAuthTokenGatewayTimeoutErrorResponseBody",
    "AuthTokenAuthTokenInternalServerErrorResponseBody",
    "AuthTokenAuthTokenMethodNotAllowedErrorResponseBody",
    "AuthTokenAuthTokenNotFoundErrorResponseBody",
    "AuthTokenAuthTokenNotImplementedErrorResponseBody",
    "AuthTokenAuthTokenResponseBody",
    "AuthTokenAuthTokenServiceUnavailableErrorResponseBody",
    "AuthTokenAuthTokenTooManyRequestsErrorResponseBody",
    "AuthTokenAuthTokenUnauthorizedErrorResponseBody",
    "AuthTokenForDriverResponseResponseBody",
    "AuthorSignatureObjectResponseBody",
    "AuthorSignatureObjectResponseBodyType",
    "BarcodeValueObjectRequestBody",
    "BarcodeValueObjectResponseBody",
    "BaseRouteResponseObjectResponseBody",
    "BehaviorCountDetailsRequestBody",
    "BehaviorCountDetailsRequestBodyComparison",
    "BehaviorCountDetailsResponseBody",
    "BehaviorCountDetailsResponseBodyComparison",
    "BehaviorResponseBody",
    "BehaviorResponseBodyCoachableBehaviorType",
    "CameraConnectorDisconectedResponseBody",
    "CameraDetailsResponseResponseBody",
    "CameraSerial",
    "CameraStreamIssueResponseBody",
    "CarrierProposedAssignment",
    "CarrierProposedAssignmentAcceptedTime",
    "CarrierProposedAssignmentActiveTime",
    "CarrierProposedAssignmentDriver",
    "CarrierProposedAssignmentDriverAllOf",
    "CarrierProposedAssignmentDriverAllOf2ExternalIds",
    "CarrierProposedAssignmentFirstSeenTime",
    "CarrierProposedAssignmentId",
    "CarrierProposedAssignmentRejectedTime",
    "CarrierProposedAssignmentResponse",
    "CarrierProposedAssignmentShippingDocs",
    "CarrierProposedAssignmentTrailer",
    "CarrierProposedAssignmentTrailers",
    "CarrierProposedAssignmentVehicle",
    "CellConnectivityResponseResponseBody",
    "CellConnectivityResponseResponseBodySignalBar",
    "CellSignalLossDetailsObjectRequestBody",
    "CellSignalLossDetailsObjectResponseBody",
    "CellSignalLossResponseBody",
    "CircleRequestBody",
    "CircleResponseBody",
    "CloudBackupUploadIssueResponseBody",
    "CoachAssignmentWithDriverExternalIdsResponseResponseBody",
    "CoachAssignmentWithoutDriverExternalIdsResponseResponseBody",
    "CoachableEventResponseBody",
    "CoachingSessionsGetCoachingSessionsBadGatewayErrorResponseBody",
    "CoachingSessionsGetCoachingSessionsGatewayTimeoutErrorResponseBody",
    "CoachingSessionsGetCoachingSessionsInternalServerErrorResponseBody",
    "CoachingSessionsGetCoachingSessionsMethodNotAllowedErrorResponseBody",
    "CoachingSessionsGetCoachingSessionsNotFoundErrorResponseBody",
    "CoachingSessionsGetCoachingSessionsNotImplementedErrorResponseBody",
    "CoachingSessionsGetCoachingSessionsResponseBody",
    "CoachingSessionsGetCoachingSessionsServiceUnavailableErrorResponseBody",
    "CoachingSessionsGetCoachingSessionsTooManyRequestsErrorResponseBody",
    "CoachingSessionsGetCoachingSessionsUnauthorizedErrorResponseBody",
    "CoachingSessionsResponseResponseBody",
    "CoachingSessionsResponseResponseBodyCoachingType",
    "CoachingSessionsResponseResponseBodySessionStatus",
    "CoastingDurationMs",
    "ColumnResponseBody",
    "ColumnResponseBodyDataType",
    "ColumnResponseBodyUnit",
    "ConditionalFieldSectionObjectResponseBody",
    "ConnectionStatusResponseObjectResponseBody",
    "ConnectionStatusResponseObjectResponseBodyHealthStatus",
    "Contact",
    "ContactEmail",
    "ContactFirstName",
    "ContactId",
    "ContactLastName",
    "ContactPhone",
    "ContactResponse",
    "ContactTinyResponse",
    "ContinuousReadingAlertThresholdResponseBody",
    "ContinuousReadingAlertThresholdResponseBodyOperation",
    "ContinuousReadingAlertThresholdResponseBodyUnit",
    "CreateAddressRequestGeofence",
    "CreateAddressRequestGeofenceSettings",
    "CreateAttributeRequestEntities",
    "CreateDriverAuthTokenResponseResponseBody",
    "CreateDriverRequestAttributes",
    "CreateReportConfigColumnRequestBody",
    "CreateReportConfigObjectRequestBody",
    "CreateRoutesStopRequestObjectRequestBody",
    "CreateUserRequestRoles",
    "CruiseControlDurationMs",
    "CumulativeOperatingHoursResponseBody",
    "CurrentDutyStatus",
    "CurrentDutyStatusHosStatusType",
    "CustomHeadersObjectRequestBody",
    "CustomHeadersObjectResponseBody",
    "CustomMetadata",
    "DashcamDisconnectedResponseBody",
    "DataInputListResponse",
    "DataInputResponse",
    "DataInputResponseAllOf",
    "DataInputSnapshot",
    "DataInputSnapshotAllOf",
    "DataInputSnapshotResponse",
    "DataInputTinyResponse",
    "DataInputValueResponseBody",
    "DataInputsTinyResponse",
    "DataUsageResponseObjectResponseBody",
    "DateTimeValueObjectRequestBody",
    "DateTimeValueObjectResponseBody",
    "DefLevelTriggerDetailsObjectRequestBody",
    "DefLevelTriggerDetailsObjectRequestBodyOperation",
    "DefLevelTriggerDetailsObjectResponseBody",
    "DefLevelTriggerDetailsObjectResponseBodyOperation",
    "DefRemainingResponseBody",
    "Defect",
    "DefectPhotoResponseResponseBody",
    "DefectResolvedBy",
    "DefectResolvedByType",
    "DefectResponse",
    "DefectTrailer",
    "DefectTrailerResponseResponseBody",
    "DefectTypesResponseDataResponseBody",
    "DefectTypesResponseDataResponseBodySectionType",
    "DefectVehicle",
    "DefectVehicleResponseResponseBody",
    "DefectsResponse",
    "DefectsResponseDataResponseBody",
    "DepreciationGetDepreciationTransactionsBadGatewayErrorResponseBody",
    "DepreciationGetDepreciationTransactionsGatewayTimeoutErrorResponseBody",
    "DepreciationGetDepreciationTransactionsInternalServerErrorResponseBody",
    "DepreciationGetDepreciationTransactionsMethodNotAllowedErrorResponseBody",
    "DepreciationGetDepreciationTransactionsNotFoundErrorResponseBody",
    "DepreciationGetDepreciationTransactionsNotImplementedErrorResponseBody",
    "DepreciationGetDepreciationTransactionsResponseBody",
    "DepreciationGetDepreciationTransactionsServiceUnavailableErrorResponseBody",
    "DepreciationGetDepreciationTransactionsTooManyRequestsErrorResponseBody",
    "DepreciationGetDepreciationTransactionsUnauthorizedErrorResponseBody",
    "DepreciationTransactionMoneyObjectResponseBody",
    "DepreciationTransactionMoneyObjectResponseBodyCurrency",
    "DepreciationTransactionObjectResponseBody",
    "DepreciationTransactionObjectResponseBodyTransactionType",
    "DetectionLogAssetObjectResponseBody",
    "DetectionLogDetectionObjectResponseBody",
    "DetectionLogDetectionObjectResponseBodyTriggerDetectionLabel",
    "DetectionLogDriverObjectResponseBody",
    "DetectionLogGetDetectionsBadGatewayErrorResponseBody",
    "DetectionLogGetDetectionsGatewayTimeoutErrorResponseBody",
    "DetectionLogGetDetectionsInternalServerErrorResponseBody",
    "DetectionLogGetDetectionsMethodNotAllowedErrorResponseBody",
    "DetectionLogGetDetectionsNotFoundErrorResponseBody",
    "DetectionLogGetDetectionsNotImplementedErrorResponseBody",
    "DetectionLogGetDetectionsResponseBody",
    "DetectionLogGetDetectionsServiceUnavailableErrorResponseBody",
    "DetectionLogGetDetectionsTooManyRequestsErrorResponseBody",
    "DetectionLogGetDetectionsUnauthorizedErrorResponseBody",
    "DetectionLogSafetyEventObjectResponseBody",
    "DetectionLogSafetyEventObjectResponseBodyInboxFilterReason",
    "DeviceAssetResponseResponseBody",
    "DeviceMovementDataResponseBody",
    "DeviceMovementStoppedDataResponseBody",
    "DeviceMovementTriggerDetailsObjectRequestBody",
    "DeviceMovementTriggerDetailsObjectResponseBody",
    "DeviceResponseResponseBody",
    "DeviceResponseResponseBodyModel",
    "DevicesGetDevicesBadGatewayErrorResponseBody",
    "DevicesGetDevicesGatewayTimeoutErrorResponseBody",
    "DevicesGetDevicesInternalServerErrorResponseBody",
    "DevicesGetDevicesMethodNotAllowedErrorResponseBody",
    "DevicesGetDevicesNotFoundErrorResponseBody",
    "DevicesGetDevicesNotImplementedErrorResponseBody",
    "DevicesGetDevicesResponseBody",
    "DevicesGetDevicesServiceUnavailableErrorResponseBody",
    "DevicesGetDevicesTooManyRequestsErrorResponseBody",
    "DevicesGetDevicesUnauthorizedErrorResponseBody",
    "DistanceDrivenMeters",
    "DistanceResponseBody",
    "DistanceTraveledObjectResponseBody",
    "DistractedDrivingDetectionAlertSettingsObjectResponseBody",
    "DocumentPdfGenerationResponse",
    "DocumentPdfGenerationResponseData",
    "DocumentPdfQueryResponse",
    "DocumentPdfQueryResponseData",
    "DocumentPdfQueryResponseDataJobStatus",
    "DocumentResponseObjectResponseBody",
    "DocumentResponseObjectResponseBodyState",
    "DocumentTypesGetDocumentTypesBadGatewayErrorResponseBody",
    "DocumentTypesGetDocumentTypesGatewayTimeoutErrorResponseBody",
    "DocumentTypesGetDocumentTypesInternalServerErrorResponseBody",
    "DocumentTypesGetDocumentTypesMethodNotAllowedErrorResponseBody",
    "DocumentTypesGetDocumentTypesNotFoundErrorResponseBody",
    "DocumentTypesGetDocumentTypesNotImplementedErrorResponseBody",
    "DocumentTypesGetDocumentTypesResponseBody",
    "DocumentTypesGetDocumentTypesServiceUnavailableErrorResponseBody",
    "DocumentTypesGetDocumentTypesTooManyRequestsErrorResponseBody",
    "DocumentTypesGetDocumentTypesUnauthorizedErrorResponseBody",
    "DocumentsDeleteDocumentBadGatewayErrorResponseBody",
    "DocumentsDeleteDocumentGatewayTimeoutErrorResponseBody",
    "DocumentsDeleteDocumentInternalServerErrorResponseBody",
    "DocumentsDeleteDocumentMethodNotAllowedErrorResponseBody",
    "DocumentsDeleteDocumentNotFoundErrorResponseBody",
    "DocumentsDeleteDocumentNotImplementedErrorResponseBody",
    "DocumentsDeleteDocumentServiceUnavailableErrorResponseBody",
    "DocumentsDeleteDocumentTooManyRequestsErrorResponseBody",
    "DocumentsDeleteDocumentUnauthorizedErrorResponseBody",
    "DocumentsGetDocumentBadGatewayErrorResponseBody",
    "DocumentsGetDocumentGatewayTimeoutErrorResponseBody",
    "DocumentsGetDocumentInternalServerErrorResponseBody",
    "DocumentsGetDocumentMethodNotAllowedErrorResponseBody",
    "DocumentsGetDocumentNotFoundErrorResponseBody",
    "DocumentsGetDocumentNotImplementedErrorResponseBody",
    "DocumentsGetDocumentResponseBody",
    "DocumentsGetDocumentServiceUnavailableErrorResponseBody",
    "DocumentsGetDocumentTooManyRequestsErrorResponseBody",
    "DocumentsGetDocumentUnauthorizedErrorResponseBody",
    "DocumentsGetDocumentsBadGatewayErrorResponseBody",
    "DocumentsGetDocumentsGatewayTimeoutErrorResponseBody",
    "DocumentsGetDocumentsInternalServerErrorResponseBody",
    "DocumentsGetDocumentsMethodNotAllowedErrorResponseBody",
    "DocumentsGetDocumentsNotFoundErrorResponseBody",
    "DocumentsGetDocumentsNotImplementedErrorResponseBody",
    "DocumentsGetDocumentsResponseBody",
    "DocumentsGetDocumentsServiceUnavailableErrorResponseBody",
    "DocumentsGetDocumentsTooManyRequestsErrorResponseBody",
    "DocumentsGetDocumentsUnauthorizedErrorResponseBody",
    "DocumentsPostDocumentBadGatewayErrorResponseBody",
    "DocumentsPostDocumentGatewayTimeoutErrorResponseBody",
    "DocumentsPostDocumentInternalServerErrorResponseBody",
    "DocumentsPostDocumentMethodNotAllowedErrorResponseBody",
    "DocumentsPostDocumentNotFoundErrorResponseBody",
    "DocumentsPostDocumentNotImplementedErrorResponseBody",
    "DocumentsPostDocumentResponseBody",
    "DocumentsPostDocumentServiceUnavailableErrorResponseBody",
    "DocumentsPostDocumentTooManyRequestsErrorResponseBody",
    "DocumentsPostDocumentUnauthorizedErrorResponseBody",
    "DoorOpenResponseBody",
    "DriveTimeDurationMs",
    "Driver",
    "DriverActivationStatus",
    "DriverAppNotificationObjectRequestBody",
    "DriverAppNotificationObjectResponseBody",
    "DriverAppSettingsGamificationConfigTinyObjectRequestBody",
    "DriverAppSettingsGamificationConfigTinyObjectResponseBody",
    "DriverAppSettingsResponseObjectResponseBody",
    "DriverAppSettingsTrailerSelectionConfigTinyObjectRequestBody",
    "DriverAppSettingsTrailerSelectionConfigTinyObjectResponseBody",
    "DriverAppSignInResponseBody",
    "DriverAppSignOutResponseBody",
    "DriverAssignmentMetadataTinyObjectResponseBody",
    "DriverAssignmentObjectResponseBody",
    "DriverAssignmentObjectResponseBodyAssignmentType",
    "DriverCarrierSettings",
    "DriverCoachAssignmentsGetDriverCoachAssignmentBadGatewayErrorResponseBody",
    "DriverCoachAssignmentsGetDriverCoachAssignmentGatewayTimeoutErrorResponseBody",
    "DriverCoachAssignmentsGetDriverCoachAssignmentInternalServerErrorResponseBody",
    "DriverCoachAssignmentsGetDriverCoachAssignmentMethodNotAllowedErrorResponseBody",
    "DriverCoachAssignmentsGetDriverCoachAssignmentNotFoundErrorResponseBody",
    "DriverCoachAssignmentsGetDriverCoachAssignmentNotImplementedErrorResponseBody",
    "DriverCoachAssignmentsGetDriverCoachAssignmentResponseBody",
    "DriverCoachAssignmentsGetDriverCoachAssignmentServiceUnavailableErrorResponseBody",
    "DriverCoachAssignmentsGetDriverCoachAssignmentTooManyRequestsErrorResponseBody",
    "DriverCoachAssignmentsGetDriverCoachAssignmentUnauthorizedErrorResponseBody",
    "DriverCoachAssignmentsPutDriverCoachAssignmentBadGatewayErrorResponseBody",
    "DriverCoachAssignmentsPutDriverCoachAssignmentGatewayTimeoutErrorResponseBody",
    "DriverCoachAssignmentsPutDriverCoachAssignmentInternalServerErrorResponseBody",
    "DriverCoachAssignmentsPutDriverCoachAssignmentMethodNotAllowedErrorResponseBody",
    "DriverCoachAssignmentsPutDriverCoachAssignmentNotFoundErrorResponseBody",
    "DriverCoachAssignmentsPutDriverCoachAssignmentNotImplementedErrorResponseBody",
    "DriverCoachAssignmentsPutDriverCoachAssignmentResponseBody",
    "DriverCoachAssignmentsPutDriverCoachAssignmentServiceUnavailableErrorResponseBody",
    "DriverCoachAssignmentsPutDriverCoachAssignmentTooManyRequestsErrorResponseBody",
    "DriverCoachAssignmentsPutDriverCoachAssignmentUnauthorizedErrorResponseBody",
    "DriverCreatedAtTime",
    "DriverDocumentSubmittedDetailsObjectRequestBody",
    "DriverDocumentSubmittedDetailsObjectResponseBody",
    "DriverDocumentSubmittedResponseBody",
    "DriverEfficienciesResponse",
    "DriverEfficienciesResponseData",
    "DriverEfficiency",
    "DriverEfficiencyDataObjectResponseBody",
    "DriverEfficiencyDifficultyScoreDataObjectResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByDriversBadGatewayErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByDriversGatewayTimeoutErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByDriversInternalServerErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByDriversMethodNotAllowedErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByDriversNotFoundErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByDriversNotImplementedErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByDriversResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByDriversServiceUnavailableErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByDriversTooManyRequestsErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByDriversUnauthorizedErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesBadGatewayErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesGatewayTimeoutErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesInternalServerErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesMethodNotAllowedErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesNotFoundErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesNotImplementedErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesServiceUnavailableErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesTooManyRequestsErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesUnauthorizedErrorResponseBody",
    "DriverEfficiencyPercentageDataObjectResponseBody",
    "DriverEfficiencyRawDataObjectResponseBody",
    "DriverEldAdverseWeatherExemptionEnabled",
    "DriverEldBigDayExemptionEnabled",
    "DriverEldDayStartHour",
    "DriverEldExempt",
    "DriverEldExemptReason",
    "DriverEldPcEnabled",
    "DriverEldRuleset",
    "DriverEldRulesetCycle",
    "DriverEldRulesetJurisdiction",
    "DriverEldRulesetRestBreak",
    "DriverEldRulesetRestart",
    "DriverEldRulesetShift",
    "DriverEldRulesets",
    "DriverEldSettings",
    "DriverEldYmEnabled",
    "DriverExternalIds",
    "DriverHasDrivingFeaturesHidden",
    "DriverHasVehicleUnpinningEnabled",
    "DriverHeavyHaulExemptionToggleEnabled",
    "DriverHomeTerminalAddress",
    "DriverHomeTerminalName",
    "DriverHosSetting",
    "DriverId",
    "DriverIdCardCode",
    "DriverIsDeactivated",
    "DriverLicenseNumber",
    "DriverLicenseState",
    "DriverLocale",
    "DriverMessageReceivedResponseBody",
    "DriverMessageSentResponseBody",
    "DriverName",
    "DriverNotes",
    "DriverObjectResponseBody",
    "DriverOrTagIdsDetailsRequestBody",
    "DriverOrTagIdsDetailsResponseBody",
    "DriverPhone",
    "DriverProfileImageBase64",
    "DriverProfileImageUrl",
    "DriverQrCodesCreateDriverQrCodeBadGatewayErrorResponseBody",
    "DriverQrCodesCreateDriverQrCodeGatewayTimeoutErrorResponseBody",
    "DriverQrCodesCreateDriverQrCodeInternalServerErrorResponseBody",
    "DriverQrCodesCreateDriverQrCodeMethodNotAllowedErrorResponseBody",
    "DriverQrCodesCreateDriverQrCodeNotFoundErrorResponseBody",
    "DriverQrCodesCreateDriverQrCodeNotImplementedErrorResponseBody",
    "DriverQrCodesCreateDriverQrCodeResponseBody",
    "DriverQrCodesCreateDriverQrCodeServiceUnavailableErrorResponseBody",
    "DriverQrCodesCreateDriverQrCodeTooManyRequestsErrorResponseBody",
    "DriverQrCodesCreateDriverQrCodeUnauthorizedErrorResponseBody",
    "DriverQrCodesDeleteDriverQrCodeBadGatewayErrorResponseBody",
    "DriverQrCodesDeleteDriverQrCodeGatewayTimeoutErrorResponseBody",
    "DriverQrCodesDeleteDriverQrCodeInternalServerErrorResponseBody",
    "DriverQrCodesDeleteDriverQrCodeMethodNotAllowedErrorResponseBody",
    "DriverQrCodesDeleteDriverQrCodeNotFoundErrorResponseBody",
    "DriverQrCodesDeleteDriverQrCodeNotImplementedErrorResponseBody",
    "DriverQrCodesDeleteDriverQrCodeServiceUnavailableErrorResponseBody",
    "DriverQrCodesDeleteDriverQrCodeTooManyRequestsErrorResponseBody",
    "DriverQrCodesDeleteDriverQrCodeUnauthorizedErrorResponseBody",
    "DriverQrCodesGetDriversQrCodesBadGatewayErrorResponseBody",
    "DriverQrCodesGetDriversQrCodesGatewayTimeoutErrorResponseBody",
    "DriverQrCodesGetDriversQrCodesInternalServerErrorResponseBody",
    "DriverQrCodesGetDriversQrCodesMethodNotAllowedErrorResponseBody",
    "DriverQrCodesGetDriversQrCodesNotFoundErrorResponseBody",
    "DriverQrCodesGetDriversQrCodesNotImplementedErrorResponseBody",
    "DriverQrCodesGetDriversQrCodesResponseBody",
    "DriverQrCodesGetDriversQrCodesServiceUnavailableErrorResponseBody",
    "DriverQrCodesGetDriversQrCodesTooManyRequestsErrorResponseBody",
    "DriverQrCodesGetDriversQrCodesUnauthorizedErrorResponseBody",
    "DriverRecordedResponseBody",
    "DriverRemoteSignoutPostDriverRemoteSignoutBadGatewayErrorResponseBody",
    "DriverRemoteSignoutPostDriverRemoteSignoutGatewayTimeoutErrorResponseBody",
    "DriverRemoteSignoutPostDriverRemoteSignoutInternalServerErrorResponseBody",
    "DriverRemoteSignoutPostDriverRemoteSignoutMethodNotAllowedErrorResponseBody",
    "DriverRemoteSignoutPostDriverRemoteSignoutNotFoundErrorResponseBody",
    "DriverRemoteSignoutPostDriverRemoteSignoutNotImplementedErrorResponseBody",
    "DriverRemoteSignoutPostDriverRemoteSignoutResponseBody",
    "DriverRemoteSignoutPostDriverRemoteSignoutServiceUnavailableErrorResponseBody",
    "DriverRemoteSignoutPostDriverRemoteSignoutTooManyRequestsErrorResponseBody",
    "DriverRemoteSignoutPostDriverRemoteSignoutUnauthorizedErrorResponseBody",
    "DriverResponse",
    "DriverRulesetObjectResponseBody",
    "DriverRulesetObjectResponseBodyBreak",
    "DriverRulesetObjectResponseBodyCycle",
    "DriverRulesetObjectResponseBodyRestart",
    "DriverRulesetObjectResponseBodyShift",
    "DriverSafetyScoreResponseBody",
    "DriverStaticAssignedVehicle",
    "DriverTachographActivityData",
    "DriverTachographActivityResponse",
    "DriverTachographCardNumber",
    "DriverTags",
    "DriverTimezone",
    "DriverTinyResponse",
    "DriverUpdatedAtTime",
    "DriverUsername",
    "DriverVehicleAssignmentV2ObjectResponseBody",
    "DriverVehicleAssignmentV2ObjectResponseBodyAssignmentType",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentBadGatewayErrorResponseBody",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentGatewayTimeoutErrorResponseBody",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentInternalServerErrorResponseBody",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentMethodNotAllowedErrorResponseBody",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentNotFoundErrorResponseBody",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentNotImplementedErrorResponseBody",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentResponseBody",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentServiceUnavailableErrorResponseBody",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentTooManyRequestsErrorResponseBody",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentUnauthorizedErrorResponseBody",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsBadGatewayErrorResponseBody",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsGatewayTimeoutErrorResponseBody",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsInternalServerErrorResponseBody",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsMethodNotAllowedErrorResponseBody",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsNotFoundErrorResponseBody",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsNotImplementedErrorResponseBody",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsServiceUnavailableErrorResponseBody",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsTooManyRequestsErrorResponseBody",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsUnauthorizedErrorResponseBody",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsBadGatewayErrorResponseBody",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsGatewayTimeoutErrorResponseBody",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsInternalServerErrorResponseBody",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsMethodNotAllowedErrorResponseBody",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsNotFoundErrorResponseBody",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsNotImplementedErrorResponseBody",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsResponseBody",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsServiceUnavailableErrorResponseBody",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsTooManyRequestsErrorResponseBody",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsUnauthorizedErrorResponseBody",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentBadGatewayErrorResponseBody",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentGatewayTimeoutErrorResponseBody",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentInternalServerErrorResponseBody",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentMethodNotAllowedErrorResponseBody",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentNotFoundErrorResponseBody",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentNotImplementedErrorResponseBody",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentResponseBody",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentServiceUnavailableErrorResponseBody",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentTooManyRequestsErrorResponseBody",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentUnauthorizedErrorResponseBody",
    "DriverVehicleGroupTag",
    "DriverWaitingTimeDutyStatusEnabled",
    "DriverWithExternalIdObjectResponseBody",
    "DriverWithTimezoneEldSettingsObjectResponseBody",
    "DriversAuthTokenCreateDriverAuthTokenBadGatewayErrorResponseBody",
    "DriversAuthTokenCreateDriverAuthTokenGatewayTimeoutErrorResponseBody",
    "DriversAuthTokenCreateDriverAuthTokenInternalServerErrorResponseBody",
    "DriversAuthTokenCreateDriverAuthTokenMethodNotAllowedErrorResponseBody",
    "DriversAuthTokenCreateDriverAuthTokenNotFoundErrorResponseBody",
    "DriversAuthTokenCreateDriverAuthTokenNotImplementedErrorResponseBody",
    "DriversAuthTokenCreateDriverAuthTokenResponseBody",
    "DriversAuthTokenCreateDriverAuthTokenServiceUnavailableErrorResponseBody",
    "DriversAuthTokenCreateDriverAuthTokenTooManyRequestsErrorResponseBody",
    "DriversAuthTokenCreateDriverAuthTokenUnauthorizedErrorResponseBody",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsBadGatewayErrorResponseBody",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsGatewayTimeoutErrorResponseBody",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsInternalServerErrorResponseBody",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsMethodNotAllowedErrorResponseBody",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsNotFoundErrorResponseBody",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsNotImplementedErrorResponseBody",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsResponseBody",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsServiceUnavailableErrorResponseBody",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsTooManyRequestsErrorResponseBody",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsUnauthorizedErrorResponseBody",
    "DriversVehicleAssignmentsObjectResponseBody",
    "DriversVehicleAssignmentsObjectResponseBodyDriverActivationStatus",
    "DutyStatusDurationObjectResponseBody",
    "Dvir",
    "Dvir2AssignedToPolymorphicUserObjectResponseBody",
    "Dvir2DeviceObjectResponseBody",
    "Dvir2FormSubmissionObjectResponseBody",
    "Dvir2RelatedDeviceObjectResponseBody",
    "Dvir2RelatedDeviceObjectResponseBodyAssetType",
    "Dvir2SubmissionResponseObjectResponseBody",
    "Dvir2SubmissionResponseObjectResponseBodyInspectionType",
    "DvirAuthorSignature",
    "DvirDefectGetDefectBadGatewayErrorResponseBody",
    "DvirDefectGetDefectGatewayTimeoutErrorResponseBody",
    "DvirDefectGetDefectInternalServerErrorResponseBody",
    "DvirDefectGetDefectMethodNotAllowedErrorResponseBody",
    "DvirDefectGetDefectNotFoundErrorResponseBody",
    "DvirDefectGetDefectNotImplementedErrorResponseBody",
    "DvirDefectGetDefectResponseBody",
    "DvirDefectGetDefectServiceUnavailableErrorResponseBody",
    "DvirDefectGetDefectTooManyRequestsErrorResponseBody",
    "DvirDefectGetDefectUnauthorizedErrorResponseBody",
    "DvirDefectStreamDefectsBadGatewayErrorResponseBody",
    "DvirDefectStreamDefectsGatewayTimeoutErrorResponseBody",
    "DvirDefectStreamDefectsInternalServerErrorResponseBody",
    "DvirDefectStreamDefectsMethodNotAllowedErrorResponseBody",
    "DvirDefectStreamDefectsNotFoundErrorResponseBody",
    "DvirDefectStreamDefectsNotImplementedErrorResponseBody",
    "DvirDefectStreamDefectsResponseBody",
    "DvirDefectStreamDefectsServiceUnavailableErrorResponseBody",
    "DvirDefectStreamDefectsTooManyRequestsErrorResponseBody",
    "DvirDefectStreamDefectsUnauthorizedErrorResponseBody",
    "DvirDefectTypeGetDefectTypesBadGatewayErrorResponseBody",
    "DvirDefectTypeGetDefectTypesGatewayTimeoutErrorResponseBody",
    "DvirDefectTypeGetDefectTypesInternalServerErrorResponseBody",
    "DvirDefectTypeGetDefectTypesMethodNotAllowedErrorResponseBody",
    "DvirDefectTypeGetDefectTypesNotFoundErrorResponseBody",
    "DvirDefectTypeGetDefectTypesNotImplementedErrorResponseBody",
    "DvirDefectTypeGetDefectTypesResponseBody",
    "DvirDefectTypeGetDefectTypesServiceUnavailableErrorResponseBody",
    "DvirDefectTypeGetDefectTypesTooManyRequestsErrorResponseBody",
    "DvirDefectTypeGetDefectTypesUnauthorizedErrorResponseBody",
    "DvirDefectsObjectV20220913ResponseBody",
    "DvirGetDvirBadGatewayErrorResponseBody",
    "DvirGetDvirGatewayTimeoutErrorResponseBody",
    "DvirGetDvirInternalServerErrorResponseBody",
    "DvirGetDvirMethodNotAllowedErrorResponseBody",
    "DvirGetDvirNotFoundErrorResponseBody",
    "DvirGetDvirNotImplementedErrorResponseBody",
    "DvirGetDvirResponseBody",
    "DvirGetDvirResponseBodySafetyStatus",
    "DvirGetDvirResponseBodyType",
    "DvirGetDvirServiceUnavailableErrorResponseBody",
    "DvirGetDvirTooManyRequestsErrorResponseBody",
    "DvirGetDvirUnauthorizedErrorResponseBody",
    "DvirGetDvirsBadGatewayErrorResponseBody",
    "DvirGetDvirsGatewayTimeoutErrorResponseBody",
    "DvirGetDvirsInternalServerErrorResponseBody",
    "DvirGetDvirsMethodNotAllowedErrorResponseBody",
    "DvirGetDvirsNotFoundErrorResponseBody",
    "DvirGetDvirsNotImplementedErrorResponseBody",
    "DvirGetDvirsResponseBody",
    "DvirGetDvirsServiceUnavailableErrorResponseBody",
    "DvirGetDvirsTooManyRequestsErrorResponseBody",
    "DvirGetDvirsUnauthorizedErrorResponseBody",
    "DvirLicensePlate",
    "DvirLocation",
    "DvirMechanicNotes",
    "DvirOdometerMeters",
    "DvirResolvedByObjectResponseBody",
    "DvirResolvedByObjectResponseBodyType",
    "DvirResponse",
    "DvirSafetyStatus",
    "DvirSecondSignature",
    "DvirSignature",
    "DvirSignatureSignatoryUser",
    "DvirSignatureType",
    "DvirStreamResponseDataResponseBody",
    "DvirStreamResponseDataResponseBodySafetyStatus",
    "DvirStreamResponseDataResponseBodyType",
    "DvirSubmittedDeviceTriggerDetailsObjectRequestBody",
    "DvirSubmittedDeviceTriggerDetailsObjectRequestBodyDvirSubmissionTypesItem",
    "DvirSubmittedDeviceTriggerDetailsObjectResponseBody",
    "DvirSubmittedDeviceTriggerDetailsObjectResponseBodyDvirSubmissionTypesItem",
    "DvirThirdSignature",
    "DvirTrailer",
    "DvirTrailerDefects",
    "DvirTrailerDefectsItems",
    "DvirTrailerDefectsItemsTrailer",
    "DvirTrailerDefectsItemsVehicle",
    "DvirType",
    "DvirVehicle",
    "DvirVehicleDefects",
    "DvirsListResponse",
    "EldSettingsObjectResponseBody",
    "EngineIdleDataResponseBody",
    "EngineIdleTriggerDetailsObjectRequestBody",
    "EngineIdleTriggerDetailsObjectResponseBody",
    "EngineImmobilizerGetEngineImmobilizerStatesBadGatewayErrorResponseBody",
    "EngineImmobilizerGetEngineImmobilizerStatesGatewayTimeoutErrorResponseBody",
    "EngineImmobilizerGetEngineImmobilizerStatesInternalServerErrorResponseBody",
    "EngineImmobilizerGetEngineImmobilizerStatesMethodNotAllowedErrorResponseBody",
    "EngineImmobilizerGetEngineImmobilizerStatesNotFoundErrorResponseBody",
    "EngineImmobilizerGetEngineImmobilizerStatesNotImplementedErrorResponseBody",
    "EngineImmobilizerGetEngineImmobilizerStatesResponseBody",
    "EngineImmobilizerGetEngineImmobilizerStatesServiceUnavailableErrorResponseBody",
    "EngineImmobilizerGetEngineImmobilizerStatesTooManyRequestsErrorResponseBody",
    "EngineImmobilizerGetEngineImmobilizerStatesUnauthorizedErrorResponseBody",
    "EngineImmobilizerRelayStateResponseBody",
    "EngineImmobilizerRelayStateResponseBodyId",
    "EngineImmobilizerStateResponseBody",
    "EngineImmobilizerUpdateEngineImmobilizerStateBadGatewayErrorResponseBody",
    "EngineImmobilizerUpdateEngineImmobilizerStateGatewayTimeoutErrorResponseBody",
    "EngineImmobilizerUpdateEngineImmobilizerStateInternalServerErrorResponseBody",
    "EngineImmobilizerUpdateEngineImmobilizerStateMethodNotAllowedErrorResponseBody",
    "EngineImmobilizerUpdateEngineImmobilizerStateNotFoundErrorResponseBody",
    "EngineImmobilizerUpdateEngineImmobilizerStateNotImplementedErrorResponseBody",
    "EngineImmobilizerUpdateEngineImmobilizerStateServiceUnavailableErrorResponseBody",
    "EngineImmobilizerUpdateEngineImmobilizerStateTooManyRequestsErrorResponseBody",
    "EngineImmobilizerUpdateEngineImmobilizerStateUnauthorizedErrorResponseBody",
    "EngineOffDetailsObjectRequestBody",
    "EngineOffDetailsObjectResponseBody",
    "EngineOffResponseBody",
    "EngineOnDetailsObjectRequestBody",
    "EngineOnDetailsObjectResponseBody",
    "EngineOnResponseBody",
    "EngineStatusResponseBody",
    "EnumReadingAlertThresholdResponseBody",
    "EnumValueResponseBody",
    "EquipmentEngineRpm",
    "EquipmentEngineSeconds",
    "EquipmentEngineState",
    "EquipmentEngineStateValue",
    "EquipmentEngineTotalIdleTimeMinutes",
    "EquipmentFuelPercent",
    "EquipmentGatewayEngineSeconds",
    "EquipmentGatewayEngineState",
    "EquipmentGatewayEngineStateValue",
    "EquipmentGatewayJ1939EngineSeconds",
    "EquipmentGpsOdometerMeters",
    "EquipmentHeaderWithAdditionalFieldsResponseBody",
    "EquipmentId",
    "EquipmentInstalledGateway",
    "EquipmentListResponse",
    "EquipmentLocation",
    "EquipmentLocationsListResponse",
    "EquipmentLocationsListResponseData",
    "EquipmentLocationsResponse",
    "EquipmentLocationsResponseData",
    "EquipmentName",
    "EquipmentObdEngineSeconds",
    "EquipmentObdEngineState",
    "EquipmentObdEngineStateValue",
    "EquipmentObject",
    "EquipmentPatchEquipmentBadGatewayErrorResponseBody",
    "EquipmentPatchEquipmentGatewayTimeoutErrorResponseBody",
    "EquipmentPatchEquipmentInternalServerErrorResponseBody",
    "EquipmentPatchEquipmentMethodNotAllowedErrorResponseBody",
    "EquipmentPatchEquipmentNotFoundErrorResponseBody",
    "EquipmentPatchEquipmentNotImplementedErrorResponseBody",
    "EquipmentPatchEquipmentResponseBody",
    "EquipmentPatchEquipmentServiceUnavailableErrorResponseBody",
    "EquipmentPatchEquipmentTooManyRequestsErrorResponseBody",
    "EquipmentPatchEquipmentUnauthorizedErrorResponseBody",
    "EquipmentResponse",
    "EquipmentStatsGps",
    "EquipmentStatsListResponse",
    "EquipmentStatsListResponseData",
    "EquipmentStatsResponse",
    "EquipmentStatsResponseData",
    "EquipmentTime",
    "EquipmentWithAttributesResponseObjectResponseBody",
    "EventLocationResponseBody",
    "ExtendedDriverTinyResponse",
    "ExtendedDriverTinyResponseExternalIds",
    "FftSpectraDataPoint",
    "FftSpectraDataPointFftSpectra",
    "FieldObjectPostRequestBody",
    "FieldObjectPostRequestBodyType",
    "FieldObjectResponseBody",
    "FieldObjectResponseBodyType",
    "FieldObjectValueRequestBody",
    "FieldObjectValueResponseBody",
    "FieldTypesObjectResponseBody",
    "FieldTypesObjectResponseBodyFieldType",
    "FiltersRequestBody",
    "FiltersResponseBody",
    "FleetDeviceObjectResponseBody",
    "FollowingDistanceDetectionAlertSettingsObjectResponseBody",
    "FormSubmissionPdfExportResponseObjectResponseBody",
    "FormSubmissionPdfExportResponseObjectResponseBodyJobStatus",
    "FormSubmissionRequestApprovalDetailsRequestBody",
    "FormSubmissionRequestAssetObjectRequestBody",
    "FormSubmissionRequestAssetValueObjectRequestBody",
    "FormSubmissionRequestAssignedToRequestBody",
    "FormSubmissionRequestAssignedToRequestBodyType",
    "FormSubmissionRequestCheckBoxesValueObjectRequestBody",
    "FormSubmissionRequestDateTimeValueObjectRequestBody",
    "FormSubmissionRequestFieldInputObjectRequestBody",
    "FormSubmissionRequestFieldInputObjectRequestBodyType",
    "FormSubmissionRequestGeofenceObjectRequestBody",
    "FormSubmissionRequestGeofenceValueObjectRequestBody",
    "FormSubmissionRequestMediaItemObjectRequestBody",
    "FormSubmissionRequestMediaValueObjectRequestBody",
    "FormSubmissionRequestMultipleChoiceValueObjectRequestBody",
    "FormSubmissionRequestNumberValueObjectRequestBody",
    "FormSubmissionRequestPersonObjectRequestBody",
    "FormSubmissionRequestPersonValueObjectRequestBody",
    "FormSubmissionRequestSignatureValueObjectRequestBody",
    "FormSubmissionRequestTableCellObjectRequestBody",
    "FormSubmissionRequestTableCellObjectRequestBodyType",
    "FormSubmissionRequestTableRowObjectRequestBody",
    "FormSubmissionRequestTableValueObjectRequestBody",
    "FormSubmissionRequestTextValueObjectRequestBody",
    "FormSubmissionResponseObjectResponseBody",
    "FormSubmissionResponseObjectResponseBodyStatus",
    "FormSubmissionsGetFormSubmissionsBadGatewayErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsGatewayTimeoutErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsInternalServerErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsMethodNotAllowedErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsNotFoundErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsNotImplementedErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsPdfExportsBadGatewayErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsPdfExportsGatewayTimeoutErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsPdfExportsInternalServerErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsPdfExportsMethodNotAllowedErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsPdfExportsNotFoundErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsPdfExportsNotImplementedErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsPdfExportsResponseBody",
    "FormSubmissionsGetFormSubmissionsPdfExportsServiceUnavailableErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsPdfExportsTooManyRequestsErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsPdfExportsUnauthorizedErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsResponseBody",
    "FormSubmissionsGetFormSubmissionsServiceUnavailableErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsStreamBadGatewayErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsStreamGatewayTimeoutErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsStreamInternalServerErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsStreamMethodNotAllowedErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsStreamNotFoundErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsStreamNotImplementedErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsStreamResponseBody",
    "FormSubmissionsGetFormSubmissionsStreamServiceUnavailableErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsStreamTooManyRequestsErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsStreamUnauthorizedErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsTooManyRequestsErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsUnauthorizedErrorResponseBody",
    "FormSubmissionsPatchFormSubmissionBadGatewayErrorResponseBody",
    "FormSubmissionsPatchFormSubmissionGatewayTimeoutErrorResponseBody",
    "FormSubmissionsPatchFormSubmissionInternalServerErrorResponseBody",
    "FormSubmissionsPatchFormSubmissionMethodNotAllowedErrorResponseBody",
    "FormSubmissionsPatchFormSubmissionNotFoundErrorResponseBody",
    "FormSubmissionsPatchFormSubmissionNotImplementedErrorResponseBody",
    "FormSubmissionsPatchFormSubmissionResponseBody",
    "FormSubmissionsPatchFormSubmissionServiceUnavailableErrorResponseBody",
    "FormSubmissionsPatchFormSubmissionTooManyRequestsErrorResponseBody",
    "FormSubmissionsPatchFormSubmissionUnauthorizedErrorResponseBody",
    "FormSubmissionsPostFormSubmissionBadGatewayErrorResponseBody",
    "FormSubmissionsPostFormSubmissionGatewayTimeoutErrorResponseBody",
    "FormSubmissionsPostFormSubmissionInternalServerErrorResponseBody",
    "FormSubmissionsPostFormSubmissionMethodNotAllowedErrorResponseBody",
    "FormSubmissionsPostFormSubmissionNotFoundErrorResponseBody",
    "FormSubmissionsPostFormSubmissionNotImplementedErrorResponseBody",
    "FormSubmissionsPostFormSubmissionResponseBody",
    "FormSubmissionsPostFormSubmissionServiceUnavailableErrorResponseBody",
    "FormSubmissionsPostFormSubmissionTooManyRequestsErrorResponseBody",
    "FormSubmissionsPostFormSubmissionUnauthorizedErrorResponseBody",
    "FormSubmissionsPostFormSubmissionsPdfExportsBadGatewayErrorResponseBody",
    "FormSubmissionsPostFormSubmissionsPdfExportsGatewayTimeoutErrorResponseBody",
    "FormSubmissionsPostFormSubmissionsPdfExportsInternalServerErrorResponseBody",
    "FormSubmissionsPostFormSubmissionsPdfExportsMethodNotAllowedErrorResponseBody",
    "FormSubmissionsPostFormSubmissionsPdfExportsNotFoundErrorResponseBody",
    "FormSubmissionsPostFormSubmissionsPdfExportsNotImplementedErrorResponseBody",
    "FormSubmissionsPostFormSubmissionsPdfExportsResponseBody",
    "FormSubmissionsPostFormSubmissionsPdfExportsServiceUnavailableErrorResponseBody",
    "FormSubmissionsPostFormSubmissionsPdfExportsTooManyRequestsErrorResponseBody",
    "FormSubmissionsPostFormSubmissionsPdfExportsUnauthorizedErrorResponseBody",
    "FormSubmittedResponseBody",
    "FormTemplateReferenceObjectResponseBody",
    "FormTemplateRequestObjectRequestBody",
    "FormTemplateResponseObjectResponseBody",
    "FormTemplateResponseObjectResponseBodyFormCategory",
    "FormTemplateSectionObjectResponseBody",
    "FormTemplatesGetFormTemplatesBadGatewayErrorResponseBody",
    "FormTemplatesGetFormTemplatesGatewayTimeoutErrorResponseBody",
    "FormTemplatesGetFormTemplatesInternalServerErrorResponseBody",
    "FormTemplatesGetFormTemplatesMethodNotAllowedErrorResponseBody",
    "FormTemplatesGetFormTemplatesNotFoundErrorResponseBody",
    "FormTemplatesGetFormTemplatesNotImplementedErrorResponseBody",
    "FormTemplatesGetFormTemplatesResponseBody",
    "FormTemplatesGetFormTemplatesServiceUnavailableErrorResponseBody",
    "FormTemplatesGetFormTemplatesTooManyRequestsErrorResponseBody",
    "FormTemplatesGetFormTemplatesUnauthorizedErrorResponseBody",
    "FormUpdatedResponseBody",
    "FormsActionObjectResponseBody",
    "FormsActionObjectResponseBodyType",
    "FormsApprovalConfigObjectResponseBody",
    "FormsApprovalConfigObjectResponseBodyType",
    "FormsAssetObjectResponseBody",
    "FormsAssetObjectResponseBodyEntryType",
    "FormsAssetValueObjectResponseBody",
    "FormsCheckBoxesValueObjectResponseBody",
    "FormsConditionObjectResponseBody",
    "FormsConditionObjectResponseBodyType",
    "FormsConditionalActionObjectResponseBody",
    "FormsDateTimeValueObjectResponseBody",
    "FormsDateTimeValueObjectResponseBodyType",
    "FormsFieldDefinitionObjectResponseBody",
    "FormsFieldDefinitionObjectResponseBodyAllowedAssetTypesItem",
    "FormsFieldDefinitionObjectResponseBodyAllowedDateTimeValueType",
    "FormsFieldDefinitionObjectResponseBodyType",
    "FormsFieldInputObjectResponseBody",
    "FormsFieldInputObjectResponseBodyType",
    "FormsGeofenceObjectResponseBody",
    "FormsGeofenceObjectResponseBodyEntryType",
    "FormsGeofenceValueObjectResponseBody",
    "FormsIssueCreatedByFieldObjectResponseBody",
    "FormsLocationObjectResponseBody",
    "FormsMediaRecordObjectResponseBody",
    "FormsMediaRecordObjectResponseBodyProcessingStatus",
    "FormsMediaValueObjectResponseBody",
    "FormsMultipleChoiceValueObjectResponseBody",
    "FormsNumberValueObjectResponseBody",
    "FormsPersonObjectResponseBody",
    "FormsPersonObjectResponseBodyEntryType",
    "FormsPersonValueObjectResponseBody",
    "FormsPolymorphicUserObjectResponseBody",
    "FormsPolymorphicUserObjectResponseBodyType",
    "FormsProductSubmissionApprovalDetailsObjectResponseBody",
    "FormsScoreObjectResponseBody",
    "FormsSelectOptionObjectResponseBody",
    "FormsSignatureValueObjectResponseBody",
    "FormsSingleApprovalConfigObjectResponseBody",
    "FormsTableCellObjectResponseBody",
    "FormsTableCellObjectResponseBodyType",
    "FormsTableColumnObjectResponseBody",
    "FormsTableColumnObjectResponseBodyType",
    "FormsTableFieldDefinitionObjectResponseBody",
    "FormsTableFieldDefinitionObjectResponseBodyAllowedDateTimeValueType",
    "FormsTableFieldDefinitionObjectResponseBodyType",
    "FormsTableRowObjectResponseBody",
    "FormsTableValueObjectResponseBody",
    "FormsTextValueObjectResponseBody",
    "ForwardCollisionDetectionAlertSettingsObjectResponseBody",
    "ForwardCollisionDetectionAlertSettingsObjectResponseBodySensitivity",
    "FuelConsumedMl",
    "FuelCostObjectResponseBody",
    "FuelCostObjectResponseBodyCurrency",
    "FuelEnergyCostResponseResponseBody",
    "FuelEnergyDriverReportDataObjectResponseBody",
    "FuelEnergyDriverReportObjectResponseBody",
    "FuelEnergyGetFuelEnergyDriverReportsBadGatewayErrorResponseBody",
    "FuelEnergyGetFuelEnergyDriverReportsGatewayTimeoutErrorResponseBody",
    "FuelEnergyGetFuelEnergyDriverReportsInternalServerErrorResponseBody",
    "FuelEnergyGetFuelEnergyDriverReportsMethodNotAllowedErrorResponseBody",
    "FuelEnergyGetFuelEnergyDriverReportsNotFoundErrorResponseBody",
    "FuelEnergyGetFuelEnergyDriverReportsNotImplementedErrorResponseBody",
    "FuelEnergyGetFuelEnergyDriverReportsResponseBody",
    "FuelEnergyGetFuelEnergyDriverReportsServiceUnavailableErrorResponseBody",
    "FuelEnergyGetFuelEnergyDriverReportsTooManyRequestsErrorResponseBody",
    "FuelEnergyGetFuelEnergyDriverReportsUnauthorizedErrorResponseBody",
    "FuelEnergyGetFuelEnergyVehicleReportsBadGatewayErrorResponseBody",
    "FuelEnergyGetFuelEnergyVehicleReportsGatewayTimeoutErrorResponseBody",
    "FuelEnergyGetFuelEnergyVehicleReportsInternalServerErrorResponseBody",
    "FuelEnergyGetFuelEnergyVehicleReportsMethodNotAllowedErrorResponseBody",
    "FuelEnergyGetFuelEnergyVehicleReportsNotFoundErrorResponseBody",
    "FuelEnergyGetFuelEnergyVehicleReportsNotImplementedErrorResponseBody",
    "FuelEnergyGetFuelEnergyVehicleReportsResponseBody",
    "FuelEnergyGetFuelEnergyVehicleReportsServiceUnavailableErrorResponseBody",
    "FuelEnergyGetFuelEnergyVehicleReportsTooManyRequestsErrorResponseBody",
    "FuelEnergyGetFuelEnergyVehicleReportsUnauthorizedErrorResponseBody",
    "FuelEnergyVehicleObjectResponseBody",
    "FuelEnergyVehicleObjectResponseBodyEnergyType",
    "FuelEnergyVehicleReportDataObjectResponseBody",
    "FuelEnergyVehicleReportObjectResponseBody",
    "FuelLevelPercentageResponseBody",
    "FuelLevelTriggerDetailsObjectRequestBody",
    "FuelLevelTriggerDetailsObjectRequestBodyOperation",
    "FuelLevelTriggerDetailsObjectResponseBody",
    "FuelLevelTriggerDetailsObjectResponseBodyOperation",
    "FuelPurchasePostFuelPurchaseBadGatewayErrorResponseBody",
    "FuelPurchasePostFuelPurchaseGatewayTimeoutErrorResponseBody",
    "FuelPurchasePostFuelPurchaseInternalServerErrorResponseBody",
    "FuelPurchasePostFuelPurchaseMethodNotAllowedErrorResponseBody",
    "FuelPurchasePostFuelPurchaseNotFoundErrorResponseBody",
    "FuelPurchasePostFuelPurchaseNotImplementedErrorResponseBody",
    "FuelPurchasePostFuelPurchaseResponseBody",
    "FuelPurchasePostFuelPurchaseServiceUnavailableErrorResponseBody",
    "FuelPurchasePostFuelPurchaseTooManyRequestsErrorResponseBody",
    "FuelPurchasePostFuelPurchaseUnauthorizedErrorResponseBody",
    "FuelRemainingResponseBody",
    "FuelVolumeResponseBody",
    "FuelVolumeResponseBodyUnit",
    "FunctionsStartFunctionRunBadGatewayErrorResponseBody",
    "FunctionsStartFunctionRunGatewayTimeoutErrorResponseBody",
    "FunctionsStartFunctionRunInternalServerErrorResponseBody",
    "FunctionsStartFunctionRunMethodNotAllowedErrorResponseBody",
    "FunctionsStartFunctionRunNotFoundErrorResponseBody",
    "FunctionsStartFunctionRunNotImplementedErrorResponseBody",
    "FunctionsStartFunctionRunResponseBody",
    "FunctionsStartFunctionRunServiceUnavailableErrorResponseBody",
    "FunctionsStartFunctionRunTooManyRequestsErrorResponseBody",
    "FunctionsStartFunctionRunUnauthorizedErrorResponseBody",
    "GaseousFuelCostObjectResponseBody",
    "GaseousFuelCostObjectResponseBodyCurrency",
    "GatewayAssetResponseObjectResponseBody",
    "GatewayDetailsResponseResponseBody",
    "GatewayDetailsResponseResponseBodyGatewayBatteryState",
    "GatewayDisconnectedDetailsObjectRequestBody",
    "GatewayDisconnectedDetailsObjectResponseBody",
    "GatewayDisconnectedResponseBody",
    "GatewayResponseObjectResponseBody",
    "GatewayResponseObjectResponseBodyModel",
    "GatewayTiny",
    "GatewayUnpluggedTriggerDetailsObjectRequestBody",
    "GatewayUnpluggedTriggerDetailsObjectResponseBody",
    "GatewayWithVehicleTinyResponseResponseBody",
    "GatewayWithVehicleTinyResponseResponseBodyModel",
    "GatewaysDeleteGatewayBadGatewayErrorResponseBody",
    "GatewaysDeleteGatewayGatewayTimeoutErrorResponseBody",
    "GatewaysDeleteGatewayInternalServerErrorResponseBody",
    "GatewaysDeleteGatewayMethodNotAllowedErrorResponseBody",
    "GatewaysDeleteGatewayNotFoundErrorResponseBody",
    "GatewaysDeleteGatewayNotImplementedErrorResponseBody",
    "GatewaysDeleteGatewayServiceUnavailableErrorResponseBody",
    "GatewaysDeleteGatewayTooManyRequestsErrorResponseBody",
    "GatewaysDeleteGatewayUnauthorizedErrorResponseBody",
    "GatewaysGetGatewaysBadGatewayErrorResponseBody",
    "GatewaysGetGatewaysGatewayTimeoutErrorResponseBody",
    "GatewaysGetGatewaysInternalServerErrorResponseBody",
    "GatewaysGetGatewaysMethodNotAllowedErrorResponseBody",
    "GatewaysGetGatewaysNotFoundErrorResponseBody",
    "GatewaysGetGatewaysNotImplementedErrorResponseBody",
    "GatewaysGetGatewaysResponseBody",
    "GatewaysGetGatewaysServiceUnavailableErrorResponseBody",
    "GatewaysGetGatewaysTooManyRequestsErrorResponseBody",
    "GatewaysGetGatewaysUnauthorizedErrorResponseBody",
    "GatewaysPostGatewayBadGatewayErrorResponseBody",
    "GatewaysPostGatewayGatewayTimeoutErrorResponseBody",
    "GatewaysPostGatewayInternalServerErrorResponseBody",
    "GatewaysPostGatewayMethodNotAllowedErrorResponseBody",
    "GatewaysPostGatewayNotFoundErrorResponseBody",
    "GatewaysPostGatewayNotImplementedErrorResponseBody",
    "GatewaysPostGatewayResponseBody",
    "GatewaysPostGatewayServiceUnavailableErrorResponseBody",
    "GatewaysPostGatewayTooManyRequestsErrorResponseBody",
    "GatewaysPostGatewayUnauthorizedErrorResponseBody",
    "GeofenceEntryTriggerDetailsObjectRequestBody",
    "GeofenceEntryTriggerDetailsObjectResponseBody",
    "GeofenceExitTriggerDetailsObjectRequestBody",
    "GeofenceExitTriggerDetailsObjectResponseBody",
    "GeofenceResponseResponseBody",
    "GetAttributesByEntityTypeResponse",
    "GetDocumentTypeResponseObjectResponseBody",
    "GetDriverTrailerAssignmentsResponseBodyResponseBody",
    "GetMediaRetrievalObjectResponseBody",
    "GetReportRunsDataObjectResponseBody",
    "GetReportRunsDataObjectResponseBodyStatus",
    "GetResponseWorkflowConfigurationObjectResponseBody",
    "GetWorkflowIncidentResponseObjectResponseBody",
    "GoaAddressTinyResponseResponseBody",
    "GoaAttributeTiny",
    "GoaAttributeTinyRequestBody",
    "GoaAttributeTinyResponseBody",
    "GoaDocumentTinyResponseResponseBody",
    "GoaDocumentTypeTinyResponseResponseBody",
    "GoaDriverTinyResponseResponseBody",
    "GoaFormTinyResponseResponseBody",
    "GoaGatewayTinyResponseResponseBody",
    "GoaGatewayTinyResponseResponseBodyModel",
    "GoaIssueTinyResponseResponseBody",
    "GoaPaginationResponseResponseBody",
    "GoaPaginationWithTokensResponseResponseBody",
    "GoaRouteStopTinyResponseResponseBody",
    "GoaRouteTinyResponseResponseBody",
    "GoaTagTinyResponseRequestBody",
    "GoaTagTinyResponseResponseBody",
    "GoaTrailerTinyResponseResponseBody",
    "GoaVehicleTinyResponseResponseBody",
    "GpsSignalLossDetailsObjectRequestBody",
    "GpsSignalLossDetailsObjectResponseBody",
    "GpsSignalLossResponseBody",
    "GreenBandDrivingDurationMs",
    "GrossVehicleWeight",
    "GrossVehicleWeightUnit",
    "HarshAccelSensitivityGForceSettingsObjectResponseBody",
    "HarshAccelSensitivityV2SettingsObjectResponseBody",
    "HarshAccelSensitivityV2SettingsObjectResponseBodyHeavyDuty",
    "HarshAccelSensitivityV2SettingsObjectResponseBodyLightDuty",
    "HarshAccelSensitivityV2SettingsObjectResponseBodyPassenger",
    "HarshBrakeSensitivityGForceSettingsObjectResponseBody",
    "HarshBrakeSensitivityV2SettingsObjectResponseBody",
    "HarshBrakeSensitivityV2SettingsObjectResponseBodyHeavyDuty",
    "HarshBrakeSensitivityV2SettingsObjectResponseBodyLightDuty",
    "HarshBrakeSensitivityV2SettingsObjectResponseBodyPassenger",
    "HarshEventDataResponseBody",
    "HarshEventSensitivitySettingsObjectResponseBody",
    "HarshEventSensitivityV2SettingsObjectResponseBody",
    "HarshEventTriggerDetailsObjectRequestBody",
    "HarshEventTriggerDetailsObjectRequestBodyTypesItem",
    "HarshEventTriggerDetailsObjectResponseBody",
    "HarshEventTriggerDetailsObjectResponseBodyTypesItem",
    "HarshTurnSensitivityGForceSettingsObjectResponseBody",
    "HarshTurnSensitivityV2SettingsObjectResponseBody",
    "HarshTurnSensitivityV2SettingsObjectResponseBodyHeavyDuty",
    "HarshTurnSensitivityV2SettingsObjectResponseBodyLightDuty",
    "HarshTurnSensitivityV2SettingsObjectResponseBodyPassenger",
    "HealthDetailsResponseResponseBody",
    "HealthReasonResponseResponseBody",
    "HealthReasonResponseResponseBodyHealthReasonCode",
    "HealthResponseResponseBody",
    "HealthResponseResponseBodyHealthStatus",
    "HealthResponseResponseBodyPrimaryHealthReason",
    "HealthResponseResponseBodyRecommendedAction",
    "HighTorqueMs",
    "HosBreak",
    "HosClocks",
    "HosClocksForDriver",
    "HosClocksForDrivers",
    "HosClocksResponse",
    "HosCycle",
    "HosDailyLogsGetHosDailyLogsBadGatewayErrorResponseBody",
    "HosDailyLogsGetHosDailyLogsGatewayTimeoutErrorResponseBody",
    "HosDailyLogsGetHosDailyLogsInternalServerErrorResponseBody",
    "HosDailyLogsGetHosDailyLogsMethodNotAllowedErrorResponseBody",
    "HosDailyLogsGetHosDailyLogsNotFoundErrorResponseBody",
    "HosDailyLogsGetHosDailyLogsNotImplementedErrorResponseBody",
    "HosDailyLogsGetHosDailyLogsResponseBody",
    "HosDailyLogsGetHosDailyLogsServiceUnavailableErrorResponseBody",
    "HosDailyLogsGetHosDailyLogsTooManyRequestsErrorResponseBody",
    "HosDailyLogsGetHosDailyLogsUnauthorizedErrorResponseBody",
    "HosDailyLogsObjectResponseBody",
    "HosDailyLogsUpdateShippingDocsBadGatewayErrorResponseBody",
    "HosDailyLogsUpdateShippingDocsGatewayTimeoutErrorResponseBody",
    "HosDailyLogsUpdateShippingDocsInternalServerErrorResponseBody",
    "HosDailyLogsUpdateShippingDocsMethodNotAllowedErrorResponseBody",
    "HosDailyLogsUpdateShippingDocsNotFoundErrorResponseBody",
    "HosDailyLogsUpdateShippingDocsNotImplementedErrorResponseBody",
    "HosDailyLogsUpdateShippingDocsResponseBody",
    "HosDailyLogsUpdateShippingDocsServiceUnavailableErrorResponseBody",
    "HosDailyLogsUpdateShippingDocsTooManyRequestsErrorResponseBody",
    "HosDailyLogsUpdateShippingDocsUnauthorizedErrorResponseBody",
    "HosDrive",
    "HosDriversEldEventObjectResponseBody",
    "HosDriversEldEventObjectResponseBodyDriverActivationStatus",
    "HosEldEventLocationObjectResponseBody",
    "HosEldEventObjectResponseBody",
    "HosEldEventObjectResponseBodyMalfunctionDiagnosticCode",
    "HosEldEventRemarkObjectResponseBody",
    "HosEldEventsGetHosEldEventsBadGatewayErrorResponseBody",
    "HosEldEventsGetHosEldEventsGatewayTimeoutErrorResponseBody",
    "HosEldEventsGetHosEldEventsInternalServerErrorResponseBody",
    "HosEldEventsGetHosEldEventsMethodNotAllowedErrorResponseBody",
    "HosEldEventsGetHosEldEventsNotFoundErrorResponseBody",
    "HosEldEventsGetHosEldEventsNotImplementedErrorResponseBody",
    "HosEldEventsGetHosEldEventsResponseBody",
    "HosEldEventsGetHosEldEventsServiceUnavailableErrorResponseBody",
    "HosEldEventsGetHosEldEventsTooManyRequestsErrorResponseBody",
    "HosEldEventsGetHosEldEventsUnauthorizedErrorResponseBody",
    "HosLogEntry",
    "HosLogEntryHosStatusType",
    "HosLogLocation",
    "HosLogsForDriver",
    "HosLogsForDrivers",
    "HosLogsList",
    "HosLogsResponse",
    "HosShift",
    "HosViolationDataResponseBody",
    "HosViolationDayObjectResponseBody",
    "HosViolationObjectResponseBody",
    "HosViolationObjectResponseBodyType",
    "HosViolationTriggerDetailsObjectRequestBody",
    "HosViolationTriggerDetailsObjectRequestBodyViolation",
    "HosViolationTriggerDetailsObjectResponseBody",
    "HosViolationTriggerDetailsObjectResponseBodyViolation",
    "HosViolations",
    "HosViolationsGetHosViolationsBadGatewayErrorResponseBody",
    "HosViolationsGetHosViolationsGatewayTimeoutErrorResponseBody",
    "HosViolationsGetHosViolationsInternalServerErrorResponseBody",
    "HosViolationsGetHosViolationsMethodNotAllowedErrorResponseBody",
    "HosViolationsGetHosViolationsNotFoundErrorResponseBody",
    "HosViolationsGetHosViolationsNotImplementedErrorResponseBody",
    "HosViolationsGetHosViolationsResponseBody",
    "HosViolationsGetHosViolationsServiceUnavailableErrorResponseBody",
    "HosViolationsGetHosViolationsTooManyRequestsErrorResponseBody",
    "HosViolationsGetHosViolationsUnauthorizedErrorResponseBody",
    "HosViolationsObjectResponseBody",
    "HubCapacitiesListHubCapacitiesBadGatewayErrorResponseBody",
    "HubCapacitiesListHubCapacitiesGatewayTimeoutErrorResponseBody",
    "HubCapacitiesListHubCapacitiesInternalServerErrorResponseBody",
    "HubCapacitiesListHubCapacitiesMethodNotAllowedErrorResponseBody",
    "HubCapacitiesListHubCapacitiesNotFoundErrorResponseBody",
    "HubCapacitiesListHubCapacitiesNotImplementedErrorResponseBody",
    "HubCapacitiesListHubCapacitiesResponseBody",
    "HubCapacitiesListHubCapacitiesServiceUnavailableErrorResponseBody",
    "HubCapacitiesListHubCapacitiesTooManyRequestsErrorResponseBody",
    "HubCapacitiesListHubCapacitiesUnauthorizedErrorResponseBody",
    "HubCapacityObjectResponseBody",
    "HubCustomPropertiesListHubCustomPropertiesBadGatewayErrorResponseBody",
    "HubCustomPropertiesListHubCustomPropertiesGatewayTimeoutErrorResponseBody",
    "HubCustomPropertiesListHubCustomPropertiesInternalServerErrorResponseBody",
    "HubCustomPropertiesListHubCustomPropertiesMethodNotAllowedErrorResponseBody",
    "HubCustomPropertiesListHubCustomPropertiesNotFoundErrorResponseBody",
    "HubCustomPropertiesListHubCustomPropertiesNotImplementedErrorResponseBody",
    "HubCustomPropertiesListHubCustomPropertiesResponseBody",
    "HubCustomPropertiesListHubCustomPropertiesServiceUnavailableErrorResponseBody",
    "HubCustomPropertiesListHubCustomPropertiesTooManyRequestsErrorResponseBody",
    "HubCustomPropertiesListHubCustomPropertiesUnauthorizedErrorResponseBody",
    "HubCustomPropertyObjectResponseBody",
    "HubLocationCreatedObjectResponseBody",
    "HubLocationInputObjectRequestBody",
    "HubLocationObjectResponseBody",
    "HubLocationServiceWindowInputRequestBody",
    "HubLocationUpdatedObjectResponseBody",
    "HubLocationsCreateHubLocationsBadGatewayErrorResponseBody",
    "HubLocationsCreateHubLocationsGatewayTimeoutErrorResponseBody",
    "HubLocationsCreateHubLocationsInternalServerErrorResponseBody",
    "HubLocationsCreateHubLocationsMethodNotAllowedErrorResponseBody",
    "HubLocationsCreateHubLocationsNotFoundErrorResponseBody",
    "HubLocationsCreateHubLocationsNotImplementedErrorResponseBody",
    "HubLocationsCreateHubLocationsResponseBody",
    "HubLocationsCreateHubLocationsServiceUnavailableErrorResponseBody",
    "HubLocationsCreateHubLocationsTooManyRequestsErrorResponseBody",
    "HubLocationsCreateHubLocationsUnauthorizedErrorResponseBody",
    "HubLocationsListHubLocationsBadGatewayErrorResponseBody",
    "HubLocationsListHubLocationsGatewayTimeoutErrorResponseBody",
    "HubLocationsListHubLocationsInternalServerErrorResponseBody",
    "HubLocationsListHubLocationsMethodNotAllowedErrorResponseBody",
    "HubLocationsListHubLocationsNotFoundErrorResponseBody",
    "HubLocationsListHubLocationsNotImplementedErrorResponseBody",
    "HubLocationsListHubLocationsResponseBody",
    "HubLocationsListHubLocationsServiceUnavailableErrorResponseBody",
    "HubLocationsListHubLocationsTooManyRequestsErrorResponseBody",
    "HubLocationsListHubLocationsUnauthorizedErrorResponseBody",
    "HubLocationsUpdateHubLocationBadGatewayErrorResponseBody",
    "HubLocationsUpdateHubLocationGatewayTimeoutErrorResponseBody",
    "HubLocationsUpdateHubLocationInternalServerErrorResponseBody",
    "HubLocationsUpdateHubLocationMethodNotAllowedErrorResponseBody",
    "HubLocationsUpdateHubLocationNotFoundErrorResponseBody",
    "HubLocationsUpdateHubLocationNotImplementedErrorResponseBody",
    "HubLocationsUpdateHubLocationResponseBody",
    "HubLocationsUpdateHubLocationServiceUnavailableErrorResponseBody",
    "HubLocationsUpdateHubLocationTooManyRequestsErrorResponseBody",
    "HubLocationsUpdateHubLocationUnauthorizedErrorResponseBody",
    "HubObjectResponseBody",
    "HubPlanRoutesListHubPlanRoutesBadGatewayErrorResponseBody",
    "HubPlanRoutesListHubPlanRoutesGatewayTimeoutErrorResponseBody",
    "HubPlanRoutesListHubPlanRoutesInternalServerErrorResponseBody",
    "HubPlanRoutesListHubPlanRoutesMethodNotAllowedErrorResponseBody",
    "HubPlanRoutesListHubPlanRoutesNotFoundErrorResponseBody",
    "HubPlanRoutesListHubPlanRoutesNotImplementedErrorResponseBody",
    "HubPlanRoutesListHubPlanRoutesResponseBody",
    "HubPlanRoutesListHubPlanRoutesServiceUnavailableErrorResponseBody",
    "HubPlanRoutesListHubPlanRoutesTooManyRequestsErrorResponseBody",
    "HubPlanRoutesListHubPlanRoutesUnauthorizedErrorResponseBody",
    "HubPlansCreateHubPlanBadGatewayErrorResponseBody",
    "HubPlansCreateHubPlanGatewayTimeoutErrorResponseBody",
    "HubPlansCreateHubPlanInternalServerErrorResponseBody",
    "HubPlansCreateHubPlanMethodNotAllowedErrorResponseBody",
    "HubPlansCreateHubPlanNotFoundErrorResponseBody",
    "HubPlansCreateHubPlanNotImplementedErrorResponseBody",
    "HubPlansCreateHubPlanResponseBody",
    "HubPlansCreateHubPlanServiceUnavailableErrorResponseBody",
    "HubPlansCreateHubPlanTooManyRequestsErrorResponseBody",
    "HubPlansCreateHubPlanUnauthorizedErrorResponseBody",
    "HubPlansListHubPlansBadGatewayErrorResponseBody",
    "HubPlansListHubPlansGatewayTimeoutErrorResponseBody",
    "HubPlansListHubPlansInternalServerErrorResponseBody",
    "HubPlansListHubPlansMethodNotAllowedErrorResponseBody",
    "HubPlansListHubPlansNotFoundErrorResponseBody",
    "HubPlansListHubPlansNotImplementedErrorResponseBody",
    "HubPlansListHubPlansResponseBody",
    "HubPlansListHubPlansServiceUnavailableErrorResponseBody",
    "HubPlansListHubPlansTooManyRequestsErrorResponseBody",
    "HubPlansListHubPlansUnauthorizedErrorResponseBody",
    "HubSkillObjectResponseBody",
    "HubSkillsListHubSkillsBadGatewayErrorResponseBody",
    "HubSkillsListHubSkillsGatewayTimeoutErrorResponseBody",
    "HubSkillsListHubSkillsInternalServerErrorResponseBody",
    "HubSkillsListHubSkillsMethodNotAllowedErrorResponseBody",
    "HubSkillsListHubSkillsNotFoundErrorResponseBody",
    "HubSkillsListHubSkillsNotImplementedErrorResponseBody",
    "HubSkillsListHubSkillsResponseBody",
    "HubSkillsListHubSkillsServiceUnavailableErrorResponseBody",
    "HubSkillsListHubSkillsTooManyRequestsErrorResponseBody",
    "HubSkillsListHubSkillsUnauthorizedErrorResponseBody",
    "HubsListHubsBadGatewayErrorResponseBody",
    "HubsListHubsGatewayTimeoutErrorResponseBody",
    "HubsListHubsInternalServerErrorResponseBody",
    "HubsListHubsMethodNotAllowedErrorResponseBody",
    "HubsListHubsNotFoundErrorResponseBody",
    "HubsListHubsNotImplementedErrorResponseBody",
    "HubsListHubsResponseBody",
    "HubsListHubsServiceUnavailableErrorResponseBody",
    "HubsListHubsTooManyRequestsErrorResponseBody",
    "HubsListHubsUnauthorizedErrorResponseBody",
    "IdleTimeDurationMs",
    "IdlingEventAddressObjectResponseBody",
    "IdlingEventAddressObjectResponseBodyAddressTypesItem",
    "IdlingEventAssetObjectResponseBody",
    "IdlingEventObjectV20251023ResponseBody",
    "IdlingEventObjectV20251023ResponseBodyPtoState",
    "IdlingEventOperatorObjectResponseBody",
    "IdlingReportEventAddressResponseBody",
    "IdlingReportEventResponseBody",
    "IdlingReportsGetVehicleIdlingReportsBadGatewayErrorResponseBody",
    "IdlingReportsGetVehicleIdlingReportsGatewayTimeoutErrorResponseBody",
    "IdlingReportsGetVehicleIdlingReportsInternalServerErrorResponseBody",
    "IdlingReportsGetVehicleIdlingReportsMethodNotAllowedErrorResponseBody",
    "IdlingReportsGetVehicleIdlingReportsNotFoundErrorResponseBody",
    "IdlingReportsGetVehicleIdlingReportsNotImplementedErrorResponseBody",
    "IdlingReportsGetVehicleIdlingReportsResponseBody",
    "IdlingReportsGetVehicleIdlingReportsServiceUnavailableErrorResponseBody",
    "IdlingReportsGetVehicleIdlingReportsTooManyRequestsErrorResponseBody",
    "IdlingReportsGetVehicleIdlingReportsUnauthorizedErrorResponseBody",
    "IftaCreateIftaDetailJobBadGatewayErrorResponseBody",
    "IftaCreateIftaDetailJobGatewayTimeoutErrorResponseBody",
    "IftaCreateIftaDetailJobInternalServerErrorResponseBody",
    "IftaCreateIftaDetailJobMethodNotAllowedErrorResponseBody",
    "IftaCreateIftaDetailJobNotFoundErrorResponseBody",
    "IftaCreateIftaDetailJobNotImplementedErrorResponseBody",
    "IftaCreateIftaDetailJobResponseBody",
    "IftaCreateIftaDetailJobServiceUnavailableErrorResponseBody",
    "IftaCreateIftaDetailJobTooManyRequestsErrorResponseBody",
    "IftaCreateIftaDetailJobUnauthorizedErrorResponseBody",
    "IftaDetailJobArgsResponseBody",
    "IftaDetailJobOutputResponseBody",
    "IftaDetailJobResponseBody",
    "IftaDetailJobResponseBodyJobStatus",
    "IftaGetIftaDetailJobBadGatewayErrorResponseBody",
    "IftaGetIftaDetailJobGatewayTimeoutErrorResponseBody",
    "IftaGetIftaDetailJobInternalServerErrorResponseBody",
    "IftaGetIftaDetailJobMethodNotAllowedErrorResponseBody",
    "IftaGetIftaDetailJobNotFoundErrorResponseBody",
    "IftaGetIftaDetailJobNotImplementedErrorResponseBody",
    "IftaGetIftaDetailJobResponseBody",
    "IftaGetIftaDetailJobServiceUnavailableErrorResponseBody",
    "IftaGetIftaDetailJobTooManyRequestsErrorResponseBody",
    "IftaGetIftaDetailJobUnauthorizedErrorResponseBody",
    "IftaGetIftaJurisdictionReportsBadGatewayErrorResponseBody",
    "IftaGetIftaJurisdictionReportsGatewayTimeoutErrorResponseBody",
    "IftaGetIftaJurisdictionReportsInternalServerErrorResponseBody",
    "IftaGetIftaJurisdictionReportsMethodNotAllowedErrorResponseBody",
    "IftaGetIftaJurisdictionReportsNotFoundErrorResponseBody",
    "IftaGetIftaJurisdictionReportsNotImplementedErrorResponseBody",
    "IftaGetIftaJurisdictionReportsResponseBody",
    "IftaGetIftaJurisdictionReportsServiceUnavailableErrorResponseBody",
    "IftaGetIftaJurisdictionReportsTooManyRequestsErrorResponseBody",
    "IftaGetIftaJurisdictionReportsUnauthorizedErrorResponseBody",
    "IftaGetIftaVehicleReportsBadGatewayErrorResponseBody",
    "IftaGetIftaVehicleReportsGatewayTimeoutErrorResponseBody",
    "IftaGetIftaVehicleReportsInternalServerErrorResponseBody",
    "IftaGetIftaVehicleReportsMethodNotAllowedErrorResponseBody",
    "IftaGetIftaVehicleReportsNotFoundErrorResponseBody",
    "IftaGetIftaVehicleReportsNotImplementedErrorResponseBody",
    "IftaGetIftaVehicleReportsResponseBody",
    "IftaGetIftaVehicleReportsServiceUnavailableErrorResponseBody",
    "IftaGetIftaVehicleReportsTooManyRequestsErrorResponseBody",
    "IftaGetIftaVehicleReportsUnauthorizedErrorResponseBody",
    "IftaJurisdictionReportDataObjectResponseBody",
    "IftaJurisdictionSummaryObjectResponseBody",
    "IftaReportTroubleshootingObjectResponseBody",
    "IftaVehicleReportDataObjectResponseBody",
    "IftaVehicleReportObjectResponseBody",
    "InAppNotificationOptionsObjectRequestBody",
    "InAppNotificationOptionsObjectResponseBody",
    "InactivityResponseBody",
    "InattentiveDrivingDetectionAlertSettingsObjectResponseBody",
    "InattentiveDrivingDetectionAlertSettingsObjectResponseBodySeverity",
    "IndustrialAssetObjectResponseBody",
    "InlineResponse200",
    "InlineResponse2001",
    "InlineResponse2002",
    "InlineResponse2003",
    "InlineResponse2004",
    "InlineResponse2005",
    "InlineResponse2006",
    "InlineResponse2007",
    "InlineResponse2008",
    "InlineResponse2009",
    "InsideGeofenceDataResponseBody",
    "InsideGeofenceTriggerDetailsObjectRequestBody",
    "InsideGeofenceTriggerDetailsObjectResponseBody",
    "InvoiceScanFileRequestBody",
    "IssueCreatedResponseBody",
    "IssueResponseObjectResponseBody",
    "IssueResponseObjectResponseBodyPriority",
    "IssueResponseObjectResponseBodyStatus",
    "IssueSourceObjectResponseBody",
    "IssueSourceObjectResponseBodyType",
    "IssuesGetIssuesBadGatewayErrorResponseBody",
    "IssuesGetIssuesGatewayTimeoutErrorResponseBody",
    "IssuesGetIssuesInternalServerErrorResponseBody",
    "IssuesGetIssuesMethodNotAllowedErrorResponseBody",
    "IssuesGetIssuesNotFoundErrorResponseBody",
    "IssuesGetIssuesNotImplementedErrorResponseBody",
    "IssuesGetIssuesResponseBody",
    "IssuesGetIssuesServiceUnavailableErrorResponseBody",
    "IssuesGetIssuesStreamBadGatewayErrorResponseBody",
    "IssuesGetIssuesStreamGatewayTimeoutErrorResponseBody",
    "IssuesGetIssuesStreamInternalServerErrorResponseBody",
    "IssuesGetIssuesStreamMethodNotAllowedErrorResponseBody",
    "IssuesGetIssuesStreamNotFoundErrorResponseBody",
    "IssuesGetIssuesStreamNotImplementedErrorResponseBody",
    "IssuesGetIssuesStreamResponseBody",
    "IssuesGetIssuesStreamServiceUnavailableErrorResponseBody",
    "IssuesGetIssuesStreamTooManyRequestsErrorResponseBody",
    "IssuesGetIssuesStreamUnauthorizedErrorResponseBody",
    "IssuesGetIssuesTooManyRequestsErrorResponseBody",
    "IssuesGetIssuesUnauthorizedErrorResponseBody",
    "IssuesPatchIssueBadGatewayErrorResponseBody",
    "IssuesPatchIssueGatewayTimeoutErrorResponseBody",
    "IssuesPatchIssueInternalServerErrorResponseBody",
    "IssuesPatchIssueMethodNotAllowedErrorResponseBody",
    "IssuesPatchIssueNotFoundErrorResponseBody",
    "IssuesPatchIssueNotImplementedErrorResponseBody",
    "IssuesPatchIssueResponseBody",
    "IssuesPatchIssueServiceUnavailableErrorResponseBody",
    "IssuesPatchIssueTooManyRequestsErrorResponseBody",
    "IssuesPatchIssueUnauthorizedErrorResponseBody",
    "J1939D1StatusDataPoint",
    "J1939D1StatusDataPointValue",
    "JammingDetectedResponseBody",
    "JobLocationResponseObjectResponseBody",
    "JobResponseObjectResponseBody",
    "JobResponseObjectResponseBodyStatus",
    "JobsCreateJobBadGatewayErrorResponseBody",
    "JobsCreateJobGatewayTimeoutErrorResponseBody",
    "JobsCreateJobInternalServerErrorResponseBody",
    "JobsCreateJobMethodNotAllowedErrorResponseBody",
    "JobsCreateJobNotFoundErrorResponseBody",
    "JobsCreateJobNotImplementedErrorResponseBody",
    "JobsCreateJobResponseBody",
    "JobsCreateJobServiceUnavailableErrorResponseBody",
    "JobsCreateJobTooManyRequestsErrorResponseBody",
    "JobsCreateJobUnauthorizedErrorResponseBody",
    "JobsDeleteJobBadGatewayErrorResponseBody",
    "JobsDeleteJobGatewayTimeoutErrorResponseBody",
    "JobsDeleteJobInternalServerErrorResponseBody",
    "JobsDeleteJobMethodNotAllowedErrorResponseBody",
    "JobsDeleteJobNotFoundErrorResponseBody",
    "JobsDeleteJobNotImplementedErrorResponseBody",
    "JobsDeleteJobResponseBody",
    "JobsDeleteJobServiceUnavailableErrorResponseBody",
    "JobsDeleteJobTooManyRequestsErrorResponseBody",
    "JobsDeleteJobUnauthorizedErrorResponseBody",
    "JobsGetJobsBadGatewayErrorResponseBody",
    "JobsGetJobsGatewayTimeoutErrorResponseBody",
    "JobsGetJobsInternalServerErrorResponseBody",
    "JobsGetJobsMethodNotAllowedErrorResponseBody",
    "JobsGetJobsNotFoundErrorResponseBody",
    "JobsGetJobsNotImplementedErrorResponseBody",
    "JobsGetJobsResponseBody",
    "JobsGetJobsServiceUnavailableErrorResponseBody",
    "JobsGetJobsTooManyRequestsErrorResponseBody",
    "JobsGetJobsUnauthorizedErrorResponseBody",
    "JobsPatchJobBadGatewayErrorResponseBody",
    "JobsPatchJobGatewayTimeoutErrorResponseBody",
    "JobsPatchJobInternalServerErrorResponseBody",
    "JobsPatchJobMethodNotAllowedErrorResponseBody",
    "JobsPatchJobNotFoundErrorResponseBody",
    "JobsPatchJobNotImplementedErrorResponseBody",
    "JobsPatchJobResponseBody",
    "JobsPatchJobServiceUnavailableErrorResponseBody",
    "JobsPatchJobTooManyRequestsErrorResponseBody",
    "JobsPatchJobUnauthorizedErrorResponseBody",
    "LastKnownLocationResponseResponseBody",
    "Latitude",
    "ListAddressesResponse",
    "ListCarrierProposedAssignmentResponse",
    "ListContactsResponse",
    "ListDriversResponse",
    "ListHubCapacitiesResponsePaginationResponseBody",
    "ListHubCustomPropertiesResponsePaginationResponseBody",
    "ListHubLocationsResponsePaginationResponseBody",
    "ListHubPlanRoutesResponsePaginationResponseBody",
    "ListHubPlansResponsePaginationResponseBody",
    "ListHubSkillsResponsePaginationResponseBody",
    "ListHubsResponsePaginationResponseBody",
    "ListIndustrialAssetsResponse",
    "ListTagsResponse",
    "ListUploadedMediaObjectResponseBody",
    "ListUserRolesResponse",
    "ListUsersResponse",
    "LiveSharingLinkFullResponseObjectResponseBody",
    "LiveSharingLinkFullResponseObjectResponseBodyType",
    "LiveSharingLinkResponseObjectResponseBody",
    "LiveSharingLinksCreateLiveSharingLinkBadGatewayErrorResponseBody",
    "LiveSharingLinksCreateLiveSharingLinkGatewayTimeoutErrorResponseBody",
    "LiveSharingLinksCreateLiveSharingLinkInternalServerErrorResponseBody",
    "LiveSharingLinksCreateLiveSharingLinkMethodNotAllowedErrorResponseBody",
    "LiveSharingLinksCreateLiveSharingLinkNotFoundErrorResponseBody",
    "LiveSharingLinksCreateLiveSharingLinkNotImplementedErrorResponseBody",
    "LiveSharingLinksCreateLiveSharingLinkResponseBody",
    "LiveSharingLinksCreateLiveSharingLinkServiceUnavailableErrorResponseBody",
    "LiveSharingLinksCreateLiveSharingLinkTooManyRequestsErrorResponseBody",
    "LiveSharingLinksCreateLiveSharingLinkUnauthorizedErrorResponseBody",
    "LiveSharingLinksDeleteLiveSharingLinkBadGatewayErrorResponseBody",
    "LiveSharingLinksDeleteLiveSharingLinkGatewayTimeoutErrorResponseBody",
    "LiveSharingLinksDeleteLiveSharingLinkInternalServerErrorResponseBody",
    "LiveSharingLinksDeleteLiveSharingLinkMethodNotAllowedErrorResponseBody",
    "LiveSharingLinksDeleteLiveSharingLinkNotFoundErrorResponseBody",
    "LiveSharingLinksDeleteLiveSharingLinkNotImplementedErrorResponseBody",
    "LiveSharingLinksDeleteLiveSharingLinkServiceUnavailableErrorResponseBody",
    "LiveSharingLinksDeleteLiveSharingLinkTooManyRequestsErrorResponseBody",
    "LiveSharingLinksDeleteLiveSharingLinkUnauthorizedErrorResponseBody",
    "LiveSharingLinksGetLiveSharingLinksBadGatewayErrorResponseBody",
    "LiveSharingLinksGetLiveSharingLinksGatewayTimeoutErrorResponseBody",
    "LiveSharingLinksGetLiveSharingLinksInternalServerErrorResponseBody",
    "LiveSharingLinksGetLiveSharingLinksMethodNotAllowedErrorResponseBody",
    "LiveSharingLinksGetLiveSharingLinksNotFoundErrorResponseBody",
    "LiveSharingLinksGetLiveSharingLinksNotImplementedErrorResponseBody",
    "LiveSharingLinksGetLiveSharingLinksResponseBody",
    "LiveSharingLinksGetLiveSharingLinksServiceUnavailableErrorResponseBody",
    "LiveSharingLinksGetLiveSharingLinksTooManyRequestsErrorResponseBody",
    "LiveSharingLinksGetLiveSharingLinksUnauthorizedErrorResponseBody",
    "LiveSharingLinksUpdateLiveSharingLinkBadGatewayErrorResponseBody",
    "LiveSharingLinksUpdateLiveSharingLinkGatewayTimeoutErrorResponseBody",
    "LiveSharingLinksUpdateLiveSharingLinkInternalServerErrorResponseBody",
    "LiveSharingLinksUpdateLiveSharingLinkMethodNotAllowedErrorResponseBody",
    "LiveSharingLinksUpdateLiveSharingLinkNotFoundErrorResponseBody",
    "LiveSharingLinksUpdateLiveSharingLinkNotImplementedErrorResponseBody",
    "LiveSharingLinksUpdateLiveSharingLinkResponseBody",
    "LiveSharingLinksUpdateLiveSharingLinkServiceUnavailableErrorResponseBody",
    "LiveSharingLinksUpdateLiveSharingLinkTooManyRequestsErrorResponseBody",
    "LiveSharingLinksUpdateLiveSharingLinkUnauthorizedErrorResponseBody",
    "Location",
    "LocationAndSpeedGetLocationAndSpeedBadGatewayErrorResponseBody",
    "LocationAndSpeedGetLocationAndSpeedGatewayTimeoutErrorResponseBody",
    "LocationAndSpeedGetLocationAndSpeedInternalServerErrorResponseBody",
    "LocationAndSpeedGetLocationAndSpeedMethodNotAllowedErrorResponseBody",
    "LocationAndSpeedGetLocationAndSpeedNotFoundErrorResponseBody",
    "LocationAndSpeedGetLocationAndSpeedNotImplementedErrorResponseBody",
    "LocationAndSpeedGetLocationAndSpeedResponseBody",
    "LocationAndSpeedGetLocationAndSpeedServiceUnavailableErrorResponseBody",
    "LocationAndSpeedGetLocationAndSpeedTooManyRequestsErrorResponseBody",
    "LocationAndSpeedGetLocationAndSpeedUnauthorizedErrorResponseBody",
    "LocationAndSpeedResponseResponseBody",
    "LocationDataPoint",
    "LocationDataPointGpsLocation",
    "LocationDataPointGpsLocationPlace",
    "LocationObjectRequestBody",
    "LocationObjectRequestBodyAddressTypesItem",
    "LocationObjectResponseBody",
    "LocationObjectResponseBodyAddressTypesItem",
    "LocationResponseBody",
    "LocationResponseResponseBody",
    "LocationType",
    "LogMetaDataObjectResponseBody",
    "Longitude",
    "MediaObjectResponseBody",
    "MediaObjectResponseBodyCameraRole",
    "MediaObjectResponseBodyInput",
    "MediaObjectResponseBodyMediaType",
    "MediaObjectResponseBodyStatus",
    "MediaRetrievalGetMediaRetrievalBadGatewayErrorResponseBody",
    "MediaRetrievalGetMediaRetrievalGatewayTimeoutErrorResponseBody",
    "MediaRetrievalGetMediaRetrievalInternalServerErrorResponseBody",
    "MediaRetrievalGetMediaRetrievalMethodNotAllowedErrorResponseBody",
    "MediaRetrievalGetMediaRetrievalNotFoundErrorResponseBody",
    "MediaRetrievalGetMediaRetrievalNotImplementedErrorResponseBody",
    "MediaRetrievalGetMediaRetrievalResponseBody",
    "MediaRetrievalGetMediaRetrievalServiceUnavailableErrorResponseBody",
    "MediaRetrievalGetMediaRetrievalTooManyRequestsErrorResponseBody",
    "MediaRetrievalGetMediaRetrievalUnauthorizedErrorResponseBody",
    "MediaRetrievalListUploadedMediaBadGatewayErrorResponseBody",
    "MediaRetrievalListUploadedMediaGatewayTimeoutErrorResponseBody",
    "MediaRetrievalListUploadedMediaInternalServerErrorResponseBody",
    "MediaRetrievalListUploadedMediaMethodNotAllowedErrorResponseBody",
    "MediaRetrievalListUploadedMediaNotFoundErrorResponseBody",
    "MediaRetrievalListUploadedMediaNotImplementedErrorResponseBody",
    "MediaRetrievalListUploadedMediaResponseBody",
    "MediaRetrievalListUploadedMediaServiceUnavailableErrorResponseBody",
    "MediaRetrievalListUploadedMediaTooManyRequestsErrorResponseBody",
    "MediaRetrievalListUploadedMediaUnauthorizedErrorResponseBody",
    "MediaRetrievalPostMediaRetrievalBadGatewayErrorResponseBody",
    "MediaRetrievalPostMediaRetrievalGatewayTimeoutErrorResponseBody",
    "MediaRetrievalPostMediaRetrievalInternalServerErrorResponseBody",
    "MediaRetrievalPostMediaRetrievalMethodNotAllowedErrorResponseBody",
    "MediaRetrievalPostMediaRetrievalNotFoundErrorResponseBody",
    "MediaRetrievalPostMediaRetrievalNotImplementedErrorResponseBody",
    "MediaRetrievalPostMediaRetrievalResponseBody",
    "MediaRetrievalPostMediaRetrievalServiceUnavailableErrorResponseBody",
    "MediaRetrievalPostMediaRetrievalTooManyRequestsErrorResponseBody",
    "MediaRetrievalPostMediaRetrievalUnauthorizedErrorResponseBody",
    "MinimalRouteAuditLogsResponseBody",
    "MinimalRouteStopAuditLogsResponseBody",
    "MinimalRouteStopAuditLogsResponseBodyState",
    "MinimalRouteStopResponseBody",
    "MinimalRouteStopResponseBodyState",
    "MissingDvirPastDueResponseBody",
    "MobileUsageDetectionAlertSettingsObjectResponseBody",
    "MotionDetectedResponseBody",
    "MultipleChoiceFieldTypeMetaDataObjectResponseBody",
    "MultipleChoiceValueObjectRequestBody",
    "MultipleChoiceValueObjectResponseBody",
    "NumberDataPoint",
    "NumberFieldTypeMetaDataObjectResponseBody",
    "OperationalSettingsObjectRequestBody",
    "OperationalSettingsObjectRequestBodyTimeRangeType",
    "OperationalSettingsObjectResponseBody",
    "OperationalSettingsObjectResponseBodyTimeRangeType",
    "OrderCustomPropertyInputRequestBody",
    "OrderCustomPropertyResponseBody",
    "OrderInputObjectRequestBody",
    "OrderObjectResponseBody",
    "OrderQuantityInputRequestBody",
    "OrderQuantityResponseBody",
    "OrderTaskCustomPropertyObjectResponseBody",
    "OrderTaskObjectResponseBody",
    "OrderTaskRequestBody",
    "OrderTaskRequestBodyPosition",
    "OrderTaskResponseBody",
    "OrderTaskResponseBodyPosition",
    "OrderTaskSkillObjectResponseBody",
    "OrganizationInfoCarrierSettings",
    "OrganizationInfoObject",
    "OrganizationInfoResponse",
    "OutOfRouteDetailsObjectRequestBody",
    "OutOfRouteDetailsObjectResponseBody",
    "OutOfRouteResponseBody",
    "OutsideGeofenceDataResponseBody",
    "OutsideGeofenceTriggerDetailsObjectRequestBody",
    "OutsideGeofenceTriggerDetailsObjectResponseBody",
    "OverSpeedMs",
    "PaginationResponse",
    "PanicButtonDetailsObjectRequestBody",
    "PanicButtonDetailsObjectResponseBody",
    "PanicButtonResponseBody",
    "ParentId",
    "ParentTag",
    "ParentTagId",
    "ParentTagName",
    "PartInstanceInputObjectRequestBody",
    "PartInstanceObjectResponseBody",
    "PatchAssetDataOutputsSingleResponseResponseBody",
    "PatchDriverTrailerAssignmentsResponseBodyResponseBody",
    "PatchDriverVehicleAssignmentsV2RequestBodyMetadataRequestBody",
    "PatchDriverVehicleAssignmentsV2ResponseBodyResponseBody",
    "PatchIssueRequestBodyAssignedToRequestBody",
    "PatchIssueRequestBodyAssignedToRequestBodyType",
    "PatchJobObjectRequestBody",
    "PatchJobObjectjobLocationRequestObjectRequestBody",
    "PatchResponseWorkflowConfigurationObjectResponseBody",
    "PatchShippingDocsResponseBodyResponseBody",
    "PendingDutyStatusDurationsObjectResponseBody",
    "PersonDetectedResponseBody",
    "PhotoValueObjectRequestBody",
    "PhotoValueObjectResponseBody",
    "PlanObjectResponseBody",
    "PlanOrdersCreatePlanOrdersBadGatewayErrorResponseBody",
    "PlanOrdersCreatePlanOrdersGatewayTimeoutErrorResponseBody",
    "PlanOrdersCreatePlanOrdersInternalServerErrorResponseBody",
    "PlanOrdersCreatePlanOrdersMethodNotAllowedErrorResponseBody",
    "PlanOrdersCreatePlanOrdersNotFoundErrorResponseBody",
    "PlanOrdersCreatePlanOrdersNotImplementedErrorResponseBody",
    "PlanOrdersCreatePlanOrdersResponseBody",
    "PlanOrdersCreatePlanOrdersServiceUnavailableErrorResponseBody",
    "PlanOrdersCreatePlanOrdersTooManyRequestsErrorResponseBody",
    "PlanOrdersCreatePlanOrdersUnauthorizedErrorResponseBody",
    "PolicyViolationsDetectionAlertSettingsObjectResponseBody",
    "PolicyViolationsDetectionAlertSettingsObjectResponseBodyEventsAvailableForTestingItem",
    "PolicyViolationsDetectionAlertSettingsObjectResponseBodyEventsToCoachItem",
    "PolygonRequestBody",
    "PolygonResponseBody",
    "PostDriverTrailerAssignmentsResponseBodyResponseBody",
    "PostDriverVehicleAssignmentsV2RequestBodyMetadataRequestBody",
    "PostDriverVehicleAssignmentsV2ResponseBodyResponseBody",
    "PostFuelPurchaseRequestBodyDiscountRequestBody",
    "PostFuelPurchaseRequestBodyDiscountRequestBodyCurrency",
    "PostFuelPurchaseRequestBodyPriceRequestBody",
    "PostFuelPurchaseRequestBodyPriceRequestBodyCurrency",
    "PostFuelPurchaseResponseBodyResponseBody",
    "PostInvoiceScanResponseDataResponseBody",
    "PostJobObjectRequestBody",
    "PostJobObjectjobLocationRequestObjectRequestBody",
    "PostMediaRetrievalObjectResponseBody",
    "PostResponseResWorkflowConfigurationObjectResponseBody",
    "PowerTakeOffDurationMs",
    "PrimaryTimeRangeRequestBody",
    "PrimaryTimeRangeResponseBody",
    "PushNotificationOptionsObjectRequestBody",
    "PushNotificationOptionsObjectResponseBody",
    "QrCodeResponseObjectResponseBody",
    "QualificationFieldInputObjectResponseBody",
    "QualificationFieldInputObjectResponseBodyType",
    "QualificationOwnerObjectResponseBody",
    "QualificationOwnerObjectResponseBodyEntityType",
    "QualificationOwnerRequestObjectRequestBody",
    "QualificationOwnerRequestObjectRequestBodyEntityType",
    "QualificationRecordRequestFieldInputObjectRequestBody",
    "QualificationRecordRequestFieldInputObjectRequestBodyType",
    "QualificationRecordResponseObjectResponseBody",
    "QualificationRecordResponseObjectResponseBodyRecordStatus",
    "QualificationTypeReferenceObjectResponseBody",
    "QualificationTypeRequestObjectRequestBody",
    "QualificationTypeResponseObjectResponseBody",
    "QualificationTypeResponseObjectResponseBodyEntityType",
    "QualificationsArchiveQualificationRecordBadGatewayErrorResponseBody",
    "QualificationsArchiveQualificationRecordGatewayTimeoutErrorResponseBody",
    "QualificationsArchiveQualificationRecordInternalServerErrorResponseBody",
    "QualificationsArchiveQualificationRecordMethodNotAllowedErrorResponseBody",
    "QualificationsArchiveQualificationRecordNotFoundErrorResponseBody",
    "QualificationsArchiveQualificationRecordNotImplementedErrorResponseBody",
    "QualificationsArchiveQualificationRecordServiceUnavailableErrorResponseBody",
    "QualificationsArchiveQualificationRecordTooManyRequestsErrorResponseBody",
    "QualificationsArchiveQualificationRecordUnauthorizedErrorResponseBody",
    "QualificationsDeleteQualificationRecordBadGatewayErrorResponseBody",
    "QualificationsDeleteQualificationRecordGatewayTimeoutErrorResponseBody",
    "QualificationsDeleteQualificationRecordInternalServerErrorResponseBody",
    "QualificationsDeleteQualificationRecordMethodNotAllowedErrorResponseBody",
    "QualificationsDeleteQualificationRecordNotFoundErrorResponseBody",
    "QualificationsDeleteQualificationRecordNotImplementedErrorResponseBody",
    "QualificationsDeleteQualificationRecordServiceUnavailableErrorResponseBody",
    "QualificationsDeleteQualificationRecordTooManyRequestsErrorResponseBody",
    "QualificationsDeleteQualificationRecordUnauthorizedErrorResponseBody",
    "QualificationsGetQualificationRecordsBadGatewayErrorResponseBody",
    "QualificationsGetQualificationRecordsGatewayTimeoutErrorResponseBody",
    "QualificationsGetQualificationRecordsInternalServerErrorResponseBody",
    "QualificationsGetQualificationRecordsMethodNotAllowedErrorResponseBody",
    "QualificationsGetQualificationRecordsNotFoundErrorResponseBody",
    "QualificationsGetQualificationRecordsNotImplementedErrorResponseBody",
    "QualificationsGetQualificationRecordsResponseBody",
    "QualificationsGetQualificationRecordsServiceUnavailableErrorResponseBody",
    "QualificationsGetQualificationRecordsStreamBadGatewayErrorResponseBody",
    "QualificationsGetQualificationRecordsStreamGatewayTimeoutErrorResponseBody",
    "QualificationsGetQualificationRecordsStreamInternalServerErrorResponseBody",
    "QualificationsGetQualificationRecordsStreamMethodNotAllowedErrorResponseBody",
    "QualificationsGetQualificationRecordsStreamNotFoundErrorResponseBody",
    "QualificationsGetQualificationRecordsStreamNotImplementedErrorResponseBody",
    "QualificationsGetQualificationRecordsStreamResponseBody",
    "QualificationsGetQualificationRecordsStreamServiceUnavailableErrorResponseBody",
    "QualificationsGetQualificationRecordsStreamTooManyRequestsErrorResponseBody",
    "QualificationsGetQualificationRecordsStreamUnauthorizedErrorResponseBody",
    "QualificationsGetQualificationRecordsTooManyRequestsErrorResponseBody",
    "QualificationsGetQualificationRecordsUnauthorizedErrorResponseBody",
    "QualificationsGetQualificationTypesBadGatewayErrorResponseBody",
    "QualificationsGetQualificationTypesGatewayTimeoutErrorResponseBody",
    "QualificationsGetQualificationTypesInternalServerErrorResponseBody",
    "QualificationsGetQualificationTypesMethodNotAllowedErrorResponseBody",
    "QualificationsGetQualificationTypesNotFoundErrorResponseBody",
    "QualificationsGetQualificationTypesNotImplementedErrorResponseBody",
    "QualificationsGetQualificationTypesResponseBody",
    "QualificationsGetQualificationTypesServiceUnavailableErrorResponseBody",
    "QualificationsGetQualificationTypesTooManyRequestsErrorResponseBody",
    "QualificationsGetQualificationTypesUnauthorizedErrorResponseBody",
    "QualificationsPatchQualificationRecordBadGatewayErrorResponseBody",
    "QualificationsPatchQualificationRecordGatewayTimeoutErrorResponseBody",
    "QualificationsPatchQualificationRecordInternalServerErrorResponseBody",
    "QualificationsPatchQualificationRecordMethodNotAllowedErrorResponseBody",
    "QualificationsPatchQualificationRecordNotFoundErrorResponseBody",
    "QualificationsPatchQualificationRecordNotImplementedErrorResponseBody",
    "QualificationsPatchQualificationRecordResponseBody",
    "QualificationsPatchQualificationRecordServiceUnavailableErrorResponseBody",
    "QualificationsPatchQualificationRecordTooManyRequestsErrorResponseBody",
    "QualificationsPatchQualificationRecordUnauthorizedErrorResponseBody",
    "QualificationsPostQualificationRecordBadGatewayErrorResponseBody",
    "QualificationsPostQualificationRecordGatewayTimeoutErrorResponseBody",
    "QualificationsPostQualificationRecordInternalServerErrorResponseBody",
    "QualificationsPostQualificationRecordMethodNotAllowedErrorResponseBody",
    "QualificationsPostQualificationRecordNotFoundErrorResponseBody",
    "QualificationsPostQualificationRecordNotImplementedErrorResponseBody",
    "QualificationsPostQualificationRecordResponseBody",
    "QualificationsPostQualificationRecordServiceUnavailableErrorResponseBody",
    "QualificationsPostQualificationRecordTooManyRequestsErrorResponseBody",
    "QualificationsPostQualificationRecordUnauthorizedErrorResponseBody",
    "QualificationsUnarchiveQualificationRecordBadGatewayErrorResponseBody",
    "QualificationsUnarchiveQualificationRecordGatewayTimeoutErrorResponseBody",
    "QualificationsUnarchiveQualificationRecordInternalServerErrorResponseBody",
    "QualificationsUnarchiveQualificationRecordMethodNotAllowedErrorResponseBody",
    "QualificationsUnarchiveQualificationRecordNotFoundErrorResponseBody",
    "QualificationsUnarchiveQualificationRecordNotImplementedErrorResponseBody",
    "QualificationsUnarchiveQualificationRecordServiceUnavailableErrorResponseBody",
    "QualificationsUnarchiveQualificationRecordTooManyRequestsErrorResponseBody",
    "QualificationsUnarchiveQualificationRecordUnauthorizedErrorResponseBody",
    "QuantityObjectResponseBody",
    "ReadingDatapointRequestBody",
    "ReadingDatapointRequestBodyEntityType",
    "ReadingDefinitionResponseBody",
    "ReadingHistoryResponseBody",
    "ReadingSnapshotResponseBody",
    "ReadingTriggerContinuousValueObjectRequestBody",
    "ReadingTriggerContinuousValueObjectRequestBodyOperation",
    "ReadingTriggerContinuousValueObjectRequestBodyUnit",
    "ReadingTriggerContinuousValueObjectResponseBody",
    "ReadingTriggerContinuousValueObjectResponseBodyOperation",
    "ReadingTriggerContinuousValueObjectResponseBodyUnit",
    "ReadingTriggerDetailsObjectRequestBody",
    "ReadingTriggerDetailsObjectResponseBody",
    "ReadingTriggerDetailsResponseBody",
    "ReadingTriggerEnumValueObjectRequestBody",
    "ReadingTriggerEnumValueObjectResponseBody",
    "ReadingsGetReadingsHistoryBadGatewayErrorResponseBody",
    "ReadingsGetReadingsHistoryGatewayTimeoutErrorResponseBody",
    "ReadingsGetReadingsHistoryInternalServerErrorResponseBody",
    "ReadingsGetReadingsHistoryMethodNotAllowedErrorResponseBody",
    "ReadingsGetReadingsHistoryNotFoundErrorResponseBody",
    "ReadingsGetReadingsHistoryNotImplementedErrorResponseBody",
    "ReadingsGetReadingsHistoryResponseBody",
    "ReadingsGetReadingsHistoryServiceUnavailableErrorResponseBody",
    "ReadingsGetReadingsHistoryTooManyRequestsErrorResponseBody",
    "ReadingsGetReadingsHistoryUnauthorizedErrorResponseBody",
    "ReadingsGetReadingsSnapshotBadGatewayErrorResponseBody",
    "ReadingsGetReadingsSnapshotGatewayTimeoutErrorResponseBody",
    "ReadingsGetReadingsSnapshotInternalServerErrorResponseBody",
    "ReadingsGetReadingsSnapshotMethodNotAllowedErrorResponseBody",
    "ReadingsGetReadingsSnapshotNotFoundErrorResponseBody",
    "ReadingsGetReadingsSnapshotNotImplementedErrorResponseBody",
    "ReadingsGetReadingsSnapshotResponseBody",
    "ReadingsGetReadingsSnapshotServiceUnavailableErrorResponseBody",
    "ReadingsGetReadingsSnapshotTooManyRequestsErrorResponseBody",
    "ReadingsGetReadingsSnapshotUnauthorizedErrorResponseBody",
    "ReadingsListReadingsDefinitionsBadGatewayErrorResponseBody",
    "ReadingsListReadingsDefinitionsGatewayTimeoutErrorResponseBody",
    "ReadingsListReadingsDefinitionsInternalServerErrorResponseBody",
    "ReadingsListReadingsDefinitionsMethodNotAllowedErrorResponseBody",
    "ReadingsListReadingsDefinitionsNotFoundErrorResponseBody",
    "ReadingsListReadingsDefinitionsNotImplementedErrorResponseBody",
    "ReadingsListReadingsDefinitionsResponseBody",
    "ReadingsListReadingsDefinitionsServiceUnavailableErrorResponseBody",
    "ReadingsListReadingsDefinitionsTooManyRequestsErrorResponseBody",
    "ReadingsListReadingsDefinitionsUnauthorizedErrorResponseBody",
    "ReadingsPostReadingsBadGatewayErrorResponseBody",
    "ReadingsPostReadingsGatewayTimeoutErrorResponseBody",
    "ReadingsPostReadingsInternalServerErrorResponseBody",
    "ReadingsPostReadingsMethodNotAllowedErrorResponseBody",
    "ReadingsPostReadingsNotFoundErrorResponseBody",
    "ReadingsPostReadingsNotImplementedErrorResponseBody",
    "ReadingsPostReadingsServiceUnavailableErrorResponseBody",
    "ReadingsPostReadingsTooManyRequestsErrorResponseBody",
    "ReadingsPostReadingsUnauthorizedErrorResponseBody",
    "RecipientObjectRequestBody",
    "RecipientObjectRequestBodyNotificationTypesItem",
    "RecipientObjectRequestBodyType",
    "RecipientObjectResponseBody",
    "RecipientObjectResponseBodyNotificationTypesItem",
    "RecipientObjectResponseBodyType",
    "ReeferTemperatureResponseBody",
    "ReportColumnsObjectResponseBody",
    "ReportColumnsObjectResponseBodyDataType",
    "ReportColumnsObjectResponseBodyUnit",
    "ReportConfigObjectResponseBody",
    "ReportRunObjectResponseBody",
    "ReportRunObjectResponseBodyStatus",
    "ReportsCreateReportRunBadGatewayErrorResponseBody",
    "ReportsCreateReportRunGatewayTimeoutErrorResponseBody",
    "ReportsCreateReportRunInternalServerErrorResponseBody",
    "ReportsCreateReportRunMethodNotAllowedErrorResponseBody",
    "ReportsCreateReportRunNotFoundErrorResponseBody",
    "ReportsCreateReportRunNotImplementedErrorResponseBody",
    "ReportsCreateReportRunResponseBody",
    "ReportsCreateReportRunServiceUnavailableErrorResponseBody",
    "ReportsCreateReportRunTooManyRequestsErrorResponseBody",
    "ReportsCreateReportRunUnauthorizedErrorResponseBody",
    "ReportsDatasetFieldResponseBody",
    "ReportsDatasetFieldResponseBodyDataType",
    "ReportsDatasetFieldResponseBodyUnit",
    "ReportsDatasetResponseBody",
    "ReportsGetDatasetsBadGatewayErrorResponseBody",
    "ReportsGetDatasetsGatewayTimeoutErrorResponseBody",
    "ReportsGetDatasetsInternalServerErrorResponseBody",
    "ReportsGetDatasetsMethodNotAllowedErrorResponseBody",
    "ReportsGetDatasetsNotFoundErrorResponseBody",
    "ReportsGetDatasetsNotImplementedErrorResponseBody",
    "ReportsGetDatasetsResponseBody",
    "ReportsGetDatasetsServiceUnavailableErrorResponseBody",
    "ReportsGetDatasetsTooManyRequestsErrorResponseBody",
    "ReportsGetDatasetsUnauthorizedErrorResponseBody",
    "ReportsGetReportConfigsBadGatewayErrorResponseBody",
    "ReportsGetReportConfigsGatewayTimeoutErrorResponseBody",
    "ReportsGetReportConfigsInternalServerErrorResponseBody",
    "ReportsGetReportConfigsMethodNotAllowedErrorResponseBody",
    "ReportsGetReportConfigsNotFoundErrorResponseBody",
    "ReportsGetReportConfigsNotImplementedErrorResponseBody",
    "ReportsGetReportConfigsResponseBody",
    "ReportsGetReportConfigsServiceUnavailableErrorResponseBody",
    "ReportsGetReportConfigsTooManyRequestsErrorResponseBody",
    "ReportsGetReportConfigsUnauthorizedErrorResponseBody",
    "ReportsGetReportRunDataBadGatewayErrorResponseBody",
    "ReportsGetReportRunDataGatewayTimeoutErrorResponseBody",
    "ReportsGetReportRunDataInternalServerErrorResponseBody",
    "ReportsGetReportRunDataMethodNotAllowedErrorResponseBody",
    "ReportsGetReportRunDataNotFoundErrorResponseBody",
    "ReportsGetReportRunDataNotImplementedErrorResponseBody",
    "ReportsGetReportRunDataResponseBody",
    "ReportsGetReportRunDataServiceUnavailableErrorResponseBody",
    "ReportsGetReportRunDataTooManyRequestsErrorResponseBody",
    "ReportsGetReportRunDataUnauthorizedErrorResponseBody",
    "ReportsGetReportRunsBadGatewayErrorResponseBody",
    "ReportsGetReportRunsGatewayTimeoutErrorResponseBody",
    "ReportsGetReportRunsInternalServerErrorResponseBody",
    "ReportsGetReportRunsMethodNotAllowedErrorResponseBody",
    "ReportsGetReportRunsNotFoundErrorResponseBody",
    "ReportsGetReportRunsNotImplementedErrorResponseBody",
    "ReportsGetReportRunsResponseBody",
    "ReportsGetReportRunsServiceUnavailableErrorResponseBody",
    "ReportsGetReportRunsTooManyRequestsErrorResponseBody",
    "ReportsGetReportRunsUnauthorizedErrorResponseBody",
    "ResolvedBy",
    "ResolvedByType",
    "ReverseGeo",
    "ReverseGeoObjectResponseBody",
    "RidershipAccountObjectResponseBody",
    "RidershipAccountsCreateRidershipAccountBadGatewayErrorResponseBody",
    "RidershipAccountsCreateRidershipAccountGatewayTimeoutErrorResponseBody",
    "RidershipAccountsCreateRidershipAccountInternalServerErrorResponseBody",
    "RidershipAccountsCreateRidershipAccountMethodNotAllowedErrorResponseBody",
    "RidershipAccountsCreateRidershipAccountNotFoundErrorResponseBody",
    "RidershipAccountsCreateRidershipAccountNotImplementedErrorResponseBody",
    "RidershipAccountsCreateRidershipAccountResponseBody",
    "RidershipAccountsCreateRidershipAccountServiceUnavailableErrorResponseBody",
    "RidershipAccountsCreateRidershipAccountTooManyRequestsErrorResponseBody",
    "RidershipAccountsCreateRidershipAccountUnauthorizedErrorResponseBody",
    "RidershipAccountsDeleteRidershipAccountBadGatewayErrorResponseBody",
    "RidershipAccountsDeleteRidershipAccountGatewayTimeoutErrorResponseBody",
    "RidershipAccountsDeleteRidershipAccountInternalServerErrorResponseBody",
    "RidershipAccountsDeleteRidershipAccountMethodNotAllowedErrorResponseBody",
    "RidershipAccountsDeleteRidershipAccountNotFoundErrorResponseBody",
    "RidershipAccountsDeleteRidershipAccountNotImplementedErrorResponseBody",
    "RidershipAccountsDeleteRidershipAccountServiceUnavailableErrorResponseBody",
    "RidershipAccountsDeleteRidershipAccountTooManyRequestsErrorResponseBody",
    "RidershipAccountsDeleteRidershipAccountUnauthorizedErrorResponseBody",
    "RidershipAccountsGetRidershipAccountBadGatewayErrorResponseBody",
    "RidershipAccountsGetRidershipAccountGatewayTimeoutErrorResponseBody",
    "RidershipAccountsGetRidershipAccountInternalServerErrorResponseBody",
    "RidershipAccountsGetRidershipAccountMethodNotAllowedErrorResponseBody",
    "RidershipAccountsGetRidershipAccountNotFoundErrorResponseBody",
    "RidershipAccountsGetRidershipAccountNotImplementedErrorResponseBody",
    "RidershipAccountsGetRidershipAccountResponseBody",
    "RidershipAccountsGetRidershipAccountServiceUnavailableErrorResponseBody",
    "RidershipAccountsGetRidershipAccountTooManyRequestsErrorResponseBody",
    "RidershipAccountsGetRidershipAccountUnauthorizedErrorResponseBody",
    "RidershipAccountsListRidershipAccountsBadGatewayErrorResponseBody",
    "RidershipAccountsListRidershipAccountsGatewayTimeoutErrorResponseBody",
    "RidershipAccountsListRidershipAccountsInternalServerErrorResponseBody",
    "RidershipAccountsListRidershipAccountsMethodNotAllowedErrorResponseBody",
    "RidershipAccountsListRidershipAccountsNotFoundErrorResponseBody",
    "RidershipAccountsListRidershipAccountsNotImplementedErrorResponseBody",
    "RidershipAccountsListRidershipAccountsResponseBody",
    "RidershipAccountsListRidershipAccountsServiceUnavailableErrorResponseBody",
    "RidershipAccountsListRidershipAccountsTooManyRequestsErrorResponseBody",
    "RidershipAccountsListRidershipAccountsUnauthorizedErrorResponseBody",
    "RidershipAccountsUpdateRidershipAccountBadGatewayErrorResponseBody",
    "RidershipAccountsUpdateRidershipAccountGatewayTimeoutErrorResponseBody",
    "RidershipAccountsUpdateRidershipAccountInternalServerErrorResponseBody",
    "RidershipAccountsUpdateRidershipAccountMethodNotAllowedErrorResponseBody",
    "RidershipAccountsUpdateRidershipAccountNotFoundErrorResponseBody",
    "RidershipAccountsUpdateRidershipAccountNotImplementedErrorResponseBody",
    "RidershipAccountsUpdateRidershipAccountResponseBody",
    "RidershipAccountsUpdateRidershipAccountServiceUnavailableErrorResponseBody",
    "RidershipAccountsUpdateRidershipAccountTooManyRequestsErrorResponseBody",
    "RidershipAccountsUpdateRidershipAccountUnauthorizedErrorResponseBody",
    "RidershipPassengerIdentifierInputRequestBody",
    "RidershipPassengerIdentifierInputRequestBodyStatus",
    "RidershipPassengerIdentifierInputRequestBodyType",
    "RidershipPassengerIdentifierObjectResponseBody",
    "RidershipPassengerIdentifierObjectResponseBodyStatus",
    "RidershipPassengerIdentifierObjectResponseBodyType",
    "RidershipPassengerObjectResponseBody",
    "RidershipPassengerSpecialInstructionsInputRequestBody",
    "RidershipPassengerSpecialInstructionsObjectResponseBody",
    "RidershipPassengersCreateRidershipPassengerBadGatewayErrorResponseBody",
    "RidershipPassengersCreateRidershipPassengerGatewayTimeoutErrorResponseBody",
    "RidershipPassengersCreateRidershipPassengerInternalServerErrorResponseBody",
    "RidershipPassengersCreateRidershipPassengerMethodNotAllowedErrorResponseBody",
    "RidershipPassengersCreateRidershipPassengerNotFoundErrorResponseBody",
    "RidershipPassengersCreateRidershipPassengerNotImplementedErrorResponseBody",
    "RidershipPassengersCreateRidershipPassengerResponseBody",
    "RidershipPassengersCreateRidershipPassengerServiceUnavailableErrorResponseBody",
    "RidershipPassengersCreateRidershipPassengerTooManyRequestsErrorResponseBody",
    "RidershipPassengersCreateRidershipPassengerUnauthorizedErrorResponseBody",
    "RidershipPassengersDeleteRidershipPassengerBadGatewayErrorResponseBody",
    "RidershipPassengersDeleteRidershipPassengerGatewayTimeoutErrorResponseBody",
    "RidershipPassengersDeleteRidershipPassengerInternalServerErrorResponseBody",
    "RidershipPassengersDeleteRidershipPassengerMethodNotAllowedErrorResponseBody",
    "RidershipPassengersDeleteRidershipPassengerNotFoundErrorResponseBody",
    "RidershipPassengersDeleteRidershipPassengerNotImplementedErrorResponseBody",
    "RidershipPassengersDeleteRidershipPassengerServiceUnavailableErrorResponseBody",
    "RidershipPassengersDeleteRidershipPassengerTooManyRequestsErrorResponseBody",
    "RidershipPassengersDeleteRidershipPassengerUnauthorizedErrorResponseBody",
    "RidershipPassengersGetRidershipPassengerBadGatewayErrorResponseBody",
    "RidershipPassengersGetRidershipPassengerGatewayTimeoutErrorResponseBody",
    "RidershipPassengersGetRidershipPassengerInternalServerErrorResponseBody",
    "RidershipPassengersGetRidershipPassengerMethodNotAllowedErrorResponseBody",
    "RidershipPassengersGetRidershipPassengerNotFoundErrorResponseBody",
    "RidershipPassengersGetRidershipPassengerNotImplementedErrorResponseBody",
    "RidershipPassengersGetRidershipPassengerResponseBody",
    "RidershipPassengersGetRidershipPassengerServiceUnavailableErrorResponseBody",
    "RidershipPassengersGetRidershipPassengerTooManyRequestsErrorResponseBody",
    "RidershipPassengersGetRidershipPassengerUnauthorizedErrorResponseBody",
    "RidershipPassengersListRidershipPassengersBadGatewayErrorResponseBody",
    "RidershipPassengersListRidershipPassengersGatewayTimeoutErrorResponseBody",
    "RidershipPassengersListRidershipPassengersInternalServerErrorResponseBody",
    "RidershipPassengersListRidershipPassengersMethodNotAllowedErrorResponseBody",
    "RidershipPassengersListRidershipPassengersNotFoundErrorResponseBody",
    "RidershipPassengersListRidershipPassengersNotImplementedErrorResponseBody",
    "RidershipPassengersListRidershipPassengersResponseBody",
    "RidershipPassengersListRidershipPassengersServiceUnavailableErrorResponseBody",
    "RidershipPassengersListRidershipPassengersTooManyRequestsErrorResponseBody",
    "RidershipPassengersListRidershipPassengersUnauthorizedErrorResponseBody",
    "RidershipPassengersUpdateRidershipPassengerBadGatewayErrorResponseBody",
    "RidershipPassengersUpdateRidershipPassengerGatewayTimeoutErrorResponseBody",
    "RidershipPassengersUpdateRidershipPassengerInternalServerErrorResponseBody",
    "RidershipPassengersUpdateRidershipPassengerMethodNotAllowedErrorResponseBody",
    "RidershipPassengersUpdateRidershipPassengerNotFoundErrorResponseBody",
    "RidershipPassengersUpdateRidershipPassengerNotImplementedErrorResponseBody",
    "RidershipPassengersUpdateRidershipPassengerResponseBody",
    "RidershipPassengersUpdateRidershipPassengerServiceUnavailableErrorResponseBody",
    "RidershipPassengersUpdateRidershipPassengerTooManyRequestsErrorResponseBody",
    "RidershipPassengersUpdateRidershipPassengerUnauthorizedErrorResponseBody",
    "RidershipRouteSetupObjectResponseBody",
    "RidershipRouteSetupPassengerInputRequestBody",
    "RidershipRouteSetupPassengerObjectResponseBody",
    "RidershipRouteSetupsCreateRidershipRouteSetupBadGatewayErrorResponseBody",
    "RidershipRouteSetupsCreateRidershipRouteSetupGatewayTimeoutErrorResponseBody",
    "RidershipRouteSetupsCreateRidershipRouteSetupInternalServerErrorResponseBody",
    "RidershipRouteSetupsCreateRidershipRouteSetupMethodNotAllowedErrorResponseBody",
    "RidershipRouteSetupsCreateRidershipRouteSetupNotFoundErrorResponseBody",
    "RidershipRouteSetupsCreateRidershipRouteSetupNotImplementedErrorResponseBody",
    "RidershipRouteSetupsCreateRidershipRouteSetupResponseBody",
    "RidershipRouteSetupsCreateRidershipRouteSetupServiceUnavailableErrorResponseBody",
    "RidershipRouteSetupsCreateRidershipRouteSetupTooManyRequestsErrorResponseBody",
    "RidershipRouteSetupsCreateRidershipRouteSetupUnauthorizedErrorResponseBody",
    "RidershipRouteSetupsDeleteRidershipRouteSetupBadGatewayErrorResponseBody",
    "RidershipRouteSetupsDeleteRidershipRouteSetupGatewayTimeoutErrorResponseBody",
    "RidershipRouteSetupsDeleteRidershipRouteSetupInternalServerErrorResponseBody",
    "RidershipRouteSetupsDeleteRidershipRouteSetupMethodNotAllowedErrorResponseBody",
    "RidershipRouteSetupsDeleteRidershipRouteSetupNotFoundErrorResponseBody",
    "RidershipRouteSetupsDeleteRidershipRouteSetupNotImplementedErrorResponseBody",
    "RidershipRouteSetupsDeleteRidershipRouteSetupServiceUnavailableErrorResponseBody",
    "RidershipRouteSetupsDeleteRidershipRouteSetupTooManyRequestsErrorResponseBody",
    "RidershipRouteSetupsDeleteRidershipRouteSetupUnauthorizedErrorResponseBody",
    "RidershipRouteSetupsGetRidershipRouteSetupBadGatewayErrorResponseBody",
    "RidershipRouteSetupsGetRidershipRouteSetupGatewayTimeoutErrorResponseBody",
    "RidershipRouteSetupsGetRidershipRouteSetupInternalServerErrorResponseBody",
    "RidershipRouteSetupsGetRidershipRouteSetupMethodNotAllowedErrorResponseBody",
    "RidershipRouteSetupsGetRidershipRouteSetupNotFoundErrorResponseBody",
    "RidershipRouteSetupsGetRidershipRouteSetupNotImplementedErrorResponseBody",
    "RidershipRouteSetupsGetRidershipRouteSetupResponseBody",
    "RidershipRouteSetupsGetRidershipRouteSetupServiceUnavailableErrorResponseBody",
    "RidershipRouteSetupsGetRidershipRouteSetupTooManyRequestsErrorResponseBody",
    "RidershipRouteSetupsGetRidershipRouteSetupUnauthorizedErrorResponseBody",
    "RidershipRouteSetupsUpdateRidershipRouteSetupBadGatewayErrorResponseBody",
    "RidershipRouteSetupsUpdateRidershipRouteSetupGatewayTimeoutErrorResponseBody",
    "RidershipRouteSetupsUpdateRidershipRouteSetupInternalServerErrorResponseBody",
    "RidershipRouteSetupsUpdateRidershipRouteSetupMethodNotAllowedErrorResponseBody",
    "RidershipRouteSetupsUpdateRidershipRouteSetupNotFoundErrorResponseBody",
    "RidershipRouteSetupsUpdateRidershipRouteSetupNotImplementedErrorResponseBody",
    "RidershipRouteSetupsUpdateRidershipRouteSetupResponseBody",
    "RidershipRouteSetupsUpdateRidershipRouteSetupServiceUnavailableErrorResponseBody",
    "RidershipRouteSetupsUpdateRidershipRouteSetupTooManyRequestsErrorResponseBody",
    "RidershipRouteSetupsUpdateRidershipRouteSetupUnauthorizedErrorResponseBody",
    "RollingStopDetectionAlertSettingsObjectResponseBody",
    "RouteChangesResponseBody",
    "RouteEventDetailsResponseBody",
    "RouteEventResponseResponseBody",
    "RouteEventResponseResponseBodyEventType",
    "RouteEventRouteResponseResponseBody",
    "RouteEventStopResponseResponseBody",
    "RouteFeedObjectResponseBody",
    "RouteFeedObjectResponseBodyOperation",
    "RouteFeedObjectResponseBodySource",
    "RouteFeedObjectResponseBodyType",
    "RouteObjectResponseBody",
    "RouteSettingsRequestBody",
    "RouteSettingsRequestBodyRouteCompletionCondition",
    "RouteSettingsRequestBodyRouteStartingCondition",
    "RouteSettingsRequestBodySequencingMethod",
    "RouteSettingsResponseBody",
    "RouteSettingsResponseBodyRouteCompletionCondition",
    "RouteSettingsResponseBodyRouteStartingCondition",
    "RouteSettingsResponseBodySequencingMethod",
    "RouteStopDetailsObjectResponseBody",
    "RouteStopDetailsObjectResponseBodyOperation",
    "RouteStopDetailsObjectResponseBodyType",
    "RouteStopEstimatedArrivalDetailsObjectRequestBody",
    "RouteStopEstimatedArrivalDetailsObjectResponseBody",
    "RouteStopEtaResponseBody",
    "RouteStopObjectResponseBody",
    "RoutesCreateRouteBadGatewayErrorResponseBody",
    "RoutesCreateRouteGatewayTimeoutErrorResponseBody",
    "RoutesCreateRouteInternalServerErrorResponseBody",
    "RoutesCreateRouteMethodNotAllowedErrorResponseBody",
    "RoutesCreateRouteNotFoundErrorResponseBody",
    "RoutesCreateRouteNotImplementedErrorResponseBody",
    "RoutesCreateRouteResponseBody",
    "RoutesCreateRouteServiceUnavailableErrorResponseBody",
    "RoutesCreateRouteTooManyRequestsErrorResponseBody",
    "RoutesCreateRouteUnauthorizedErrorResponseBody",
    "RoutesDeleteRouteBadGatewayErrorResponseBody",
    "RoutesDeleteRouteGatewayTimeoutErrorResponseBody",
    "RoutesDeleteRouteInternalServerErrorResponseBody",
    "RoutesDeleteRouteMethodNotAllowedErrorResponseBody",
    "RoutesDeleteRouteNotFoundErrorResponseBody",
    "RoutesDeleteRouteNotImplementedErrorResponseBody",
    "RoutesDeleteRouteServiceUnavailableErrorResponseBody",
    "RoutesDeleteRouteTooManyRequestsErrorResponseBody",
    "RoutesDeleteRouteUnauthorizedErrorResponseBody",
    "RoutesFetchRouteBadGatewayErrorResponseBody",
    "RoutesFetchRouteGatewayTimeoutErrorResponseBody",
    "RoutesFetchRouteInternalServerErrorResponseBody",
    "RoutesFetchRouteMethodNotAllowedErrorResponseBody",
    "RoutesFetchRouteNotFoundErrorResponseBody",
    "RoutesFetchRouteNotImplementedErrorResponseBody",
    "RoutesFetchRouteResponseBody",
    "RoutesFetchRouteServiceUnavailableErrorResponseBody",
    "RoutesFetchRouteTooManyRequestsErrorResponseBody",
    "RoutesFetchRouteUnauthorizedErrorResponseBody",
    "RoutesFetchRoutesBadGatewayErrorResponseBody",
    "RoutesFetchRoutesGatewayTimeoutErrorResponseBody",
    "RoutesFetchRoutesInternalServerErrorResponseBody",
    "RoutesFetchRoutesMethodNotAllowedErrorResponseBody",
    "RoutesFetchRoutesNotFoundErrorResponseBody",
    "RoutesFetchRoutesNotImplementedErrorResponseBody",
    "RoutesFetchRoutesResponseBody",
    "RoutesFetchRoutesServiceUnavailableErrorResponseBody",
    "RoutesFetchRoutesTooManyRequestsErrorResponseBody",
    "RoutesFetchRoutesUnauthorizedErrorResponseBody",
    "RoutesGetRouteEventsStreamBadGatewayErrorResponseBody",
    "RoutesGetRouteEventsStreamGatewayTimeoutErrorResponseBody",
    "RoutesGetRouteEventsStreamInternalServerErrorResponseBody",
    "RoutesGetRouteEventsStreamMethodNotAllowedErrorResponseBody",
    "RoutesGetRouteEventsStreamNotFoundErrorResponseBody",
    "RoutesGetRouteEventsStreamNotImplementedErrorResponseBody",
    "RoutesGetRouteEventsStreamResponseBody",
    "RoutesGetRouteEventsStreamServiceUnavailableErrorResponseBody",
    "RoutesGetRouteEventsStreamTooManyRequestsErrorResponseBody",
    "RoutesGetRouteEventsStreamUnauthorizedErrorResponseBody",
    "RoutesGetRoutesFeedBadGatewayErrorResponseBody",
    "RoutesGetRoutesFeedGatewayTimeoutErrorResponseBody",
    "RoutesGetRoutesFeedInternalServerErrorResponseBody",
    "RoutesGetRoutesFeedMethodNotAllowedErrorResponseBody",
    "RoutesGetRoutesFeedNotFoundErrorResponseBody",
    "RoutesGetRoutesFeedNotImplementedErrorResponseBody",
    "RoutesGetRoutesFeedResponseBody",
    "RoutesGetRoutesFeedServiceUnavailableErrorResponseBody",
    "RoutesGetRoutesFeedTooManyRequestsErrorResponseBody",
    "RoutesGetRoutesFeedUnauthorizedErrorResponseBody",
    "RoutesPatchRouteBadGatewayErrorResponseBody",
    "RoutesPatchRouteGatewayTimeoutErrorResponseBody",
    "RoutesPatchRouteInternalServerErrorResponseBody",
    "RoutesPatchRouteMethodNotAllowedErrorResponseBody",
    "RoutesPatchRouteNotFoundErrorResponseBody",
    "RoutesPatchRouteNotImplementedErrorResponseBody",
    "RoutesPatchRouteResponseBody",
    "RoutesPatchRouteServiceUnavailableErrorResponseBody",
    "RoutesPatchRouteTooManyRequestsErrorResponseBody",
    "RoutesPatchRouteUnauthorizedErrorResponseBody",
    "RoutesSingleUseAddressObjectRequestBody",
    "RoutesSingleUseAddressObjectResponseBody",
    "RoutesStopResponseObjectResponseBody",
    "RoutesStopResponseObjectResponseBodyState",
    "SafetyBehaviorTriggerDetailsObjectRequestBody",
    "SafetyBehaviorTriggerDetailsObjectRequestBodyBehaviorsItem",
    "SafetyBehaviorTriggerDetailsObjectRequestBodySeveritiesItem",
    "SafetyBehaviorTriggerDetailsObjectRequestBodyStatusesItem",
    "SafetyBehaviorTriggerDetailsObjectResponseBody",
    "SafetyBehaviorTriggerDetailsObjectResponseBodyBehaviorsItem",
    "SafetyBehaviorTriggerDetailsObjectResponseBodySeveritiesItem",
    "SafetyBehaviorTriggerDetailsObjectResponseBodyStatusesItem",
    "SafetyEvent",
    "SafetyEventActivityFeedItemResponseBody",
    "SafetyEventActivityFeedItemResponseBodyType",
    "SafetyEventBehaviorLabel",
    "SafetyEventBehaviorLabelName",
    "SafetyEventBehaviorLabelSource",
    "SafetyEventBehaviorLabelType",
    "SafetyEventBehaviorLabels",
    "SafetyEventBehaviorLabelsResponseBody",
    "SafetyEventBehaviorLabelsResponseBodyType",
    "SafetyEventCoachingState",
    "SafetyEventDismissalReasonResponseBody",
    "SafetyEventDismissalReasonResponseBodyCode",
    "SafetyEventDownloadForwardVideoUrl",
    "SafetyEventDownloadInwardVideoUrl",
    "SafetyEventDownloadTrackedInwardVideoUrl",
    "SafetyEventDriverObjectResponseBody",
    "SafetyEventId",
    "SafetyEventMaxAccelerationGForce",
    "SafetyEventObjectResponseBody",
    "SafetyEventSpeedingMetadataResponseBody",
    "SafetyEventTime",
    "SafetyEventV2AssetObjectResponseBody",
    "SafetyEventV2AssetObjectResponseBodyType",
    "SafetyEventV2BehaviorLabelsResponseBody",
    "SafetyEventV2BehaviorLabelsResponseBodyLabel",
    "SafetyEventV2BehaviorLabelsResponseBodySource",
    "SafetyEventV2ContextLabelsResponseBody",
    "SafetyEventV2DriverObjectResponseBody",
    "SafetyEventV2MediaResponseBody",
    "SafetyEventV2MediaResponseBodyCameraRole",
    "SafetyEventV2MediaResponseBodyInput",
    "SafetyEventV2ObjectResponseBody",
    "SafetyEventV2ObjectResponseBodyEventState",
    "SafetyEventVehicleObjectResponseBody",
    "SafetyEventsGetSafetyActivityEventFeedBadGatewayErrorResponseBody",
    "SafetyEventsGetSafetyActivityEventFeedGatewayTimeoutErrorResponseBody",
    "SafetyEventsGetSafetyActivityEventFeedInternalServerErrorResponseBody",
    "SafetyEventsGetSafetyActivityEventFeedMethodNotAllowedErrorResponseBody",
    "SafetyEventsGetSafetyActivityEventFeedNotFoundErrorResponseBody",
    "SafetyEventsGetSafetyActivityEventFeedNotImplementedErrorResponseBody",
    "SafetyEventsGetSafetyActivityEventFeedResponseBody",
    "SafetyEventsGetSafetyActivityEventFeedServiceUnavailableErrorResponseBody",
    "SafetyEventsGetSafetyActivityEventFeedTooManyRequestsErrorResponseBody",
    "SafetyEventsGetSafetyActivityEventFeedUnauthorizedErrorResponseBody",
    "SafetyEventsListResponse",
    "SafetyEventsV2GetSafetyEventsV2BadGatewayErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2GatewayTimeoutErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2InternalServerErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2MethodNotAllowedErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2NotFoundErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2NotImplementedErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2ResponseBody",
    "SafetyEventsV2GetSafetyEventsV2ServiceUnavailableErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2StreamBadGatewayErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2StreamGatewayTimeoutErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2StreamInternalServerErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2StreamMethodNotAllowedErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2StreamNotFoundErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2StreamNotImplementedErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2StreamResponseBody",
    "SafetyEventsV2GetSafetyEventsV2StreamServiceUnavailableErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2StreamTooManyRequestsErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2StreamUnauthorizedErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2TooManyRequestsErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2UnauthorizedErrorResponseBody",
    "SafetyScoreBehaviorObjectResponseBody",
    "SafetyScoreBehaviorObjectResponseBodyBehaviorType",
    "SafetyScoreConfigurationSettingsObjectResponseBody",
    "SafetyScoreDetailsRequestBody",
    "SafetyScoreDetailsRequestBodyComparison",
    "SafetyScoreDetailsResponseBody",
    "SafetyScoreDetailsResponseBodyComparison",
    "SafetyScoreSpeedingObjectResponseBody",
    "SafetyScoreSpeedingObjectResponseBodySpeedingType",
    "SafetyScoresGetDriverSafetyScoreTripsBadGatewayErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoreTripsGatewayTimeoutErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoreTripsInternalServerErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoreTripsMethodNotAllowedErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoreTripsNotFoundErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoreTripsNotImplementedErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoreTripsResponseBody",
    "SafetyScoresGetDriverSafetyScoreTripsServiceUnavailableErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoreTripsTooManyRequestsErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoreTripsUnauthorizedErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoresBadGatewayErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoresGatewayTimeoutErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoresInternalServerErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoresMethodNotAllowedErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoresNotFoundErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoresNotImplementedErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoresResponseBody",
    "SafetyScoresGetDriverSafetyScoresServiceUnavailableErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoresTooManyRequestsErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoresUnauthorizedErrorResponseBody",
    "SafetyScoresGetTagGroupSafetyScoresBadGatewayErrorResponseBody",
    "SafetyScoresGetTagGroupSafetyScoresGatewayTimeoutErrorResponseBody",
    "SafetyScoresGetTagGroupSafetyScoresInternalServerErrorResponseBody",
    "SafetyScoresGetTagGroupSafetyScoresMethodNotAllowedErrorResponseBody",
    "SafetyScoresGetTagGroupSafetyScoresNotFoundErrorResponseBody",
    "SafetyScoresGetTagGroupSafetyScoresNotImplementedErrorResponseBody",
    "SafetyScoresGetTagGroupSafetyScoresResponseBody",
    "SafetyScoresGetTagGroupSafetyScoresServiceUnavailableErrorResponseBody",
    "SafetyScoresGetTagGroupSafetyScoresTooManyRequestsErrorResponseBody",
    "SafetyScoresGetTagGroupSafetyScoresUnauthorizedErrorResponseBody",
    "SafetyScoresGetTagSafetyScoresBadGatewayErrorResponseBody",
    "SafetyScoresGetTagSafetyScoresGatewayTimeoutErrorResponseBody",
    "SafetyScoresGetTagSafetyScoresInternalServerErrorResponseBody",
    "SafetyScoresGetTagSafetyScoresMethodNotAllowedErrorResponseBody",
    "SafetyScoresGetTagSafetyScoresNotFoundErrorResponseBody",
    "SafetyScoresGetTagSafetyScoresNotImplementedErrorResponseBody",
    "SafetyScoresGetTagSafetyScoresResponseBody",
    "SafetyScoresGetTagSafetyScoresServiceUnavailableErrorResponseBody",
    "SafetyScoresGetTagSafetyScoresTooManyRequestsErrorResponseBody",
    "SafetyScoresGetTagSafetyScoresUnauthorizedErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoreTripsBadGatewayErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoreTripsGatewayTimeoutErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoreTripsInternalServerErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoreTripsMethodNotAllowedErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoreTripsNotFoundErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoreTripsNotImplementedErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoreTripsResponseBody",
    "SafetyScoresGetVehicleSafetyScoreTripsServiceUnavailableErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoreTripsTooManyRequestsErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoreTripsUnauthorizedErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoresBadGatewayErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoresGatewayTimeoutErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoresInternalServerErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoresMethodNotAllowedErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoresNotFoundErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoresNotImplementedErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoresResponseBody",
    "SafetyScoresGetVehicleSafetyScoresServiceUnavailableErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoresTooManyRequestsErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoresUnauthorizedErrorResponseBody",
    "SafetySettingsGetSafetySettingsBadGatewayErrorResponseBody",
    "SafetySettingsGetSafetySettingsGatewayTimeoutErrorResponseBody",
    "SafetySettingsGetSafetySettingsInternalServerErrorResponseBody",
    "SafetySettingsGetSafetySettingsMethodNotAllowedErrorResponseBody",
    "SafetySettingsGetSafetySettingsNotFoundErrorResponseBody",
    "SafetySettingsGetSafetySettingsNotImplementedErrorResponseBody",
    "SafetySettingsGetSafetySettingsResponseBody",
    "SafetySettingsGetSafetySettingsServiceUnavailableErrorResponseBody",
    "SafetySettingsGetSafetySettingsTooManyRequestsErrorResponseBody",
    "SafetySettingsGetSafetySettingsUnauthorizedErrorResponseBody",
    "SafetySettingsObjectResponseBody",
    "SafetySettingsObjectResponseBodyDefaultVehicleType",
    "ScannedDocumentValueObjectRequestBody",
    "ScannedDocumentValueObjectResponseBody",
    "ScheduledMaintenanceByEngineHoursDetailsObjectRequestBody",
    "ScheduledMaintenanceByEngineHoursDetailsObjectResponseBody",
    "ScheduledMaintenanceByEngineHoursResponseBody",
    "ScheduledMaintenanceDataResponseBody",
    "ScheduledMaintenanceOdometerDataResponseBody",
    "ScheduledMaintenanceOdometerTriggerDetailsObjectRequestBody",
    "ScheduledMaintenanceOdometerTriggerDetailsObjectResponseBody",
    "ScheduledMaintenanceTriggerDetailsObjectRequestBody",
    "ScheduledMaintenanceTriggerDetailsObjectResponseBody",
    "ScopeObjectRequestBody",
    "ScopeObjectResponseBody",
    "Sensor",
    "SensorResponseBody",
    "Serial",
    "ServiceTaskDefinitionObjectResponseBody",
    "ServiceTaskInstanceInputObjectRequestBody",
    "ServiceTaskInstanceInputObjectRequestBodyStatus",
    "ServiceTaskInstanceObjectResponseBody",
    "ServiceTaskInstanceObjectResponseBodyStatus",
    "ServiceWindowObjectResponseBody",
    "SettingsComplianceResponseObjectResponseBody",
    "SettingsGetComplianceSettingsBadGatewayErrorResponseBody",
    "SettingsGetComplianceSettingsGatewayTimeoutErrorResponseBody",
    "SettingsGetComplianceSettingsInternalServerErrorResponseBody",
    "SettingsGetComplianceSettingsMethodNotAllowedErrorResponseBody",
    "SettingsGetComplianceSettingsNotFoundErrorResponseBody",
    "SettingsGetComplianceSettingsNotImplementedErrorResponseBody",
    "SettingsGetComplianceSettingsResponseBody",
    "SettingsGetComplianceSettingsServiceUnavailableErrorResponseBody",
    "SettingsGetComplianceSettingsTooManyRequestsErrorResponseBody",
    "SettingsGetComplianceSettingsUnauthorizedErrorResponseBody",
    "SettingsGetDriverAppSettingsBadGatewayErrorResponseBody",
    "SettingsGetDriverAppSettingsGatewayTimeoutErrorResponseBody",
    "SettingsGetDriverAppSettingsInternalServerErrorResponseBody",
    "SettingsGetDriverAppSettingsMethodNotAllowedErrorResponseBody",
    "SettingsGetDriverAppSettingsNotFoundErrorResponseBody",
    "SettingsGetDriverAppSettingsNotImplementedErrorResponseBody",
    "SettingsGetDriverAppSettingsResponseBody",
    "SettingsGetDriverAppSettingsServiceUnavailableErrorResponseBody",
    "SettingsGetDriverAppSettingsTooManyRequestsErrorResponseBody",
    "SettingsGetDriverAppSettingsUnauthorizedErrorResponseBody",
    "SettingsPatchComplianceSettingsBadGatewayErrorResponseBody",
    "SettingsPatchComplianceSettingsGatewayTimeoutErrorResponseBody",
    "SettingsPatchComplianceSettingsInternalServerErrorResponseBody",
    "SettingsPatchComplianceSettingsMethodNotAllowedErrorResponseBody",
    "SettingsPatchComplianceSettingsNotFoundErrorResponseBody",
    "SettingsPatchComplianceSettingsNotImplementedErrorResponseBody",
    "SettingsPatchComplianceSettingsResponseBody",
    "SettingsPatchComplianceSettingsServiceUnavailableErrorResponseBody",
    "SettingsPatchComplianceSettingsTooManyRequestsErrorResponseBody",
    "SettingsPatchComplianceSettingsUnauthorizedErrorResponseBody",
    "SettingsPatchDriverAppSettingsBadGatewayErrorResponseBody",
    "SettingsPatchDriverAppSettingsGatewayTimeoutErrorResponseBody",
    "SettingsPatchDriverAppSettingsInternalServerErrorResponseBody",
    "SettingsPatchDriverAppSettingsMethodNotAllowedErrorResponseBody",
    "SettingsPatchDriverAppSettingsNotFoundErrorResponseBody",
    "SettingsPatchDriverAppSettingsNotImplementedErrorResponseBody",
    "SettingsPatchDriverAppSettingsResponseBody",
    "SettingsPatchDriverAppSettingsServiceUnavailableErrorResponseBody",
    "SettingsPatchDriverAppSettingsTooManyRequestsErrorResponseBody",
    "SettingsPatchDriverAppSettingsUnauthorizedErrorResponseBody",
    "SettingsResponseBody",
    "SevereSpeedingStartedObjectResponseBody",
    "SevereSpeedingStartedResponseObjectResponseBody",
    "SignatoryUserObjectResponseBody",
    "SignatureFieldTypeMetaDataObjectResponseBody",
    "SignatureValueObjectRequestBody",
    "SignatureValueObjectResponseBody",
    "SingleApprovalRequirementsObjectResponseBody",
    "SingleDriverEfficiencyByDriverDataObjectResponseBody",
    "SingleDriverEfficiencyByVehicleDataObjectResponseBody",
    "SingleUseLocationObjectResponseBody",
    "SiteGatewayDisconnectedResponseBody",
    "SkillObjectResponseBody",
    "SpecificVehicleFaultCodeObjectRequestBody",
    "SpecificVehicleFaultCodeObjectRequestBodyType",
    "SpecificVehicleFaultCodeObjectResponseBody",
    "SpecificVehicleFaultCodeObjectResponseBodyType",
    "SpeedDataResponseBody",
    "SpeedDataResponseBodyOperation",
    "SpeedResponseResponseBody",
    "SpeedTriggerDetailsObjectRequestBody",
    "SpeedTriggerDetailsObjectRequestBodyOperation",
    "SpeedTriggerDetailsObjectResponseBody",
    "SpeedTriggerDetailsObjectResponseBodyOperation",
    "SpeedingIntervalLocationResponseResponseBody",
    "SpeedingIntervalResponseBody",
    "SpeedingIntervalResponseBodySeverityLevel",
    "SpeedingIntervalsGetSpeedingIntervalsBadGatewayErrorResponseBody",
    "SpeedingIntervalsGetSpeedingIntervalsGatewayTimeoutErrorResponseBody",
    "SpeedingIntervalsGetSpeedingIntervalsInternalServerErrorResponseBody",
    "SpeedingIntervalsGetSpeedingIntervalsMethodNotAllowedErrorResponseBody",
    "SpeedingIntervalsGetSpeedingIntervalsNotFoundErrorResponseBody",
    "SpeedingIntervalsGetSpeedingIntervalsNotImplementedErrorResponseBody",
    "SpeedingIntervalsGetSpeedingIntervalsResponseBody",
    "SpeedingIntervalsGetSpeedingIntervalsServiceUnavailableErrorResponseBody",
    "SpeedingIntervalsGetSpeedingIntervalsTooManyRequestsErrorResponseBody",
    "SpeedingIntervalsGetSpeedingIntervalsUnauthorizedErrorResponseBody",
    "SpeedingSettingsObjectResponseBody",
    "SpeedingSettingsObjectResponseBodyUnit",
    "SpeedingSeverityLevelResponseBody",
    "SpeedingSeverityLevelResponseBodySeverityLevel",
    "StartFunctionRunResponseBodyResponseBody",
    "StopEtaUpdatedEventDetailsResponseBody",
    "StopTaskCompletedEventDetailsResponseBody",
    "StopTaskCompletedEventDetailsResponseBodyTaskType",
    "StopTaskSkippedEventDetailsResponseBody",
    "StopTaskSkippedEventDetailsResponseBodyTaskType",
    "StringDataPoint",
    "SuddenFuelLevelDropResponseBody",
    "SuddenFuelLevelDropTriggerDetailsObjectRequestBody",
    "SuddenFuelLevelDropTriggerDetailsObjectResponseBody",
    "SuddenFuelLevelRiseResponseBody",
    "SuddenFuelLevelRiseTriggerDetailsObjectRequestBody",
    "SuddenFuelLevelRiseTriggerDetailsObjectResponseBody",
    "TachographActivity",
    "TachographActivityList",
    "TachographActivityListWrapper",
    "TachographActivityState",
    "TachographDriverFile",
    "TachographDriverFileData",
    "TachographDriverFileList",
    "TachographDriverFileListWrapper",
    "TachographDriverFilesResponse",
    "TachographVehicleFile",
    "TachographVehicleFileData",
    "TachographVehicleFileList",
    "TachographVehicleFileListWrapper",
    "TachographVehicleFilesResponse",
    "Tag",
    "TagAllOf",
    "TagAllOfExternalIds",
    "TagGroupSafetyScoreResponseBody",
    "TagId",
    "TagIds",
    "TagName",
    "TagResponse",
    "TagSafetyScoreResponseBody",
    "TagTinyResponse",
    "TaggedObject",
    "TaggedObjectId",
    "TaggedObjectName",
    "TamperingDetectedResponseBody",
    "Time",
    "TimeRangeObjectRequestBody",
    "TimeRangeObjectRequestBodyDaysOfWeekItem",
    "TimeRangeObjectResponseBody",
    "TimeRangeObjectResponseBodyDaysOfWeekItem",
    "TinyAssetObjectRequestBody",
    "TinyAssetObjectRequestBodyAssetType",
    "TinyAssetObjectResponseBody",
    "TinyAssetObjectResponseBodyAssetType",
    "TinyDriverObjectRequestBody",
    "TinyDriverObjectResponseBody",
    "TinyTag",
    "TinyWidgetObjectRequestBody",
    "TinyWidgetObjectResponseBody",
    "TireFaultCodeDetailsObjectRequestBody",
    "TireFaultCodeDetailsObjectRequestBodyManufacturer",
    "TireFaultCodeDetailsObjectRequestBodySpecificTireFaultCodesItem",
    "TireFaultCodeDetailsObjectResponseBody",
    "TireFaultCodeDetailsObjectResponseBodyManufacturer",
    "TireFaultCodeDetailsObjectResponseBodySpecificTireFaultCodesItem",
    "TireFaultsResponseBody",
    "TotalBrakeEventCount",
    "TrailerAssignmentsCreateDriverTrailerAssignmentBadGatewayErrorResponseBody",
    "TrailerAssignmentsCreateDriverTrailerAssignmentGatewayTimeoutErrorResponseBody",
    "TrailerAssignmentsCreateDriverTrailerAssignmentInternalServerErrorResponseBody",
    "TrailerAssignmentsCreateDriverTrailerAssignmentMethodNotAllowedErrorResponseBody",
    "TrailerAssignmentsCreateDriverTrailerAssignmentNotFoundErrorResponseBody",
    "TrailerAssignmentsCreateDriverTrailerAssignmentNotImplementedErrorResponseBody",
    "TrailerAssignmentsCreateDriverTrailerAssignmentResponseBody",
    "TrailerAssignmentsCreateDriverTrailerAssignmentServiceUnavailableErrorResponseBody",
    "TrailerAssignmentsCreateDriverTrailerAssignmentTooManyRequestsErrorResponseBody",
    "TrailerAssignmentsCreateDriverTrailerAssignmentUnauthorizedErrorResponseBody",
    "TrailerAssignmentsGetDriverTrailerAssignmentsBadGatewayErrorResponseBody",
    "TrailerAssignmentsGetDriverTrailerAssignmentsGatewayTimeoutErrorResponseBody",
    "TrailerAssignmentsGetDriverTrailerAssignmentsInternalServerErrorResponseBody",
    "TrailerAssignmentsGetDriverTrailerAssignmentsMethodNotAllowedErrorResponseBody",
    "TrailerAssignmentsGetDriverTrailerAssignmentsNotFoundErrorResponseBody",
    "TrailerAssignmentsGetDriverTrailerAssignmentsNotImplementedErrorResponseBody",
    "TrailerAssignmentsGetDriverTrailerAssignmentsResponseBody",
    "TrailerAssignmentsGetDriverTrailerAssignmentsServiceUnavailableErrorResponseBody",
    "TrailerAssignmentsGetDriverTrailerAssignmentsTooManyRequestsErrorResponseBody",
    "TrailerAssignmentsGetDriverTrailerAssignmentsUnauthorizedErrorResponseBody",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentBadGatewayErrorResponseBody",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentGatewayTimeoutErrorResponseBody",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentInternalServerErrorResponseBody",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentMethodNotAllowedErrorResponseBody",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentNotFoundErrorResponseBody",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentNotImplementedErrorResponseBody",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentResponseBody",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentServiceUnavailableErrorResponseBody",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentTooManyRequestsErrorResponseBody",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentUnauthorizedErrorResponseBody",
    "TrailerDvirObjectResponseBody",
    "TrailerGoaGatewayTinyResponseResponseBody",
    "TrailerGoaGatewayTinyResponseResponseBodyModel",
    "TrailerObjectResponseBody",
    "TrailerResponseObjectResponseBody",
    "TrailerStatDecorationResponseBody",
    "TrailerStatGpsOdometerMetersTypeResponseBody",
    "TrailerStatGpsOdometerMetersWithDecorationsTypeResponseBody",
    "TrailerStatGpsTypeResponseBody",
    "TrailerStatGpsWithDecorationsTypeResponseBody",
    "TrailerStatReeferAlarmResponseBody",
    "TrailerStatReeferAlarmTypeResponseBody",
    "TrailerStatReeferAlarmWithDecorationsTypeResponseBody",
    "TrailerStatReeferAmbientAirTemperatureMilliCTypeResponseBody",
    "TrailerStatReeferAmbientAirTemperatureWithDecorationsTypeResponseBody",
    "TrailerStatReeferDoorStateZone1TypeResponseBody",
    "TrailerStatReeferDoorStateZone1TypeResponseBodyValue",
    "TrailerStatReeferDoorStateZone1WithDecorationsTypeResponseBody",
    "TrailerStatReeferDoorStateZone1WithDecorationsTypeResponseBodyValue",
    "TrailerStatReeferDoorStateZone2TypeResponseBody",
    "TrailerStatReeferDoorStateZone2TypeResponseBodyValue",
    "TrailerStatReeferDoorStateZone2WithDecorationsTypeResponseBody",
    "TrailerStatReeferDoorStateZone2WithDecorationsTypeResponseBodyValue",
    "TrailerStatReeferDoorStateZone3TypeResponseBody",
    "TrailerStatReeferDoorStateZone3TypeResponseBodyValue",
    "TrailerStatReeferDoorStateZone3WithDecorationsTypeResponseBody",
    "TrailerStatReeferDoorStateZone3WithDecorationsTypeResponseBodyValue",
    "TrailerStatReeferFuelPercentTypeResponseBody",
    "TrailerStatReeferFuelPercentWithDecorationsTypeResponseBody",
    "TrailerStatReeferObdEngineSecondsTypeResponseBody",
    "TrailerStatReeferObdEngineSecondsWithDecorationsTypeResponseBody",
    "TrailerStatReeferReturnAirTemperatureMilliCZone1TypeResponseBody",
    "TrailerStatReeferReturnAirTemperatureMilliCZone1WithDecorationsTypeResponseBody",
    "TrailerStatReeferReturnAirTemperatureMilliCZone2TypeResponseBody",
    "TrailerStatReeferReturnAirTemperatureMilliCZone2WithDecorationsTypeResponseBody",
    "TrailerStatReeferReturnAirTemperatureMilliCZone3TypeResponseBody",
    "TrailerStatReeferReturnAirTemperatureMilliCZone3WithDecorationsTypeResponseBody",
    "TrailerStatReeferRunModeTypeResponseBody",
    "TrailerStatReeferRunModeWithDecorationsTypeResponseBody",
    "TrailerStatReeferSetPointTemperatureMilliCZone1TypeResponseBody",
    "TrailerStatReeferSetPointTemperatureMilliCZone1WithDecorationsTypeResponseBody",
    "TrailerStatReeferSetPointTemperatureMilliCZone2TypeResponseBody",
    "TrailerStatReeferSetPointTemperatureMilliCZone2WithDecorationsTypeResponseBody",
    "TrailerStatReeferSetPointTemperatureMilliCZone3TypeResponseBody",
    "TrailerStatReeferSetPointTemperatureMilliCZone3WithDecorationsTypeResponseBody",
    "TrailerStatReeferStateTypeResponseBody",
    "TrailerStatReeferStateWithDecorationsTypeResponseBody",
    "TrailerStatReeferStateZone1TypeResponseBody",
    "TrailerStatReeferStateZone1WithDecorationsTypeResponseBody",
    "TrailerStatReeferStateZone2TypeResponseBody",
    "TrailerStatReeferStateZone2WithDecorationsTypeResponseBody",
    "TrailerStatReeferStateZone3TypeResponseBody",
    "TrailerStatReeferStateZone3WithDecorationsTypeResponseBody",
    "TrailerStatReeferSupplyAirTemperatureMilliCZone1TypeResponseBody",
    "TrailerStatReeferSupplyAirTemperatureMilliCZone1WithDecorationsTypeResponseBody",
    "TrailerStatReeferSupplyAirTemperatureMilliCZone2TypeResponseBody",
    "TrailerStatReeferSupplyAirTemperatureMilliCZone2WithDecorationsTypeResponseBody",
    "TrailerStatReeferSupplyAirTemperatureMilliCZone3TypeResponseBody",
    "TrailerStatReeferSupplyAirTemperatureMilliCZone3WithDecorationsTypeResponseBody",
    "TrailerStatsGetTrailerStatsFeedBadGatewayErrorResponseBody",
    "TrailerStatsGetTrailerStatsFeedGatewayTimeoutErrorResponseBody",
    "TrailerStatsGetTrailerStatsFeedInternalServerErrorResponseBody",
    "TrailerStatsGetTrailerStatsFeedMethodNotAllowedErrorResponseBody",
    "TrailerStatsGetTrailerStatsFeedNotFoundErrorResponseBody",
    "TrailerStatsGetTrailerStatsFeedNotImplementedErrorResponseBody",
    "TrailerStatsGetTrailerStatsFeedResponseBody",
    "TrailerStatsGetTrailerStatsFeedServiceUnavailableErrorResponseBody",
    "TrailerStatsGetTrailerStatsFeedTooManyRequestsErrorResponseBody",
    "TrailerStatsGetTrailerStatsFeedUnauthorizedErrorResponseBody",
    "TrailerStatsGetTrailerStatsHistoryBadGatewayErrorResponseBody",
    "TrailerStatsGetTrailerStatsHistoryGatewayTimeoutErrorResponseBody",
    "TrailerStatsGetTrailerStatsHistoryInternalServerErrorResponseBody",
    "TrailerStatsGetTrailerStatsHistoryMethodNotAllowedErrorResponseBody",
    "TrailerStatsGetTrailerStatsHistoryNotFoundErrorResponseBody",
    "TrailerStatsGetTrailerStatsHistoryNotImplementedErrorResponseBody",
    "TrailerStatsGetTrailerStatsHistoryResponseBody",
    "TrailerStatsGetTrailerStatsHistoryServiceUnavailableErrorResponseBody",
    "TrailerStatsGetTrailerStatsHistoryTooManyRequestsErrorResponseBody",
    "TrailerStatsGetTrailerStatsHistoryUnauthorizedErrorResponseBody",
    "TrailerStatsGetTrailerStatsSnapshotBadGatewayErrorResponseBody",
    "TrailerStatsGetTrailerStatsSnapshotGatewayTimeoutErrorResponseBody",
    "TrailerStatsGetTrailerStatsSnapshotInternalServerErrorResponseBody",
    "TrailerStatsGetTrailerStatsSnapshotMethodNotAllowedErrorResponseBody",
    "TrailerStatsGetTrailerStatsSnapshotNotFoundErrorResponseBody",
    "TrailerStatsGetTrailerStatsSnapshotNotImplementedErrorResponseBody",
    "TrailerStatsGetTrailerStatsSnapshotResponseBody",
    "TrailerStatsGetTrailerStatsSnapshotServiceUnavailableErrorResponseBody",
    "TrailerStatsGetTrailerStatsSnapshotTooManyRequestsErrorResponseBody",
    "TrailerStatsGetTrailerStatsSnapshotUnauthorizedErrorResponseBody",
    "TrailerStatsObjectResponseBody",
    "TrailerStatsSnapshotObjectResponseBody",
    "TrailerTinyResponse",
    "TrailerWithAttributesResponseObjectResponseBody",
    "TrailersCreateTrailerBadGatewayErrorResponseBody",
    "TrailersCreateTrailerGatewayTimeoutErrorResponseBody",
    "TrailersCreateTrailerInternalServerErrorResponseBody",
    "TrailersCreateTrailerMethodNotAllowedErrorResponseBody",
    "TrailersCreateTrailerNotFoundErrorResponseBody",
    "TrailersCreateTrailerNotImplementedErrorResponseBody",
    "TrailersCreateTrailerResponseBody",
    "TrailersCreateTrailerServiceUnavailableErrorResponseBody",
    "TrailersCreateTrailerTooManyRequestsErrorResponseBody",
    "TrailersCreateTrailerUnauthorizedErrorResponseBody",
    "TrailersDeleteTrailerBadGatewayErrorResponseBody",
    "TrailersDeleteTrailerGatewayTimeoutErrorResponseBody",
    "TrailersDeleteTrailerInternalServerErrorResponseBody",
    "TrailersDeleteTrailerMethodNotAllowedErrorResponseBody",
    "TrailersDeleteTrailerNotFoundErrorResponseBody",
    "TrailersDeleteTrailerNotImplementedErrorResponseBody",
    "TrailersDeleteTrailerServiceUnavailableErrorResponseBody",
    "TrailersDeleteTrailerTooManyRequestsErrorResponseBody",
    "TrailersDeleteTrailerUnauthorizedErrorResponseBody",
    "TrailersGetTrailerBadGatewayErrorResponseBody",
    "TrailersGetTrailerGatewayTimeoutErrorResponseBody",
    "TrailersGetTrailerInternalServerErrorResponseBody",
    "TrailersGetTrailerMethodNotAllowedErrorResponseBody",
    "TrailersGetTrailerNotFoundErrorResponseBody",
    "TrailersGetTrailerNotImplementedErrorResponseBody",
    "TrailersGetTrailerResponseBody",
    "TrailersGetTrailerServiceUnavailableErrorResponseBody",
    "TrailersGetTrailerTooManyRequestsErrorResponseBody",
    "TrailersGetTrailerUnauthorizedErrorResponseBody",
    "TrailersListTrailersBadGatewayErrorResponseBody",
    "TrailersListTrailersGatewayTimeoutErrorResponseBody",
    "TrailersListTrailersInternalServerErrorResponseBody",
    "TrailersListTrailersMethodNotAllowedErrorResponseBody",
    "TrailersListTrailersNotFoundErrorResponseBody",
    "TrailersListTrailersNotImplementedErrorResponseBody",
    "TrailersListTrailersResponseBody",
    "TrailersListTrailersServiceUnavailableErrorResponseBody",
    "TrailersListTrailersTooManyRequestsErrorResponseBody",
    "TrailersListTrailersUnauthorizedErrorResponseBody",
    "TrailersUpdateTrailerBadGatewayErrorResponseBody",
    "TrailersUpdateTrailerGatewayTimeoutErrorResponseBody",
    "TrailersUpdateTrailerInternalServerErrorResponseBody",
    "TrailersUpdateTrailerMethodNotAllowedErrorResponseBody",
    "TrailersUpdateTrailerNotFoundErrorResponseBody",
    "TrailersUpdateTrailerNotImplementedErrorResponseBody",
    "TrailersUpdateTrailerResponseBody",
    "TrailersUpdateTrailerServiceUnavailableErrorResponseBody",
    "TrailersUpdateTrailerTooManyRequestsErrorResponseBody",
    "TrailersUpdateTrailerUnauthorizedErrorResponseBody",
    "TrainingAssignmentNearDueDateTriggerAssignmentGroupObjectRequestBody",
    "TrainingAssignmentNearDueDateTriggerAssignmentGroupObjectRequestBodyAssignmentGroupType",
    "TrainingAssignmentNearDueDateTriggerAssignmentGroupObjectResponseBody",
    "TrainingAssignmentNearDueDateTriggerAssignmentGroupObjectResponseBodyAssignmentGroupType",
    "TrainingAssignmentNearDueDateTriggerDetailsObjectRequestBody",
    "TrainingAssignmentNearDueDateTriggerDetailsObjectRequestBodyConditionUnits",
    "TrainingAssignmentNearDueDateTriggerDetailsObjectResponseBody",
    "TrainingAssignmentNearDueDateTriggerDetailsObjectResponseBodyConditionUnits",
    "TrainingAssignmentPostResponseObjectResponseBody",
    "TrainingAssignmentResponseObjectResponseBody",
    "TrainingAssignmentResponseObjectResponseBodyStatus",
    "TrainingAssignmentsDeleteTrainingAssignmentsBadGatewayErrorResponseBody",
    "TrainingAssignmentsDeleteTrainingAssignmentsGatewayTimeoutErrorResponseBody",
    "TrainingAssignmentsDeleteTrainingAssignmentsInternalServerErrorResponseBody",
    "TrainingAssignmentsDeleteTrainingAssignmentsMethodNotAllowedErrorResponseBody",
    "TrainingAssignmentsDeleteTrainingAssignmentsNotFoundErrorResponseBody",
    "TrainingAssignmentsDeleteTrainingAssignmentsNotImplementedErrorResponseBody",
    "TrainingAssignmentsDeleteTrainingAssignmentsServiceUnavailableErrorResponseBody",
    "TrainingAssignmentsDeleteTrainingAssignmentsTooManyRequestsErrorResponseBody",
    "TrainingAssignmentsDeleteTrainingAssignmentsUnauthorizedErrorResponseBody",
    "TrainingAssignmentsGetTrainingAssignmentsStreamBadGatewayErrorResponseBody",
    "TrainingAssignmentsGetTrainingAssignmentsStreamGatewayTimeoutErrorResponseBody",
    "TrainingAssignmentsGetTrainingAssignmentsStreamInternalServerErrorResponseBody",
    "TrainingAssignmentsGetTrainingAssignmentsStreamMethodNotAllowedErrorResponseBody",
    "TrainingAssignmentsGetTrainingAssignmentsStreamNotFoundErrorResponseBody",
    "TrainingAssignmentsGetTrainingAssignmentsStreamNotImplementedErrorResponseBody",
    "TrainingAssignmentsGetTrainingAssignmentsStreamResponseBody",
    "TrainingAssignmentsGetTrainingAssignmentsStreamServiceUnavailableErrorResponseBody",
    "TrainingAssignmentsGetTrainingAssignmentsStreamTooManyRequestsErrorResponseBody",
    "TrainingAssignmentsGetTrainingAssignmentsStreamUnauthorizedErrorResponseBody",
    "TrainingAssignmentsPatchTrainingAssignmentsBadGatewayErrorResponseBody",
    "TrainingAssignmentsPatchTrainingAssignmentsGatewayTimeoutErrorResponseBody",
    "TrainingAssignmentsPatchTrainingAssignmentsInternalServerErrorResponseBody",
    "TrainingAssignmentsPatchTrainingAssignmentsMethodNotAllowedErrorResponseBody",
    "TrainingAssignmentsPatchTrainingAssignmentsNotFoundErrorResponseBody",
    "TrainingAssignmentsPatchTrainingAssignmentsNotImplementedErrorResponseBody",
    "TrainingAssignmentsPatchTrainingAssignmentsResponseBody",
    "TrainingAssignmentsPatchTrainingAssignmentsServiceUnavailableErrorResponseBody",
    "TrainingAssignmentsPatchTrainingAssignmentsTooManyRequestsErrorResponseBody",
    "TrainingAssignmentsPatchTrainingAssignmentsUnauthorizedErrorResponseBody",
    "TrainingAssignmentsPostTrainingAssignmentsBadGatewayErrorResponseBody",
    "TrainingAssignmentsPostTrainingAssignmentsGatewayTimeoutErrorResponseBody",
    "TrainingAssignmentsPostTrainingAssignmentsInternalServerErrorResponseBody",
    "TrainingAssignmentsPostTrainingAssignmentsMethodNotAllowedErrorResponseBody",
    "TrainingAssignmentsPostTrainingAssignmentsNotFoundErrorResponseBody",
    "TrainingAssignmentsPostTrainingAssignmentsNotImplementedErrorResponseBody",
    "TrainingAssignmentsPostTrainingAssignmentsResponseBody",
    "TrainingAssignmentsPostTrainingAssignmentsServiceUnavailableErrorResponseBody",
    "TrainingAssignmentsPostTrainingAssignmentsTooManyRequestsErrorResponseBody",
    "TrainingAssignmentsPostTrainingAssignmentsUnauthorizedErrorResponseBody",
    "TrainingCategoryObjectResponseBody",
    "TrainingCourseLabelObjectResponseBody",
    "TrainingCourseObjectResponseBody",
    "TrainingCourseResponseObjectResponseBody",
    "TrainingCourseResponseObjectResponseBodyStatus",
    "TrainingCoursesGetTrainingCoursesBadGatewayErrorResponseBody",
    "TrainingCoursesGetTrainingCoursesGatewayTimeoutErrorResponseBody",
    "TrainingCoursesGetTrainingCoursesInternalServerErrorResponseBody",
    "TrainingCoursesGetTrainingCoursesMethodNotAllowedErrorResponseBody",
    "TrainingCoursesGetTrainingCoursesNotFoundErrorResponseBody",
    "TrainingCoursesGetTrainingCoursesNotImplementedErrorResponseBody",
    "TrainingCoursesGetTrainingCoursesResponseBody",
    "TrainingCoursesGetTrainingCoursesServiceUnavailableErrorResponseBody",
    "TrainingCoursesGetTrainingCoursesTooManyRequestsErrorResponseBody",
    "TrainingCoursesGetTrainingCoursesUnauthorizedErrorResponseBody",
    "TrainingLearnerObjectResponseBody",
    "TrainingLearnerObjectResponseBodyType",
    "TriggerParamsObjectRequestBody",
    "TriggerParamsObjectResponseBody",
    "TripAssetResponseBody",
    "TripAssetResponseBodyType",
    "TripResponseBody",
    "TripResponseBodyCompletionStatus",
    "TripSpeedingIntervalsResponseBody",
    "TripsBreakdownResponseBody",
    "TripsGetTripsBadGatewayErrorResponseBody",
    "TripsGetTripsGatewayTimeoutErrorResponseBody",
    "TripsGetTripsInternalServerErrorResponseBody",
    "TripsGetTripsMethodNotAllowedErrorResponseBody",
    "TripsGetTripsNotFoundErrorResponseBody",
    "TripsGetTripsNotImplementedErrorResponseBody",
    "TripsGetTripsResponseBody",
    "TripsGetTripsServiceUnavailableErrorResponseBody",
    "TripsGetTripsTooManyRequestsErrorResponseBody",
    "TripsGetTripsUnauthorizedErrorResponseBody",
    "UnassignedDrivingDataResponseBody",
    "UnassignedDrivingTriggerDetailsObjectRequestBody",
    "UnassignedDrivingTriggerDetailsObjectResponseBody",
    "UpdateAddressRequestGeofence",
    "UpdateDriverRequestAttributes",
    "UpdateDriverRequestHosSetting",
    "UpdateEngineImmobilizerRelayStateRequestBodyRequestBody",
    "UpdateEngineImmobilizerRelayStateRequestBodyRequestBodyId",
    "UpdateHubLocationRequestBodyRequestBody",
    "UpdateRoutesStopRequestObjectRequestBody",
    "UploadedMediaObjectResponseBody",
    "UploadedMediaObjectResponseBodyCameraRole",
    "UploadedMediaObjectResponseBodyInput",
    "UploadedMediaObjectResponseBodyMediaType",
    "UploadedMediaObjectResponseBodyTriggerReason",
    "UrlInfoObjectResponseBody",
    "UsDriverRulesetOverride",
    "UsDriverRulesetOverrideCycle",
    "UsDriverRulesetOverrideRestart",
    "UsDriverRulesetOverrideRestbreak",
    "UsDriverRulesetOverrideUsStateToOverride",
    "User",
    "UserAuthType",
    "UserEmail",
    "UserExpireAt",
    "UserId",
    "UserIdentifierSerial",
    "UserName",
    "UserResponse",
    "UserRole",
    "UserRoleAssignment",
    "UserRoles",
    "UserTinyResponse",
    "V1Asset",
    "V1AssetCable",
    "V1AssetCurrentLocation",
    "V1AssetCurrentLocationsResponse",
    "V1AssetLocationResponse",
    "V1AssetLocationResponseItem",
    "V1AssetReeferResponse",
    "V1AssetReeferResponseReeferStats",
    "V1AssetReeferResponseReeferStatsAlarms",
    "V1AssetReeferResponseReeferStatsAlarms1",
    "V1AssetReeferResponseReeferStatsEngineHours",
    "V1AssetReeferResponseReeferStatsFuelPercentage",
    "V1AssetReeferResponseReeferStatsPowerStatus",
    "V1AssetReeferResponseReeferStatsReturnAirTemp",
    "V1AssetReeferResponseReeferStatsSetPoint",
    "V1AssetsReefer",
    "V1AssetsReeferReeferStats",
    "V1AssetsReeferReeferStatsAmbientAirTemperature",
    "V1AssetsReeferReeferStatsDischargeAirTemperature",
    "V1AssetsReeferReeferStatsPowerStatus",
    "V1AssetsReeferReeferStatsPowerStatusStatus",
    "V1CargoResponse",
    "V1CargoResponseSensors",
    "V1DoorResponse",
    "V1DoorResponseSensors",
    "V1DriverSafetyScoreResponse",
    "V1HosAuthenticationLogsResponse",
    "V1HosAuthenticationLogsResponseAuthenticationLogs",
    "V1HumidityResponse",
    "V1HumidityResponseSensors",
    "V1Machine",
    "V1MachineHistoryResponse",
    "V1MachineHistoryResponseMachines",
    "V1MachineHistoryResponseVibrations",
    "V1Message",
    "V1MessageResponse",
    "V1MessageSender",
    "V1Messages",
    "V1MessagesResponse",
    "V1Pagination",
    "V1ProgramsForTheCameraResponse",
    "V1ProgramsForTheCameraResponseItem",
    "V1SafetyReportHarshEvent",
    "V1Sensor",
    "V1SensorHistoryResponse",
    "V1SensorHistoryResponseResults",
    "V1SensorsHistorySeries",
    "V1SensorsHistorySeriesField",
    "V1TemperatureResponse",
    "V1TemperatureResponseSensors",
    "V1TrailerAssignmentResponse",
    "V1TrailerAssignmentsResponse",
    "V1TrailerAssignmentsResponseAllOf",
    "V1TrailerBase",
    "V1TripResponse",
    "V1TripResponseEndAddress",
    "V1TripResponseEndCoordinates",
    "V1TripResponseStartAddress",
    "V1TripResponseStartCoordinates",
    "V1TripResponseTrips",
    "V1VehicleHarshEventResponse",
    "V1VehicleHarshEventResponseLocation",
    "V1VehicleMaintenance",
    "V1VehicleMaintenanceJ1939",
    "V1VehicleMaintenanceJ1939CheckEngineLight",
    "V1VehicleMaintenanceJ1939DiagnosticTroubleCodes",
    "V1VehicleMaintenancePassenger",
    "V1VehicleMaintenancePassengerCheckEngineLight",
    "V1VehicleMaintenancePassengerDiagnosticTroubleCodes",
    "V1VehicleSafetyScoreResponse",
    "V1VisionCamerasResponse",
    "V1VisionCamerasResponseItem",
    "V1VisionRunByCameraResponse",
    "V1VisionRunByCameraResponseInspectionResults",
    "V1VisionRunByCameraResponseProgram",
    "V1VisionRunByCameraResponseRunSummary",
    "V1VisionRunsByCameraAndProgramResponse",
    "V1VisionRunsByCameraResponse",
    "V1VisionRunsByCameraResponseItem",
    "V1VisionRunsByCameraResponseItemProgram",
    "V1VisionRunsByCameraResponseItemReportMetadata",
    "V1VisionRunsResponse",
    "V1VisionRunsResponseReportMetadata",
    "V1VisionRunsResponseVisionRuns",
    "V1VisionStepResults",
    "V1VisionStepResultsItem",
    "V1VisionStepResultsItemAngleCheck",
    "V1VisionStepResultsItemAngleCheckAngleConfigured",
    "V1VisionStepResultsItemBarcodeItem",
    "V1VisionStepResultsItemBooleanLogic",
    "V1VisionStepResultsItemBooleanLogicStepsItem",
    "V1VisionStepResultsItemCaliper",
    "V1VisionStepResultsItemCaliperAngleRange",
    "V1VisionStepResultsItemCaliperContrastRange",
    "V1VisionStepResultsItemCaliperFilterPolarity",
    "V1VisionStepResultsItemCaliperSharpnessRange",
    "V1VisionStepResultsItemCaliperStraightnessRange",
    "V1VisionStepResultsItemContour",
    "V1VisionStepResultsItemDistance",
    "V1VisionStepResultsItemExpirationDate",
    "V1VisionStepResultsItemFindCopies",
    "V1VisionStepResultsItemFindEdge",
    "V1VisionStepResultsItemFindEdgeAngleRange",
    "V1VisionStepResultsItemFindEdgeContrastRange",
    "V1VisionStepResultsItemFindEdgeSharpnessRange",
    "V1VisionStepResultsItemFindEdgeStraightnessRange",
    "V1VisionStepResultsItemFindShapes",
    "V1VisionStepResultsItemFixture",
    "V1VisionStepResultsItemFixtureCoordinates",
    "V1VisionStepResultsItemLabelMatch",
    "V1VisionStepResultsItemPresenceAbsence",
    "V1VisionStepResultsItemPresenceAbsenceBlueRange",
    "V1VisionStepResultsItemPresenceAbsenceGrayscaleRange",
    "V1VisionStepResultsItemPresenceAbsenceGreenRange",
    "V1VisionStepResultsItemPresenceAbsenceHueRange",
    "V1VisionStepResultsItemPresenceAbsenceRedRange",
    "V1VisionStepResultsItemPresenceAbsenceSaturationRange",
    "V1VisionStepResultsItemPresenceAbsenceValueRange",
    "V1VisionStepResultsItemTextMatch",
    "Vehicle",
    "VehicleAssignmentObjectResponseBody",
    "VehicleAssignmentObjectResponseBodyAssignmentType",
    "VehicleAuxInputName",
    "VehicleAuxInputType",
    "VehicleBatterVoltageDetailsObjectRequestBody",
    "VehicleBatterVoltageDetailsObjectRequestBodyOperation",
    "VehicleBatterVoltageDetailsObjectResponseBody",
    "VehicleBatterVoltageDetailsObjectResponseBodyOperation",
    "VehicleBatteryVoltageResponseBody",
    "VehicleDefLevelPercentageResponseBody",
    "VehicleDetectedResponseBody",
    "VehicleDvirObjectResponseBody",
    "VehicleEsn",
    "VehicleExternalIds",
    "VehicleFaultCodeDetailsObjectRequestBody",
    "VehicleFaultCodeDetailsObjectResponseBody",
    "VehicleFaultsResponseBody",
    "VehicleHarshAccelerationSettingType",
    "VehicleId",
    "VehicleLicensePlate",
    "VehicleLocation",
    "VehicleLocationAddress",
    "VehicleLocationHeading",
    "VehicleLocationIsEcuSpeed",
    "VehicleLocationLatitude",
    "VehicleLocationLongitude",
    "VehicleLocationSpeed",
    "VehicleLocationsListResponse",
    "VehicleLocationsListResponseData",
    "VehicleLocationsResponse",
    "VehicleLocationsResponseData",
    "VehicleMake",
    "VehicleModel",
    "VehicleName",
    "VehicleNotes",
    "VehicleRegulationMode",
    "VehicleResponse",
    "VehicleResponseObjectResponseBody",
    "VehicleResponseObjectResponseBodyVehicleRegulationMode",
    "VehicleResponseObjectResponseBodyVehicleType",
    "VehicleResponseResponseBody",
    "VehicleResponseResponseBodyAssetType",
    "VehicleSafetyScoreResponseBody",
    "VehicleSensorConfiguration",
    "VehicleSensorConfigurationArea",
    "VehicleSensorConfigurationAreaPosition",
    "VehicleSensorConfigurationAreaResponseBody",
    "VehicleSensorConfigurationAreaResponseBodyPosition",
    "VehicleSensorConfigurationDoor",
    "VehicleSensorConfigurationDoorPosition",
    "VehicleSensorConfigurationDoorResponseBody",
    "VehicleSensorConfigurationDoorResponseBodyPosition",
    "VehicleSensorConfigurationResponseBody",
    "VehicleStatsAmbientAirTempMilliC",
    "VehicleStatsAmbientAirTempMilliCValue",
    "VehicleStatsAmbientAirTempMilliCWithDecoration",
    "VehicleStatsAuxInput",
    "VehicleStatsAuxInputDecoration",
    "VehicleStatsAuxInputTime",
    "VehicleStatsAuxInputValue",
    "VehicleStatsAuxInputWithDecoration",
    "VehicleStatsBarometricPressurePa",
    "VehicleStatsBarometricPressurePaValue",
    "VehicleStatsBarometricPressurePaWithDecoration",
    "VehicleStatsBatteryMilliVoltsValue",
    "VehicleStatsBatteryVoltage",
    "VehicleStatsBatteryVoltageWithDecoration",
    "VehicleStatsDecorations",
    "VehicleStatsDecorationsAmbientAirTemperatureMilliC",
    "VehicleStatsDecorationsBarometricPressurePa",
    "VehicleStatsDecorationsBatteryMilliVolts",
    "VehicleStatsDecorationsDefLevelMilliPercent",
    "VehicleStatsDecorationsEcuSpeedMph",
    "VehicleStatsDecorationsEngineCoolantTemperatureMilliC",
    "VehicleStatsDecorationsEngineLoadPercent",
    "VehicleStatsDecorationsEngineOilPressureKPa",
    "VehicleStatsDecorationsEngineRpm",
    "VehicleStatsDecorationsEngineStates",
    "VehicleStatsDecorationsEngineStatesValue",
    "VehicleStatsDecorationsFuelConsumedMilliliters",
    "VehicleStatsDecorationsFuelPercents",
    "VehicleStatsDecorationsGps",
    "VehicleStatsDecorationsGpsDistanceMeters",
    "VehicleStatsDecorationsGpsOdometerMeters",
    "VehicleStatsDecorationsIdlingDurationMilliseconds",
    "VehicleStatsDecorationsIntakeManifoldTemperatureMilliC",
    "VehicleStatsDecorationsObdEngineSeconds",
    "VehicleStatsDecorationsObdOdometerMeters",
    "VehicleStatsDefLevelMilliPercent",
    "VehicleStatsDefLevelMilliPercentValue",
    "VehicleStatsDefLevelMilliPercentWithDecoration",
    "VehicleStatsEcuDoorStatus",
    "VehicleStatsEcuDoorStatusValue",
    "VehicleStatsEcuSpeedMph",
    "VehicleStatsEcuSpeedMphValue",
    "VehicleStatsEcuSpeedMphWithDecoration",
    "VehicleStatsEngineCoolantTempMilliC",
    "VehicleStatsEngineCoolantTempMilliCValue",
    "VehicleStatsEngineCoolantTempMilliCWithDecoration",
    "VehicleStatsEngineImmobilizer",
    "VehicleStatsEngineImmobilizerState",
    "VehicleStatsEngineImmobilizerWithDecoration",
    "VehicleStatsEngineImmobilizerWithDecorationState",
    "VehicleStatsEngineLoadPercent",
    "VehicleStatsEngineLoadPercentValue",
    "VehicleStatsEngineLoadPercentWithDecoration",
    "VehicleStatsEngineOilPressureKPa",
    "VehicleStatsEngineOilPressureKPaValue",
    "VehicleStatsEngineOilPressureKPaWithDecoration",
    "VehicleStatsEngineRpm",
    "VehicleStatsEngineRpmValue",
    "VehicleStatsEngineRpmWithDecoration",
    "VehicleStatsEngineState",
    "VehicleStatsEngineStateSetting",
    "VehicleStatsEngineStateWithDecoration",
    "VehicleStatsEvAverageBatteryTemperatureMilliCelsius",
    "VehicleStatsEvBatteryCurrentMilliAmp",
    "VehicleStatsEvBatteryStateOfHealthMilliPercent",
    "VehicleStatsEvBatteryVoltageMilliVolt",
    "VehicleStatsEvChargingCurrentMilliAmp",
    "VehicleStatsEvChargingEnergyMicroWh",
    "VehicleStatsEvChargingStatus",
    "VehicleStatsEvChargingVoltageMilliVolt",
    "VehicleStatsEvConsumedEnergyMicroWh",
    "VehicleStatsEvDistanceDrivenMeters",
    "VehicleStatsEvRegeneratedEnergyMicroWh",
    "VehicleStatsEvStateOfChargeMilliPercent",
    "VehicleStatsFaultCodes",
    "VehicleStatsFaultCodesCanBusType",
    "VehicleStatsFaultCodesIgnitionType",
    "VehicleStatsFaultCodesJ1939",
    "VehicleStatsFaultCodesJ1939Lights",
    "VehicleStatsFaultCodesJ1939TroubleCode",
    "VehicleStatsFaultCodesJ1939TroubleCodes",
    "VehicleStatsFaultCodesObdii",
    "VehicleStatsFaultCodesObdiiTroubleCode",
    "VehicleStatsFaultCodesOem",
    "VehicleStatsFaultCodesOemTroubleCode",
    "VehicleStatsFaultCodesOemTroubleCodes",
    "VehicleStatsFaultCodesPassengerDtc",
    "VehicleStatsFaultCodesPassengerMonitorStatus",
    "VehicleStatsFaultCodesPassengerMonitorStatusValue",
    "VehicleStatsFaultCodesTxId",
    "VehicleStatsFaultCodesValue",
    "VehicleStatsFaultCodesValueJ1939",
    "VehicleStatsFaultCodesValueJ1939CheckEngineLights",
    "VehicleStatsFaultCodesValueJ1939DiagnosticTroubleCodes",
    "VehicleStatsFaultCodesValueJ1939VendorSpecificFields",
    "VehicleStatsFaultCodesValueObdii",
    "VehicleStatsFaultCodesValueObdiiConfirmedDtcs",
    "VehicleStatsFaultCodesValueObdiiDiagnosticTroubleCodes",
    "VehicleStatsFaultCodesValueObdiiDiagnosticTroubleCodesIgnitionType",
    "VehicleStatsFaultCodesValueObdiiMonitorStatus",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusCatalyst",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusComprehensive",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusEgr",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusEvapSystem",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusFuel",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusHeatedCatalyst",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusHeatedO2Sensor",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusIsoSaeReserved",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusMisfire",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusO2Sensor",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusSecondaryAir",
    "VehicleStatsFaultCodesValueOem",
    "VehicleStatsFaultCodesValueOemDiagnosticTroubleCodes",
    "VehicleStatsFaultCodesVendorSpecificFields",
    "VehicleStatsFaultCodesWithDecoration",
    "VehicleStatsFuelConsumedMilliliters",
    "VehicleStatsFuelConsumedMillilitersValue",
    "VehicleStatsFuelConsumedMillilitersWithDecoration",
    "VehicleStatsFuelPercent",
    "VehicleStatsFuelPercentValue",
    "VehicleStatsFuelPercentWithDecoration",
    "VehicleStatsGps",
    "VehicleStatsGpsDistanceMeters",
    "VehicleStatsGpsDistanceMetersValue",
    "VehicleStatsGpsDistanceMetersWithDecoration",
    "VehicleStatsGpsOdometerMeters",
    "VehicleStatsGpsOdometerMetersValue",
    "VehicleStatsGpsOdometerMetersWithDecoration",
    "VehicleStatsIdlingDurationMilliseconds",
    "VehicleStatsIdlingDurationMillisecondsValue",
    "VehicleStatsIdlingDurationMillisecondsWithDecoration",
    "VehicleStatsIntakeManifoldTempMilliC",
    "VehicleStatsIntakeManifoldTempMilliCValue",
    "VehicleStatsIntakeManifoldTempMilliCWithDecoration",
    "VehicleStatsListGps",
    "VehicleStatsListResponse",
    "VehicleStatsListResponseData",
    "VehicleStatsListSyntheticEngineSeconds",
    "VehicleStatsNfcCardScan",
    "VehicleStatsNfcCardScanCard",
    "VehicleStatsNfcCardScanWithDecoration",
    "VehicleStatsObdEngineSeconds",
    "VehicleStatsObdEngineSecondsValue",
    "VehicleStatsObdEngineSecondsWithDecoration",
    "VehicleStatsObdOdometerMeters",
    "VehicleStatsObdOdometerMetersValue",
    "VehicleStatsObdOdometerMetersWithDecoration",
    "VehicleStatsResponse",
    "VehicleStatsResponseData",
    "VehicleStatsResponseEcuDoorStatus",
    "VehicleStatsResponseEcuDoorStatusValue",
    "VehicleStatsResponseEvAverageBatteryTemperatureMilliCelsius",
    "VehicleStatsResponseEvBatteryCurrentMilliAmp",
    "VehicleStatsResponseEvBatteryStateOfHealthMilliPercent",
    "VehicleStatsResponseEvBatteryVoltageMilliVolt",
    "VehicleStatsResponseEvChargingCurrentMilliAmp",
    "VehicleStatsResponseEvChargingEnergyMicroWh",
    "VehicleStatsResponseEvChargingStatus",
    "VehicleStatsResponseEvChargingVoltageMilliVolt",
    "VehicleStatsResponseEvConsumedEnergyMicroWh",
    "VehicleStatsResponseEvDistanceDrivenMeters",
    "VehicleStatsResponseEvRegeneratedEnergyMicroWh",
    "VehicleStatsResponseEvStateOfChargeMilliPercent",
    "VehicleStatsResponseSeatbeltDriver",
    "VehicleStatsResponseSeatbeltDriverValue",
    "VehicleStatsResponseSpreaderActive",
    "VehicleStatsResponseSpreaderActiveValue",
    "VehicleStatsResponseSpreaderAirTemp",
    "VehicleStatsResponseSpreaderBlastState",
    "VehicleStatsResponseSpreaderBlastStateValue",
    "VehicleStatsResponseSpreaderGranularName",
    "VehicleStatsResponseSpreaderGranularRate",
    "VehicleStatsResponseSpreaderLiquidName",
    "VehicleStatsResponseSpreaderLiquidRate",
    "VehicleStatsResponseSpreaderOnState",
    "VehicleStatsResponseSpreaderOnStateValue",
    "VehicleStatsResponseSpreaderPlowStatus",
    "VehicleStatsResponseSpreaderPlowStatusValue",
    "VehicleStatsResponseSpreaderPrewetName",
    "VehicleStatsResponseSpreaderPrewetRate",
    "VehicleStatsResponseSpreaderRoadTemp",
    "VehicleStatsSeatbeltDriver",
    "VehicleStatsSeatbeltDriverValue",
    "VehicleStatsSpreaderActive",
    "VehicleStatsSpreaderActiveValue",
    "VehicleStatsSpreaderAirTemp",
    "VehicleStatsSpreaderBlastState",
    "VehicleStatsSpreaderBlastStateValue",
    "VehicleStatsSpreaderGranularName",
    "VehicleStatsSpreaderGranularRate",
    "VehicleStatsSpreaderLiquidName",
    "VehicleStatsSpreaderLiquidRate",
    "VehicleStatsSpreaderOnState",
    "VehicleStatsSpreaderOnStateValue",
    "VehicleStatsSpreaderPlowStatus",
    "VehicleStatsSpreaderPlowStatusValue",
    "VehicleStatsSpreaderPrewetName",
    "VehicleStatsSpreaderPrewetRate",
    "VehicleStatsSpreaderRoadTemp",
    "VehicleStatsSyntheticEngineSeconds",
    "VehicleStatsSyntheticEngineSecondsValue",
    "VehicleStatsTirePressures",
    "VehicleSummary",
    "VehicleTags",
    "VehicleTinyResponse",
    "VehicleType",
    "VehicleVin",
    "VehicleWithGatewayTinyResponseResponseBody",
    "VehicleWithGatewayTinyResponseResponseBodyAssetType",
    "VehicleYear",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsBadGatewayErrorResponseBody",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsGatewayTimeoutErrorResponseBody",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsInternalServerErrorResponseBody",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsMethodNotAllowedErrorResponseBody",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsNotFoundErrorResponseBody",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsNotImplementedErrorResponseBody",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsResponseBody",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsServiceUnavailableErrorResponseBody",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsTooManyRequestsErrorResponseBody",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsUnauthorizedErrorResponseBody",
    "VehiclesDriverAssignmentsObjectResponseBody",
    "VehiclesListVehiclesBadGatewayErrorResponseBody",
    "VehiclesListVehiclesGatewayTimeoutErrorResponseBody",
    "VehiclesListVehiclesInternalServerErrorResponseBody",
    "VehiclesListVehiclesMethodNotAllowedErrorResponseBody",
    "VehiclesListVehiclesNotFoundErrorResponseBody",
    "VehiclesListVehiclesNotImplementedErrorResponseBody",
    "VehiclesListVehiclesResponseBody",
    "VehiclesListVehiclesServiceUnavailableErrorResponseBody",
    "VehiclesListVehiclesTooManyRequestsErrorResponseBody",
    "VehiclesListVehiclesUnauthorizedErrorResponseBody",
    "VehiclesLockLockVehicleBadGatewayErrorResponseBody",
    "VehiclesLockLockVehicleGatewayTimeoutErrorResponseBody",
    "VehiclesLockLockVehicleInternalServerErrorResponseBody",
    "VehiclesLockLockVehicleMethodNotAllowedErrorResponseBody",
    "VehiclesLockLockVehicleNotFoundErrorResponseBody",
    "VehiclesLockLockVehicleNotImplementedErrorResponseBody",
    "VehiclesLockLockVehicleServiceUnavailableErrorResponseBody",
    "VehiclesLockLockVehicleTooManyRequestsErrorResponseBody",
    "VehiclesLockLockVehicleUnauthorizedErrorResponseBody",
    "VehiclesLockUnlockVehicleBadGatewayErrorResponseBody",
    "VehiclesLockUnlockVehicleGatewayTimeoutErrorResponseBody",
    "VehiclesLockUnlockVehicleInternalServerErrorResponseBody",
    "VehiclesLockUnlockVehicleMethodNotAllowedErrorResponseBody",
    "VehiclesLockUnlockVehicleNotFoundErrorResponseBody",
    "VehiclesLockUnlockVehicleNotImplementedErrorResponseBody",
    "VehiclesLockUnlockVehicleServiceUnavailableErrorResponseBody",
    "VehiclesLockUnlockVehicleTooManyRequestsErrorResponseBody",
    "VehiclesLockUnlockVehicleUnauthorizedErrorResponseBody",
    "VertexRequestBody",
    "VertexResponseBody",
    "VoiceCoachingSettingsObjectResponseBody",
    "VoiceCoachingSettingsObjectResponseBodyEventsToCoachItem",
    "VoiceCoachingSettingsObjectResponseBodyLanguage",
    "WalkaroundPhotoObjectResponseBody",
    "WebhookParamsObjectRequestBody",
    "WebhookParamsObjectRequestBodyPayloadType",
    "WebhookParamsObjectResponseBody",
    "WebhookParamsObjectResponseBodyPayloadType",
    "WebhookResponseResponseBody",
    "WebhookResponseResponseBodyEventTypesItem",
    "WebhookResponseResponseBodyVersion",
    "WebhookRouteResponseObjectResponseBody",
    "WebhooksDeleteWebhookBadGatewayErrorResponseBody",
    "WebhooksDeleteWebhookGatewayTimeoutErrorResponseBody",
    "WebhooksDeleteWebhookInternalServerErrorResponseBody",
    "WebhooksDeleteWebhookMethodNotAllowedErrorResponseBody",
    "WebhooksDeleteWebhookNotFoundErrorResponseBody",
    "WebhooksDeleteWebhookNotImplementedErrorResponseBody",
    "WebhooksDeleteWebhookServiceUnavailableErrorResponseBody",
    "WebhooksDeleteWebhookTooManyRequestsErrorResponseBody",
    "WebhooksDeleteWebhookUnauthorizedErrorResponseBody",
    "WebhooksGetWebhookBadGatewayErrorResponseBody",
    "WebhooksGetWebhookGatewayTimeoutErrorResponseBody",
    "WebhooksGetWebhookInternalServerErrorResponseBody",
    "WebhooksGetWebhookMethodNotAllowedErrorResponseBody",
    "WebhooksGetWebhookNotFoundErrorResponseBody",
    "WebhooksGetWebhookNotImplementedErrorResponseBody",
    "WebhooksGetWebhookResponseBody",
    "WebhooksGetWebhookResponseBodyEventTypesItem",
    "WebhooksGetWebhookResponseBodyVersion",
    "WebhooksGetWebhookServiceUnavailableErrorResponseBody",
    "WebhooksGetWebhookTooManyRequestsErrorResponseBody",
    "WebhooksGetWebhookUnauthorizedErrorResponseBody",
    "WebhooksListWebhooksBadGatewayErrorResponseBody",
    "WebhooksListWebhooksGatewayTimeoutErrorResponseBody",
    "WebhooksListWebhooksInternalServerErrorResponseBody",
    "WebhooksListWebhooksMethodNotAllowedErrorResponseBody",
    "WebhooksListWebhooksNotFoundErrorResponseBody",
    "WebhooksListWebhooksNotImplementedErrorResponseBody",
    "WebhooksListWebhooksResponseBody",
    "WebhooksListWebhooksServiceUnavailableErrorResponseBody",
    "WebhooksListWebhooksTooManyRequestsErrorResponseBody",
    "WebhooksListWebhooksUnauthorizedErrorResponseBody",
    "WebhooksPatchWebhookBadGatewayErrorResponseBody",
    "WebhooksPatchWebhookGatewayTimeoutErrorResponseBody",
    "WebhooksPatchWebhookInternalServerErrorResponseBody",
    "WebhooksPatchWebhookMethodNotAllowedErrorResponseBody",
    "WebhooksPatchWebhookNotFoundErrorResponseBody",
    "WebhooksPatchWebhookNotImplementedErrorResponseBody",
    "WebhooksPatchWebhookResponseBody",
    "WebhooksPatchWebhookResponseBodyEventTypesItem",
    "WebhooksPatchWebhookResponseBodyVersion",
    "WebhooksPatchWebhookServiceUnavailableErrorResponseBody",
    "WebhooksPatchWebhookTooManyRequestsErrorResponseBody",
    "WebhooksPatchWebhookUnauthorizedErrorResponseBody",
    "WebhooksPostWebhooksBadGatewayErrorResponseBody",
    "WebhooksPostWebhooksGatewayTimeoutErrorResponseBody",
    "WebhooksPostWebhooksInternalServerErrorResponseBody",
    "WebhooksPostWebhooksMethodNotAllowedErrorResponseBody",
    "WebhooksPostWebhooksNotFoundErrorResponseBody",
    "WebhooksPostWebhooksNotImplementedErrorResponseBody",
    "WebhooksPostWebhooksResponseBody",
    "WebhooksPostWebhooksResponseBodyEventTypesItem",
    "WebhooksPostWebhooksResponseBodyVersion",
    "WebhooksPostWebhooksServiceUnavailableErrorResponseBody",
    "WebhooksPostWebhooksTooManyRequestsErrorResponseBody",
    "WebhooksPostWebhooksUnauthorizedErrorResponseBody",
    "WorkOrderAttachmentObjectResponseBody",
    "WorkOrderAttachmentObjectResponseBodyProcessingStatus",
    "WorkOrderDiscountObjectRequestBody",
    "WorkOrderDiscountObjectResponseBody",
    "WorkOrderItemObjectRequestBody",
    "WorkOrderItemObjectRequestBodyType",
    "WorkOrderItemObjectResponseBody",
    "WorkOrderItemObjectResponseBodyType",
    "WorkOrderMoneyObjectRequestBody",
    "WorkOrderMoneyObjectRequestBodyCurrency",
    "WorkOrderMoneyObjectResponseBody",
    "WorkOrderMoneyObjectResponseBodyCurrency",
    "WorkOrderObjectResponseBody",
    "WorkOrderObjectResponseBodyPriority",
    "WorkOrderObjectResponseBodyStatus",
    "WorkOrderTaxCreateObjectRequestBody",
    "WorkOrderTaxObjectRequestBody",
    "WorkOrderTaxObjectResponseBody",
    "WorkOrderUnallocatedLaborObjectResponseBody",
    "WorkOrdersDeleteWorkOrdersBadGatewayErrorResponseBody",
    "WorkOrdersDeleteWorkOrdersGatewayTimeoutErrorResponseBody",
    "WorkOrdersDeleteWorkOrdersInternalServerErrorResponseBody",
    "WorkOrdersDeleteWorkOrdersMethodNotAllowedErrorResponseBody",
    "WorkOrdersDeleteWorkOrdersNotFoundErrorResponseBody",
    "WorkOrdersDeleteWorkOrdersNotImplementedErrorResponseBody",
    "WorkOrdersDeleteWorkOrdersServiceUnavailableErrorResponseBody",
    "WorkOrdersDeleteWorkOrdersTooManyRequestsErrorResponseBody",
    "WorkOrdersDeleteWorkOrdersUnauthorizedErrorResponseBody",
    "WorkOrdersGetServiceTasksBadGatewayErrorResponseBody",
    "WorkOrdersGetServiceTasksGatewayTimeoutErrorResponseBody",
    "WorkOrdersGetServiceTasksInternalServerErrorResponseBody",
    "WorkOrdersGetServiceTasksMethodNotAllowedErrorResponseBody",
    "WorkOrdersGetServiceTasksNotFoundErrorResponseBody",
    "WorkOrdersGetServiceTasksNotImplementedErrorResponseBody",
    "WorkOrdersGetServiceTasksResponseBody",
    "WorkOrdersGetServiceTasksServiceUnavailableErrorResponseBody",
    "WorkOrdersGetServiceTasksTooManyRequestsErrorResponseBody",
    "WorkOrdersGetServiceTasksUnauthorizedErrorResponseBody",
    "WorkOrdersGetWorkOrdersBadGatewayErrorResponseBody",
    "WorkOrdersGetWorkOrdersGatewayTimeoutErrorResponseBody",
    "WorkOrdersGetWorkOrdersInternalServerErrorResponseBody",
    "WorkOrdersGetWorkOrdersMethodNotAllowedErrorResponseBody",
    "WorkOrdersGetWorkOrdersNotFoundErrorResponseBody",
    "WorkOrdersGetWorkOrdersNotImplementedErrorResponseBody",
    "WorkOrdersGetWorkOrdersResponseBody",
    "WorkOrdersGetWorkOrdersServiceUnavailableErrorResponseBody",
    "WorkOrdersGetWorkOrdersTooManyRequestsErrorResponseBody",
    "WorkOrdersGetWorkOrdersUnauthorizedErrorResponseBody",
    "WorkOrdersPatchWorkOrdersBadGatewayErrorResponseBody",
    "WorkOrdersPatchWorkOrdersGatewayTimeoutErrorResponseBody",
    "WorkOrdersPatchWorkOrdersInternalServerErrorResponseBody",
    "WorkOrdersPatchWorkOrdersMethodNotAllowedErrorResponseBody",
    "WorkOrdersPatchWorkOrdersNotFoundErrorResponseBody",
    "WorkOrdersPatchWorkOrdersNotImplementedErrorResponseBody",
    "WorkOrdersPatchWorkOrdersResponseBody",
    "WorkOrdersPatchWorkOrdersServiceUnavailableErrorResponseBody",
    "WorkOrdersPatchWorkOrdersTooManyRequestsErrorResponseBody",
    "WorkOrdersPatchWorkOrdersUnauthorizedErrorResponseBody",
    "WorkOrdersPostInvoiceScanBadGatewayErrorResponseBody",
    "WorkOrdersPostInvoiceScanGatewayTimeoutErrorResponseBody",
    "WorkOrdersPostInvoiceScanInternalServerErrorResponseBody",
    "WorkOrdersPostInvoiceScanMethodNotAllowedErrorResponseBody",
    "WorkOrdersPostInvoiceScanNotFoundErrorResponseBody",
    "WorkOrdersPostInvoiceScanNotImplementedErrorResponseBody",
    "WorkOrdersPostInvoiceScanResponseBody",
    "WorkOrdersPostInvoiceScanServiceUnavailableErrorResponseBody",
    "WorkOrdersPostInvoiceScanTooManyRequestsErrorResponseBody",
    "WorkOrdersPostInvoiceScanUnauthorizedErrorResponseBody",
    "WorkOrdersPostWorkOrdersBadGatewayErrorResponseBody",
    "WorkOrdersPostWorkOrdersGatewayTimeoutErrorResponseBody",
    "WorkOrdersPostWorkOrdersInternalServerErrorResponseBody",
    "WorkOrdersPostWorkOrdersMethodNotAllowedErrorResponseBody",
    "WorkOrdersPostWorkOrdersNotFoundErrorResponseBody",
    "WorkOrdersPostWorkOrdersNotImplementedErrorResponseBody",
    "WorkOrdersPostWorkOrdersResponseBody",
    "WorkOrdersPostWorkOrdersServiceUnavailableErrorResponseBody",
    "WorkOrdersPostWorkOrdersTooManyRequestsErrorResponseBody",
    "WorkOrdersPostWorkOrdersUnauthorizedErrorResponseBody",
    "WorkOrdersStreamWorkOrdersBadGatewayErrorResponseBody",
    "WorkOrdersStreamWorkOrdersGatewayTimeoutErrorResponseBody",
    "WorkOrdersStreamWorkOrdersInternalServerErrorResponseBody",
    "WorkOrdersStreamWorkOrdersMethodNotAllowedErrorResponseBody",
    "WorkOrdersStreamWorkOrdersNotFoundErrorResponseBody",
    "WorkOrdersStreamWorkOrdersNotImplementedErrorResponseBody",
    "WorkOrdersStreamWorkOrdersResponseBody",
    "WorkOrdersStreamWorkOrdersServiceUnavailableErrorResponseBody",
    "WorkOrdersStreamWorkOrdersTooManyRequestsErrorResponseBody",
    "WorkOrdersStreamWorkOrdersUnauthorizedErrorResponseBody",
    "WorkerSafetySosDataResponseBody",
    "WorkerSafetySosDataResponseBodySourceType",
    "WorkflowAddressEventWithGeofenceObjectResponseBody",
    "WorkflowAuthorSignatureObjectResponseBody",
    "WorkflowAuthorSignatureObjectResponseBodyType",
    "WorkflowCircleResponseBody",
    "WorkflowDvirObjectResponseBody",
    "WorkflowDvirObjectResponseBodySafetyStatus",
    "WorkflowDvirObjectResponseBodyType",
    "WorkflowDvirSubmittedResponseObjectResponseBody",
    "WorkflowGeofenceEventResponseObjectResponseBody",
    "WorkflowGeofenceResponseBody",
    "WorkflowIncidentConditionObjectResponseBody",
    "WorkflowIncidentDetailsObjectResponseBody",
    "WorkflowPolygonResponseBody",
    "WorkflowSignatoryUserObjectResponseBody",
    "WorkflowTriggerObjectRequestBody",
    "WorkflowTriggerObjectResponseBody",
]
